(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    387399,      16308]*)
(*NotebookOutlinePosition[    395591,      16537]*)
(*  CellTagsIndexPosition[    395350,      16525]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Minimization of free energy", "Section",
  CellTags->{"i:60", "c:44"}],

Cell[TextData[{
  "In the section ",
  ButtonBox["Description of Introductory Example",
    ButtonStyle->"AddOnsLink"],
  " the description of the steady-state heat conduction on a \
three-dimensional domain was given. The solution of the same physical problem \
can be obtained also as a minimum of the free energy of the problem. Free \
energy of the heat conduction problem is formulated as\n",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPi] = \[Integral]\_\[CapitalOmega]\((\(1\/2\
\) k\ \[CapitalDelta]\[Phi] . \[CapitalDelta]\[Phi] - \[Phi]\ Q)\) \
\[DifferentialD]\[CapitalOmega]\)]],
  "  \nwhere a \[Phi] indicates temperature, a k is the conductivity and a Q \
is the heat generation per unit volume and \[CapitalOmega] is the domain of \
the problem. "
}], "Text"],

Cell[TextData[{
  "The domain of the example is a cube filled with water ([-.0.5m,0.5m]\
\[Times][-0.5m,0.5m]\[Times][0,1m]). On all sides, apart from the upper \
surface, the constant temperature \[Phi]=0 is maintained. The upper surface \
is isolated so that there is no heat flow over the boundary. There exists a \
constant heat source Q=500 ",
  Cell[BoxData[
      \(TraditionalForm\`W/m\^3\)]],
  " inside the cube. The thermal conductivity of water is 0.58 W/m K. The \
task is to calculate the temperature distribution inside the cube.\nThe \
problem is formulated using various approaches:\nA.\tTrial polynomial \
interpolation\n\tM.G\tGradient method of optimization ",
  StyleBox["+ Mathematica ",
    FontSlant->"Italic"],
  "directly\n\tM.N\tNewton method of optimization ",
  StyleBox["+ Mathematica ",
    FontSlant->"Italic"],
  "directly\n\tA.G\tGradient method of optimization ",
  StyleBox["+ AceGen+MathLink",
    FontSlant->"Italic"],
  "\n\tA.N\tNewton method of optimization ",
  StyleBox["+ AceGen+MathLink",
    FontSlant->"Italic"],
  "\nB.\tFinite difference interpolation \n\tM.G\tGradient method of \
optimization ",
  StyleBox["+ Mathematica ",
    FontSlant->"Italic"],
  "directly\n\tM.N\tNewton method of optimization ",
  StyleBox["+ Mathematica ",
    FontSlant->"Italic"],
  "directly\n\tA.G\tGradient method of optimization ",
  StyleBox["+ AceGen+MathLink",
    FontSlant->"Italic"],
  "\n\tA.N\tNewton method of optimization ",
  StyleBox["+ AceGen+MathLink",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
The following quantities are compared:
\[Bullet]\ttemperature at the central point of the cube (\[Phi](0.,0.,0.5))
\[Bullet]\ttime for derivation of the equations
\[Bullet]\ttime for solution of the optimization problem
\[Bullet]\tnumber of unknown parameters used to discretize the problem
\[Bullet]\tpeak memory allocated during the analysis
\[Bullet]\tnumber of evaluations of function, gradient and hessian.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["A. Trial Lagrange polynomial interpolation", "Subsection",
  CellTags->{"b:8.1.0", "c:45"}],

Cell[CellGroupData[{

Cell["Definitions", "SubsubsectionIcon",
  CellTags->"b:8.1.0"],

Cell["\<\
A trial function for temperature \[Phi] is constructed as a fifth order \
Lagrange polynomials in x y and z direction. The chosen trial function is \
constructed in a way that  satisfies boundary conditions. \
\>", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< AceGen`;\)\), "\[IndentingNewLine]", 
    \(\(Clear[x, y, z, a];\)\), "\[IndentingNewLine]", 
    \(kcond = 0.58; Q = 500;\), "\[IndentingNewLine]", 
    \(\(order = 5;\)\), "\[IndentingNewLine]", 
    \(nterm = \((order - 1)\) \((order - 1)\) \((order)\)\)}], "Input",
  CellLabel->"In[246]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \(80\)], "Output",
  CellLabel->"Out[250]=",
  CellTags->"b:8.1.0"]
}, Closed]],

Cell["\<\
Here the fifth order Lagrange polynomials are constructed in three \
dimensions.\
\>", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.0"],

Cell[BoxData[{
    \(toc = Table[{x, 0}, {x, \(-0.5\), 0.5, 1/order}]; 
    xp = MapIndexed[\ 
        InterpolatingPolynomial[ReplacePart[toc, 1, {#, 2}], x] &, 
        Range[2, order]];\), "\[IndentingNewLine]", 
    \(\(yp = 
        MapIndexed[\ 
          InterpolatingPolynomial[ReplacePart[toc, 1, {#, 2}], y] &, 
          Range[2, order]];\)\), "\[IndentingNewLine]", 
    \(\(toc = 
        Table[{x, 0}, {x, 0. , 1. , 1/order}];\)\), "\[IndentingNewLine]", 
    \(\(zp = 
        MapIndexed[\ 
          InterpolatingPolynomial[ReplacePart[toc, 1, {#, 2}], z] &, 
          Range[2, order + 1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Phi]i = Array[a, nterm];\)\), "\[IndentingNewLine]", 
    \(\(poly = 
        Flatten[Outer[Times, xp, yp, zp]] // 
          Chop;\)\), "\[IndentingNewLine]", 
    \(\(\[Phi] = poly . \[Phi]i;\)\)}], "Input",
  CellLabel->"In[251]:=",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(poly[\([28]\)]\), "\[IndentingNewLine]", 
    \(\(Plot3D[
        poly[\([28]\)] /. z \[Rule] 0.5, {x, \(-0.5\), 0.5}, {y, \(-0.5\), 
          0.5}, PlotRange \[Rule] All];\)\)}], "Input",
  CellLabel->"In[258]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \(\((\(\(0.3`\)\(\[InvisibleSpace]\)\) + 
          x)\)\ \((\(\(0.5`\)\(\[InvisibleSpace]\)\) + 
          x)\)\ \((\(\(12.5`\)\(\[InvisibleSpace]\)\) + \
\((\(-62.49999999999999`\) + \
\((\(\(156.24999999999997`\)\(\[InvisibleSpace]\)\) - 
                      260.41666666666663`\ \((\(-0.30000000000000004`\) + 
                            x)\))\)\ \((\(-0.10000000000000003`\) + 
                      x)\))\)\ \((\(\(0.09999999999999998`\)\(\
\[InvisibleSpace]\)\) + x)\))\)\ \((\(\(0.3`\)\(\[InvisibleSpace]\)\) + 
          y)\)\ \((\(\(0.5`\)\(\[InvisibleSpace]\)\) + 
          y)\)\ \((\(\(12.5`\)\(\[InvisibleSpace]\)\) + \
\((\(-62.49999999999999`\) + \
\((\(\(156.24999999999997`\)\(\[InvisibleSpace]\)\) - 
                      260.41666666666663`\ \((\(-0.30000000000000004`\) + 
                            y)\))\)\ \((\(-0.10000000000000003`\) + 
                      y)\))\)\ \((\(\(0.09999999999999998`\)\(\
\[InvisibleSpace]\)\) + 
                y)\))\)\ \((\(\(20.833333333333318`\)\(\[InvisibleSpace]\)\) \
+ \((\(-104.16666666666661`\) + 
                260.41666666666663`\ \((\(-0.8`\) + 
                      z)\))\)\ \((\(-0.6000000000000001`\) + 
                z)\))\)\ \((\(-0.4`\) + z)\)\ \((\(-0.2`\) + 
          z)\)\ z\)], "Output",
  CellLabel->"Out[258]=",
  CellTags->"b:8.1.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.08608 .22315 -24 -8.87306 ]
[.08608 .22315 0 .12694 ]
[.20731 .17545 -23.3476 -9 ]
[.20731 .17545 .65243 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.46808 .07289 -16.0095 -9 ]
[.46808 .07289 1.99047 0 ]
[.60856 .01769 -15.259 -9 ]
[.60856 .01769 2.74104 0 ]
[.73498 .04732 0 -6.2105 ]
[.73498 .04732 24 2.7895 ]
[.79846 .14452 0 -6.11593 ]
[.79846 .14452 24 2.88407 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.90976 .31495 0 -5.95504 ]
[.90976 .31495 18 3.04496 ]
[.95881 .39008 0 -5.88604 ]
[.95881 .39008 18 3.11396 ]
[.02369 .26775 -24 -2.74455 ]
[.02369 .26775 0 6.25545 ]
[.0162 .31469 -30 -2.78423 ]
[.0162 .31469 0 6.21577 ]
[.00848 .36308 -6 -2.82527 ]
[.00848 .36308 0 6.17473 ]
[.00052 .41299 -24 -2.86773 ]
[.00052 .41299 0 6.13227 ]
[-0.0077 .46449 -18 -2.91169 ]
[-0.0077 .46449 0 6.08831 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09549 .2323 m
.1002 .23687 L
s
[(-0.4)] .08608 .22315 1 .97179 Mshowa
.21633 .18498 m
.22084 .18975 L
s
[(-0.2)] .20731 .17545 .94563 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.47614 .08324 m
.48017 .08842 L
s
[(0.2)] .46808 .07289 .77884 1 Mshowa
.61605 .02846 m
.6198 .03385 L
s
[(0.4)] .60856 .01769 .69544 1 Mshowa
.125 Mabswid
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.18558 .19702 m
.18832 .19985 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.51046 .06981 m
.51284 .07294 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.06616 .24378 m
.06901 .2465 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72272 .05198 m
.71658 .05431 L
s
[(-0.4)] .73498 .04732 -1 .38011 Mshowa
.78611 .14895 m
.77994 .15117 L
s
[(-0.2)] .79846 .14452 -1 .3591 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.89727 .31899 m
.89103 .32101 L
s
[(0.2)] .90976 .31495 -1 .32334 Mshowa
.94627 .39394 m
.94 .39587 L
s
[(0.4)] .95881 .39008 -1 .30801 Mshowa
.125 Mabswid
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.7708 .12553 m
.7671 .12688 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.9099 .3383 m
.90615 .3395 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.70593 .0263 m
.70226 .02771 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03592 .26298 m
.04203 .2606 L
s
[(-0.5)] .02369 .26775 1 -0.3901 Mshowa
.02846 .31001 m
.03459 .30768 L
s
[(-0.25)] .0162 .31469 1 -0.38128 Mshowa
.02078 .3585 m
.02693 .35621 L
s
[(0)] .00848 .36308 1 -0.37216 Mshowa
.01285 .40852 m
.01902 .40628 L
s
[(0.25)] .00052 .41299 1 -0.36273 Mshowa
.00468 .46013 m
.01086 .45794 L
s
[(0.5)] -0.0077 .46449 1 -0.35296 Mshowa
.125 Mabswid
.03444 .27227 m
.03811 .27085 L
s
.03296 .28162 m
.03663 .2802 L
s
.03147 .29103 m
.03515 .28962 L
s
.02997 .30049 m
.03365 .29908 L
s
.02695 .31959 m
.03063 .3182 L
s
.02542 .32923 m
.0291 .32784 L
s
.02388 .33893 m
.02757 .33754 L
s
.02234 .34868 m
.02602 .34731 L
s
.01921 .36838 m
.02291 .36701 L
s
.01764 .37832 m
.02133 .37696 L
s
.01605 .38832 m
.01975 .38697 L
s
.01446 .39839 m
.01816 .39704 L
s
.01124 .41871 m
.01494 .41737 L
s
.00961 .42896 m
.01332 .42763 L
s
.00798 .43929 m
.01169 .43796 L
s
.00633 .44967 m
.01004 .44836 L
s
.00301 .47065 m
.00672 .46934 L
s
.00133 .48124 m
.00505 .47994 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.868 .755 .735 r
.38887 .68166 .40199 .69318 .42393 .68696 .41198 .64281 Metetra
.665 .538 .7 r
.41198 .64281 .42393 .68696 .44604 .68069 .4342 .62887 Metetra
.571 .463 .692 r
.4342 .62887 .44604 .68069 .46834 .67437 .4562 .63045 Metetra
.496 .434 .717 r
.4562 .63045 .46834 .67437 .49082 .66799 .47837 .64046 Metetra
.365 .433 .799 r
.47837 .64046 .49082 .66799 .51348 .66157 .50092 .65351 Metetra
0 .3 .712 r
.50092 .65351 .51348 .66157 .53634 .65509 .52392 .66552 Metetra
.578 .112 .11 r
.52392 .66552 .53634 .65509 .55938 .64855 .54734 .67365 Metetra
.541 .174 .293 r
.54734 .67365 .55938 .64855 .58262 .64196 .57108 .67623 Metetra
.498 .168 .337 r
.57108 .67623 .58262 .64196 .60606 .63532 .59503 .6726 Metetra
.449 .132 .335 r
.59503 .6726 .60606 .63532 .62969 .62862 .61907 .66307 Metetra
.38 .06 .292 r
.61907 .66307 .62969 .62862 .65353 .62186 .64312 .64863 Metetra
.254 0 .178 r
.64312 .64863 .65353 .62186 .67757 .61504 .66713 .63084 Metetra
.66713 .63084 .67757 .61504 .70181 .60817 .69113 .61151 Metetra
.695 .979 .808 r
.69113 .61151 .70181 .60817 .72626 .60123 .71518 .59253 Metetra
.793 .854 .896 r
.71518 .59253 .72626 .60123 .75093 .59424 .73941 .57566 Metetra
.721 .701 .831 r
.73941 .57566 .75093 .59424 .77581 .58719 .76397 .56234 Metetra
.663 .624 .801 r
.76397 .56234 .77581 .58719 .80091 .58007 .78901 .55355 Metetra
.614 .59 .802 r
.78901 .55355 .80091 .58007 .82622 .57289 .81467 .54964 Metetra
.56 .588 .838 r
.81467 .54964 .82622 .57289 .85176 .56565 .84103 .55012 Metetra
.463 .629 .925 r
.84103 .55012 .85176 .56565 .87753 .55835 .86804 .55347 Metetra
.135 .635 .907 r
.86804 .55347 .87753 .55835 .90352 .55098 .89547 .55686 Metetra
.25 0 0 r
.89547 .55686 .90352 .55098 .92975 .54354 .9228 .55586 Metetra
.154 0 0 r
.9228 .55586 .92975 .54354 .95621 .53604 .94916 .54431 Metetra
.575 .83 .465 r
.94916 .54431 .95621 .53604 .98291 .52847 .97323 .51431 Metetra
.878 .751 .718 r
.37555 .66996 .38887 .68166 .41198 .64281 .39911 .62516 Metetra
.743 .696 .806 r
.39911 .62516 .41198 .64281 .4342 .62887 .42148 .60978 Metetra
.499 .586 .873 r
.42148 .60978 .4342 .62887 .4562 .63045 .44348 .61267 Metetra
.163 .42 .859 r
.44348 .61267 .4562 .63045 .47837 .64046 .46562 .62554 Metetra
0 .281 .777 r
.46562 .62554 .47837 .64046 .50092 .65351 .48816 .64203 Metetra
0 .256 .728 r
.48816 .64203 .50092 .65351 .52392 .66552 .51121 .65736 Metetra
0 .367 .769 r
.51121 .65736 .52392 .66552 .54734 .67365 .53474 .66814 Metetra
.078 .591 .885 r
.53474 .66814 .54734 .67365 .57108 .67623 .55865 .67235 Metetra
.405 .815 .977 r
.55865 .67235 .57108 .67623 .59503 .6726 .5828 .66921 Metetra
.655 .921 .976 r
.5828 .66921 .59503 .6726 .61907 .66307 .60704 .65905 Metetra
.782 .929 .931 r
.60704 .65905 .61907 .66307 .64312 .64863 .63127 .64308 Metetra
.831 .901 .889 r
.63127 .64308 .64312 .64863 .66713 .63084 .65544 .62315 Metetra
.839 .866 .863 r
.65544 .62315 .66713 .63084 .69113 .61151 .67956 .60142 Metetra
.825 .831 .852 r
.67956 .60142 .69113 .61151 .71518 .59253 .7037 .58014 Metetra
.795 .797 .854 r
.7037 .58014 .71518 .59253 .73941 .57566 .72801 .56137 Metetra
.748 .763 .865 r
.72801 .56137 .73941 .57566 .76397 .56234 .75266 .54683 Metetra
.683 .728 .884 r
.75266 .54683 .76397 .56234 .78901 .55355 .77782 .53764 Metetra
.597 .689 .907 r
.77782 .53764 .78901 .55355 .81467 .54964 .80367 .53422 Metetra
.492 .648 .927 r
.80367 .53422 .81467 .54964 .84103 .55012 .83029 .536 Metetra
.39 .615 .941 r
.83029 .536 .84103 .55012 .86804 .55347 .85763 .54119 Metetra
.349 .627 .956 r
.85763 .54119 .86804 .55347 .89547 .55686 .88542 .54645 Metetra
.457 .725 .983 r
.88542 .54645 .89547 .55686 .9228 .55586 .91308 .54654 Metetra
.72 .86 .948 r
.91308 .54654 .9228 .55586 .94916 .54431 .93958 .53413 Metetra
.91 .866 .783 r
.93958 .53413 .94916 .54431 .97323 .51431 .96338 .49991 Metetra
.86 .758 .748 r
.36202 .65808 .37555 .66996 .39911 .62516 .38547 .62247 Metetra
.756 .927 .945 r
.38547 .62247 .39911 .62516 .42148 .60978 .40798 .60912 Metetra
.003 .579 .731 r
.40798 .60912 .42148 .60978 .44348 .61267 .4302 .60966 Metetra
.334 0 0 r
.4302 .60966 .44348 .61267 .46562 .62554 .45254 .61775 Metetra
0 .331 .728 r
.45254 .61775 .46562 .62554 .48816 .64203 .47523 .62851 Metetra
.148 .488 .902 r
.47523 .62851 .48816 .64203 .51121 .65736 .49836 .63833 Metetra
.411 .553 .887 r
.49836 .63833 .51121 .65736 .53474 .66814 .52192 .64466 Metetra
.543 .575 .837 r
.52192 .64466 .53474 .66814 .55865 .67235 .54583 .64602 Metetra
.616 .591 .802 r
.54583 .64602 .55865 .67235 .5828 .66921 .56999 .64184 Metetra
.664 .609 .783 r
.56999 .64184 .5828 .66921 .60704 .65905 .5943 .63238 Metetra
.699 .63 .776 r
.5943 .63238 .60704 .65905 .63127 .64308 .61867 .61854 Metetra
.726 .656 .78 r
.61867 .61854 .63127 .64308 .65544 .62315 .64305 .6017 Metetra
.747 .687 .793 r
.64305 .6017 .65544 .62315 .67956 .60142 .66746 .58347 Metetra
.761 .723 .818 r
.66746 .58347 .67956 .60142 .7037 .58014 .69193 .56553 Metetra
.761 .763 .855 r
.69193 .56553 .7037 .58014 .72801 .56137 .71658 .54946 Metetra
.736 .799 .902 r
.71658 .54946 .72801 .56137 .75266 .54683 .74153 .53656 Metetra
.674 .813 .95 r
.74153 .53656 .75266 .54683 .77782 .53764 .76692 .52769 Metetra
.577 .787 .978 r
.76692 .52769 .77782 .53764 .80367 .53422 .79287 .52318 Metetra
.488 .727 .977 r
.79287 .52318 .80367 .53422 .83029 .536 .81945 .52258 Metetra
.457 .668 .954 r
.81945 .52258 .83029 .536 .85763 .54119 .84662 .52453 Metetra
.495 .638 .918 r
.84662 .52453 .85763 .54119 .88542 .54645 .87421 .5265 Metetra
.579 .64 .876 r
.87421 .5265 .88542 .54645 .91308 .54654 .90176 .52454 Metetra
.688 .674 .831 r
.90176 .52454 .91308 .54654 .93958 .53413 .92853 .51315 Metetra
.813 .733 .776 r
.92853 .51315 .93958 .53413 .96338 .49991 .95336 .48527 Metetra
.798 .768 .825 r
.34828 .64602 .36202 .65808 .38547 .62247 .37126 .62622 Metetra
.427 .868 .804 r
.37126 .62622 .38547 .62247 .40798 .60912 .39387 .61646 Metetra
.167 0 0 r
.39387 .61646 .40798 .60912 .4302 .60966 .41643 .613 Metetra
.177 0 0 r
.41643 .613 .4302 .60966 .45254 .61775 .43914 .61293 Metetra
.217 .695 .935 r
.43914 .61293 .45254 .61775 .47523 .62851 .46212 .614 Metetra
.505 .665 .934 r
.46212 .614 .47523 .62851 .49836 .63833 .4854 .61456 Metetra
.577 .59 .829 r
.4854 .61456 .49836 .63833 .52192 .64466 .509 .6135 Metetra
.605 .556 .773 r
.509 .6135 .52192 .64466 .54583 .64602 .53287 .61017 Metetra
.622 .546 .747 r
.53287 .61017 .54583 .64602 .56999 .64184 .55699 .60433 Metetra
.638 .548 .737 r
.55699 .60433 .56999 .64184 .5943 .63238 .5813 .59611 Metetra
.652 .562 .74 r
.5813 .59611 .5943 .63238 .61867 .61854 .60575 .5859 Metetra
.668 .586 .754 r
.60575 .5859 .61867 .61854 .64305 .6017 .63034 .5743 Metetra
.685 .622 .779 r
.63034 .5743 .64305 .6017 .66746 .58347 .65507 .56203 Metetra
.7 .672 .819 r
.65507 .56203 .66746 .58347 .69193 .56553 .67994 .54984 Metetra
.708 .738 .874 r
.67994 .54984 .69193 .56553 .71658 .54946 .70502 .53844 Metetra
.694 .807 .935 r
.70502 .53844 .71658 .54946 .74153 .53656 .73034 .52842 Metetra
.644 .848 .978 r
.73034 .52842 .74153 .53656 .76692 .52769 .75599 .5202 Metetra
.585 .842 .993 r
.75599 .5202 .76692 .52769 .79287 .52318 .78202 .5139 Metetra
.562 .799 .988 r
.78202 .5139 .79287 .52318 .81945 .52258 .80845 .50933 Metetra
.575 .732 .949 r
.80845 .50933 .81945 .52258 .84662 .52453 .83529 .50587 Metetra
.597 .666 .887 r
.83529 .50587 .84662 .52453 .87421 .5265 .86244 .50235 Metetra
.623 .624 .831 r
.86244 .50235 .87421 .5265 .90176 .52454 .88972 .49703 Metetra
.659 .619 .798 r
.88972 .49703 .90176 .52454 .92853 .51315 .9168 .48743 Metetra
.723 .663 .791 r
.9168 .48743 .92853 .51315 .95336 .48527 .94317 .47038 Metetra
.595 .733 .941 r
.33433 .63378 .34828 .64602 .37126 .62622 .35669 .63009 Metetra
.183 .708 .684 r
.35669 .63009 .37126 .62622 .39387 .61646 .37938 .62404 Metetra
.37938 .62404 .39387 .61646 .41643 .613 .40232 .61645 Metetra
.345 .82 .776 r
.40232 .61645 .41643 .613 .43914 .61293 .42547 .60802 Metetra
.654 .888 .982 r
.42547 .60802 .43914 .61293 .46212 .614 .44881 .59926 Metetra
.682 .729 .886 r
.44881 .59926 .46212 .614 .4854 .61456 .47232 .59055 Metetra
.661 .629 .807 r
.47232 .59055 .4854 .61456 .509 .6135 .49601 .58215 Metetra
.644 .577 .764 r
.49601 .58215 .509 .6135 .53287 .61017 .51989 .57419 Metetra
.633 .551 .745 r
.51989 .57419 .53287 .61017 .55699 .60433 .54397 .56671 Metetra
.628 .543 .739 r
.54397 .56671 .55699 .60433 .5813 .59611 .56826 .5597 Metetra
.626 .547 .746 r
.56826 .5597 .5813 .59611 .60575 .5859 .59278 .55306 Metetra
.628 .564 .764 r
.59278 .55306 .60575 .5859 .63034 .5743 .61753 .54666 Metetra
.633 .596 .795 r
.61753 .54666 .63034 .5743 .65507 .56203 .64253 .54033 Metetra
.64 .647 .841 r
.64253 .54033 .65507 .56203 .67994 .54984 .66777 .5339 Metetra
.644 .715 .9 r
.66777 .5339 .67994 .54984 .70502 .53844 .69324 .52722 Metetra
.639 .79 .954 r
.69324 .52722 .70502 .53844 .73034 .52842 .71893 .52013 Metetra
.626 .843 .983 r
.71893 .52013 .73034 .52842 .75599 .5202 .74484 .51256 Metetra
.629 .858 .986 r
.74484 .51256 .75599 .5202 .78202 .5139 .77095 .50445 Metetra
.653 .834 .97 r
.77095 .50445 .78202 .5139 .80845 .50933 .79727 .49585 Metetra
.671 .771 .925 r
.79727 .49585 .80845 .50933 .83529 .50587 .82379 .48692 Metetra
.668 .698 .868 r
.82379 .48692 .83529 .50587 .86244 .50235 .85054 .47792 Metetra
.656 .641 .823 r
.85054 .47792 .86244 .50235 .88972 .49703 .87757 .46923 Metetra
.642 .61 .802 r
.87757 .46923 .88972 .49703 .9168 .48743 .90495 .46143 Metetra
.628 .617 .82 r
.90495 .46143 .9168 .48743 .94317 .47038 .93281 .45523 Metetra
.113 .499 .905 r
.32016 .62134 .33433 .63378 .35669 .63009 .34198 .62968 Metetra
.252 .761 .861 r
.34198 .62968 .35669 .63009 .37938 .62404 .36473 .62639 Metetra
.535 .924 .882 r
.36473 .62639 .37938 .62404 .40232 .61645 .38802 .61566 Metetra
.748 .961 .938 r
.38802 .61566 .40232 .61645 .42547 .60802 .41159 .60093 Metetra
.789 .861 .904 r
.41159 .60093 .42547 .60802 .44881 .59926 .43529 .58483 Metetra
.757 .752 .848 r
.43529 .58483 .44881 .59926 .47232 .59055 .45906 .56926 Metetra
.715 .673 .808 r
.45906 .56926 .47232 .59055 .49601 .58215 .4829 .55545 Metetra
.68 .621 .783 r
.4829 .55545 .49601 .58215 .51989 .57419 .50683 .54409 Metetra
.651 .588 .772 r
.50683 .54409 .51989 .57419 .54397 .56671 .53093 .53541 Metetra
.627 .571 .772 r
.53093 .53541 .54397 .56671 .56826 .5597 .55524 .52924 Metetra
.608 .566 .782 r
.55524 .52924 .56826 .5597 .59278 .55306 .57982 .52515 Metetra
.593 .575 .802 r
.57982 .52515 .59278 .55306 .61753 .54666 .60471 .5225 Metetra
.583 .599 .834 r
.60471 .5225 .61753 .54666 .64253 .54033 .62991 .52049 Metetra
.579 .641 .876 r
.62991 .52049 .64253 .54033 .66777 .5339 .65542 .51828 Metetra
.582 .698 .922 r
.65542 .51828 .66777 .5339 .69324 .52722 .6812 .51506 Metetra
.597 .762 .958 r
.6812 .51506 .69324 .52722 .71893 .52013 .7072 .51013 Metetra
.627 .814 .972 r
.7072 .51013 .71893 .52013 .74484 .51256 .73334 .50299 Metetra
.671 .838 .964 r
.73334 .50299 .74484 .51256 .77095 .50445 .75958 .49349 Metetra
.709 .827 .938 r
.75958 .49349 .77095 .50445 .79727 .49585 .78587 .48187 Metetra
.725 .785 .9 r
.78587 .48187 .79727 .49585 .82379 .48692 .81223 .46886 Metetra
.715 .73 .862 r
.81223 .46886 .82379 .48692 .85054 .47792 .83876 .45577 Metetra
.684 .676 .836 r
.83876 .45577 .85054 .47792 .87757 .46923 .86566 .44459 Metetra
.632 .631 .831 r
.86566 .44459 .87757 .46923 .90495 .46143 .89331 .43805 Metetra
.526 .588 .859 r
.89331 .43805 .90495 .46143 .93281 .45523 .92226 .43981 Metetra
0 .277 .745 r
.30577 .6087 .32016 .62134 .34198 .62968 .32733 .62234 Metetra
.466 .785 .999 r
.32733 .62234 .34198 .62968 .36473 .62639 .35016 .62023 Metetra
.735 .876 .946 r
.35016 .62023 .36473 .62639 .38802 .61566 .37369 .60803 Metetra
.801 .85 .887 r
.37369 .60803 .38802 .61566 .41159 .60093 .39755 .59042 Metetra
.804 .808 .854 r
.39755 .59042 .41159 .60093 .43529 .58483 .42154 .57099 Metetra
.784 .765 .837 r
.42154 .57099 .43529 .58483 .45906 .56926 .44554 .55233 Metetra
.752 .727 .83 r
.44554 .55233 .45906 .56926 .4829 .55545 .46955 .53609 Metetra
.714 .693 .829 r
.46955 .53609 .4829 .55545 .50683 .54409 .49361 .52318 Metetra
.673 .665 .834 r
.49361 .52318 .50683 .54409 .53093 .53541 .5178 .51389 Metetra
.632 .644 .844 r
.5178 .51389 .53093 .53541 .55524 .52924 .54219 .50802 Metetra
.593 .631 .858 r
.54219 .50802 .55524 .52924 .57982 .52515 .56686 .50498 Metetra
.56 .628 .876 r
.56686 .50498 .57982 .52515 .60471 .5225 .59187 .5039 Metetra
.537 .637 .897 r
.59187 .5039 .60471 .5225 .62991 .52049 .61722 .50372 Metetra
.53 .66 .919 r
.61722 .50372 .62991 .52049 .65542 .51828 .64292 .5033 Metetra
.545 .696 .938 r
.64292 .5033 .65542 .51828 .6812 .51506 .6689 .50154 Metetra
.583 .737 .949 r
.6689 .50154 .6812 .51506 .7072 .51013 .69511 .49748 Metetra
.635 .774 .947 r
.69511 .49748 .7072 .51013 .73334 .50299 .72145 .49047 Metetra
.688 .795 .932 r
.72145 .49047 .73334 .50299 .75958 .49349 .74784 .48027 Metetra
.726 .798 .909 r
.74784 .48027 .75958 .49349 .78587 .48187 .77423 .46723 Metetra
.744 .785 .886 r
.77423 .46723 .78587 .48187 .81223 .46886 .80064 .45233 Metetra
.738 .76 .87 r
.80064 .45233 .81223 .46886 .83876 .45577 .82719 .43737 Metetra
.705 .727 .867 r
.82719 .43737 .83876 .45577 .86566 .44459 .85416 .425 Metetra
.626 .68 .882 r
.85416 .425 .86566 .44459 .89331 .43805 .88202 .41894 Metetra
.435 .588 .905 r
.88202 .41894 .89331 .43805 .92226 .43981 .91153 .42413 Metetra
0 .383 .829 r
.29115 .59586 .30577 .6087 .32733 .62234 .31288 .60706 Metetra
.577 .693 .92 r
.31288 .60706 .32733 .62234 .35016 .62023 .33582 .60429 Metetra
.713 .727 .861 r
.33582 .60429 .35016 .62023 .37369 .60803 .35945 .59256 Metetra
.759 .743 .837 r
.35945 .59256 .37369 .60803 .39755 .59042 .38343 .57602 Metetra
.777 .759 .837 r
.38343 .57602 .39755 .59042 .42154 .57099 .40754 .55786 Metetra
.778 .777 .852 r
.40754 .55786 .42154 .57099 .44554 .55233 .43168 .54036 Metetra
.764 .794 .877 r
.43168 .54036 .44554 .55233 .46955 .53609 .45585 .52499 Metetra
.732 .805 .91 r
.45585 .52499 .46955 .53609 .49361 .52318 .48009 .51257 Metetra
.682 .806 .942 r
.48009 .51257 .49361 .52318 .5178 .51389 .50444 .50337 Metetra
.619 .793 .965 r
.50444 .50337 .5178 .51389 .54219 .50802 .529 .49719 Metetra
.558 .768 .976 r
.529 .49719 .54219 .50802 .56686 .50498 .55382 .49352 Metetra
.515 .741 .976 r
.55382 .49352 .56686 .50498 .59187 .5039 .57895 .49158 Metetra
.502 .722 .97 r
.57895 .49158 .59187 .5039 .61722 .50372 .60443 .49043 Metetra
.518 .713 .961 r
.60443 .49043 .61722 .50372 .64292 .5033 .63023 .48906 Metetra
.554 .715 .947 r
.63023 .48906 .64292 .5033 .6689 .50154 .65634 .48648 Metetra
.598 .723 .931 r
.65634 .48648 .6689 .50154 .69511 .49748 .68267 .48185 Metetra
.643 .734 .915 r
.68267 .48185 .69511 .49748 .72145 .49047 .70916 .47459 Metetra
.683 .747 .9 r
.70916 .47459 .72145 .49047 .74784 .48027 .73574 .4645 Metetra
.715 .761 .889 r
.73574 .4645 .74784 .48027 .77423 .46723 .76235 .45186 Metetra
.734 .775 .886 r
.76235 .45186 .77423 .46723 .80064 .45233 .78903 .43757 Metetra
.736 .787 .893 r
.78903 .43757 .80064 .45233 .82719 .43737 .81585 .42321 Metetra
.708 .789 .915 r
.81585 .42321 .82719 .43737 .85416 .425 .84307 .41114 Metetra
.618 .761 .948 r
.84307 .41114 .85416 .425 .88202 .41894 .8711 .40466 Metetra
.402 .646 .956 r
.8711 .40466 .88202 .41894 .91153 .42413 .90061 .40816 Metetra
.431 .67 .963 r
.27629 .58282 .29115 .59586 .31288 .60706 .29869 .5843 Metetra
.623 .627 .834 r
.29869 .5843 .31288 .60706 .33582 .60429 .32181 .57912 Metetra
.666 .628 .802 r
.32181 .57912 .33582 .60429 .35945 .59256 .34538 .56969 Metetra
.692 .657 .81 r
.34538 .56969 .35945 .59256 .38343 .57602 .36923 .55794 Metetra
.714 .708 .843 r
.36923 .55794 .38343 .57602 .40754 .55786 .39327 .54537 Metetra
.727 .783 .897 r
.39327 .54537 .40754 .55786 .43168 .54036 .41743 .53307 Metetra
.712 .868 .955 r
.41743 .53307 .43168 .54036 .45585 .52499 .44171 .52173 Metetra
.636 .92 .977 r
.44171 .52173 .45585 .52499 .48009 .51257 .46613 .51176 Metetra
.506 .901 .938 r
.46613 .51176 .48009 .51257 .50444 .50337 .49073 .50329 Metetra
.401 .853 .894 r
.49073 .50329 .50444 .50337 .529 .49719 .51553 .49623 Metetra
.377 .836 .908 r
.51553 .49623 .529 .49719 .55382 .49352 .54057 .49033 Metetra
.427 .844 .963 r
.54057 .49033 .55382 .49352 .57895 .49158 .56588 .48522 Metetra
.506 .835 .999 r
.56588 .48522 .57895 .49158 .60443 .49043 .59148 .48044 Metetra
.57 .797 .985 r
.59148 .48044 .60443 .49043 .63023 .48906 .61736 .4755 Metetra
.608 .752 .946 r
.61736 .4755 .63023 .48906 .65634 .48648 .64351 .46995 Metetra
.632 .719 .91 r
.64351 .46995 .65634 .48648 .68267 .48185 .66991 .46338 Metetra
.651 .703 .885 r
.66991 .46338 .68267 .48185 .70916 .47459 .69651 .45552 Metetra
.667 .705 .875 r
.69651 .45552 .70916 .47459 .73574 .4645 .7233 .44628 Metetra
.683 .723 .88 r
.7233 .44628 .73574 .4645 .76235 .45186 .75024 .43579 Metetra
.696 .757 .899 r
.75024 .43579 .76235 .45186 .78903 .43757 .77735 .42446 Metetra
.698 .804 .931 r
.77735 .42446 .78903 .43757 .81585 .42321 .80467 .41306 Metetra
.671 .848 .967 r
.80467 .41306 .81585 .42321 .84307 .41114 .83232 .4027 Metetra
.595 .853 .993 r
.83232 .4027 .84307 .41114 .8711 .40466 .86049 .39495 Metetra
.489 .782 .997 r
.86049 .39495 .8711 .40466 .90061 .40816 .88949 .3919 Metetra
.745 .766 .87 r
.26119 .56956 .27629 .58282 .29869 .5843 .28476 .55562 Metetra
.653 .6 .782 r
.28476 .55562 .29869 .5843 .32181 .57912 .30812 .54672 Metetra
.618 .563 .77 r
.30812 .54672 .32181 .57912 .34538 .56969 .33148 .54097 Metetra
.604 .577 .797 r
.33148 .54097 .34538 .56969 .36923 .55794 .35498 .5369 Metetra
.596 .638 .863 r
.35498 .5369 .36923 .55794 .39327 .54537 .37872 .53335 Metetra
.572 .753 .963 r
.37872 .53335 .39327 .54537 .41743 .53307 .40274 .52951 Metetra
.439 .842 .975 r
.40274 .52951 .41743 .53307 .44171 .52173 .42706 .5248 Metetra
.188 .715 .715 r
.42706 .5248 .44171 .52173 .46613 .51176 .45166 .51891 Metetra
.45166 .51891 .46613 .51176 .49073 .50329 .47654 .51172 Metetra
.47654 .51172 .49073 .50329 .51553 .49623 .50166 .50329 Metetra
.50166 .50329 .51553 .49623 .54057 .49033 .52701 .49383 Metetra
.362 .828 .766 r
.52701 .49383 .54057 .49033 .56588 .48522 .55256 .48362 Metetra
.58 .929 .95 r
.55256 .48362 .56588 .48522 .59148 .48044 .57831 .47303 Metetra
.676 .879 .974 r
.57831 .47303 .59148 .48044 .61736 .4755 .60427 .46244 Metetra
.686 .79 .928 r
.60427 .46244 .61736 .4755 .64351 .46995 .63044 .4522 Metetra
.673 .722 .886 r
.63044 .4522 .64351 .46995 .66991 .46338 .65686 .44261 Metetra
.658 .684 .863 r
.65686 .44261 .66991 .46338 .69651 .45552 .68356 .43387 Metetra
.645 .671 .86 r
.68356 .43387 .69651 .45552 .7233 .44628 .71056 .42607 Metetra
.634 .683 .878 r
.71056 .42607 .7233 .44628 .75024 .43579 .7379 .41909 Metetra
.623 .724 .919 r
.7379 .41909 .75024 .43579 .77735 .42446 .76556 .41262 Metetra
.603 .794 .972 r
.76556 .41262 .77735 .42446 .80467 .41306 .79354 .40607 Metetra
.562 .866 .996 r
.79354 .40607 .80467 .41306 .83232 .4027 .82174 .39856 Metetra
.554 .907 .969 r
.82174 .39856 .83232 .4027 .86049 .39495 .85002 .38886 Metetra
.685 .931 .968 r
.85002 .38886 .86049 .39495 .88949 .3919 .87816 .37535 Metetra
.848 .761 .767 r
.24584 .55609 .26119 .56956 .28476 .55562 .27098 .52341 Metetra
.68 .595 .754 r
.27098 .52341 .28476 .55562 .30812 .54672 .29464 .51005 Metetra
.57 .516 .756 r
.29464 .51005 .30812 .54672 .33148 .54097 .31768 .50876 Metetra
.48 .489 .79 r
.31768 .50876 .33148 .54097 .35498 .5369 .34065 .51399 Metetra
.369 .509 .867 r
.34065 .51399 .35498 .5369 .37872 .53335 .3639 .52152 Metetra
.155 .553 .928 r
.3639 .52152 .37872 .53335 .40274 .52951 .38762 .52819 Metetra
.148 0 0 r
.38762 .52819 .40274 .52951 .42706 .5248 .41187 .53181 Metetra
.238 0 0 r
.41187 .53181 .42706 .5248 .45166 .51891 .43662 .53109 Metetra
.193 0 0 r
.43662 .53109 .45166 .51891 .47654 .51172 .46181 .52556 Metetra
.074 0 0 r
.46181 .52556 .47654 .51172 .50166 .50329 .48732 .51543 Metetra
.48732 .51543 .50166 .50329 .52701 .49383 .51304 .50149 Metetra
.442 .847 .66 r
.51304 .50149 .52701 .49383 .55256 .48362 .53891 .48493 Metetra
.711 .984 .886 r
.53891 .48493 .55256 .48362 .57831 .47303 .56488 .46713 Metetra
.786 .921 .928 r
.56488 .46713 .57831 .47303 .60427 .46244 .59094 .44957 Metetra
.76 .813 .895 r
.59094 .44957 .60427 .46244 .63044 .4522 .61715 .4336 Metetra
.713 .729 .863 r
.61715 .4336 .63044 .4522 .65686 .44261 .64359 .42034 Metetra
.666 .675 .849 r
.64359 .42034 .65686 .44261 .68356 .43387 .67037 .41057 Metetra
.62 .646 .854 r
.67037 .41057 .68356 .43387 .71056 .42607 .69759 .40455 Metetra
.571 .642 .882 r
.69759 .40455 .71056 .42607 .7379 .41909 .72533 .4019 Metetra
.511 .669 .934 r
.72533 .4019 .7379 .41909 .76556 .41262 .7536 .40143 Metetra
.435 .731 .989 r
.7536 .40143 .76556 .41262 .79354 .40607 .78229 .40094 Metetra
.388 .81 .971 r
.78229 .40094 .79354 .40607 .82174 .39856 .81112 .39702 Metetra
.539 .923 .912 r
.81112 .39702 .82174 .39856 .85002 .38886 .83953 .38491 Metetra
.856 .981 .859 r
.83953 .38491 .85002 .38886 .87816 .37535 .86664 .3585 Metetra
.884 .748 .706 r
.23024 .54239 .24584 .55609 .27098 .52341 .25717 .49044 Metetra
.706 .605 .741 r
.25717 .49044 .27098 .52341 .29464 .51005 .28118 .47257 Metetra
.516 .481 .757 r
.28118 .47257 .29464 .51005 .31768 .50876 .30384 .47579 Metetra
.292 .374 .775 r
.30384 .47579 .31768 .50876 .34065 .51399 .32617 .49055 Metetra
0 .258 .767 r
.32617 .49055 .34065 .51399 .3639 .52152 .3488 .50955 Metetra
0 .122 .582 r
.3488 .50955 .3639 .52152 .38762 .52819 .37209 .52726 Metetra
.526 0 0 r
.37209 .52726 .38762 .52819 .41187 .53181 .39619 .53973 Metetra
.435 0 0 r
.39619 .53973 .41187 .53181 .43662 .53109 .42105 .54456 Metetra
.271 0 0 r
.42105 .54456 .43662 .53109 .46181 .52556 .44654 .54081 Metetra
.039 0 0 r
.44654 .54081 .46181 .52556 .48732 .51543 .47247 .52886 Metetra
.47247 .52886 .48732 .51543 .51304 .50149 .49864 .51014 Metetra
.64 .939 .697 r
.49864 .51014 .51304 .50149 .53891 .48493 .52489 .4868 Metetra
.836 .996 .843 r
.52489 .4868 .53891 .48493 .56488 .46713 .55113 .46139 Metetra
.859 .918 .869 r
.55113 .46139 .56488 .46713 .59094 .44957 .57736 .43653 Metetra
.812 .82 .856 r
.57736 .43653 .59094 .44957 .61715 .4336 .60365 .4146 Metetra
.747 .739 .844 r
.60365 .4146 .61715 .4336 .64359 .42034 .63014 .39757 Metetra
.675 .677 .844 r
.63014 .39757 .64359 .42034 .67037 .41057 .657 .38673 Metetra
.594 .631 .858 r
.657 .38673 .67037 .41057 .69759 .40455 .68441 .38255 Metetra
.493 .601 .889 r
.68441 .38255 .69759 .40455 .72533 .4019 .71254 .38438 Metetra
.362 .588 .93 r
.71254 .38438 .72533 .4019 .7536 .40143 .74139 .39017 Metetra
.22 .607 .951 r
.74139 .39017 .7536 .40143 .78229 .40094 .7708 .39605 Metetra
.223 .712 .924 r
.7708 .39605 .78229 .40094 .81112 .39702 .80025 .39593 Metetra
.594 .948 .898 r
.80025 .39593 .81112 .39702 .83953 .38491 .82879 .38127 Metetra
.941 .952 .752 r
.82879 .38127 .83953 .38491 .86664 .3585 .85489 .34134 Metetra
.899 .738 .674 r
.21438 .52847 .23024 .54239 .25717 .49044 .2431 .45958 Metetra
.734 .628 .741 r
.2431 .45958 .25717 .49044 .28118 .47257 .26747 .43778 Metetra
.448 .456 .775 r
.26747 .43778 .28118 .47257 .30384 .47579 .28977 .44489 Metetra
.004 .204 .717 r
.28977 .44489 .30384 .47579 .32617 .49055 .31145 .46795 Metetra
0 0 .503 r
.31145 .46795 .32617 .49055 .3488 .50955 .33344 .49708 Metetra
.691 .175 0 r
.33344 .49708 .3488 .50955 .37209 .52726 .35626 .52466 Metetra
.677 .131 0 r
.35626 .52466 .37209 .52726 .39619 .53973 .38014 .54513 Metetra
.526 0 0 r
.38014 .54513 .39619 .53973 .42105 .54456 .40506 .55501 Metetra
.254 0 0 r
.40506 .55501 .42105 .54456 .44654 .54081 .43083 .55289 Metetra
.43083 .55289 .44654 .54081 .47247 .52886 .45717 .53925 Metetra
.582 .905 .653 r
.45717 .53925 .47247 .52886 .49864 .51014 .4838 .51613 Metetra
.835 .998 .777 r
.4838 .51613 .49864 .51014 .52489 .4868 .51047 .48662 Metetra
.907 .96 .813 r
.51047 .48662 .52489 .4868 .55113 .46139 .53705 .45434 Metetra
.893 .888 .819 r
.53705 .45434 .55113 .46139 .57736 .43653 .56352 .42293 Metetra
.844 .816 .822 r
.56352 .42293 .57736 .43653 .60365 .4146 .58995 .3957 Metetra
.775 .75 .831 r
.58995 .3957 .60365 .4146 .63014 .39757 .61652 .37531 Metetra
.686 .689 .847 r
.61652 .37531 .63014 .39757 .657 .38673 .64348 .36351 Metetra
.567 .627 .871 r
.64348 .36351 .657 .38673 .68441 .38255 .67109 .36093 Metetra
.406 .561 .895 r
.67109 .36093 .68441 .38255 .71254 .38438 .69953 .3667 Metetra
.202 .492 .901 r
.69953 .3667 .71254 .38438 .74139 .39017 .72887 .37803 Metetra
.038 .47 .881 r
.72887 .37803 .74139 .39017 .7708 .39605 .75889 .38959 Metetra
.142 .637 .912 r
.75889 .38959 .7708 .39605 .80025 .39593 .78891 .39287 Metetra
.694 .97 .927 r
.78891 .39287 .80025 .39593 .82879 .38127 .81761 .3759 Metetra
.972 .906 .689 r
.81761 .3759 .82879 .38127 .85489 .34134 .84293 .32386 Metetra
.905 .733 .657 r
.19825 .51431 .21438 .52847 .2431 .45958 .22849 .4335 Metetra
.764 .665 .752 r
.22849 .4335 .2431 .45958 .26747 .43778 .2532 .40893 Metetra
.348 .44 .814 r
.2532 .40893 .26747 .43778 .28977 .44489 .27523 .41869 Metetra
0 0 .556 r
.27523 .41869 .28977 .44489 .31145 .46795 .29639 .44751 Metetra
.718 .268 0 r
.29639 .44751 .31145 .46795 .33344 .49708 .31783 .48374 Metetra
.785 .298 0 r
.31783 .48374 .33344 .49708 .35626 .52466 .34024 .51832 Metetra
.731 .203 0 r
.34024 .51832 .35626 .52466 .38014 .54513 .36391 .54452 Metetra
.54 0 0 r
.36391 .54452 .38014 .54513 .40506 .55501 .38885 .55803 Metetra
.073 0 0 r
.38885 .55803 .40506 .55501 .43083 .55289 .41485 .55705 Metetra
.546 .927 .825 r
.41485 .55705 .43083 .55289 .45717 .53925 .44155 .54214 Metetra
.837 .996 .841 r
.44155 .54214 .45717 .53925 .4838 .51613 .46861 .51578 Metetra
.913 .95 .807 r
.46861 .51578 .4838 .51613 .51047 .48662 .4957 .48177 Metetra
.92 .897 .788 r
.4957 .48177 .51047 .48662 .53705 .45434 .52265 .44451 Metetra
.899 .85 .786 r
.52265 .44451 .53705 .45434 .56352 .42293 .5494 .4084 Metetra
.858 .807 .799 r
.5494 .4084 .56352 .42293 .58995 .3957 .57603 .37737 Metetra
.795 .764 .825 r
.57603 .37737 .58995 .3957 .61652 .37531 .60276 .35456 Metetra
.696 .711 .86 r
.60276 .35456 .61652 .37531 .64348 .36351 .62986 .34203 Metetra
.542 .637 .894 r
.62986 .34203 .64348 .36351 .67109 .36093 .65762 .34052 Metetra
.319 .529 .902 r
.65762 .34052 .67109 .36093 .69953 .3667 .68631 .34902 Metetra
.074 .411 .862 r
.68631 .34902 .69953 .3667 .72887 .37803 .71601 .36423 Metetra
0 .382 .833 r
.71601 .36423 .72887 .37803 .75889 .38959 .74647 .37979 Metetra
.165 .604 .937 r
.74647 .37979 .75889 .38959 .78891 .39287 .77692 .38546 Metetra
.77 .938 .937 r
.77692 .38546 .78891 .39287 .81761 .3759 .80582 .36677 Metetra
.976 .862 .662 r
.80582 .36677 .81761 .3759 .84293 .32386 .83075 .30604 Metetra
.907 .731 .652 r
.18186 .49991 .19825 .51431 .22849 .4335 .21305 .41441 Metetra
.799 .722 .779 r
.21305 .41441 .22849 .4335 .2532 .40893 .23802 .38869 Metetra
.163 .431 .867 r
.23802 .38869 .2532 .40893 .27523 .41869 .25996 .39939 Metetra
.666 .203 0 r
.25996 .39939 .27523 .41869 .29639 .44751 .28086 .43034 Metetra
.808 .348 0 r
.28086 .43034 .29639 .44751 .31783 .48374 .30201 .46924 Metetra
.803 .327 0 r
.30201 .46924 .31783 .48374 .34024 .51832 .32417 .50648 Metetra
.703 .183 0 r
.32417 .50648 .34024 .51832 .36391 .54452 .34773 .53484 Metetra
0 .202 .61 r
.34773 .53484 .36391 .54452 .38885 .55803 .37269 .54969 Metetra
.354 .745 .986 r
.37269 .54969 .38885 .55803 .41485 .55705 .39885 .54907 Metetra
.751 .887 .941 r
.39885 .54907 .41485 .55705 .44155 .54214 .42582 .53356 Metetra
.861 .872 .845 r
.42582 .53356 .44155 .54214 .46861 .51578 .45321 .50583 Metetra
.892 .845 .791 r
.45321 .50583 .46861 .51578 .4957 .48177 .48066 .46995 Metetra
.897 .825 .768 r
.48066 .46995 .4957 .48177 .52265 .44451 .50795 .43064 Metetra
.886 .81 .769 r
.50795 .43064 .52265 .44451 .5494 .4084 .53501 .39259 Metetra
.859 .796 .789 r
.53501 .39259 .5494 .4084 .57603 .37737 .5619 .35999 Metetra
.806 .779 .828 r
.5619 .35999 .57603 .37737 .60276 .35456 .58884 .33614 Metetra
.705 .744 .882 r
.58884 .33614 .60276 .35456 .62986 .34203 .61611 .32323 Metetra
.52 .664 .926 r
.61611 .32323 .62986 .34203 .65762 .34052 .64403 .32203 Metetra
.25 .518 .91 r
.64403 .32203 .65762 .34052 .68631 .34902 .67288 .33147 Metetra
.015 .376 .841 r
.67288 .33147 .68631 .34902 .71601 .36423 .70276 .34808 Metetra
0 .366 .831 r
.70276 .34808 .71601 .36423 .74647 .37979 .73344 .36509 Metetra
.265 .592 .948 r
.73344 .36509 .74647 .37979 .77692 .38546 .76415 .37159 Metetra
.78 .848 .903 r
.76415 .37159 .77692 .38546 .80582 .36677 .79329 .35212 Metetra
.962 .823 .659 r
.79329 .35212 .80582 .36677 .83075 .30604 .81833 .2879 Metetra
.905 .733 .657 r
.16518 .48527 .18186 .49991 .21305 .41441 .19649 .40389 Metetra
.836 .811 .826 r
.19649 .40389 .21305 .41441 .23802 .38869 .22162 .37899 Metetra
0 .363 .756 r
.22162 .37899 .23802 .38869 .25996 .39939 .24371 .38855 Metetra
.767 .26 0 r
.24371 .38855 .25996 .39939 .28086 .43034 .26473 .41723 Metetra
.817 .341 0 r
.26473 .41723 .28086 .43034 .30201 .46924 .28598 .45337 Metetra
.759 .276 0 r
.28598 .45337 .30201 .46924 .32417 .50648 .30822 .48786 Metetra
0 0 .501 r
.30822 .48786 .32417 .50648 .34773 .53484 .33183 .51393 Metetra
.094 .399 .854 r
.33183 .51393 .34773 .53484 .37269 .54969 .35687 .52725 Metetra
.534 .629 .892 r
.35687 .52725 .37269 .54969 .39885 .54907 .38311 .526 Metetra
.715 .698 .833 r
.38311 .526 .39885 .54907 .42582 .53356 .41021 .51075 Metetra
.793 .723 .787 r
.41021 .51075 .42582 .53356 .45321 .50583 .43777 .484 Metetra
.832 .739 .762 r
.43777 .484 .45321 .50583 .48066 .46995 .46545 .44955 Metetra
.852 .753 .754 r
.46545 .44955 .48066 .46995 .50795 .43064 .49301 .41184 Metetra
.857 .768 .763 r
.49301 .41184 .50795 .43064 .53501 .39259 .52035 .37528 Metetra
.847 .784 .791 r
.52035 .37528 .53501 .39259 .5619 .35999 .54753 .34384 Metetra
.807 .797 .842 r
.54753 .34384 .5619 .35999 .58884 .33614 .57473 .32065 Metetra
.708 .787 .913 r
.57473 .32065 .58884 .33614 .61611 .32323 .60222 .30778 Metetra
.504 .709 .963 r
.60222 .30778 .61611 .32323 .64403 .32203 .63029 .30595 Metetra
.226 .544 .928 r
.63029 .30595 .64403 .32203 .67288 .33147 .65922 .31417 Metetra
.048 .408 .859 r
.65922 .31417 .67288 .33147 .70276 .34808 .68911 .32912 Metetra
.091 .415 .864 r
.68911 .32912 .70276 .34808 .73344 .36509 .7198 .34442 Metetra
.384 .581 .919 r
.7198 .34442 .73344 .36509 .76415 .37159 .75056 .34979 Metetra
.749 .747 .85 r
.75056 .34979 .76415 .37159 .79329 .35212 .77996 .33069 Metetra
.931 .782 .673 r
.77996 .33069 .79329 .35212 .81833 .2879 .80568 .2694 Metetra
.897 .739 .678 r
.14822 .47038 .16518 .48527 .19649 .40389 .17858 .40267 Metetra
.843 .939 .888 r
.17858 .40267 .19649 .40389 .22162 .37899 .20372 .38072 Metetra
.383 0 0 r
.20372 .38072 .22162 .37899 .24371 .38855 .22626 .38687 Metetra
.719 .199 0 r
.22626 .38687 .24371 .38855 .26473 .41723 .24791 .40851 Metetra
.755 .238 0 r
.24791 .40851 .26473 .41723 .28598 .45337 .26977 .43602 Metetra
.563 .073 0 r
.26977 .43602 .28598 .45337 .30822 .48786 .2925 .46201 Metetra
0 .265 .771 r
.2925 .46201 .30822 .48786 .33183 .51393 .31644 .48108 Metetra
.386 .457 .811 r
.31644 .48108 .33183 .51393 .35687 .52725 .34163 .48984 Metetra
.569 .534 .777 r
.34163 .48984 .35687 .52725 .38311 .526 .3679 .48694 Metetra
.662 .579 .751 r
.3679 .48694 .38311 .526 .41021 .51075 .39496 .47284 Metetra
.721 .614 .737 r
.39496 .47284 .41021 .51075 .43777 .484 .42249 .44953 Metetra
.762 .648 .735 r
.42249 .44953 .43777 .484 .46545 .44955 .4502 .42 Metetra
.793 .684 .744 r
.4502 .42 .46545 .44955 .49301 .41184 .47788 .38777 Metetra
.813 .724 .766 r
.47788 .38777 .49301 .41184 .52035 .37528 .50543 .35638 Metetra
.819 .77 .807 r
.50543 .35638 .52035 .37528 .54753 .34384 .53289 .32904 Metetra
.793 .815 .869 r
.53289 .32904 .54753 .34384 .57473 .32065 .56039 .30832 Metetra
.699 .834 .947 r
.56039 .30832 .57473 .32065 .60222 .30778 .58813 .29593 Metetra
.5 .77 .992 r
.58813 .29593 .60222 .30778 .63029 .30595 .61637 .29248 Metetra
.273 .621 .96 r
.61637 .29248 .63029 .30595 .65922 .31417 .64532 .29713 Metetra
.184 .509 .912 r
.64532 .29713 .65922 .31417 .68911 .32912 .6751 .30715 Metetra
.277 .502 .893 r
.6751 .30715 .68911 .32912 .7198 .34442 .70557 .31737 Metetra
.484 .572 .868 r
.70557 .31737 .7198 .34442 .75056 .34979 .7362 .31955 Metetra
.706 .662 .804 r
.7362 .31955 .75056 .34979 .77996 .33069 .76588 .30206 Metetra
.88 .736 .699 r
.76588 .30206 .77996 .33069 .80568 .2694 .79278 .25054 Metetra
.871 .754 .73 r
.13096 .45523 .14822 .47038 .17858 .40267 .15919 .41031 Metetra
.612 .952 .806 r
.15919 .41031 .17858 .40267 .20372 .38072 .18415 .39342 Metetra
.349 0 0 r
.18415 .39342 .20372 .38072 .22626 .38687 .20749 .39392 Metetra
.544 .015 0 r
.20749 .39392 .22626 .38687 .24791 .40851 .23033 .4039 Metetra
.501 0 0 r
.23033 .4039 .24791 .40851 .26977 .43602 .25338 .41729 Metetra
.032 .391 .85 r
.25338 .41729 .26977 .43602 .2925 .46201 .27708 .42954 Metetra
.393 .462 .813 r
.27708 .42954 .2925 .46201 .31644 .48108 .30165 .43743 Metetra
.519 .475 .748 r
.30165 .43743 .31644 .48108 .34163 .48984 .32711 .43902 Metetra
.582 .49 .716 r
.32711 .43902 .34163 .48984 .3679 .48694 .35336 .43357 Metetra
.624 .51 .703 r
.35336 .43357 .3679 .48694 .39496 .47284 .38022 .42139 Metetra
.659 .537 .704 r
.38022 .42139 .39496 .47284 .42249 .44953 .40751 .40366 Metetra
.691 .571 .715 r
.40751 .40366 .42249 .44953 .4502 .42 .43502 .38212 Metetra
.721 .615 .739 r
.43502 .38212 .4502 .42 .47788 .38777 .46263 .35885 Metetra
.749 .674 .778 r
.46263 .35885 .47788 .38777 .50543 .35638 .49027 .33597 Metetra
.768 .749 .836 r
.49027 .33597 .50543 .35638 .53289 .32904 .51795 .31546 Metetra
.754 .829 .91 r
.51795 .31546 .53289 .32904 .56039 .30832 .54575 .29892 Metetra
.668 .874 .976 r
.54575 .29892 .56039 .30832 .58813 .29593 .57378 .28746 Metetra
.517 .835 .999 r
.57378 .28746 .58813 .29593 .61637 .29248 .60221 .28143 Metetra
.406 .742 .993 r
.60221 .28143 .61637 .29248 .64532 .29713 .63117 .2803 Metetra
.403 .65 .958 r
.63117 .2803 .64532 .29713 .6751 .30715 .66074 .28237 Metetra
.47 .587 .889 r
.66074 .28237 .6751 .30715 .70557 .31737 .69085 .28446 Metetra
.56 .569 .82 r
.69085 .28446 .70557 .31737 .7362 .31955 .72121 .2816 Metetra
.664 .598 .771 r
.72121 .2816 .7362 .31955 .76588 .30206 .75116 .26682 Metetra
.795 .675 .731 r
.75116 .26682 .76588 .30206 .79278 .25054 .77963 .23132 Metetra
.741 .766 .872 r
.1134 .43981 .13096 .45523 .15919 .41031 .1384 .4248 Metetra
.1384 .4248 .15919 .41031 .18415 .39342 .16298 .41472 Metetra
.226 0 0 r
.16298 .41472 .18415 .39342 .20749 .39392 .18744 .40772 Metetra
.153 0 0 r
.18744 .40772 .20749 .39392 .23033 .4039 .212 .40234 Metetra
.344 .813 .914 r
.212 .40234 .23033 .4039 .25338 .41729 .23679 .39746 Metetra
.595 .685 .904 r
.23679 .39746 .25338 .41729 .27708 .42954 .26191 .39227 Metetra
.597 .549 .771 r
.26191 .39227 .27708 .42954 .30165 .43743 .28739 .38621 Metetra
.593 .494 .711 r
.28739 .38621 .30165 .43743 .32711 .43902 .31325 .37897 Metetra
.593 .474 .686 r
.31325 .37897 .32711 .43902 .35336 .43357 .33946 .37043 Metetra
.597 .471 .679 r
.33946 .37043 .35336 .43357 .38022 .42139 .366 .36066 Metetra
.605 .481 .684 r
.366 .36066 .38022 .42139 .40751 .40366 .39284 .34985 Metetra
.618 .505 .703 r
.39284 .34985 .40751 .40366 .43502 .38212 .41994 .33829 Metetra
.635 .547 .738 r
.41994 .33829 .43502 .38212 .46263 .35885 .44729 .32634 Metetra
.657 .613 .794 r
.44729 .32634 .46263 .35885 .49027 .33597 .47487 .31435 Metetra
.678 .712 .874 r
.47487 .31435 .49027 .33597 .51795 .31546 .50269 .3027 Metetra
.672 .826 .958 r
.50269 .3027 .51795 .31546 .54575 .29892 .53076 .29166 Metetra
.613 .891 .989 r
.53076 .29166 .54575 .29892 .57378 .28746 .5591 .28143 Metetra
.564 .891 .987 r
.5591 .28143 .57378 .28746 .60221 .28143 .58776 .27209 Metetra
.587 .857 .995 r
.58776 .27209 .60221 .28143 .63117 .2803 .61675 .26354 Metetra
.62 .761 .946 r
.61675 .26354 .63117 .2803 .66074 .28237 .64609 .25545 Metetra
.623 .649 .855 r
.64609 .25545 .66074 .28237 .69085 .28446 .67579 .24727 Metetra
.619 .577 .785 r
.67579 .24727 .69085 .28446 .72121 .2816 .70579 .23811 Metetra
.627 .553 .752 r
.70579 .23811 .72121 .2816 .75116 .26682 .73599 .22679 Metetra
.66 .588 .763 r
.73599 .22679 .75116 .26682 .77963 .23132 .76622 .21171 Metetra
0 .075 .554 r
.09553 .42413 .1134 .43981 .1384 .4248 .11657 .44199 Metetra
.297 0 0 r
.11657 .44199 .1384 .4248 .16298 .41472 .14061 .43959 Metetra
.006 0 0 r
.14061 .43959 .16298 .41472 .18744 .40772 .16641 .42416 Metetra
.5 .85 .588 r
.16641 .42416 .18744 .40772 .212 .40234 .19306 .40176 Metetra
.852 .954 .878 r
.19306 .40176 .212 .40234 .23679 .39746 .21997 .37706 Metetra
.786 .735 .806 r
.21997 .37706 .23679 .39746 .26191 .39227 .24679 .35337 Metetra
.703 .598 .735 r
.24679 .35337 .26191 .39227 .28739 .38621 .27338 .33282 Metetra
.647 .521 .696 r
.27338 .33282 .28739 .38621 .31325 .37897 .29972 .31652 Metetra
.607 .477 .677 r
.29972 .31652 .31325 .37897 .33946 .37043 .32591 .30485 Metetra
.578 .452 .672 r
.32591 .30485 .33946 .37043 .366 .36066 .35207 .29752 Metetra
.557 .443 .68 r
.35207 .29752 .366 .36066 .39284 .34985 .37836 .2938 Metetra
.54 .45 .702 r
.37836 .2938 .39284 .34985 .41994 .33829 .40491 .29257 Metetra
.529 .478 .743 r
.40491 .29257 .41994 .33829 .44729 .32634 .43184 .29249 Metetra
.526 .538 .811 r
.43184 .29249 .44729 .32634 .47487 .31435 .45922 .29211 Metetra
.53 .646 .908 r
.45922 .29211 .47487 .31435 .50269 .3027 .48708 .29001 Metetra
.537 .783 .989 r
.48708 .29001 .50269 .3027 .53076 .29166 .51537 .28496 Metetra
.56 .881 .991 r
.51537 .28496 .53076 .29166 .5591 .28143 .54403 .27611 Metetra
.642 .929 .972 r
.54403 .27611 .5591 .28143 .58776 .27209 .57295 .26316 Metetra
.741 .911 .952 r
.57295 .26316 .58776 .27209 .61675 .26354 .60203 .24656 Metetra
.765 .809 .888 r
.60203 .24656 .61675 .26354 .64609 .25545 .63122 .22759 Metetra
.727 .691 .815 r
.63122 .22759 .64609 .25545 .67579 .24727 .66056 .20854 Metetra
.668 .597 .766 r
.66056 .20854 .67579 .24727 .70579 .23811 .69023 .19281 Metetra
.594 .528 .749 r
.69023 .19281 .70579 .23811 .73599 .22679 .72064 .18509 Metetra
.454 .462 .777 r
.72064 .18509 .73599 .22679 .76622 .21171 .75254 .19172 Metetra
.893 .47 .138 r
.07734 .40816 .09553 .42413 .11657 .44199 .09453 .45491 Metetra
.436 0 0 r
.09453 .45491 .11657 .44199 .14061 .43959 .118 .45941 Metetra
.118 .45941 .14061 .43959 .16641 .42416 .14512 .43637 Metetra
.896 .988 .755 r
.14512 .43637 .16641 .42416 .19306 .40176 .17385 .39885 Metetra
.922 .873 .771 r
.17385 .39885 .19306 .40176 .21997 .37706 .20283 .35691 Metetra
.85 .743 .745 r
.20283 .35691 .21997 .37706 .24679 .35337 .23131 .31749 Metetra
.77 .642 .72 r
.23131 .31749 .24679 .35337 .27338 .33282 .25898 .28482 Metetra
.697 .564 .702 r
.25898 .28482 .27338 .33282 .29972 .31652 .28584 .26106 Metetra
.63 .505 .692 r
.28584 .26106 .29972 .31652 .32591 .30485 .31205 .2468 Metetra
.568 .46 .691 r
.31205 .2468 .32591 .30485 .35207 .29752 .33789 .24144 Metetra
.508 .428 .7 r
.33789 .24144 .35207 .29752 .37836 .2938 .36367 .24349 Metetra
.45 .409 .722 r
.36367 .24349 .37836 .2938 .40491 .29257 .38969 .25079 Metetra
.392 .413 .762 r
.38969 .25079 .40491 .29257 .43184 .29249 .41618 .26065 Metetra
.344 .451 .826 r
.41618 .26065 .43184 .29249 .45922 .29211 .4433 .27012 Metetra
.329 .547 .912 r
.4433 .27012 .45922 .29211 .48708 .29001 .47112 .27623 Metetra
.392 .701 .983 r
.47112 .27623 .48708 .29001 .51537 .28496 .49958 .27636 Metetra
.548 .854 .998 r
.49958 .27636 .51537 .28496 .54403 .27611 .52852 .26868 Metetra
.723 .927 .959 r
.52852 .26868 .54403 .27611 .57295 .26316 .55773 .25256 Metetra
.823 .899 .894 r
.55773 .25256 .57295 .26316 .60203 .24656 .587 .22894 Metetra
.836 .817 .831 r
.587 .22894 .60203 .24656 .63122 .22759 .61618 .20059 Metetra
.794 .725 .787 r
.61618 .20059 .63122 .22759 .66056 .20854 .64533 .1723 Metetra
.714 .635 .767 r
.64533 .1723 .66056 .20854 .69023 .19281 .6748 .15103 Metetra
.569 .529 .771 r
.6748 .15103 .69023 .19281 .72064 .18509 .7054 .14629 Metetra
.173 .3 .754 r
.7054 .14629 .72064 .18509 .75254 .19172 .73858 .17132 Metetra
.922 .538 .247 r
.05883 .3919 .07734 .40816 .09453 .45491 .07376 .45323 Metetra
.368 0 0 r
.07376 .45323 .09453 .45491 .118 .45941 .09692 .46121 Metetra
.862 .964 .865 r
.09692 .46121 .118 .45941 .14512 .43637 .12488 .43416 Metetra
.927 .867 .761 r
.12488 .43416 .14512 .43637 .17385 .39885 .15492 .38884 Metetra
.91 .803 .73 r
.15492 .38884 .17385 .39885 .20283 .35691 .18522 .33815 Metetra
.874 .752 .725 r
.18522 .33815 .20283 .35691 .23131 .31749 .21479 .29085 Metetra
.825 .704 .731 r
.21479 .29085 .23131 .31749 .25898 .28482 .24321 .25219 Metetra
.76 .653 .743 r
.24321 .25219 .25898 .28482 .28584 .26106 .27048 .22474 Metetra
.677 .598 .759 r
.27048 .22474 .28584 .26106 .31205 .2468 .29681 .20914 Metetra
.572 .536 .776 r
.29681 .20914 .31205 .2468 .33789 .24144 .32255 .20463 Metetra
.446 .47 .791 r
.32255 .20463 .33789 .24144 .36367 .24349 .34809 .20937 Metetra
.308 .409 .802 r
.34809 .20937 .36367 .24349 .38969 .25079 .37383 .22071 Metetra
.187 .37 .814 r
.37383 .22071 .38969 .25079 .41618 .26065 .40008 .23535 Metetra
.126 .384 .839 r
.40008 .23535 .41618 .26065 .4433 .27012 .42706 .2496 Metetra
.171 .476 .895 r
.42706 .2496 .4433 .27012 .47112 .27623 .45486 .25971 Metetra
.346 .64 .963 r
.45486 .25971 .47112 .27623 .49958 .27636 .48345 .26235 Metetra
.583 .794 .98 r
.48345 .26235 .49958 .27636 .52852 .26868 .51262 .25516 Metetra
.757 .855 .923 r
.51262 .25516 .52852 .26868 .55773 .25256 .54211 .23733 Metetra
.837 .845 .851 r
.54211 .23733 .55773 .25256 .587 .22894 .57164 .21008 Metetra
.857 .809 .803 r
.57164 .21008 .587 .22894 .61618 .20059 .60101 .17695 Metetra
.835 .765 .785 r
.60101 .17695 .61618 .20059 .64533 .1723 .63026 .144 Metetra
.763 .709 .801 r
.63026 .144 .64533 .1723 .6748 .15103 .6598 .1199 Metetra
.551 .588 .844 r
.6598 .1199 .6748 .15103 .7054 .14629 .69057 .1165 Metetra
0 .147 .691 r
.69057 .1165 .7054 .14629 .73858 .17132 .72434 .15051 Metetra
.897 .477 .148 r
.03998 .37535 .05883 .3919 .07376 .45323 .05649 .42325 Metetra
.405 .505 .847 r
.05649 .42325 .07376 .45323 .09692 .46121 .08003 .42778 Metetra
.737 .643 .755 r
.08003 .42778 .09692 .46121 .12488 .43416 .10767 .40402 Metetra
.809 .684 .726 r
.10767 .40402 .12488 .43416 .15492 .38884 .13715 .36541 Metetra
.846 .725 .73 r
.13715 .36541 .15492 .38884 .18522 .33815 .16694 .32229 Metetra
.872 .779 .756 r
.16694 .32229 .18522 .33815 .21479 .29085 .19618 .28176 Metetra
.882 .849 .806 r
.19618 .28176 .21479 .29085 .24321 .25219 .22448 .24818 Metetra
.848 .931 .882 r
.22448 .24818 .24321 .25219 .27048 .22474 .25184 .22373 Metetra
.677 .96 .942 r
.25184 .22373 .27048 .22474 .29681 .20914 .27841 .209 Metetra
.297 .792 .86 r
.27841 .209 .29681 .20914 .32255 .20463 .3045 .20337 Metetra
.057 0 0 r
.3045 .20337 .32255 .20463 .34809 .20937 .33044 .20533 Metetra
.217 0 0 r
.33044 .20533 .34809 .20937 .37383 .22071 .35655 .21266 Metetra
0 .367 .717 r
.35655 .21266 .37383 .22071 .40008 .23535 .38314 .22261 Metetra
0 .454 .852 r
.38314 .22261 .40008 .23535 .42706 .2496 .41038 .23217 Metetra
.235 .565 .937 r
.41038 .23217 .42706 .2496 .45486 .25971 .43839 .23829 Metetra
.462 .639 .933 r
.43839 .23829 .45486 .25971 .48345 .26235 .46712 .23827 Metetra
.615 .684 .891 r
.46712 .23827 .48345 .26235 .51262 .25516 .49644 .23025 Metetra
.714 .718 .852 r
.49644 .23025 .51262 .25516 .54211 .23733 .52613 .21357 Metetra
.782 .752 .825 r
.52613 .21357 .54211 .23733 .57164 .21008 .55594 .18919 Metetra
.827 .79 .818 r
.55594 .18919 .57164 .21008 .60101 .17695 .58572 .15998 Metetra
.845 .836 .837 r
.58572 .15998 .60101 .17695 .63026 .144 .61546 .13084 Metetra
.8 .883 .906 r
.61546 .13084 .63026 .144 .6598 .1199 .64545 .10888 Metetra
.477 .802 1 r
.64545 .10888 .6598 .1199 .69057 .1165 .67644 .10384 Metetra
0 .134 .608 r
.67644 .10384 .69057 .1165 .72434 .15051 .70981 .12927 Metetra
.657 .75 .919 r
.02078 .3585 .03998 .37535 .05649 .42325 .04565 .34924 Metetra
.576 .435 .653 r
.04565 .34924 .05649 .42325 .08003 .42778 .07078 .33989 Metetra
.566 .411 .63 r
.07078 .33989 .08003 .42778 .10767 .40402 .09615 .33045 Metetra
.577 .437 .655 r
.09615 .33045 .10767 .40402 .13715 .36541 .12179 .32091 Metetra
.611 .532 .741 r
.12179 .32091 .13715 .36541 .16694 .32229 .14768 .31127 Metetra
.647 .837 .973 r
.14768 .31127 .16694 .32229 .19618 .28176 .17384 .30154 Metetra
.071 0 0 r
.17384 .30154 .19618 .28176 .22448 .24818 .20026 .2917 Metetra
.306 0 .134 r
.20026 .2917 .22448 .24818 .25184 .22373 .22696 .28177 Metetra
.359 .007 .224 r
.22696 .28177 .25184 .22373 .27841 .209 .25394 .27173 Metetra
.37 .026 .245 r
.25394 .27173 .27841 .209 .3045 .20337 .2812 .26158 Metetra
.359 .008 .225 r
.2812 .26158 .3045 .20337 .33044 .20533 .30874 .25133 Metetra
.319 0 .156 r
.30874 .25133 .33044 .20533 .35655 .21266 .33657 .24098 Metetra
.201 0 0 r
.33657 .24098 .35655 .21266 .38314 .22261 .3647 .23051 Metetra
.3647 .23051 .38314 .22261 .41038 .23217 .39313 .21993 Metetra
.646 .842 .976 r
.39313 .21993 .41038 .23217 .43839 .23829 .42186 .20924 Metetra
.643 .651 .843 r
.42186 .20924 .43839 .23829 .46712 .23827 .4509 .19843 Metetra
.624 .573 .777 r
.4509 .19843 .46712 .23827 .49644 .23025 .48025 .1875 Metetra
.619 .557 .763 r
.48025 .1875 .49644 .23025 .52613 .21357 .50993 .17646 Metetra
.63 .594 .795 r
.50993 .17646 .52613 .21357 .55594 .18919 .53993 .1653 Metetra
.653 .711 .89 r
.53993 .1653 .55594 .18919 .58572 .15998 .57026 .15401 Metetra
.571 .908 .975 r
.57026 .15401 .58572 .15998 .61546 .13084 .60092 .1426 Metetra
.60092 .1426 .61546 .13084 .64545 .10888 .63193 .13106 Metetra
.144 0 0 r
.63193 .13106 .64545 .10888 .67644 .10384 .66328 .11939 Metetra
.036 0 0 r
.66328 .11939 .67644 .10384 .70981 .12927 .69498 .10759 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09549 .2323 m
.1002 .23687 L
s
[(-0.4)] .08608 .22315 1 .97179 Mshowa
.21633 .18498 m
.22084 .18975 L
s
[(-0.2)] .20731 .17545 .94563 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.47614 .08324 m
.48017 .08842 L
s
[(0.2)] .46808 .07289 .77884 1 Mshowa
.61605 .02846 m
.6198 .03385 L
s
[(0.4)] .60856 .01769 .69544 1 Mshowa
.125 Mabswid
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.18558 .19702 m
.18832 .19985 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.51046 .06981 m
.51284 .07294 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.06616 .24378 m
.06901 .2465 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[258]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00YP3oool2000000@0oooo0P0000050?ooo`<00000JP3oool00:D0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`1Y0?ooo`00Y@3oool010000000oooo
0?ooo`0000080?ooo`D00000JP3oool00:D0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00001[0?ooo`00Y@3oool010000000oooo0?ooo`0000090?ooo`030000003oool00000
0180oooo0P00001G0?ooo`00YP3oool2000000/0oooo0P00000@0?ooo`80000000<0oooo00000000
0000EP3oool00<80oooo0`0000030?ooo`800000EP3oool00;l0oooo0`0000060?ooo`030000003o
ool0000005D0oooo002m0?ooo`<00000203oool010000000oooo0?ooo`00001D0?ooo`00^P3oool3
000000/0oooo00@000000?ooo`3oool00000E03oool00;P0oooo0P00000>0?ooo`050000003oool0
oooo0?ooo`000000D`3oool00;D0oooo0`00000@0?ooo`060000003oool0oooo0000003oool00000
3P3oool2000000@0oooo0P0000050?ooo`<00000=03oool00;<0oooo0P0000020?ooo`030000003o
ool0oooo00l0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool0<`3oool00;00oooo0`00000F0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`D00000=03oool00880oooo
0P0000040?ooo`8000000`3oool4000001`0oooo0`00000I0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool400000080oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000e0?ooo`00P@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
01/0oooo0`00000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000003D0oooo00210?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool05`3oool3000001h0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`090?ooo`8000002`3oool2000003D0oooo00210?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool0503oool200000240oooo00<000000?ooo`3oool00`3oool3
000004h0oooo00210?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000004P3o
ool3000002<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1<0?ooo`00PP3oool2
000000X0oooo0P00000A0?ooo`80000000<0oooo0000003oool08`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo04/0oooo002N0?ooo`<00000:03oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo04X0oooo002K0?ooo`<00000:`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo04X0oooo002I0?ooo`<00000;@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo04T0oooo002F0?ooo`<00000<03oool00`000000oooo0?ooo`080?ooo`800000BP3o
ool009@0oooo0P00000c0?ooo`030000003oool0oooo00P0oooo0P00001:0?ooo`00T@3oool30000
03D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`170?ooo`00SP3oool300000080
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04L0
oooo001[0?ooo`8000007`3oool2000003/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`160?ooo`00JP3oool010000000oooo0?ooo`00000K0?ooo`<00000?P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo04D0oooo001Z0?ooo`040000003oool0oooo000001T0oooo
0P0000000`3oool000000?ooo`0n0?ooo`030000003oool0oooo00/0oooo0P0000160?ooo`00JP3o
ool010000000oooo0?ooo`00000F0?ooo`<00000>`3oool4000000@0oooo00<000000?ooo`3oool0
2`3oool2000004H0oooo001Z0?ooo`040000003oool0oooo000001<0oooo0`00000i0?ooo`D00000
0P0T00000`0000002@00000000020?ooo`8000003`3oool00`000000oooo0?ooo`130?ooo`00J`3o
ool200000180oooo1000000i0?ooo`030000000T0000900000@0900000@0000000T0000900002@00
0P0000000`09000000000000000>0?ooo`030000003oool0oooo04<0oooo001l0?ooo`<00000>`3o
ool3000000H090002@00000?0?ooo`030000003oool0oooo0480oooo001j0?ooo`800000?@3oool3
000000D090001000000308fFf0<0000000<02@000000003oool03P3oool00`000000oooo0?ooo`11
0?ooo`00M`3oool3000003h0oooo1000000302@000<000001`2=U]P4000000l0oooo0P0000120?oo
o`00M@3oool2000003l0oooo1@0000000`0T000000000000000200000080`kG=00<0000008fFf02=
U]P0102=U]P300000003000RV`000000oooo00d0oooo0P00000>0?ooo`800000103oool2000000<0
oooo1000000U0?ooo`00LP3oool300000400oooo1`0000000`3<h^L000000<>ec@030<>ec@030000
002=U]P0SIKH00D0SIKH00D00000000U/000000002:K0000000?0?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0V0?ooo`00L03oool200000480
oooo1@0000030<cRi`0300000033]Ld0`kG=00<0`kG=00<0000008fFf02=U]P01@2=U]P00`000000
02F`000U/002000000l0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo02D0oooo001]0?ooo`<0000000<0oooo0000003oool0@03oool600000003
0<cRi`000000000000L0`kG=00<0000008fFf02=U]P0102=U]P20000008002F`0P00000?0?ooo`03
0000003oool0oooo00<0oooo100000020?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool0903oool003l0oooo0P0000040?ooo`8000000`3oool4000001`0oooo0`0000140?ooo`<0
00001@3He]H00`000000`kG=0<>ec@070<>ec@030000002=U]P0SIKH00@0SIKH0P000003000U/080
00003`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000009@3oool003h0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0K
0?ooo`800000A@3oool3000000H0f=KF00<000000=G3b00000002@33]Ld00`000000SIKH08fFf002
08fFf0@000000`009K000`000000oooo0?ooo`0=0?ooo`8000002P3oool2000000X0oooo0P00000V
0?ooo`00?P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo01L0oooo0`000000
0`3oool000000?ooo`110?ooo`<0000000<0T^Si0000003He]H01@3He]H010000000eL?80=G3b000
00090<>ec@D0000000<0THO50000002AQlD00`000002000U/0030000003oool0oooo00/0oooo0`00
000n0?ooo`00>03oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`0D0?ooo`800000A03oool3000000<0T^Si00<000000=SFeP3He]H01@3He]H01@000000eL?80=G3
b03E`lP0000000H0`kG=0`0000060967a@050000002AQlD0000002a<`@0000000P009K000`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo03/0oooo000n0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000004P3oool3000004@0oooo0P0000030:Nfh`<000001`3He]H00`00
0000eL?80=G3b0020=G3b00300000033]Ld0`kG=00<0`kG=00D000000;JRa02fX/@0]Z;400000005
0967a@030000002AQlD000000080;4c10P0000000`009K0000000?ooo`0=0?ooo`030000003oool0
oooo03/0oooo000o0?ooo`8000002P3oool200000140oooo0P0000000`3oool000000?ooo`110?oo
o`<000001P2W]^<00`000000dl[A000000050=SFeP030000003E`lP0eL?800@0eL?800D000000<>e
c@33]Ld0`kG=000000040;JRa0030000002AQlD0THO500<0THO500@000000967a@2AQlD000000`0/
C<42000000l0oooo00<000000?ooo`3oool0>P3oool005/0oooo0`0000130?ooo`<00000202W]^<0
1@000000dl[A0=?:d@3Cb]40000000<0f=KF00<000000=G3b03E`lP01@3E`lP010000000`kG=0000
000000050;JRa0030000002AQlD0THO500<0THO500@000000967a@2AQlD00000100/C<42000000l0
oooo00<000000?ooo`3oool0>@3oool005P0oooo0`0000120?ooo`@000000P2QV</00`000000YkKS
0:Nfh`050:Nfh`030000003Cb]40dl[A0080dl[A00D000000=SFeP3He]H0f=KF000000080=G3b003
0000002fX/@0]Z;400H0]Z;400<000000967a@2AQlD00P2AQlD010000000THO50967a@00000602a<
`@030000003oool0oooo00`0oooo0P00000j0?ooo`00EP3oool2000000030?ooo`000000oooo03l0
oooo0`0000060:6Hb`030000002W]^<0YkKS00@0YkKS00<000000=?:d@3Cb]40103Cb]400`000000
f=KF000000080=G3b0800000202fX/@00`000000THO50967a@020967a@050000002AQlD0THO50967
a@0000001P0/C<400`000000oooo0?ooo`0;0?ooo`800000>P3oool005<0oooo0`0000120?ooo`80
000000<0WXk30000002QV</01`2QV</00`000000YkKS0:Nfh`020:Nfh`030000003Cb]40dl[A00H0
dl[A00<000000=G3b03E`lP01P3E`lP010000000bkW90<^ib@0000080;JRa0050000002AQlD0THO5
0967a@0000000`2AQlD00`000000;4c102a<`@0402a<`@030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0=`3oool00540oooo0P0000120?ooo`<00000102NS/<00`000000XIS;0:6Hb`060:6H
b`040000002W]^<0YkKS000000P0dl[A00<000000=_?c@0000001P3E`lP01@000000bkW90<^ib@3;
^LT0000000P0]Z;400D000000967a@2AQlD0THO5000000040967a@030000000/C<40;4c100@0;4c1
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0g0?ooo`00CP3oool300000440oooo0`00
000709j>``030000002QV</0XIS;00H0XIS;00<000000:Nfh`000000203Cb]4010000000flo=0=_?
c@0000050=G3b0030000003;^LT0bkW900<0bkW900<000000;JRa02fX/@01@2fX/@01@000000THO5
0967a@2AQlD0000000<0THO51@00000302a<`@030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0=P3oool001l0oooo0P0000040?ooo`8000001@3oool3000001`0oooo0`0000030?ooo`030000
003oool0oooo03`0oooo0P0000000`2OT/H0000009j>``0809j>``030000002QV</0XIS;00H0XIS;
00<000000=?:d@3Cb]401P3Cb]400`000000flo=0=_?c@020=_?c@030000003E`lP0eL?80080eL?8
00<000000<^ib@3;^LT00`3;^LT00`000000]Z;40;JRa0060;JRa0030000002AQlD0THO500@00000
00<0V8No0000001dM/H00P1dM/H5000000l0oooo00<000000?ooo`3oool0=@3oool001h0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`0I0?ooo`800000@`3oool2000000@0Wi;6
00<0000009j>``2NS/<01P2NS/<00`000000XIS;0:6Hb`050:6Hb`0300000038`=<0000000H0dl[A
00<000000=_?c@3Kcld0103Kcld010000000eL?80=G3b00000060<^ib@030000002fX/@0]Z;400H0
]Z;41000000509R7_`030000001dM/H0M7K600D0M7K600<000000?ooo`3oool02`3oool2000003L0
oooo000N0?ooo`040000003oool0oooo000000P0oooo1@00000G0?ooo`@00000@@3oool3000000H0
Wi;600<0000009j>``2NS/<01P2NS/<00`000000XIS;0:6Hb`040:6Hb`0500000038`=<0b<3C0<S0
d`000000103Cb]400`000000flo=0=_?c@050=_?c@030000003E`lP0000000P0bkW900<000000;JR
a02fX/@00`2fX/@300000080V8No00<0000009R7_`2HQkl00`2HQkl00`000000M7K607AfaP0607Af
aP030000003oool0oooo00`0oooo00<000000?ooo`3oool0=03oool001P0oooo100000020?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000005P3oool200000200oooo1000000O
0?ooo`80000000<0Y:KG0000002OT/H01P2OT/H00`000000WXk309j>``0709j>``040000002QV</0
XIS;0:6Hb`8000001038`=<01@000000dl[A0=?:d@3Cb]40000000T0flo=00<000000<^ib@3;^LT0
1`3;^LT010000000]Z;40;JRa02fX/@2000000<0ZiS400<0000009R7_`0000001P2HQkl00`000000
M7K607AfaP0507AfaP030000003oool0oooo00d0oooo00<000000?ooo`3oool0<`3oool001h0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0000000C0?ooo`<000007P3oool400000004
05h6?P000000F`8i05/2>@H000005P3oool3000000@0Y:KG00<0000009nBaP2OT/H01@2OT/H00`00
0000WXk309j>``0609j>``040000002QV</0XIS;000000L0b<3C00<000000=?:d@0000002@3Kcld2
000000X0bkW90`0000050:^Ha0030000002HQkl0000000H0V8No00<0000007AfaP1dM/H01P1dM/H0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03<0oooo000O0?ooo`8000002`3oool20000
0140oooo0`00000M0?ooo`<00000101N1Sh00`000000F`8i05/2>@0405/2>@030000001A02L00000
00<00000403oool3000000L0Y:KG00<0000009nBaP2OT/H01@2OT/H00`000000WXk309j>``0709j>
``8000002@38`=<00`000000flo=0=_?c@070=_?c@040000003FdM@0e]7D000000T0bkW900<00000
0:^Ha02[V<@01@2[V<@00`000000V8No0000000609R7_`030000001dM/H0M7K600L0M7K600<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0b0?ooo`00?03oool3000001h0oooo0P0000000`1K
0CT0000005h6?P0405h6?P030000001K0ST0F`8i00<0F`8i00<0000005409`1A02L0101A02L30000
00T0oooo100000020:GGn@030000002TY]L0Y:KG00H0Y:KG00<0000009nBaP2OT/H01@2OT/H00`00
0000WXk309j>``0609j>``0300000038`=<0b<3C00L0b<3C00<000000=KHf@0000001`3Kcld01@00
0000e]7D0=KAe03FdM@0000000L0bkW90`0000080:^Ha08000001`2HQkl00`000000M7K607AfaP04
07AfaP80000000<0Z9K30000003oool0303oool2000003<0oooo000i0?ooo`<000007`3oool20000
0080F`4i00<0000005h6?P1N1Sh00`1N1Sh00`000000F`8i05/2>@0405/2>@030000001A02L0D@0W
00@0D@0W00<0000003<0000c0000100000020?ooo`<000001P2UeoT00`000000Y:KG0:BVe`060:BV
e`030000002OT/H0Wi;600D0Wi;600<0000009j>``2NS/<0102NS/<2000000030;JgfP000000b<3C
00H0b<3C00D000000=KHf@3Ff=T0e]SI000000040=_?c@8000001@3FdM@00`000000bkW90<^ib@02
0<^ib@8000000`2j/=000`000000ZiS40:^Ha0050:^Ha0030000002HQkl0000000H0V8No00<00000
07AfaP1dM/H00P1dM/H2000000<0Z9K300<000000?ooo`3oool02`3oool2000000P0oooo0P00000Y
0?ooo`00=`3oool4000001h0oooo0P00000405/1>@030000001N1Sh0GPHn00<0GPHn00<0000005/2
>@1K0ST00`1K0ST00`000000D@0W05409`0505409`030000000c0000<`0000@0<`001@0000070:GG
n@030000002TY]L0Y:KG00D0Y:KG00<0000009nBaP2OT/H01@2OT/H00`000000WXk309j>``0209j>
``8000000`2f]mX00`000000b<3C0<S0d`040<S0d`030000003Ff=T0e]SI0080e]SI00D000000=_?
c@3Kcld0flo=000000070=KAe0030000003;^LT0bkW9008000001@2j/=000`000000ZiS40:^Ha006
0:^Ha08000001`2HQkl010000000M7K60000000000060:RF``030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000X0?ooo`00=03oool300000240oooo0P00
000405/1>@030000001N1Sh0GPHn00@0GPHn00<0000005/2>@1K0ST00`1K0ST00`000000D@0W0540
9`0405409`030000000c0000<`0000<0<`00200000070:GGn@030000002TY]L0Y:KG00D0Y:KG00<0
000009nBaP2OT/H01@2OT/H010000000WXk30000000000060;JgfP0300000038`=<0b<3C0080b<3C
00<000000=KHf@3Ff=T0103Ff=T00`000000flo=000000090=KAe0800000202j/=000`000000ZiS4
0:^Ha0050:^Ha08000001P2HQkl3000000P0Z9K300<000000?ooo`3oool0303oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000002P0oooo000b0?ooo`8000008`3oool2000000D0F`4i
00<0000005h6?P1N1Sh00`1N1Sh00`000000F`8i05/2>@0305/2>@030000001A02L0D@0W00@0D@0W
00@0000003<0000c0000<`000`000000101>J<d0000002mNd00_G]05000000L0YMOi00<000000:BV
e`2TY]L0102TY]L00`000000Wi;609nBaP0409nBaP<000002@2f]mX010000000b<3C0<S0d`000008
0=KHf@030000003FdM@0e]7D00H0e]7D0P0000000`33cn<000000;Z`d0070;Z`d0030000002[V<@0
ZiS400D0ZiS40P00000409R7_`80000000<0X8g00000002XU/<02@2XU/<00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:03oool002l0oooo1000000S
0?ooo`030000001>0280000000D0F`4i00<0000005h6?P1N1Sh00`1N1Sh00`000000F`8i05/2>@03
05/2>@030000001A02L0D@0W00<0D@0W00<0000003<0000c00000`00000404iXc@040000000_G]00
;ek@02mNd0L000000`2UeoT00`000000Y:KG0:BVe`050:BVe`030000002OT/H0000000<000000P2M
[n@00`000000][OJ0;JgfP070;JgfP0300000038`=<0000000P0e]SI00<000000=;Vi00000001P3F
dM@01@000000`loS0<??h`33cn<0000000T0^[3@00<000000:^Ha02[V<@01@2[V<@00`000000V8No
00000002000000@0X8g000<000000:RF``2XU/<01P2XU/<00`000000bjbk0000000>0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000:03oool002d0oooo0P0000040?ooo`030000
003oool0oooo01l0oooo00<0000004h08P0000001@1K0CT00`000000GPHn05h6?P0305h6?P030000
001K0ST0F`8i00<0F`8i00<0000005409`1A02L0101A02L300000080LWS:00<0000004iXc@1>J<d0
0P1>J<d00`000000;ek@02mNd00302mNd0<000000P0lT>l=000000H0WJoT00<000000;JgfP2f]mX0
202f]mX00`000000e]SI0=KHf@060=KHf@050000003Bi^@0d^KT0=;Vi0000000103FdM@00`000000
`loS0<??h`030<??h`030000002j/=00^[3@00H0^[3@00<000000:^Ha02[V<@0102[V<@3000000L0
X8g000<000000:RF``2XU/<01@2XU/<010000000bjbk0<^/^`00000=0?ooo`8000001@3oool20000
02T0oooo000Z0?ooo`<000009`3oool010000000CP0R04h08P00000505/1>@030000001N1Sh0GPHn
00<0GPHn00<0000005/2>@1K0ST00`1K0ST00`000000D@0W05409`0205409`X000000`1>J<d00`00
0000;ek@02mNd00202mNd0030000000PH]H00000008000001@0lT>l00`000000MZ?^07JSkP0407JS
kP030000002M[n@0WJoT00D0WJoT00<000000;JgfP2f]mX01@2f]mX2000000030<7Jk0000000e]SI
00@0e]SI0P0000050=;Vi0040000003FdM@00000000000H0`loS00<000000;Z`d02j/=001`2j/=00
0`000000ZiS4000000030000000309jCb0000000X8g000P0X8g000<000000:RF``2XU/<0102XU/<0
1@000000bjbk0<^/^`3;[;/0000000h0oooo00<000000?ooo`3oool0;@3oool002L0oooo0`000000
0`3oool000000?ooo`0V0?ooo`050000001>0280CP0R04h08P0000001@1K0CT00`000000GPHn05h6
?P0305h6?P030000001K0ST0F`8i0080F`8i00<0000005409`0000000`0000000`2AMK000000089]
/`05089]/`030000001cJ;P0000000<000001@0_G]000`00000086;F021ReP02000000D0?93_00<0
000007JSkP1fXnh00`1fXnh00`000000WJoT09f_i00609f_i0030000002f]mX0][OJ0080][OJ0P00
00040<7Jk0050000003Ff=T0e]SI0=KHf@000000203Bi^@00`000000`loS0<??h`070<??h`030000
002j/=00^[3@00D0^[3@0`00000409jCb0<00000202PSL000`000000Z9K30:RF``030:RF``030000
003;[;/0bjbk0080bjbk00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0/0?ooo`009@3o
ool2000002/0oooo00D0000004h08P1>0280CP0R0000000505/1>@030000001N1Sh0GPHn00<0GPHn
00<0000005/2>@1K0ST00P1K0ST3000000H0TGF`00<00000089]/`22KK<00`22KK<00`000000LfRh
07=X^00207=X^0<000000`0_G]000`00000086;F021ReP02021ReP8000000`0lT>l00`000000MZ?^
07JSkP0407JSkP030000002M[n@0WJoT00D0WJoT00<000000;JgfP2f]mX00P0000070<7Jk0030000
003Ff=T0000000L0d^KT0P0000000`2mjO<000000<??h`070<??h`040000002j/=00^[3@0;Z`d0@0
000000@0WjKJ0000002NTlP0WY?80`00000209jCb0030000002PSL00X8g000H0X8g000<000000:RF
``2XU/<00P2XU/<00`000000bjbk0<^/^`040<^/^`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0;03oool002<0oooo0P00000/0?ooo`030000001>0280CP0R0080CP0R00<0000005/1>@1K
0CT00`1K0CT00`000000GPHn05h6?P0305h6?P030000001K0ST0F`8i008000000P2QPK400`000000
TGF`095e/004095e/00300000022KK<0PVfc00@0PVfc00<0000007=X^01cJ;P00P1cJ;P010000000
I6W300000000000202mNd0030000000PH]H086;F008086;F1P00000607JSkP030000002M[n@0WJoT
00@0WJoT0`00000:0<7Jk0030000003Bi^@0d^KT00@0d^KT0P0000040;gYl`0300000033cn<0`loS
00D0`loS1000000509nVfP<000001@2NTlP00`000000X8g00:2=`0070:2=`0040000002XU/<0Z9K3
000000L0bjbk0P00000>0?ooo`030000003oool0oooo02/0oooo000S0?ooo`800000:`3oool20000
00<0CP0R00<0000005/1>@1K0CT00`1K0CT00`000000GPHn05h6?P0305h6?P040000001K0ST00000
000000D0XH6a00<00000095e/02AMK000`2AMK000`000000PVfc089]/`04089]/`030000001cJ;P0
LfRh00<0LfRh00<0000006AY``1TJL<00`000005021ReP040000000[NND0:gWU02]ii@D000000P1f
Xnh00`000000WJoT09f_i00400000080UL_j00<000000<7Jk031f^`01P31f^`2000000030;W]m@00
000000000080d^KT0P0000070;gYl`0300000033cn<0`loS00@000000P2N`_8010000000WjKJ09nV
fP2OY]X30000000309nVfP000000WY?800H0WY?800<000000:2=`02PSL001P2PSL0010000000Z9K3
0:RF``0000060<^/^`040000003Q_;80hKbb000000h0oooo00<000000?ooo`3oool0:P3oool002<0
oooo0`00000Y0?ooo`800000101>02800`000000F`4i05/1>@0305/1>@030000001N1Sh0GPHn0080
GPHn0`0000070:61/@030000002AMK00TGF`00<0TGF`00<00000089]/`22KK<01022KK<00`000000
LfRh07=X^00307=X^0030000001TJL<0I6W30080I6W30`000003021ReP030000000[NND0:gWU00<0
:gWU00<0000005RSmP1HXoH01@00000709G;nP0300000031f^`0`M[/00<0`M[/0P0000050;W]m@80
00002@2mjO<3000000H0W/;b00@0000009nVfP00000000001@2OY]X00`000000WY?809jCb00409jC
b0800000202PSL02000000L0bjbk00@000000>6l/P3Q_;8000003@3oool2000002`0oooo000R0?oo
o`050000003oool0oooo0?ooo`0000009`3oool00`0000004P000000000404h08P030000001K0CT0
F`4i00<0F`4i00<0000005h6?P1N1Sh00P0000000`32Ykh00000000000070:61/@030000002AMK00
TGF`00@0TGF`00<00000089]/`22KK<00`22KK<00`000000LfRh07=X^00307=X^0030000001TJL<0
I6W300<0I6W300<0000005Qcd`0000001000000502]ii@030000001HXoH0F:?f00<0F:?f00<00000
09G;nP2EboX01P2EboX00`000000`M[/0<7Jk002000000H0^Nge0P0000000`2TkOP000000;gYl`05
0;gYl`8000000P2Ffoh00`000000W/;b09k2lP0309k2lP<000001`2OY]X00`000000WY?809jCb005
09jCb08000001`2PSL000`000000bjbk0<^/^`050<^/^`030000003Q_;80hKbb0080hKbb00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0Y0?ooo`003`3oool2000000@0oooo0P0000040?oo
o`8000001@3oool2000000<0oooo00<000000?ooo`3oool0903oool2000000@0CP0R00<0000005/1
>@1K0CT00`1K0CT010000000GPHn0000000000020<:W_P030000002bT;<0000000L0XH6a00<00000
095e/02AMK00102AMK000`000000PVfc089]/`04089]/`030000001cJ;P0LfRh00<0LfRh00<00000
06AY``1TJL<00`1TJL<00`000000F7?C05Qcd`0205Qcd`<000000`0[NND00`000000F:?f05RSmP04
05RSmP030000002EboX0UL_j00D0UL_j0`0000060;W]m@800000102TkOP00`000000_NWc0;gYl`03
000000@0U]_n00<0000009k2lP2N`_800`00000209k2lP030000002OY]X0WjKJ00D0WjKJ00<00000
09jCb02NTlP01@2NTlP2000000D0X8g00`0000070<^/^`030000003Q_;80hKbb00<0hKbb00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0X0?ooo`003P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0R0?ooo`030000000B0000000000@0CP0R00<0000005/1>@1K0CT00P1K0CT300000080`ZNn0P00
00030;:@/`030000002QPK40XH6a00@0XH6a00<00000095e/02AMK00102AMK000`000000PVfc089]
/`04089]/`030000001cJ;P0LfRh00<0LfRh00<0000006AY``1TJL<00`1TJL<00`000000F7?C05Qc
d`0405Qcd`H000001P1HXoH00`000000UL_j09G;nP0400000080S=[o0P0000030;W]m@8000001P2T
kOP3000000L0U]_n0`00000609k2lP030000002OY]X0WjKJ00D0WjKJ00<0000009jCb02NTlP0102N
TlP00`000000X8g0000000020:2=`08000000`2YVLD00`000000bjbk0<^/^`030<^/^`030000003Q
_;80hKbb00@0hKbb0P00000=0?ooo`030000003oool0oooo02P0oooo000>0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0200oooo00<00000018000000000101>02800`000000F`4i00000003000000050=>d^`00
0000`ZNn0<:W_P0000001@2bT;<00`000000XH6a0:61/@050:61/@030000002AMK00TGF`00@0TGF`
00<00000089]/`22KK<00`22KK<00`000000LfRh07=X^00407=X^0030000001TJL<0I6W300<0I6W3
00<0000005Qcd`1HLm<00`1HLm<00`000000E8cY05B<j@0205B<j@X00000202<f_l3000000@0Y>gh
10000002093To08000000`2Ffoh30000000309KKoP000000W/;b00H0W/;b00<0000009nVfP2OY]X0
1@2OY]X00`000000WY?809jCb00509jCb0040000002PSL000000000000D0ZIW500<000000<^/^`3;
[;/00`3;[;/00`000000hKbb0>6l/P030>6l/P030000003^b:`0000000h0oooo00<000000?ooo`3o
ool09`3oool000P0oooo100000020?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`80
00001P3oool00`000000oooo0?ooo`0N0?ooo`040000000B00004P00000000<0CP0R0`0000050=>d
^`0300000032Ykh0000000H0/Y2c00<000000:61/@2QPK401@2QPK400`000000TGF`095e/004095e
/00300000022KK<0PVfc00<0PVfc00<0000007=X^01cJ;P0101cJ;P00`000000I6W306AY``0306AY
``030000001HLm<0F7?C00@0F7?C00<0000005B<j@1DS>T00`1DS>T00`000000I;?k06Bcn`0406Bc
n`8000000`2<f_l4000000<0Sn7m10000008093To1@00000102OY]X010000000WY?809jCb02NTlP5
000000030:VIa@000000ZIW500D0ZIW500D000000<^/^`3;[;/0bjbk000000060>6l/P040000003^
b:`0k/R/000000`0oooo00<000000?ooo`000000:03oool000h0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
703oool0100000004P0001800000000204h08P8000002@3C];/00`000000/Y2c0;:@/`050;:@/`03
0000002QPK40XH6a00D0XH6a00<00000095e/02AMK00102AMK000`000000PVfc089]/`04089]/`03
0000001cJ;P0LfRh00<0LfRh00<0000006AY``1TJL<0101TJL<00`000000F7?C05Qcd`0405Qcd`03
0000001DS>T0E8cY00<0E8cY0P00000406Bcn`D000001P2?hOd200000080W>Cm0P000003093To0@0
00000P24eOl00`000000Ikgn06NmoP0406NmoP030000001WY_D0IjKe00D0IjKe00<0000007RFh`1h
U^<02000000308nAd@040000002YVLD0ZIW5000000H0ZIW500D000000<^/^`3;[;/0bjbk00000005
0>6l/P050000003^b:`0k/R/0>k8[00000003P3oool00`000000oooo0?ooo`0V0?ooo`003`3oool2
000000X0oooo0`0000030?ooo`8000002@3oool2000001/0oooo00@000000180000B00004P001000
00090=>d^`8000001`2bT;<00`000000XH6a0:61/@050:61/@030000002AMK00TGF`00@0TGF`00<0
0000089]/`22KK<01022KK<00`000000LfRh07=X^00407=X^0030000001TJL<0I6W300<0I6W300<0
000005Qcd`1HLm<0101HLm<00`000000E8cY05B<j@0205B<j@L000001029b?d2000000<0Sn7m0P00
000609cTo@@000001P24eOl2000000D0Ikgn00<0000006NVm@1WY_D0101WY_D00`000000N9KS07RF
h`0407RFh`030000002?TM40Si7A00D0Si7A00@000000:VIa@2YVLD000001P2YVLD00`000000bjbk
000000060>6l/P030000003^b:`0k/R/0080k/R/00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0U0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo0P00
0002018000<0000000@0glO10000003O`;T000001`3C];/010000000aJBh0<FT^00000070;:@/`03
0000002QPK40XH6a00@0XH6a00<00000095e/02AMK001@2AMK0010000000PVfc089]/`22KK<K0000
00@0QjGX00<0000008W8o@29b?d01P29b?d3000000@0W>Cm1@0000000`2[goT000000000000508CE
o`L000000P1W_Oh00`000000IjKe06NVm@0406NVm@030000001hU^<0N9KS00@0N9KS00<0000008nA
d@2?TM40102?TM401@000000ZIW50:VIa@2YVLD0000000D0ZIW500<000000<^/^`0000001@3Q_;80
0`000000k/R/0>k8[0030>k8[08000003P3oool00`000000oooo0?ooo`0T0?ooo`008@3oool20000
00`0oooo00<000000?ooo`3oool0503oool5000000@0glO100<000000=o0^@0000001P3C];/01@00
0000aJBh0<FT^035Y;P0000000L0/Y2c00<000000:61/@2QPK401@2QPK400`000000TGF`095e/003
095e/0D000000P2>LJh00`000000RW>c08Yc/`0408Yc/`0300000027N[h0QgZn00@0QgZn00<00000
08J9c`26RLl01@26RLl00`000000QjGX08NUj00508NUj08000000P29b?d4000000<0[=?e1P000006
0:_On@D00000101oaOd00`000000AIke04FNm@05000000@0IjKe00<0000007RFh`1hU^<0101hU^<0
0`000000Si7A08nAd@0508nAd@040000002YVLD0ZIW5000000H0ZIW500<000000>6l/P3Q_;80103Q
_;800`000000k/R/0>k8[0020>k8[0030000003fdZP0000000h0oooo00<000000?ooo`3oool0903o
ool00240oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`<000001P3Oal40
1@000000gl2i0=o0^@3O`;T0000000@0dkBk00<000000<FT^035Y;P00P35Y;P00`000000/Y2c0;:@
/`050;:@/`030000002QPK40XH6a00D0XH6a00<00000095e/00000000`0000000`2CLj`0000008ia
[P0508ia[P030000002:Lk<0RW>c00@0RW>c00<0000008Mj_P27N[h01027N[h00`000000QXW?08J9
c`0508J9c`0300000027YNP0QjGX00D0QjGX0`0000070:cCm@@000001P2[goT200000080/]Gb00<0
000007o5o@1oaOd01@1oaOd00`000000AIke04FNm@0304FNm@<000000`1WY_D00`000000N9KS07RF
h`0307RFh`030000002?TM40Si7A00D0Si7A00D000000:VIa@2YVLD0ZIW5000000050:VIa@030000
003Q_;80hKbb00<0hKbb00<000000>k8[03^b:`00`3^b:`010000000m]:X0?KBZ000000=0?ooo`80
00001`3oool2000000@0oooo0P0000030?ooo`@000003`3oool00240oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0?0?ooo`8000000P2Ue_T00`000000glO10=o7`@030=o7`@030000
003O`;T0gl2i0080gl2i00<000000=>d^`3C];/00P3C];/00`000000aJBh0<FT^0030<FT^0030000
002bT;<0/Y2c00@0/Y2c00<000000:61/@2QPK40102QPK43000000D0Tg>/00<0000008ia[P2>LJh0
102>LJh00`000000RW>c08Yc/`0408Yc/`0300000027N[h0QgZn00@0QgZn00<0000008J9c`26RLl0
1@26RLl00`000000QjGX08NUj00308NUj08000000P2]]]l00`000000[=?e0:cCm@030:cCm@<00000
0`31e>P00`000000Zmoi0:_On@03000000D0/]Gb00<0000007o5o@1oaOd00P1oaOd5000000@0AIke
00<0000002n2j@0000000`00000607RFh`030000002?TM40Si7A00@0Si7A00<000000:VIa@2YVLD0
0P2YVLD00`000000ZIW50:VIa@03000000D0hKbb00<000000>k8[03^b:`00P3^b:`00`000000m]:X
0?KBZ0020?KBZ0030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo0100oooo000Q0?ooo`8000003`3oool00`000000oooo
0?ooo`0<0?ooo`8000000`2Ue_T00`000000glO10=o7`@040=o7`@030000003O`;T0gl2i00<0gl2i
00@000000=>d^`3C];/000001P35Y;P00`000000/Y2c0;:@/`050;:@/`040000002QPK40XH6a0:61
/@80000000<0VgZ]0000002CLj`01P2CLj`00`000000SW6^08ia[P0308ia[P030000002:Lk<0RW>c
00@0RW>c00<0000008Mj_P27N[h01@27N[h00`000000QXW?08J9c`0508J9c`0300000027YNP0QjGX
008000001@2]]]l00`000000[=?e00000003000000H0`MCX0P0000080;;ElPD000001021]OH50000
000304FNm@000000;h;Y0080;h;Y0`00000407RFh`030000002?TM40Si7A00D0Si7A00<000000:VI
a@2YVLD00P2YVLD2000000<0]:W=00D000000>6l/P3Q_;80hKbb000000050>k8[0030000003fdZP0
m]:X0080m]:X0P00000=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00P0oooo0`0000040:GFn@030000003Oal40glO100@0glO100<000000=o0^@3O`;T0103O`;T0
0`000000dkBk000000070<FT^0030000002bT;<0/Y2c00D0/Y2c00@000000:61/@00000000000`2K
NZd00`000000Tg>/09=c[00509=c[0030000002>LJh0SW6^00<0SW6^00<0000008Yc/`2:Lk<01@2:
Lk<00`000000QgZn08Mj_P0408Mj_P0300000026RLl0QXW?00D0QXW?0`0000060:ffg`<0000000<0
[=?e0000000000001P31e>P00`000000bm3N000000060;;ElP8000000P2ebNT00`000000PKGf086e
mP05086emP040000000iRnd0>H_]03V;k@<00000100_P^T50000000307RFh`000000Si7A00D0Si7A
00@000000:VIa@2YVLD0ZIW50P0000040;BYc@050000003Q_;80hKbb0>6l/P0000001@3^b:`01`00
0000m]:X0?KBZ03fdZP000000?WLZ@0000003P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool03P3oool000P0oooo0P0000040?ooo`8000000`3o
ool4000000<0oooo0P0000040?ooo`8000004P3oool00`000000oooo0?ooo`030?ooo`@000000`2L
R;d200000080YMKi00<000000=o7`@3Oal400`3Oal400`000000gl2i0=o0^@060=o0^@0300000035
Y;P0aJBh00L0aJBh00<000000;:@/`2bT;<0102bT;<2000000H0VgZ]00<0000009=c[02CLj`0102C
Lj`00`000000SW6^08ia[P0408ia[P030000002:Lk<0RW>c00@0RW>c00<0000008Mj_P27N[h01@27
N[h00`000000QXW?08J9c`0208J9c`8000000P2XW</010000000[KKO0:ffg`2]]]l3000000<0[KKO
00<000000<7Dj031e>P01@31e>P010000000bm3N0<_@gP3;d=h200000080/]Gb0P0000050;G9j@03
00000021]OH0PKGf00D0PKGf00<0000003V;k@0iRnd00`0iRnd200000080;h;Y00<0000004J0i016
P>@00P16P>@5000000@0Si7A0`0000020;BYc@030000002dZLd0]:W=0080]:W=00<000000>6l/P00
00001@3^b:`00`000000m]:X0?KBZ0020?KBZ0040000003ig:T0nMbY000000h0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000003`3o
ool000L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool04P3oool00`000000oooo00000002000000T0W8Rm
0P0000060=o7`@030000003O`;T0gl2i00D0gl2i0P0000090<FT^0030000002bT;<0/Y2c0080/Y2c
0`00000709]j[@030000002CLj`0Tg>/00@0Tg>/00<0000008ia[P2>LJh0102>LJh00`000000RW>c
08Yc/`0508Yc/`0300000027N[h0QgZn00@0QgZn00<0000008J9c`26RLl00P0000040:RLb`@00000
102]]]l2000000030<BoeP000000`MCX00<0`MCX0P0000060<_@gP800000202ebNT00`000000PKGf
086emP02086emPD000000`0iRnd01P00000036SK000000000000;h;Y000000D0AX3T00<0000007^B
gP1kT]h01@0000050;BYc@070000002dZLd0]:W=0;BYc@000000hKbb000000050>k8[0050000003f
dZP0m]:X0?KBZ00000000`3ig:T00`000000oooo0?ooo`0:0?ooo`<00000103oool2000000X0oooo
0P00000@0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`3oool0oooo0000000C0?ooo`<0000000<0TfnW0000002LR;d02@2LR;d00`000000
f;Vj000000040=o7`@030000003O`;T0gl2i00H0gl2i00<000000=Vn_P0000002035Y;P01@000000
/Y2c0;:@/`2bT;<000000080YHFb00<0000009]j[@2KNZd01@2KNZd00`000000Tg>/09=c[00409=c
[0030000002>LJh0SW6^00@0SW6^00<0000008Yc/`2:Lk<01@2:Lk<00`000000QgZn08Mj_P0408Mj
_P<00000102XW</4000000D0[KKO00<000000<BoeP34_mH00P34_mH2000000030<7Dj0000000bm3N
00H0bm3N00<000000<k<e`000000202ebNT5000000@0QJW]0`00000203V;k@030000000<J=/036SK
008000001@16P>@00`000000Ni;N07^BgP0507^BgP030000002dZLd0]:W=00<0]:W=00D000000;BY
c@2dZLd0]:W=000000060>k8[0050000003fdZP0m]:X0?KBZ0000000103ig:T00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01l0oooo00000`3oool000000000000200000080oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`800000103oool2000000l0oooo0`00
000509=_Y`030000002LR;d0W8Rm00L0W8Rm00@000000=Ri^P3H^KX000000P3Oal400`000000gl2i
0=o0^@060=o0^@040000003I_[h0fKjn000000T0aJBh0`0000040:F5/P030000002KNZd0VgZ]00@0
VgZ]00<0000009=c[02CLj`0102CLj`00`000000SW6^08ia[P0508ia[P030000002:Lk<0RW>c00@0
RW>c00<0000008Mj_P27N[h00P27N[h2000000040::<_0000000Z9c;0:RLb`<00000102XW</01@00
0000[KKO0:ffg`2]]]l0000000L0a;oF00<000000<_@gP3;d=h01@3;d=h01@000000c/cG0<k<e`3>
c=L0000000D0]LWY0P0000020;Bnh@0300000025ZNd0QJW]00@0QJW]00<0000003n4j00oQ>P00`00
000400aXf`0300000016P>@0AX3T00<0AX3T00<0000007^BgP1kT]h0101kT]h00`000000]:W=0;BY
c@030;BYc@050000002dZLd0]:W=0;BYc@0000001@3^b:`00`000000m]:X0?KBZ0020?KBZ0030000
003ig:T0nMbY0080nMbY0P00000>0?ooo`030000003oool0oooo01h0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo0P0000000`2@JJ40000009=_Y`0509=_Y`030000002LR;d0W8Rm00H0
W8Rm00<000000=Ri^P3H^KX00P3H^KX00`000000glO1000000070=o0^@030000003I_[h0fKjn0080
fKjn00<000000<FT^035Y;P01P35Y;P00`000000YHFb0:F5/P040:F5/P030000002KNZd0VgZ]00@0
VgZ]00<0000009=c[02CLj`01@2CLj`00`000000SW6^08ia[P0408ia[P030000002:Lk<0RW>c00D0
RW>c00@0000008Mj_P0000000000102RS;`2000000L0Z9c;00@000000:ffg`00000000001`34_mH0
0`000000dLG>000000040<_@gP8000001@3>c=L00`000000]LWY0;G9j@02000000@0];kQ00<00000
08FYk@25ZNd01@25ZNd010000000?hCX03n4j00oQ>P2000000@036SK0P00000304J0i0030000001k
T]h0Ni;N00D0Ni;N00<000000;BYc@2dZLd00`2dZLd3000000030;nof@000000k/R/00<0k/R/00D0
00000?KBZ03fdZP0m]:X000000040?WLZ@030000003hik00000000h0oooo00<000000?ooo`3oool0
7P3oool000P0oooo0P00000:0?ooo`800000103oool300000080oooo0P00000<0?ooo`8000000`2@
JJ400`000000TfnW09=_Y`0409=_Y`030000002LR;d0W8Rm00D0W8Rm00<000000=Ri^P3H^KX0103H
^KX00`000000gl2i0=o0^@050=o0^@030000003I_[h0fKjn00<0fKjn00<000000<FT^035Y;P01035
Y;P3000000H0YHFb00<0000009]j[@2KNZd0102KNZd00`000000Tg>/09=c[00509=c[0030000002>
LJh0SW6^00@0SW6^00<0000008Yc/`2:Lk<0102:Lk<3000000<0XXbl100000090:RLb`0300000034
_mH0a;oF00H0a;oF00@000000=75cP3AaLh000000`3;d=h00`000000c/cG0<k<e`060<k<e`800000
1`2d_^400`000000QJW]08FYk@0408FYk@030000000oQ>P0?hCX00<0?hCX0P00000300aXf`<00000
0P16P>@00`000000Ni;N07^BgP0407^BgP030000002dZLd0]:W=00<0]:W=0P0000020;nof@050000
003^b:`0k/R/0>k8[0000000103fdZP00`000000nMbY0?WLZ@020?WLZ@040000003hik00n>N`0000
00h0oooo00<000000?ooo`3oool07@3oool001l0oooo00<000000?ooo`3oool0203oool3000000D0
T6VQ00<0000009=_Y`2CKjL01@2CKjL00`000000W8Rm09b8_@0309b8_@030000003H^KX0f;Vj00@0
f;Vj00<000000>S=^P0000001P3O`;T00`000000fKjn0=Vn_P040=Vn_P0300000035Y;P0aJBh0080
aJBh00@000000;>I_02cVK`000001P2UQK800`000000VgZ]09]j[@0509]j[@030000002CLj`0Tg>/
00@0Tg>/00<0000008ia[P2>LJh0102>LJh00`000000RW>c08Yc/`0208Yc/`80000000<0WX6c0000
002RS;`00`0000040::<_0030000002XW</0Z9c;00D0Z9c;00<000000;n/a`0000001P34_mH00`00
0000dLG>0=75cP020=75cP030000003;d=h0000000P0c/cG00<000000<k7d`000000202d_^490000
00<0?hCX00H0000000=Pe`000000000000aXf`00000201MZg@<000001`1kT]h01`000000]:W=0;BY
c@2dZLd000000;nof@0000000`2o_mT010000000k/R/0>k8[00000040?KBZ0050000003ig:T0nMbY
0?WLZ@000000103hik000`000000oooo0?ooo`0:0?ooo`030000003oool0000001h0oooo000O0?oo
o`030000003oool0oooo00D0oooo0`0000000`2CKjL00000091YX@06091YX@030000002CKjL0TfnW
00@0TfnW00<0000009b8_@2LR;d00`2LR;d00`000000f;Vj0=Ri^P040=Ri^P040000003XcKX0j<fj
000000@0gl2i00<000000=Vn_P3I_[h01@3I_[h01@000000aJBh0<FT^035Y;P0000000@0/iVl00<0
00000:F5/P2UQK80102UQK800`000000VgZ]09]j[@0409]j[@030000002CLj`0Tg>/00@0Tg>/00<0
000008ia[P2>LJh01@2>LJh010000000RW>c00000000000209j1/`<000001`2RS;`00`000000Z9c;
0:RLb`040:RLb`050000002o[<L0_jc70;n/a`0000001034_mH00`000000dLG>0=75cP040=75cP03
0000003>c=L0c/cG00H0c/cG00@000000<k7d`3>am<000001P2d_^42000000030;:fg0000000RZ?T
00D0RZ?T1P00000200=Pe`<000000`0GJ]d5000000<0Ni;N00@000000;BYc@00000000000`2o_mT0
1`000000_koI0;nof@2o_mT000000>k8[00000000`3fdZP00`000000nMbY0?WLZ@020?WLZ@070000
003hik00n>N`0?SW/0000000l??00000000=0?ooo`030000003oool0oooo01`0oooo000O0?ooo`80
0000103oool2000000@0TfnW00<00000091YX@2@JJ401@2@JJ400`000000TfnW09=_Y`0509=_Y`05
0000002LR;d0W8Rm09b8_@0000001P3H^KX00`000000j<fj0>S=^P020>S=^P040000003O`;T0gl2i
000000T0fKjn0`0000050;>I_0030000002UQK80YHFb00@0YHFb00<0000009]j[@2KNZd0102KNZd0
0`000000Tg>/09=c[00409=c[0030000002>LJh0SW6^00@0SW6^0`000000102NPK<0000000000000
000209j1/`030000002RS;`0XXbl00H0XXbl00@000000:RLb`2XW</0Z9c;0P0000040;n/a`050000
0034_mH0a;oF0<BoeP0000001P3AaLh00`000000f<S:000000050<k<e`800000103>am<010000000
];kQ0;Bnh@2d_^42000000<0/[KL00<0000008ZSi02:Xn@01@2:Xn@010000000DHOV0567iP1AQnH2
000000<00f3G0P00000401MZg@030000001RU>/0HYC[00D000001P2o_mT00`000000_koI0;nof@02
000000@0m]:X00D000000?WLZ@3ig:T0nMbY000000040?SW/0030000003`ll00000000h0oooo00<0
00000?ooo`3oool06`3oool001l0oooo00@000000?ooo`3oool0oooo0`00000509=_Y`030000002@
JJ40T6VQ00D0T6VQ00<0000009=_Y`2CKjL01@2CKjL010000000W8Rm09b8_@0000070=Ri^P030000
003XcKX0j<fj00<0j<fj00<000000=o0^@0000002@3I_[h00`000000/iVl0;>I_0050;>I_0030000
002UQK80YHFb00@0YHFb00<0000009]j[@2KNZd0102KNZd00`000000Tg>/09=c[00509=c[0040000
002>LJh0SW6^08ia[P80000000@0VW^_00000000000000001@2NPK<00`000000XXbl0::<_0060::<
_0040000002XW</0Z9c;000000L0_jc700<000000<BoeP0000001P3AaLh01@000000f<S:0=S8bP3H
b<X0000000<0c/cG00<000000<k7d`3>am<0103>am<010000000];kQ0000000000060;:fg0030000
002:Xn@0RZ?T00@0RZ?T00<000000567iP1AQnH00`1AQnH2000000<00f3G0P00000201MZg@030000
001RU>/0HYC[00@0HYC[00<000000;nof@2o_mT01@2o_mT010000000_koI0;nof@0000030?KBZ003
0000003ig:T0nMbY0080nMbY00D000000?SW/03hik00n>N`000000030?3c`0030000003oool0oooo
00`0oooo00<000000?ooo`3oool06P3oool001l0oooo100000020:Roj`030000002CKjL0TfnW00@0
TfnW00<00000091YX@2@JJ40102@JJ400`000000TfnW09=_Y`0509=_Y`030000002LR;d0000000L0
f;Vj00<000000>S=^P3XcKX01@3XcKX00`000000fKjn0=Vn_P070=Vn_P8000001`2cVK`00`000000
YHFb0:F5/P040:F5/P030000002KNZd0VgZ]00@0VgZ]00<0000009=c[02CLj`01@2CLj`00`000000
SW6^000000040000000309Yk[`000000WX6c00H0WX6c00<000000::<_02RS;`01P2RS;`2000000T0
_jc700<000000=75cP3AaLh0103AaLh00`000000f<S:0=S8bP030=S8bP030000003>c=L0000000P0
c/OC00<000000;:fg02b]]`01`2b]]`00`000000RZ?T08ZSi00408ZSi0030000001AQnH0DHOV00<0
DHOV0`0000000`03H=L00000001Me0020000000301MZg@000000HYC[00D0HYC[00<000000;nof@2o
_mT0102o_mT3000000050<OIi`000000m]:X0?KBZ00000000`3ig:T00`000000n>N`0?SW/0020?SW
/0050000003`ll00l??00?3c`00000003P3oool00`000000oooo0?ooo`0J0?ooo`007P3oool30000
00@0Z;o[00<0000009=_Y`2CKjL0102CKjL00`000000T6VQ091YX@04091YX@030000002CKjL0TfnW
00H0TfnW0P0000070=Ri^P030000003XcKX0j<fj00@0j<fj00<000000>cOa@0000001`3I_[h01000
0000bKc>0<VlcP0000060;>I_0030000002UQK80YHFb00D0YHFb00<0000009]j[@2KNZd00`2KNZd0
0`000000Tg>/09=c[00409=c[0D00000102JNjl00`000000WX6c09j1/`0509j1/`030000002RS;`0
XXbl00H0XXbl00<000000;n/a`2o[<L01`2o[<L00`000000d;W4000000040=75cP030000003Hb<X0
f<S:00D0f<S:00<000000<k7d`3>am<01@3>am<2000000030<_3d`000000/[KL00L0/[KL00<00000
08ZSi02:Xn@00P2:Xn@5000000<0DHOV00<00000019Yg00BJM`00`000002001Me08000001P1RU>/0
0`000000_koI0;nof@040;nof@8000000P37fNL010000000m]:X0?KBZ00000030?WLZ@050000003h
ik00n>N`0?SW/00000001@3`ll000`000000oooo0?ooo`0:0?ooo`030000003oool0000001/0oooo
000H0?ooo`800000103oool00`000000oooo000000050:Roj`030000002CKjL0TfnW00<0TfnW00<0
0000091YX@2@JJ40102@JJ400`000000TfnW09=_Y`0609=_Y`030000003H^KX0f;Vj00D0f;Vj00<0
00000>S=^P3XcKX01@3XcKX010000000k=o50>cOa@0000040=Vn_P8000000`39_<h00`000000/iVl
0;>I_0050;>I_0030000002UQK80YHFb00@0YHFb00<0000009]j[@2KNZd0102KNZd010000000Tg>/
09=c[02CLj`4000000L0VW^_00<0000009j1/`2NPK<01@2NPK<00`000000XXbl0::<_0050::<_003
0000002hWKd0000000L0_jc700@000000=2ia03@^L@00000103AaLh00`000000f<S:0=S8bP040=S8
bP030000003KblT0000000D0c/OC00<000000<_3d`3;`m<00P3;`m<00`000000/[KL0;:fg0050;:f
g0D000000`2AX=h00`000000IhoU00000004000000<04VWL0P000003001Me08000001@1RU>/01000
0000_koI0;nof@2o_mT200000080amWW00<000000<OIi`37fNL00P0000030?WLZ@050000003hik00
n>N`0?SW/00000001@3`ll000`000000fo_K0000000=0?ooo`030000003oool0oooo01T0oooo000G
0?ooo`040000003oool0oooo000000<0oooo0P0000000`3oool00000000000030:Roj`030000002C
KjL0TfnW00<0TfnW00<00000091YX@2@JJ401@2@JJ400`000000TfnW09=_Y`0409=_Y`030000003?
[kT0000000H0f;Vj00<000000>S=^P3XcKX0103XcKX01@000000k=o50>cOa@3/glD0000000<0fKjn
00<000000<VlcP39_<h01039_<h00`000000/iVl0;>I_0040;>I_0030000002UQK80YHFb00@0YHFb
00<0000009]j[@2KNZd0102KNZd00`000000Tg>/00000002000000<0V7R]00<0000009Yk[`2JNjl0
102JNjl00`000000WX6c09j1/`0609j1/`030000002RS;`0XXbl00<0XXbl00@000000;RM_@2hWKd0
00001P2o[<L00`000000d;W40=2ia0020=2ia0040000003AaLh0dLG>000000H0f<S:00@000000=_;
b@3KblT00000103>am<00`000000bl?C0<_3d`030<_3d`030000002b]]`0/[KL00<0/[KL0P000000
0`2_/=P00000096PgP06096PgP030000001WSnD0IhoU0080IhoU0`000003019Yg08000000P00GM@5
0000000306:Dj`000000_koI008000001@37fNL010000000amWW0<OIi`0000030?WLZ@050000003h
ik00n>N`0?SW/0000000103`ll0010000000fo_K0=_kf`00000>0?ooo`030000003oool0oooo01P0
oooo000G0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000
Z;o[0:Roj`00000509=_Y`030000002@JJ40T6VQ00D0T6VQ00<0000009=_Y`2CKjL0102CKjL01000
0000cjni0<n_^@0000040=Ri^P030000003XcKX0j<fj00@0j<fj00<000000>cOa@3/glD00`3/glD0
0`000000fKjn000000070<VlcP030000002cVK`0/iVl00@0/iVl00<000000:F5/P2UQK80102UQK80
0`000000VgZ]09]j[@0309]j[@@000001@2HN:d00`000000VW^_09Yk[`0509Yk[`030000002NPK<0
WX6c00D0WX6c00@000000::<_02RS;`0XXbl0P0000040;RM_@030000002o[<L0_jc70080_jc700<0
00000=2ia03@^L@00`3@^L@00`000000dLG>000000060=S8bP030000003KblT0fl_90080fl_900@0
00000<k7d`00000000001`3;`m<00`000000/[KL0;:fg002000000@0[k3H00<00000096PgP2AX=h0
102AX=h00`000000IhoU06N?i@0406N?i@P0000000<005gD00000013Uo800P13Uo83000000L0amWW
0`0000001035l>l000000000000000030?SW/0040000003`ll00l??00?3c`0800000103Knm/00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01L0oooo000G0?ooo`040000003oool0oooo0000
00<0oooo0P0000040?ooo`030000002X_n/0000000D0TfnW00<00000091YX@2@JJ401@2@JJ400`00
0000TfnW09=_Y`0309=_Y`050000003?[kT0cjni0<n_^@000000103H^KX00`000000j<fj0>S=^P03
0>S=^P030000003/glD0k=o500D0k=o500<000000<VlcP39_<h01P39_<h00`000000/iVl0;>I_004
0;>I_0030000002UQK80YHFb00D0YHFb00<0000009]j[@0000001000000709Qh[@030000002JNjl0
VW^_00D0VW^_00<0000009j1/`2NPK<01@2NPK<010000000XXbl0::<_00000060;RM_@030000002o
[<L0_jc70080_jc700<000000=2ia03@^L@0103@^L@00`000000f<S:0=S8bP040=S8bP030000003K
blT0fl_900@0fl_900<000000<_3d`3;`m<0203;`m<2000000H0[k3H00<00000096PgP2AX=h01@2A
X=h00`000000IhoU06N?i@0306N?i@030000000cONH0<ggV0080<ggV1P00000504>GlP0300000037
fNL0amWW00<0amWW0`0000040<G`k`8000000P3hik0010000000l??00?3c`00000060=_kf`800000
303oool2000000P0oooo0P0000040?ooo`8000001@3oool300000040oooo000G0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000Z;o[0000000509=_Y`030000
002@JJ40T6VQ00D0T6VQ00<0000009=_Y`2CKjL00P2CKjL00`000000cjni0<n_^@030<n_^@040000
003H^KX0f;Vj000000H0j<fj00<000000>cOa@3/glD0103/glD00`000000f_CP000000080<VlcP03
0000002cVK`0/iVl00@0/iVl00<000000:F5/P2UQK800`2UQK84000000<0UgV_00<0000009Qh[@2H
N:d01@2HN:d00`000000VW^_09Yk[`0509Yk[`030000002NPK<0WX6c00H0WX6c0P0000080;RM_@04
0000002o[<L0_jc7000000H0d;W400<000000=_4``0000001@3Hb<X00`000000fl_90=_;b@030=_;
b@030000003Kc/`0000000L0bl?C0P0000000`36_m@000000:n`f0060:n`f0030000002AX=h0TJ3N
00@0TJ3N00<0000006N?i@1WSnD0101WSnD00`000000<ggV03=miP0303=miPP000000P13Uo800`00
0000amWW0<OIi`02000000<0aO3_00@000000<G`k`00000000000P2an>d200000080l??000<00000
0=_kf`3Knm/00`3Knm/200000080[nkg00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000/0oooo0@0000010?ooo`40oooo000H0?ooo`8000000`3oool0
0`000000oooo0?ooo`050?ooo`8000001@2CKjL00`000000T6VQ091YX@05091YX@050000002CKjL0
TfnW09=_Y`0000001`3?[kT00`000000f;Vj000000050>S=^P030000003/glD0k=o500@0k=o500D0
00000=[dh03Jm>00f_CP000000070<VlcP030000002cVK`0/iVl00@0/iVl00<000000:F5/P000000
1@00000609Mi[`030000002HN:d0V7R]00D0V7R]00<0000009Yk[`2JNjl01@2JNjl00`000000WX6c
09j1/`0509j1/`030000002hWKd0^9fm00L0^9fm00<000000;n/a`0000001P3@^L@01@000000flC3
0=_4``3Ka<<0000000<0f<S:00<000000=_;b@3KblT00`3KblT01@000000flk<0=_>c03Kc/`00000
00D0bl?C00D000000<Joe036_m@0a[oD000000070:n`f0030000002AX=h0TJ3N0080TJ3N30000003
03=miP0300000009N>402GSQ00@0000000<0:Y[_0000000000000`0000050<G`k`8000000`2an>d2
0000000409Sbi@0000000000000000<0fo_K0P0000040:o^m`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?ooo`D000000@3oool001d0oooo0P00
00060?ooo`030000002X_n/0000000D0TfnW00<00000091YX@2@JJ40102@JJ401@000000TfnW09=_
Y`2CKjL0000000P0cjni00<000000>S=^P3XcKX00`3XcKX00`000000k=o50>cOa@040>cOa@030000
003Jm>00f_CP0080f_CP00<000000<VlcP39_<h01P39_<h010000000/iVl0;>I_02cVK`6000000<0
Ugjf00<0000009Mi[`2GNJl0102GNJl00`000000V7R]09Qh[@0509Qh[@030000002JNjl0VW^_00D0
VW^_00<0000009j1/`2NPK<00`2NPK<3000000X0^9fm00<000000=2ia03@^L@01@3@^L@00`000000
flC30=_4``020=_4``030000003Hb<X0000000H0fl_900D000000=_>c03Kc/`0flk<000000040<_3
d`0300000036_m@0a[oD00<0a[oD00<000000:n`f02_/=P0102_/=P5000000@0V:7K00<0000007jI
h`1nVN<0101nVN<6000000@02GSQ1@0000000`0ZV^l00000000000020<G`k`80000000<0/OS]0000
002an>d00P0000000`2Hl^D000000000000308W/j@<000001`2_k_L00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030000002X_n/0000000D0TfnW00<00000
091YX@2@JJ401@2@JJ400`000000TfnW000000080<n_^@030000003]gL80000000<0j<fj00<00000
0>cOa@3/glD0103/glD00`000000f_CP0=[dh0040=[dh00300000039_<h0bKc>0080bKc>2P000007
09Mn]P030000002GNJl0UgV_00<0UgV_00<0000009Qh[@2HN:d01@2HN:d00`000000VW^_09Yk[`05
09Yk[`030000002NPK<0WX6c0080WX6c00D000000;2B]`2`T[L0/9:g000000080;RM_@8000001P3@
^L@00`000000flC30=_4``040=_4``030000003KblT0fl_900@0fl_900<000000=_>c03Kc/`00`3K
c/`010000000bl?C0000000000060<Joe0030000002_/=P0[k3H00@0000000<0[:gH0000002HXM/0
1P2HXM/00`000000OYWS07jIh`0407jIh`030000001LU^h0G9K^0080G9K^1@00000200Uhh@800000
00<09:?Y0000000000000`0000030;7hk@80000000<0V?;U0000000000000`29k>T200000080SNSh
0P0000040:o^m`@000003@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`0000000P3oool001d0oooo0P0000070?ooo`8000001@2CKjL00`000000T6VQ
091YX@05091YX@8000002@3?[kT00`000000kMg20>gM`P02000000030>S=^P000000k=o500@0k=o5
00<000000=[dh03Jm>001@3Jm>05000000<0V:oW1000000309R<a@030000002GO[H0Ugjf00@0Ugjf
00<0000009Mi[`2GNJl00`2GNJl00`000000V7R]09Qh[@0509Qh[@030000002JNjl0VW^_00D0VW^_
00D0000009j1/`2NPK<0WX6c000000040;2B]`030000002hWKd0^9fm00D0^9fm00@000000<^__P3;
[kh00000103@^L@00`000000flC30=_4``040=_4``030000003Rcl@0000000@0fl_900<000000=_>
c03Kc/`01@3Kc/`00`000000a[oD0<Joe0070<Joe08000001P2/[MP00`000000V:7K09RQf`0509RQ
f`030000001nVN<0OYWS00@0OYWS00<0000005bFkP1LU^h00`1LU^h20000000303RKl`0000000000
00h000000`29k>T2000000D0SNSh1@00000407g8o`030000003oool0oooo00T0oooo0`0000040?oo
o`8000002`3oool200000080oooo000M0?ooo`030000003oool0oooo00H0oooo0P00000509=_Y`03
0000002@JJ40T6VQ00D0T6VQ0P0000080<n_^@030000003]gL80kMg200<0kMg20`0000030>cOa@03
0000003Jm>00f_CP00<0f_CP0`00000205S@j@040000002H[nL0V:oW09R_i`@000001@2HS<D00`00
0000Ugjf09Mn]P0409Mn]P030000002GNJl0UgV_00@0UgV_00<0000009Qh[@2HN:d01@2HN:d00`00
0000VW^_09Yk[`0509Yk[`<000001P2`T[L00`000000^9fm0;RM_@030;RM_@050000003;[kh0bjnn
0<^__P0000000`3@^L@00`000000flC30=_4``050=_4``040000003Rcl@0h/o400000080fl_900<0
00000=_>c03Kc/`01@3Kc/`00`000000f=3B000000060<Joe080000000<0_kgH0000002/[MP01@2/
[MP00`000000V:7K09RQf`0509RQf`030000001nVN<0OYWS00@0OYWS00<0000005bFkP1LU^h00P1L
U^h?000000@0Hloh1000000308gXn0@000000P2Hf_h00`000000OLSo07g8o`0407g8o`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool04`3oool001d0oooo00<000000?ooo`3oool01P3oool2
000000D0TfnW00<00000091YX@2@JJ401@2@JJ400`000000cjni0<n_^@060<n_^@030000003]gL80
kMg200<0kMg200@000000>Gl`@3Uo<40iOc13@00000205S@j@<000000`2H[nL00`000000V8c509R<
a@0309R<a@030000002GO[H0Ugjf00@0Ugjf00<0000009Mi[`2GNJl0102GNJl00`000000V7R]09Qh
[@0509Qh[@030000002JNjl0VW^_00D0VW^_00<000000;2B]`2`T[L01P2`T[L00`000000^9fm0;RM
_@020;RM_@030000003;[kh0bjnn00<0bjnn00@000000=2ia03@^L@000001P3Ka<<00`000000h/o4
0>;?a0020>;?a0030000003KblT0000000H0flk<00@000000=S@dP3Hd=8000001@36_m@01@000000
_kgH0;nmf02o_MP0000000L0[:gH00<0000009RQf`2HXM/0102HXM/<000000@0PZ__00<0000006nk
o@1_^od01@1_^od200000080Hloh1@0000000`2?gOh0000000000002000000H0V=[n1@00000307g8
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool04P3oool001`0oooo0`0000080?ooo`03
0000002CKjL0TfnW00<0TfnW00<00000091YX@2@JJ40102@JJ42000000P0cjni00<000000>gM`P3]
gL800P3]gL800`000000iOc10>Gl`@030>Gl`@@00000103Fcm<010000000c;S70<bha`3<^<L40000
00D0V:oW00<0000009R<a@2HS<D00`2HS<D00`000000Ugjf09Mn]P0309Mn]P030000002GNJl0UgV_
00@0UgV_00<0000009Qh[@2HN:d01@2HN:d00`000000VW^_09Yk[`0309Yk[`<000002@2`T[L01@00
0000^9fm0;RM_@2hWKd0000000D0bjnn00<000000=2ia00000001P3Ka<<00`000000h/o40>;?a004
0>;?a0030000003Kc/`0flk<00@0flk<00<000000=S@dP3Hd=800P3Hd=801@000000a[oD0<Joe036
_m@0000000D0_kgH00<000000:b]f02/[MP0102/[MP00`000000V:7K09RQf`0400000080WZGJ00<0
000009:Th@2BY>40102BY>400`000000PZ__08:[k`0508:[k`800000101_^od500000080Smgn1000
00020:_Im`8000000P2Hf_h400000080W/;b00<0000006JUm01VYO@01@00000=0?ooo`030000003o
ool0oooo0140oooo000L0?ooo`030000003oool0oooo00P0oooo0P00000409=_Y`030000002@JJ40
T6VQ00<0T6VQ00@000000;bT`@2lY<4000001P3?[kT00`000000kMg20>gM`P030>gM`P030000003U
o<40iOc10080iOc100<000000>Fm[@0000000P3W^jP2000000030=K?d`000000c;S700<000000P3<
^<L3000000@0V:oW00<0000009R<a@2HS<D00`2HS<D00`000000Ugjf09Mn]P0409Mn]P030000002G
NJl0UgV_00<0UgV_00<0000009Qh[@2HN:d01@2HN:d010000000VW^_09Yk[`2JNjl2000000<0Z8Vd
00<000000;2B]`2`T[L01P2`T[L010000000^9fm0;RM_@0000070<^__P030000003Ka<<0flC300@0
flC300<000000>;?a03Rcl@0103Rcl@00`000000i]W9000000040=_>c0030000003Hd=80f=3B00<0
f=3B00@000000<Joe000000000001`2o_MP00`000000[:gH0:b]f0030:b]f0<000001P2NYMX00`00
0000TZCQ09:Th@0409:Th@0300000022Znl0PZ__00H0PZ__1@00000409[;n0<00000102[fOL00`00
0000ZmWg0:_Im`03000000H0W/;b00<0000006JUm01VYO@01@1VYO@00`000000oooo0?ooo`090?oo
o`8000004`3oool000@0oooo0P0000040?ooo`8000000`3oool4000000<0oooo0P0000040?ooo`80
00002@3oool2000000D0TfnW00<00000091YX@2@JJ400P0000030;bT`@030000003?[kT0cjni00<0
cjni00<000000>gM`P3]gL800`3]gL8010000000iOc10>Gl`@3Uo<4200000080iKf]00<000000>Nk
Z03W^jP00P3W^jP3000000H0c;S70`00000309R_i`030000002HS<D0V8c500<0V8c500<0000009Mn
]P2GO[H0102GO[H00`000000UgV_09Mi[`0409Mi[`030000002HN:d0V7R]00D0V7R]0`0000050:R9
]0030000002`T[L0/9:g00L0/9:g0P0000070<^__P030000003J`<40000000D0flC300<000000>;?
a03Rcl@00`3Rcl@010000000i]W90>KIb@0000030=_>c0030000003Hd=80f=3B00D0f=3B00<00000
0;nmf02o_MP01`2o_MP00`000000[:gH0:b]f00300000080ZZcI00<0000009jUfP2NYMX01@2NYMX0
0`000000TZCQ09:Th@0409:Th@0400000022Znl0PZ__08:[k`@000000P2O^N/00`000000V/_h09[;
n00209[;n08000000P2bcNh00`000000ZmWg0:_Im`020:_Im`<000000P2ebNX00`000000W/;b09k2
lP0509k2lP030000001VYO@0IZGd00@0IZGd00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0@0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`090?ooo`030000002CKjL0TfnW00<0TfnW
00<00000091YX@0000001P2lY<400`000000cjni0<n_^@020<n_^@030000003]gL80kMg20080kMg2
00D000000>Gl`@3Uo<40iOc1000000030>Fm[@030000003W^jP0ik^X00D000001P3<^<L010000000
`j[00<>Z`033Z/0200000080V:oW00<0000009R<a@2HS<D00P2HS<D00`000000Ugjf09Mn]P0409Mn
]P030000002GNJl0UgV_00@0UgV_00<0000009Qh[@2HN:d01@2HN:d00`000000Z8Vd0:R9]0050:R9
]0030000002`T[L0/9:g00L0/9:g00<000000<^__P3;[kh01P3;[kh010000000f/310=[0`@000003
0=_4``030000003Rcl@0h/o400@0h/o400L000000>KIb@3VfLT0i]W90000003Kc/`0000000L0f=3B
00<000000<oAf`0000002@2o_MP2000000D0ZZcI00<0000009jUfP2NYMX01P2NYMX00`000000TZCQ
09:Th@0309:Th@@000001P2O^N/00`000000V/_h09[;n002000000D0//g^00<000000:_Im`2[fOL0
0`0000040;G9jP030000002N`_80W/;b0080W/;b1`00000306JUm0030000003oool0oooo00/0oooo
00<000000?ooo`3oool03`3oool000<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`0000002`3oool3000000<0TfnW0P0000070;bT`@05
0000003?[kT0cjni0<n_^@000000103]gL8010000000iOc10>Gl`@3Uo<42000000<0iKf]0`000002
0>NkZ0040000003X^jH0j;^V000000@0c;S700<000000<>Z`033Z/000P33Z/030000000309R_i`00
0000V8c500@0V8c500<0000009Mn]P2GO[H00`2GO[H00`000000UgV_09Mi[`0409Mi[`030000002H
N:d0V7R]00<0V7R]0`0000080:R9]0030000002`T[L0/9:g00D0/9:g0P0000070<^__P050000003J
`<40f/310=[0`@0000000P3Ka<<00`000000h/o40>;?a0040>;?a0030000003VfLT0i]W900<0i]W9
00<000000=S@dP3Hd=801@3Hd=801@000000cm7K0<oAf`3?dM/0000000H0_kgH0`0000070:Z/f@03
0000002NYMX0WZGJ00D0WZGJ00<0000009:Th@2BY>400`0000020::^h0030000002O^N/0WkW[00H0
WkW[0P0000080;;=kP8000000`2ebNX00`000000]LWZ0;G9jP020;G9jP@00000102P[^400`000000
KiKW06nFi`05000000`0oooo00<000000?ooo`3oool03`3oool000<0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`020?ooo`800000103oool2000000X0oooo00<0000006N1f01W
PMP0100000090;bT`@030000003?[kT0000000D0kMg200<000000>Gl`@0000000P0000000`3U_Jd0
000000000002000000@0ik^X00@000000>RkYP3X^jH000000`3<^<L00`000000`j[00<>Z`0040<>Z
`00300000008I=T0000000800000102HS<D00`000000Ugjf09Mn]P0309Mn]P030000002GNJl0UgV_
00@0UgV_00@0000009Qh[@2HN:d0V7R]0P00000309n2/`030000002XRK@0Z8Vd00D0Z8Vd00<00000
0;2B]`2`T[L0102`T[L010000000`jFl0<>U_00000050<^__P030000003J`<40f/3100<0f/3100<0
00000=_4``0000001@3Rcl@00`000000i]W90>KIb@030>KIb@030000003Thm40000000@0f=3B0P00
00040<oAf`030000002o_MP0_kgH0080_kgH0P0000030;Jjg0030000002Z[=T0ZZcI00D0ZZcI00<0
000009jUfP2NYMX0102NYMX3000000H0XZkP00<0000009nij`2O^N/00`2O^N/2000000030;;1iP00
0000//g^00D0//g^0P0000000`2lbN@000000;G9jP020;G9jP030000002ebNX0]LWZ0080000000<0
];[M0000002P[^401@2P[^400`000000KiKW06nFi`0406nFi`030000003oool0oooo00X0oooo0P00
000@0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000001WPMP0Ih7H0080Ih7H
00<000000;bT`@2lY<401`2lY<400`000000cjni000000040>gM`P<0000000@0g/6j000000000000
00000P3U_Jd00`000000ik^X0>NkZ0030>NkZ0070000003X^jH0j;^V0>RkYP000000c;S700000007
0<>Z`08000000P08I=T2000000<0V8c500<0000009Mn]P2GO[H0102GO[H00`000000UgV_09Mi[`04
09Mi[`<000001@2OP[<00`000000Z8Vd0:R9]0050:R9]0030000002`T[L0/9:g00<0/9:g00D00000
0<>U_033YK`0`jFl000000040<^__P030000003J`<40f/3100D0f/3100<000000>;?a03Rcl@00`3R
cl@00`000000i]W90>KIb@030>KIb@040000003Thm40i>?A0>CSd@80000000<0f=3B0000003?dM/0
1P3?dM/010000000_kgH0000000000050;Jjg0030000002Z[=T0ZZcI00D0ZZcI00<0000009jUfP2N
YMX0100000020:F[g0030000002R[^00XZkP00D0XZkP00<0000009nij`2O^N/00P0000030;;1iP03
0000002bcNh0//g^0080//g^0P0000030;c9i0030000002ebNX0]LWZ0080]LWZ0P0000030;Bjg@03
0000002P[^40X:kQ00D0X:kQ00<0000006nFi`1_U^L0101_U^L00`000000oooo0?ooo`060?ooo`<0
000000<0oooo0000003oool03`3oool000@0oooo0P00000:0?ooo`800000103oool300000080oooo
00<000000?ooo`3oool02`3oool00`000000Ih7H06N1f00306N1f0030000002lY<40_:C100L0_:C1
2`0000040>Fm[@030000003W^jP0ik^X0080ik^X00<000000>RkYP3X^jH00`3X^jH00`000000`j[0
0<>Z`0070<>Z`080000000<026CI0000001TM]000`0000000`2HS<D0000009Mn]P0409Mn]P040000
002GNJl0UgV_09Mi[`@000001`2OP[<00`000000Z8Vd0:R9]0060:R9]0050000002`T[L0/9:g0;2B
]`0000001033YK`00`000000bjnn0<^__P020<^__P030000003J`<40f/3100@0f/3100<000000>GC
a0000000103Rcl@00`000000i]W90>KIb@030>KIb@030000003Thm40i>?A00<0i>?A00<000000<oA
f`3?dM/01`3?dM/00`000000][[L0;Jjg0060;Jjg0030000002Z[=T0ZZcI00@0ZZcI0`0000060:F[
g0030000002R[^00XZkP00D0XZkP0`0000060;;1iP040000002bcNh00000000000H0_<WT00H00000
0;G9jP00000000000;Bjg@0000040;Bjg@030000002P[^40X:kQ00@0X:kQ00<0000006nFi`1_U^L0
101_U^L00`000000oooo0?ooo`020?ooo`@00000103oool00`000000oooo0?ooo`0>0?ooo`006`3o
ool2000000d0oooo00<0000006N1f01WPMP00P1WPMP00`000000_:C10;bT`@060;bT`@030000003L
m]d0g?KM0080g?KM0`0000030=k1^P030000003U_Jd0iKf]0080iKf]00<000000>NkZ03W^jP00P3W
^jP00`000000j;^V0>RkYP030>RkYP8000002033Z/030000000300QTf@000000I7K@0080I7K@2`00
000309Am]`030000002OP[<0Wh:c00D0Wh:c00<000000:R9]02XRK@01P2XRK@01@000000/9:g0;2B
]`2`T[L0000000D0`jFl00@000000<^__P3;[kh000001`3J`<400`000000iM?40>GCa00200000003
0>;?a0000000i]W900@0i]W900<000000>CSd@3Thm400`3Thm400`000000fn_N000000060<oAf`80
000000<0`]3U0000002f^]`01P2f^]`00`000000ZZcI0:Z/f@0400000080Z:oL00<000000:F[g02U
Zm`01@2UZm`00`000000XZkP0::^h0020::^h08000000P2^^N400`000000//7V0;;1iP050;;1iP03
0000002lbN@0_<WT00H0_<WT0P0000040;Bjg@050000002d^]d0];[M0;Bjg@000000102P[^4>0000
00P0oooo00<000000?ooo`3oool03P3oool001/0oooo00<000000?ooo`3oool0303oool00`000000
Ih7H06N1f00306N1f0030000002lY<40_:C100@0_:C100@000000=cfg@3Lm]d0g?KM0`0000040=k1
^P030000003U_Jd0iKf]0080iKf]00<000000>NkZ03W^jP00`3W^jP00`000000j;^V0>RkYP020>Rk
YP030000003W^jP0000000L0`j[00P000002079daP800000101TM]000`000000Q7Vo08Ai_`0308Ai
_`030000002DOKL0U7fg00D0U7fg00<0000009n2/`2OP[<01@2OP[<00`000000Z8Vd0:R9]0050:R9
]0040000002`T[L0/9:g000000H0`jFl00<000000<^__P0000001`3J`<400`000000iM?40>GCa003
0>GCa0030000003VfLT0i]W900<0i]W900<000000>CSd@3Thm400`3Thm4010000000fn_N0=_[gP00
00040<oAf`8000000`32d>D00`000000][[L0;Jjg0050;Jjg0<000001P2X[m`00`000000YJ_L0:F[
g0050:F[g0030000002R[^00XZkP00800000102^^N400`000000//7V0;;1iP030;;1iP80000000<0
^lKR0000002lbN@0102lbN@200000080_<;N00D000000;Bjg@2d^]d0];[M000000030;Bjg@D00000
0`2QXM@00`000000QYKK08JFf`0508JFf`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
3@3oool001/0oooo0P00000>0?ooo`030000001WPMP0Ih7H0080Ih7H00<000000;bT`@2lY<400`2l
Y<400`000000g?KM00000004000000D0g/6j00<000000>Fm[@3U_Jd00P3U_Jd00`000000ik^X0>Nk
Z0020>NkZ0030000003X^jH0j;^V00<0j;^V00@000000>NkZ03W^jP000001@33Z/001@000000^j2m
0;^P_@000000LWC600<00000101TM]000`000000Q7Vo08Ai_`0308Ai_`030000002DOKL0U7fg00@0
U7fg00<0000009n2/`2OP[<01@2OP[<00`000000Z8Vd0:R9]0060:R9]08000002033YK`2000000H0
f/3100<000000>GCa03Udl@00`3Udl@00`000000jnG9000000030>KIb@030000003Thm40i>?A00<0
i>?A00<000000=_[gP3Kjmh00P3Kjmh010000000cm7K0000000000060<;@i@030000002f^]`0][[L
00@000000P2/^>800`000000Z:oL0:R_g0050:R_g0030000002UZm`0YJ_L00@0YJ_L0`0000070:ji
h@030000002b`NH0//7V00800000102ka^800`000000_<WT0;c9i002000000@0_<;N00<000000;Bj
g@2d^]d00P2d^]d3000000030:n]eP000000XJ7D00H0XJ7D00<0000008JFf`26U]/01026U]/00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo000K0?ooo`030000003oool0oooo00d0
oooo00<0000006N1f01WPMP00`1WPMP010000000_:C10;bT`@2lY<43000000050=cfg@0000000000
0;g4g`000000103N`KX00`000000iKf]0>Fm[@020>Fm[@030000003W^jP0ik^X00<0ik^X00<00000
0>RkYP3X^jH00`3X^jH01@000000ik^X0>NkZ03W^jP000000080`j[00P0000030;^P_@030000001b
M<H0LWC600800000101TM]000`000000Q7Vo08Ai_`0308Ai_`030000002DOKL0U7fg00@0U7fg00<0
000009n2/`2OP[<01@2OP[<00`000000Z8Vd0:R9]0060:R9]00300000033YK`0`jFl00L0`jFl00<0
00000=[0`@3J`<40103J`<400`000000iM?40>GCa0040>GCa0030000003[iLT0jnG90080000000<0
i]W90000003Thm400`3Thm400`000000fn_N0=_[gP040=_[gP0300000032d>D0`]3U00L0`]3U0P00
00060:bhhP030000002X[m`0Z:oL00D0Z:oL00<000000:F[g02UZm`0100000020:Zdg`030000002^
^N40[[WQ00D0[[WQ0`0000070;_6hP8000001`2l`]h00`000000];[M0;Bjg@03000000<0[jgF00<0
00000:6Qe02QXM@0102QXM@00`000000QYKK08JFf`0508JFf`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool001X0oooo00<000000?ooo`3oool03`3oool2000000<0Ih7H10000003
0=cfg@040000003oool0oooo000000D0g/6j00<000000>Fm[@3U_Jd00P3U_Jd00`000000ik^X0>Nk
Z0030>NkZ0030000003X^jH0j;^V0080j;^V00<000000>NkZ03W^jP00P3W^jP00`000000`j[00000
00060;^P_@030000001bM<H0LWC6008000000`1TM]000`000000Q7Vo08Ai_`0308Ai_`030000002D
OKL0U7fg00D0U7fg00<0000009n2/`2OP[<01@2OP[<00`000000Z8Vd0:R9]0040:R9]08000002033
YK`00`000000e;g3000000050=[0`@030000003Udl@0iM?400<0iM?400<000000>_Ub@3[iLT00`3[
iLT00`000000i>?A0>CSd@020>CSd@030000003Kjmh0fn_N00<0fn_N0P0000000`39jnd000000<;@
i@050<;@i@80000000<0[l[]0000002/^>801P2/^>800`000000Z:oL0:R_g0040:R_g0<000001P2Z
]=l00`000000[[WQ0:jih@030:jih@8000000P2g`^<00`000000^lKR0;_6hP030;_6hP80000000<0
_/SR0000002l`]h01`2l`]h2000000<0[jgF00@000000:n]eP2_[MH000001`2QXM@00`000000QYKK
08JFf`0408JFf`8000002@3oool00`000000oooo0?ooo`0=0?ooo`006P3oool300000140oooo1P00
0000103Lm]d000000000000000040?ooo`050000003N`KX0g/6j0=k1^P0000001@3U_Jd00`000000
ik^X0>NkZ0020>NkZ0030000003X^jH0j;^V00<0j;^V00<000000>NkZ03W^jP00`3W^jP00`000000
^j2m0;^P_@050;^P_@050000001bM<H0LWC6079daP000000101TM]000`000000Q7Vo08Ai_`0308Ai
_`030000002DOKL0U7fg00@0U7fg00<0000009n2/`2OP[<01@2OP[<00`000000Z8Vd0:R9]0030:R9
]0040000002hWK`0^9fl000000H0`jFl00D000000=Bm``3D_L<0e;g3000000030=[0`@030000003U
dl@0iM?400<0iM?400<000000>_Ub@3[iLT00`3[iLT01P000000j?G@000000000000i>?A000000D0
fn_N00<000000<W[k@39jnd00P39jnd200000080`]3U0P0000040:o:k@030000002/^>80[;SR00@0
[;SR00<000000:R_g02X[m`0100000020:JchP030000002Z]=l0Z[CO00D0Z[CO00<000000:jih@2^
^N400P0000040;O2h`030000002ka^80^lKR0080^lKR00D000000;k8hP2nb>80_/SR000000060;c2
gP<00000102_[MH01@000000[jgF0:n]eP2_[MH0000000H0XJ7D00<0000008JFf`26U]/010000002
0:2Md@030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool001X0oooo00<000000?oo
o`3oool03`3oool300000080oooo100000080?ooo`040000003N`KX0g/6j000000@0iKf]00<00000
0>NkZ03W^jP00`3W^jP00`000000j;^V0>RkYP030>RkYP030000003W^jP0ik^X00<0ik^X00<00000
0;^P_@2kX;d01P2kX;d00`000000LWC6079daP02000000<0I7K@00<0000008Ai_`24NKl00`24NKl0
0`000000U7fg09Am]`0409Am]`030000002OP[<0Wh:c00D0Wh:c00@000000:R9]02XRK@0Z8Vd0P00
00030;RM_00300000033YK`0`jFl00<0`jFl00<000000=Bm``3D_L<00P3D_L<010000000f/310=[0
`@0000050>GCa0030000003[iLT0jnG900<0jnG900<000000>Sed03XmM000P3XmM02000000<0fn_N
0P0000060<W[k@<000001P2_b^d00`000000[;SR0:bhhP040:bhhP<000001P2V/n800`000000Z[CO
0:Zdg`050:Zdg`<000001`2g`^<010000000^lKR0000000000050;k8hP040000002l`]h0_<;N0;c2
gP8000000`2g^]`00`000000[jgF0:n]eP020:n]eP040000002_[MH0[jgF000000H0XJ7D0`000006
0:2Md@030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool000L0oooo0P0000040?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool0303oool300000180oooo0P0000050>Fm
[@030000003W^jP0ik^X00<0ik^X00<000000>RkYP3X^jH00P3X^jH00`000000ik^X0>NkZ0030>Nk
Z0030000003V_:`0000000L0^j2m00@00000079daP1bM<H0LWC60P00000306Afd00300000024NKl0
Q7Vo0080Q7Vo00<0000009Am]`2DOKL0102DOKL00`000000Wh:c09n2/`0509n2/`040000002XRK@0
Z8Vd000000D0^9fl00<000000<>U_033YK`00P33YK`00`000000e;g30=Bm``040=Bm``030000003J
`<40000000D0iM?400<000000>_Ub@3[iLT00P3[iLT00`000000j?G@0>Sed0020>Sed0030000003F
o]L0e_kG00<000001P39jnd200000080[N7i00<000000:o:k@2_b^d01@2_b^d00`000000[;SR0:bh
hP0300000080XKSX00<000000:JchP2V/n801@2V/n800`000000Z[CO0:Zdg`020:Zdg`8000000P2^
_nH00`000000]l;S0;O2h`050;O2h`8000001`2nb>8010000000_<;N0000000000050;Njg0030000
002_[MH0[jgF00<0[jgF00D000000:n]eP2_[MH000000:6Qe004000000030:BLc@000000X9gA00L0
X9gA00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`001P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P00000:0?ooo`<000005P3oool00`00
0000iKf]0>Fm[@030>Fm[@030000003W^jP0ik^X0080ik^X00<000000>RkYP3X^jH00`3X^jH00`00
0000ik^X0>NkZ0030>NkZ0030000003V_:`0000000P0^j2m0`0000000`1bM<H000000000000206Af
d00300000024NKl0Q7Vo0080Q7Vo00<0000009Am]`2DOKL01@2DOKL00`000000Wh:c09n2/`0509n2
/`8000001`2hWK`01@000000`jFl0<>U_033YK`0000000L0e;g300<000000>GCa03Udl@00`3Udl@0
0`000000jnG90>_Ub@020>_Ub@030000003XmM00j?G@0080j?G@00@000000=Kne`3Fo]L0e_kG0P00
00000`2fnn800000000000020<W[k@8000001@2]hOT00`000000[l[]0:o:k@020:o:k@D000001@2Q
^>P00`000000Y[?R0:JchP050:JchP030000002Z]=l0Z[CO00800000102^_nH00`000000]l;S0;O2
h`030;O2h`8000000P2ic>P00`000000_/SR0;k8hP050;k8hP030000002g^]`0]k[L00H0]k[L00<0
00000:n]eP2_[MH00`2_[MH4000000H0Y9c=00<000000:2Md@2PWM401P2PWM400`000000oooo0?oo
o`050?ooo`030000003oool0oooo00`0oooo00060?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`8000006P3oool01@000000iKf]0>Fm
[@3U_Jd0000000D0ik^X00<000000>RkYP3X^jH00P3X^jH00`000000ik^X0>NkZ0030>NkZ0050000
003V_:`0i[b/0>Jl[00000001P2kX;d200000080Q7_11P00000508Ai_`030000002DOKL0U7fg00@0
U7fg00<0000009n2/`2OP[<0102OP[<2000000P0^9fl00@000000<>U_033YK`000001`3D_L<00`00
0000i=S:000000030>GCa0030000003[iLT0jnG900<0jnG900<000000>Sed03XmM000P0000030=Kn
e`030000002fnn80]__R0080]__R0`0000050:gQn@L00000102K`?800`000000XKSX0:6hj0040:6h
j0030000002V/n80Y[?R00@0Y[?R0`0000070:joiP030000002g`^<0]l;S00800000102ic>P00`00
0000_/SR0;k8hP030;k8hP80000000<0^LSV0000002g^]`01P2g^]`00`000000[jgF0:n]eP040000
00030:NTdP000000Y9c=00H0Y9c=00<000000:2Md@2PWM40102PWM43000000L0oooo00<000000?oo
o`3oool0303oool000H0oooo00@000000?ooo`3oool000002@3oool2000000@0oooo00<000000?oo
o`0000001@3oool3000001d0oooo00@000000>Fm[@3U_Jd000001@3W^jP00`000000j;^V0>RkYP02
0>RkYP030000003W^jP0ik^X00<0ik^X00D000000>Jl[03V_:`0i[b/000000050;^P_@040000002d
V[d0]9Zm000000<0Q7_10P0000000`00@lD000000000000408Ai_`030000002DOKL0U7fg00@0U7fg
00<0000009n2/`2OP[<00P2OP[<2000000030:VD`0000000^9fl00P0^9fl0P0000070=Bm``040000
003Tf<X0i=S:0>CHbP80000000<0iM?40000003[iLT00`3[iLT010000000j?G@0>Sed00000040=Kn
e`030000002fnn80000000<000000`2DkO<5000000@0TLcl00<0000009_0lP2K`?80102K`?800`00
0000XKSX0:6hj0040:6hj0030000002V/n80Y[?R00@000000P2T^nX00`000000[[oV0:joiP050:jo
iP<000001`2ic>P00`000000_/SR0;k8hP02000000<0^LSV00<000000;Njg02g^]`01@2g^]`30000
00@0YjCB00<000000:NTdP0000001`2TW<d010000000X9gA0:2Md@2PWM42000000<0^JW:00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`001P3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000008@3oool2000000D0ik^X00<00000
0>RkYP3X^jH00`3X^jH00`000000ik^X0>NkZ0030>NkZ0030000003V_:`0i[b/0080i[b/00<00000
0;^P_@2kX;d00P0000030;BJ_@0300000024Nl40Q7_10080Q7_100<000000013a@00@lD00P000003
08Ai_`030000002DOKL0U7fg00D0U7fg00@0000009n2/`0000000000102YU<000`000000^9fl0;RM
_0060;RM_0030000003D_L<0e;g300H0e;g300<000000>CHbP3Tf<X00`3Tf<X2000000<0jnG900@0
00000>Sed03XmM0000000`3Fo]L4000000@0U>gc0`000002087Eo`030000002Ac?`0TLcl00@0TLcl
00<0000009_0lP2K`?801@2K`?800`000000XKSX0:6hj0020:6hj0@000001P2T^nX00`000000[[oV
0:joiP030:joiP8000000P2`bnh00`000000^LcX0;W<j0050;W<j0<000001P2ib>H00`000000]k[L
0;Njg004000000030:^bgP000000YjCB00D0YjCB0P0000070:BLc@040000002PWM400000000000D0
^JW:00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`001`3oool2000000X0oooo
0`0000030?ooo`030000003oool00000008000009@3oool00`000000ik^X0>NkZ0030>NkZ0030000
003X^jH0j;^V0080j;^V00<000000>NkZ03W^jP00`3W^jP00`000000i[b/0>Jl[0030>Jl[0030000
002kX;d0000000D0]9Zm00<0000008Ak`@24Nl400P24Nl42000000030013a@000000HWC?00<00000
00<0Q7Vo0000002DOKL00P2DOKL5000000H0ZIC000<000000;RM_02hWK`01@2hWK`00`000000bkW9
000000060=Bm``030000003Tf<X0i=S:00<0i=S:00<000000>WccP3Yllh0300000000`1Ldl@00000
00000003000000H0PMGo0P000005097<o0030000002K`?80Vl3b0080Vl3b1`00000309VikP030000
002T^nX0Y;_Z00D0Y;_Z00<000000:joiP2^_nH00P0000040;3;kP030000002ic>P0^LcX00<0^LcX
0P0000020;GCl0030000002ib>H0^LSV00@0^LSV0`0000060:^bgP030000002WY=80YjCB00<0YjCB
00<000000:NTdP0000001P2TW<d2000000P0^JW:00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0<0?ooo`006@3oool2000002T0oooo0P0000030>NkZ0030000003X^jH0j;^V0080j;^V00<0
00000>NkZ03W^jP00`3W^jP00`000000i[b/0>Jl[0040>Jl[0030000002dV[d0]9Zm00@0]9Zm00<0
000008Ak`@24Nl400`24Nl42000000030013a@000000HWC?0080HWC?1@0000030968aP030000002Y
U<00ZIC000D0ZIC000<000000;RM_02hWK`0102hWK`010000000bkW90<^ib@0000050=Bm``030000
003Tf<X0i=S:00<0i=S:00<000000>WccP3Yllh00P3Yllh010000000eOo60=GoaP0000020:?`/PH0
0000101]f?HC000000@0SKOb00<0000009VikP2I^Nh0102I^Nh00`000000Y;_Z0:BkjP040:BkjP<0
00001`2`bnh00`000000^LcX0;W<j002000000D0]M?`00<000000;W8iP2ib>H00`0000020:_5k003
0000002[/]h0Zk;N00@0Zk;N00<000000:NTdP2WY=80102WY=82000000@0Y9c=0P0000000`2XW/`0
00000;VYbP060;VYbP030000003@^lH0000000@0oooo00<000000?ooo`3oool0303oool001X0oooo
00<000000?ooo`3oool0:@3oool3000000D0j;^V00<000000>NkZ03W^jP00P3W^jP00`000000i[b/
0>Jl[0040>Jl[08000001`2dV[d00`000000Q7_108Ak`@0208Ak`@040000001:GlH00000000000@0
HWC?00<000000968aP2AR<H01@2AR<H00`000000ZIC00:VD`0050:VD`0030000002hWK`0^9fl0080
^9fl00<000000<^ib@3;^LT00P3;^LT01@000000e;g30=Bm``3D_L<0000000D0i=S:00<000000>Wc
cP3Yllh00P3Yllh01@000000eOo60=GoaP000000Xo2b00<000000`1Pe^P6000000<0Pkgi00<00000
082hn020^?P01020^?P00`000000Q;Kf08BfmP0308BfmP030000002=]o80SKOb00@0SKOb00<00000
09VikP2I^Nh01@2I^Nh00`000000Y;_Z0:BkjP0300000080X/Kb00<000000;3;kP2`bnh01@2`bnh3
000000L0]M?`0`0000050:_5k0030000002[/]h0Zk;N00D0Zk;N00<000000:NTdP2WY=80102WY=82
000000030:BLc@000000000000@0Z9k<00<000000;VYbP2iZLX00`2iZLX01@000000d;_60=2kaP3@
^lH0000000<0oooo00<000000?ooo`3oool0303oool001/0oooo0P00000[0?ooo`030000003X^jH0
j;^V0080j;^V00<000000>NkZ03W^jP00`3W^jP00`000000i[b/0>Jl[0040>Jl[0030000003R_k@0
000000H0]9Zm00<0000008Ak`@24Nl400`24Nl44000000@0HWC?00<000000968aP2AR<H0102AR<H0
0`000000ZIC00:VD`0050:VD`0050000002hWK`0^9fl0;RM_00000001P3;^LT010000000e;g30=Bm
``0000040>CHbP030000003Yllh0jO?>0080jO?>00<000000=GoaP3EolH02@00000308k4n@030000
0023_OT0Pkgi00@0Pkgi00<00000082hn020^?P01020^?P00`000000Q;Kf08BfmP0308BfmP030000
002=]o80SKOb00@0SKOb00<0000009VikP2I^Nh00P2I^Nh5000000H0X/Kb00<000000;3;kP2`bnh0
100000020:_FmP030000002edo00]M?`00<0]M?`0P0000000`2WeOP000000:_5k0060:_5k0030000
002[/]h0Zk;N00@0Zk;N00<000000:NTdP2WY=800P2WY=85000000H0Z9k<00<000000;VYbP2iZLX0
0P2iZLX00`000000d;_60=2kaP030=2kaP050000003oool0oooo0?ooo`0000003@3oool001d0oooo
00<000000?ooo`3oool0:@3oool01@000000j;^V0>RkYP3X^jH0000000D0ik^X00<000000>Jl[03V
_:`00`3V_:`010000000h[nd0>:o]00000060;BJ_@0300000024Nl40Q7_100<0Q7_100@0000004YO
aP0000000000101RM<l00`000000THS60968aP050968aP030000002YU<00ZIC000@0ZIC000@00000
0;RM_02hWK`000001`3;^LT00`000000e;g3000000050>CHbP050000003Yllh0jO?>0>WccP000000
0P3EolH3000000@0W/_g0P00000508k4n@0300000023_OT0Pkgi0080Pkgi6P00000409FllP030000
002Ra_80X/Kb00@0X/Kb0`0000070:_FmP030000002edo00]M?`00800000102WeOP00`000000ZlG/
0:_5k0040:_5k0030000002[/]h0Zk;N0080Zk;N1`00000309nOe0030000002XW/`0Z9k<00H0Z9k<
00D000000;VYbP2iZLX0^JW:000000040=2kaP8000000`3oool00`000000oooo0?ooo`0;0?ooo`00
7P3oool00`000000oooo0?ooo`0Y0?ooo`040000003X^jH0j;^V000000@0ik^X00<000000>Jl[03V
_:`0103V_:`010000000h[nd0>:o]00000070;BJ_@0300000024Nl40Q7_100<0Q7_100@0000004YO
aP0000000000101RM<l00`000000THS60968aP040968aP030000002YU<00ZIC000D0ZIC00P000009
0<^ib@030000003Tf<X0i=S:00<0i=S:00<000000>WccP3Yllh00P3Yllh010000000eOo600000000
000709k;m`/000000`2?X>000`000000RJ?U08VSi@0408VSi@0300000027Z>/0QjS[00<0QjS[00<0
000008^bl02;/_00102;/_000`000000UKcb09FllP0509FllP030000002Ra_80X/Kb00<000000P2P
d?P00`000000ZmKf0:_FmP050:_FmP<000001P2WeOP00`000000ZlG/0:_5k0020:_5k0L000000`2H
Z^<00`000000WioD09nOe00509nOe0030000002XW/`0Z9k<00D0Z9k<00@000000;VYbP2iZLX00000
1@3@^lH00`000000j=g8000000020?ooo`030000003oool0oooo00/0oooo000O0?ooo`030000003o
ool0oooo02T0oooo0P0000050>NkZ0030000003V_:`0i[b/00<0i[b/00<000000>:o]03R_k@00P3R
_k@00`000000]9Zm0;BJ_@040;BJ_@X00000101RM<l00`000000THS60968aP040968aP030000002Y
U<00ZIC000D0ZIC000<000000<^ib@3;^LT01`3;^LT010000000g=oH0000000000020>CHbP030000
003Yllh0jO?>0080jO?>00<000000=GoaP0000000P2^c_4200000080W/_g0`0000000`2QY=P00000
09NQf`0509NQf`030000002?X>00Sj3P00@0Sj3P00<0000008VSi@29XnD00`29XnD00`000000QjS[
08NXj`0408NXj`030000002;/_00Rk;`00@0Rk;`00<0000009FllP2E_?800P2E_?85000000H0X=3h
00<000000:_FmP2[e_H0100000020:7Ko0800000102WeOP6000000@0Tk_b00<0000009RZh`2HZ^<0
102HZ^<00`000000WioD09nOe00409nOe08000001`2XW/`2000000D0d;_600@000000>SMb03XgLP0
00000P3oool00`000000oooo0?ooo`0;0?ooo`00803oool2000002X0oooo00<000000>NkZ03W^jP0
0`3W^jP00`000000i[b/0>Jl[0030>Jl[0030000003R_k@0h[nd0080h[nd00<000000;BJ_@2dV[d0
0P2dV[d3000000D0THC100<0000007YmbP1jOLX00P000004069dc`030000002AR<H0THS600@0THS6
00<000000:VD`02YU<000P2YU<02000000030;Nbe@000000bkW900H0bkW900<000000=cOf03LgmP0
0P3LgmP3000000<0jO?>0`0000040:k>l@<000001@2QY=P00`000000Uj7K09NQf`0309NQf`030000
002?X>00Sj3P00@0Sj3P00<0000008VSi@29XnD01029XnD00`000000QjS[08NXj`0408NXj`030000
002;/_00Rk;`0080Rk;`1P00000409S3m@030000002Pd?P0X=3h00@0X=3h0`0000070:7Ko0D00000
0`2?c?`00`000000Tk_b09>klP0409>klP030000002HZ^<0V:[S00@0V:[S00<0000009nOe02OWm@0
1@2OWm@2000000D0Z9k<0P0000050=2kaP030000003XgLP0j=g80080j=g800<000000?ooo`000000
3@3oool00280oooo00<000000?ooo`3oool0:03oool01@000000ik^X0>NkZ03W^jP0000000D0i[b/
00<000000>:o]03R_k@0103R_k@010000000]9Zm0000000000030:jH`@030000002AQ<40THC100<0
THC100@0000007YmbP1jOLX0NWg:0P000002069dc`030000002AR<H0THS600@0THS600D000000:VD
`02YU<00ZIC0000000030;Nbe@030000003;^LT0bkW900@0bkW900<000000=cOf03LgmP00`3LgmP0
0`000000e_kG0=Kne`04000000<0[/ka0`0000020:bZe@030000002QY=P0XJCH00<0XJCH00<00000
09NQf`2GXM/0102GXM/00`000000Sj3P08nPh00408nPh00300000029XnD0RJ?U00<0RJ?U00<00000
08NXj`27Z>/00P27Z>/7000000<0U;;/00<0000009S3m@2H`oD01@2H`oD00`000000X=3h0:3@n003
00000080X=Ok0P0000020:7Ko0@000000P2Eeoh00`000000Slcl08o<o00408o<o0030000002C^o80
Tk_b00@0Tk_b00<0000009RZh`2HZ^<0102HZ^<00`000000WioD09nOe00409nOe08000000`2XW/`2
00000080/:cD00<000000=2kaP3@^lH00P3@^lH01P000000j=g80>SMb03XgLP0000009?DM`800000
3@3oool002<0oooo00<000000?ooo`3oool0:03oool010000000ik^X0>NkZ00000050>Jl[0030000
003R_k@0h[nd00@0h[nd0P0000050:jH`@030000002AQ<40THC100<0THC100@0000007YmbP1jOLX0
NWg:100000000`1RM<l000000968aP050968aP<000001@2g/]D00`000000bkW90<^ib@020<^ib@03
0000003LgmP0g=oH00<0g=oH00@000000=Kne`3Fo]L0e_kG0`000000102kc^P00000000000000005
0:bZe@030000002QY=P0XJCH00@0XJCH00<0000009NQf`2GXM/00`2GXM/00`000000Sj3P08nPh002
08nPh0d00000102DY>000`000000U;;/09Bbk00409Bbk0030000002H`oD0V<?e0080V<?e1@000006
0:3Gn`<000001@2Eeoh=00000080Tk_b00<0000009RZh`2HZ^<0102HZ^<00`000000WioD09nOe005
09nOe0@00000102`[=@01@000000d;_60=2kaP3@^lH0000000<0j=g800<0000009?DM`2Ce7L00P00
000=0?ooo`00903oool00`000000oooo0?ooo`0X0?ooo`8000001@3V_:`00`000000h[nd0>:o]004
0>:o]08000001`2^V<400`000000THC10964`@020964`@030000001jOLX0NWg:0080NWg:00<00000
01QVfP0HI]X02@0000080;Nbe@040000003;^LT0bkW9000000D0g=oH00@000000=Kne`3Fo]L0e_kG
0`000000102kc^P000000000000000070:bZe@030000002QY=P0XJCH00<0XJCH00<0000009NQf`2G
XM/00P2GXM/6000000<0Ui?=00<0000009FIe@2EVMD0102EVMD00`000000U:CP09BTh00409BTh003
0000002D/^`0U;;/00@0U;;/1@0000040:?:m08000000P2Peo/3000000<0Y=Wj1@00000309?9nP03
0000001l^_X0O;[j00@0O;[j00<0000007B[m01dZo@0500000060;2/e0030000003@^lH0000000@0
j=g800@0000009?DM`2Ce7L0TmAg0P00000<0?ooo`009@3oool2000002T0oooo00<000000>Jl[03V
_:`00`3V_:`00`000000h[nd0>:o]0040>:o]0030000003I`/@0000000H0[YS100<000000964`@2A
Q<400`2AQ<400`000000NWg:07YmbP0207YmbP050000000HI]X066KJ01QVfP0000001P28XN@00`00
0000]k;E0;Nbe@050;Nbe@030000003;^LT0000000D0g=oH00@000000=Kne`3Fo]L0e_kG0P000000
0`2kc^P00000000000030;Jae0030000002/Z]D0[:[E00@0[:[E00<000000:6Tf02QY=P00P2QY=P6
000000<0Vi3800<0000009NCc@2GTld0102GTld00`000000UIWE09FIe@0309FIe@030000002DY>00
U:CP00D0U:CP00<0000009Bbk02D/^`00`0000020:BgiP030000002Sb_@0Xl[d00D0Xl[d0`000004
0:CInP8000000P2/d?<00`000000TlWj09?9nP0409?9nP030000001l^_X0O;[j00<0O;[j00<00000
07B[m01dZo@0101dZo@00`000000OZ?[07jSj`0407jSj`030000002DXn00U:?P00@0U:?P0P000006
0;2/e0030000003@^lH0000000<0j=g800<0000009?DM`2Ce7L00P2Ce7L2000000`0oooo000W0?oo
o`030000003oool0oooo02L0oooo00D000000>Jl[03V_:`0i[b/000000060>:o]0040000003I`/@0
fL;4000000L0[YS100<000000964`@2AQ<400P2AQ<400`000000NWg:07YmbP0307YmbP040000000H
I]X066KJ000000H0R:7T00<000000;Nbe@2g/]D01P2g/]D00`000000g=oH0=cOf0030=cOf0030000
003Fo]L0e_kG00D000001@2f/M@00`000000[:[E0:bZe@050:bZe@@000000P2PT/D00`000000Vi38
09^@b00409^@b0030000002GTld0Ui?=00@0Ui?=00<0000009FIe@2EVMD0102EVMD00`000000U:CP
09BTh00409BTh0<000001P2T]nH00`000000Xl[d0:?:m00400000080/Lk_00<000000:CInP2TfOX0
0P0000050:c@l`030000002CbOX0TlWj0080TlWj1P00000207bjnP030000001dZo@0M:_d00<0M:_d
00<0000007jSj`1nXn/0101nXn/00`000000U:?P09BSh00409BSh0030000002`[=@0000000D0/:cD
0P0000030>SMb0030000002Ce7L0000000<0000000<0oooo0000003oool02`3oool002P0oooo00<0
00000?ooo`3oool09`3oool2000000030>Jl[0000000h[nd00@0h[nd00<000000=W2a03I`/@00P3I
`/@00`000000[YS10:jH`@040:jH`@030000002AQ<40THC100<0THC100@0000007YmbP1jOLX0NWg:
100000000`0HI]X0000008RQi00508RQi0030000002g/]D0]k;E00<0]k;E0P0000000`30ho000000
000000020=cOf0030000003Fo]L000000080000000<0`l_P0000002f/M@01`2f/M@00`000000[:[E
0:bZe@020:bZe@<000001P2PT/D00`000000Vi3809^@b00409^@b0030000002GTld0Ui?=00@0Ui?=
00<0000009FIe@2EVMD00`2EVMD00`000000U:CP09BTh00400000080XjGG00<000000:BgiP2T]nH0
1@2T]nH2000000L0/Lk_0P0000070:c@l`D000000`2H/>P00`000000OJG]07fUk@0700000080M:_d
00<0000007jSj`1nXn/0101nXn/00`000000U:?P09BSh00409BSh0030000002`[=@000000080/:cD
0P0000020;SLlP030000003XgLP00000008000001@3oool00`000000oooo0?ooo`0:0?ooo`00:@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003R_k@0h[nd00@0h[nd00<000000=W2a03I`/@00P3I
`/@00`000000[YS10:jH`@050:jH`@030000002AQ<40THC100H000000`2JTl`20000000301QVfP00
0000R:7T00D0R:7T00D000000;Nbe@2g/]D0]k;E000000050<3Sl0D0000000D0`l_P000000000000
`;[D000000070;Jae0030000002/Z]D0[:[E008000000`2VU/D00`000000X9;50:2Ba@030:2Ba@03
0000002KT<P0Vi3800@0Vi3800<0000009NCc@2GTld0102GTld00`000000UIWE09FIe@0209FIe@@0
00001P2SYML00`000000Y;OV0:BgiP030:BgiP80000000<0]KcO0000002ac^l0102ac^l200000003
0;c<iP00000000000080[=3c100000000`2^^^80000009R`j00509R`j0030000001mYNd0OJG]00@0
OJG]00<0000006>Ml01SWO001`00000207jSj`030000002DXn00U:?P00@0U:?P00<000000;2/e02`
[=@00P0000040;SLlP030000003XgLP0000000L0oooo00<000000?ooo`3oool02P3oool002X0oooo
0P00000Y0?ooo`030000003R_k@0h[nd0080h[nd00<000000=W2a03I`/@0103I`/@00`000000[YS1
0:jH`@040:jH`@<000000`2NT<D00`000000VY?<09ZCc00409ZCc0<000001P28XN@010000000]k;E
0000000000050<3Sl080000000D0RngC00000033bn00`l_P000000040<2je0030000002f/M@0][7D
00@0][7D0`0000050:JFa@030000002PT/D0X9;500<0X9;500<0000009^@b02KT<P01@2KT<P00`00
0000Ui?=09NCc@0309NCc@D000000`2RV</00`000000XjGG0:>Ue`050:>Ue`030000002T]nH0Y;OV
00800000102e_=l00`000000/Lk_0;7>k`02000000D0_<cV0P0000060:jjhP030000002H/>P0V;3X
00@0V;3X00<0000007fUk@1mYNd0101mYNd00`000000Hig`06>Ml00306>Ml0030000001IX?@0FJ3d
00d000001@2hg?82000000P0oooo00<000000?ooo`3oool02P3oool002`0oooo00<000000?ooo`3o
ool09`3oool010000000h[nd0>:o]00000070=W2a0030000002^V<40[YS10080[YS10`00000509j@
a@030000002JTl`0VY?<00@0VY?<00<0000009RSg0000000200000060<3Sl0050000002;kM<00000
00000033bn000P0000060<2je0030000002f/M@0][7D00<0000000<0[Yk80000002VU/D01@2VU/D0
0`000000X9;50:2Ba@040:2Ba@030000002KT<P0Vi3800@0Vi3800<0000009NCc@2GTld00`000000
0`2PT<<000000::Hb`050::Hb`030000002SYML0XjGG00D0XjGG0`0000070;Flg`8000001@2lc>H2
000000030;o3g@000000[[[R00D0[[[R00<0000009R`j02H/>P00P2H/>P=00000080Hig`00<00000
05VPm01IX?@0101IX?@00`000000M;Wk07Bin`0407Bin`030000002hg?8000000080^=cb0P00000:
0?ooo`030000003oool0oooo00X0oooo000]0?ooo`030000003oool0oooo02L0oooo00<000000>:o
]0000000203I`/@010000000[YS10000000000030:NIb0030000002NT<D0WY3500<0WY3500<00000
09ZCc02JTl`0102JTl`00`000000V:?L09RSg002000000D0F[kl0P0000020<3Sl0@000000P37a]X0
0`000000`;[D0<2je0070<2je08000001@2^W/P00`000000YYK50:JFa@040:JFa@030000002PT/D0
X9;500<0X9;500<0000009^@b02KT<P0102KT<P3000000D0X93300<000000::Hb`2RV</0102RV</0
0`000000XjGG0:>Ue`020:>Ue`8000000P2c[=400`000000]KcO0;Flg`030;Flg`80000000<0`/?J
0000002lc>H00`2lc>H01@000000_l?M0;o3g@2o`md0000000H0[[[R1@00000309fGc@030000002?
U]H0SiKF00@0SiKF00<0000007JQk01fXN`01`00000205VPm0030000001d^O/0M;Wk00@0M;Wk00<0
00000;SLlP2hg?800P00000<0?ooo`030000003oool0oooo00X0oooo000^0?ooo`030000003oool0
oooo02L0oooo00<000000=W2a03I`/@01`3I`/@2000000D0YiW800<0000009j@a@2NT<D00`2NT<D0
0`000000VY?<09ZCc00509ZCc08000000P2f]ML;00000080alKJ0P0000000`38`mH000000<2je005
0<2je0<000001P2^W/P00`000000YYK50:JFa@040:JFa@030000002PT/D0X9;500@0X9;500<00000
09^@b00000000`0000000`2PS;h000000:2@``050:2@``030000002RV</0XYS;00@0XYS;00<00000
0:>Ue`2SYML00P0000040;>/d@030000002e_=l0]KcO0080]KcO00<000000<;3fP32`mX00P32`mX0
10000000_<cV0000000000050;o3g@030000002^^^80[[[R00<0000000<0ZIo=0000002MUld01P2M
Uld00`000000SiKF08nFeP0408nFeP030000001fXN`0MZ7/00@0MZ7/3P0000000`3oool000000?oo
o`0<0?ooo`030000003oool0oooo00T0oooo000_0?ooo`800000:03oool00`000000fL;40=W2a004
0=W2a0<000001P2WVLP00`000000WY3509j@a@0409j@a@030000002JTl`0VY?<0080VY?<0P000000
0`2aZ<l000000;Jee`060;Jee`0300000036`]H0000000@0alKJ00<000000<S3eP38`mH00P38`mH0
0`000000`;[D0<2je0020<2je0050000002g[<h0]jc>0;N/cP0000001P2^W/P00`000000YYK50:JF
a@040:JFa@040000002PT/D0X9;50:2Ba@@000001P2PS;h00`000000X9330:2@``040:2@``030000
002RV</0XYS;00@0XYS;0P0000070;>/d@040000002e_=l00000000000H0`/?J00<000000;o3g@2o
`md01P2o`md2000000D0ZIo=00<0000009fGc@2MUld0102MUld00`000000SiKF08nFeP0408nFeP03
0000001fXN`0MZ7/00@000003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0
oooo000a0?ooo`030000003oool0oooo02H0oooo0P0000020=W2a08000000`2na=h00`000000YiW8
0:NIb0040:NIb0030000002NT<D0WY3500<0WY3500<0000009ZCc02JTl`00P0000040;6Xc`030000
002f]ML0][GG00<0][GG00H000000<K2eP36`]H0a/;F00000037a]X2000000H0b<?F00@000000<2j
e00000000000102g[<h00`000000[Yk80:jNb0040:jNb0030000002VU/D0YYK500<0YYK51@000002
0:2;_@030000002PS;h0X8bn00D0X8bn00<000000:2@``2PT<<0102PT<<00`000000XYS;0::Hb`02
0::Hb`80000000<0[io70000002c[=401`2c[=400`000000`/?J0<;3fP050<;3fP030000003;c=X0
000000D0_l?M0`0000060:VOc@030000002MUld0WIO=00D0WIO=00<0000008nFeP2?U]H00`2?U]H3
000001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00<P3oool00`00
0000oooo0?ooo`0W0?ooo`8000001@2na=h00`000000YiW80:NIb0040:NIb0030000002NT<D0WY35
00<0WY350`0000060;6Xc`040000002f]ML0][GG0;Jee`8000001@36`]H00`000000b<?F0<S3eP07
0<S3eP030000002g[<h0]jc>00D0]jc>00<000000:jNb02^W/P0102^W/P00`000000YYK500000002
000000030::=_P000000X8^m00D0X8^m00<000000:2<_P2PS;h0102PS;h00`000000X9330:2@``05
0:2@``040000002RV</00000000000<0[io700<000000;>/d@2c[=401@2c[=400`000000`[WA0000
00050<;3fP040000003;c=X0blcJ000000@0_l?M00D000000;Rce02h/m@0^;?D000000060:VOc@03
0000002MUld0WIO=00@0WIO=00<0000008nFeP2?U]H00`00000H0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool003<0oooo00<000000?ooo`3oool09`3oool00`000000_/CN
0;k4gP040;k4gP030000002WVLP0YiW800@0YiW800<0000009j@a@0000000P0000020:ZPc@030000
002aZ<l0/JS?00D0/JS?00<000000;Jee`0000001P36`]H00`000000cLkJ000000060<S3eP800000
00<0`L3I0000002g[<h01@2g[<h00`000000[Yk80:jNb0030:jNb0<000001@2RSKh00`000000X8^m
0:2;_@030:2;_@030000002PS;h0X8bn00D0X8bn00<000000:2@``2PT<<0102PT<<2000000H0[io7
00<000000;>/d@2c[=400`2c[=4010000000`[WA0<:id@0000030<;3fP800000103;c=X010000000
_l?M0000000000040;Rce0030000002YWld0ZIo=00@0ZIo=00<0000009fGc@2MUld0102MUld30000
01/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`00=03oool2000002P0
oooo00<000000;k4gP2na=h00`2na=h00`000000YiW80:NIb0030:NIb0<000001@2ZX<d00`000000
/JS?0;6Xc`060;6Xc`0300000036`]H0a/;F00@0a/;F00D000000<g>fP3=c]X0cLkJ000000040<S3
eP0500000031`=T0`L3I0<70f@0000001`2g[<h00`000000[Yk800000002000000030:BC``000000
XXfn00D0XXfn00<000000:2;_@2PRkd0102PRkd00`000000X8bn0:2<_P040:2<_P030000002PT<<0
X9330080X9330`0000080:nOa`030000002c[=40/jcA008000001032^M400`000000`/?J00000007
0<_<fP030000002h/m@0^;?D00D0^;?D00<000000:VOc@2YWld0102YWld00`000000WIO=00000003
000001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00=P3oool00`00
0000oooo0?ooo`0V0?ooo`<000000`2na=h00`000000YiW80000000200000080Wj3E00<000000:ZP
c@2ZX<d0102ZX<d00`000000/JS?0;6Xc`030;6Xc`80000000<0`[kF00000036`]H00P36`]H20000
00D0cLkJ00@000000<S3eP00000000001@31`=T00`000000]jc>0;N/cP030;N/cP<000001@2TTl<0
0`000000XXfn0::=_P040::=_P030000002PRkd0X8^m00<0X8^m00<000000:2<_P2PS;h01@2PS;h0
10000000X9330000000000030:^F`@030000002_WlL0[io700D0[io700<000000;>/d@0000001`32
^M400`000000blcJ0<_<fP040<_<fP80000000<0bm[U0000002h/m@01@2h/m@00`000000ZIo=0:VO
c@030:VOc@<00000903oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000g
0?ooo`030000003oool0oooo02H0oooo00<0000006j[mP0000001000000509nPe@030000002ZX<d0
ZZ3=00D0ZZ3=00D000000;6Xc`2aZ<l0/JS?000000040<:neP0300000036`]H0000000P0cLkJ00<0
00000<70f@31`=T01@31`=T00`000000]jc>0;N/cP03000000030:VQcP000000Y9?300D0Y9?300<0
00000::=_P2RSKh0102RSKh00`000000X8^m0:2;_@040:2;_@030000002PS;h0X8bn00@0X8bn0P00
00050:^F`@030000002_WlL0[io700H0[io700<000000<:id@32^M401@32^M400`000000dmCJ0000
00040<_<fP050000003;f^D0bm[U0<_Ji@0000001`2h/m@00`000000ZIo=00000002000002P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`00>03oool00`000000oooo0?oo
o`0V0?ooo`030000001^ZoH0KZ_f0080KZ_f00<0000009nPe@2OX=D0102OX=D00`000000ZZ3=0:ZP
c@040:ZPc@040000002aZ<l00000000000H0`[kF00<000000<g>fP3=c]X01@3=c]X2000000030<WL
i`000000`L3I00H0`L3I0P0000050:VQcP030000002TTl<0Y9?300@0Y9?300<000000::=_P2RSKh0
0`2RSKh00`000000X8^m0:2;_@040:2;_@030000002PS;h0X8bn0080X8bn0`0000070:^F`@030000
002_WlL0[io700<0[io70P0000000`2o[l/000000<:id@040<:id@060000003Ce=X0dmCJ0=?DfP00
0000blcJ0P0000050<_Ji@030000002h/m@0^;?D0080^;?D1000000[0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool003T0oooo0P00000W0?ooo`050000001^ZoH0KZ_f06j[
mP0000001P2OX=D00`000000ZZ3=0:ZPc@050:ZPc@0300000032_]H0`[kF00D0`[kF00<000000<gI
h`0000001@3=c]X01@000000bMcW0<WLi`39g>L0000000D0`L3I0`0000060:VQcP030000002TTl<0
Y9?300@0Y9?300<000000::=_P2RSKh0102RSKh00`000000X8^m0:2;_@040:2;_@040000002PS;h0
0000000000<0YXnm00<000000:^F`@2[U/40102[U/4010000000[io70:nOa`2_WlL2000000<0_jo;
00@000000<:id@32^M40`[WA0P0000050=?DfP030000003;f^D0bm[U00D0bm[U1@00000`0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool003/0oooo00<000000?ooo`3oool0
9@3oool01@000000KZ_f06j[mP1^ZoH0000000H0Wj3E00<000000:ZPc@2ZX<d00P2ZX<d200000003
0;Jjg0000000`[kF00@0`[kF00@000000<gIh`3=fN<0cMWS0P0000000`3=c]X00000000000050<WL
i`0300000031`=T0`L3I008000000`2^^^800`000000ZJ7>0:VQcP030:VQcP030000002TTl<0Y9?3
00D0Y9?300<000000::=_P2RSKh00`2RSKh00`000000X8^m0:2;_@030:2;_@<000001@2VSkd00`00
0000ZiK10:^F`@050:^F`@<000001P2o[l/00`000000`[WA000000060=?DfP040000002an/h00000
00000080bm[U0`00000f0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
03`0oooo00<000000?ooo`3oool09@3oool200000080KZ_f00<0000009nPe@2OX=D00`2OX=D00`00
0000ZZ3=0:ZPc@02000000<0][[L00@000000<:neP32_]H0`[kF0P0000060<gIh`0300000039g>L0
bMcW00D0bMcW0`0000050:jjhP030000002YXLh0ZJ7>00@0ZJ7>00<000000:BC``2TTl<0102TTl<0
0`000000XXfn0::=_P040::=_P030000002PRkd000000080000000<0Xhbl0000002VSkd01@2VSkd0
0`000000ZiK10:^F`@050:^F`@030000002o[l/0_jo;00L0_jo;00<000000=?DfP3Ce=X0103Ce=X0
10000000/O[>0;7jcP2an/h3000003X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`080?ooo`00?@3oool00`000000oooo0?ooo`0U0?ooo`@00000102OX=D4000000H0][[L00<00000
0<:neP0000001P3=fN<2000000030;ofl000000000000080bMcW0`0000020:OSn`030000002^^^80
[[[R00@0[[[R00<000000:VQcP2YXLh00`2YXLh00`000000Y9?30:BC``050:BC``040000002RSKh0
XXfn0::=_P@000001@2SS;`00`000000YXnm0:J?_@040:J?_@030000002[U/40ZiK10080ZiK10P00
00000`2iYlL000000;n_b`060;n_b`030000003FgM`0000000<0dmCJ1P00000m0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool003h0oooo0P00000W0?ooo`H000000`2C/N/0
0`000000][[L0;Jjg0050;Jjg0030000003=fN<0cMWS00@0cMWS00<000000;ofl02om_000P2om_03
000000H0Yn?k0P0000040:jjhP030000002YXLh0ZJ7>00@0ZJ7>00@000000:BC``2TTl<0Y9?31`00
000209n;_`030000002SS;`0Xhbl00@0Xhbl00<000000:J?_@2VSkd0102VSkd01@000000ZiK10:^F
`@2[U/40000000<0^JO700<000000;n_b`2o[l/0102o[l/01P000000e]gL0=KMg03FgM`000000=?D
fP<00000@P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00100?ooo`03
0000003oool0oooo02D0oooo0`00000509>aj`030000002f^]`0][[L00<0][[L0P0000000`2lh?80
0000000000020<gIh`8000000P2om_0M000000<0VXk500<0000009n;_`2ORkl0102ORkl00`000000
Xhbl0:><_0030:><_0030000002VSkd0YXnm00D0YXnm0`0000050;VWa`030000002o[l/0_jo;0080
_jo;00<000000=KMg03FgM`00`3FgM`2000004D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`00@@3oool00`000000oooo0?ooo`0U0?ooo`<000001@2C/N/00`000000][[L
0;Jjg002000000D0_>3b200000020;jbcP030000001oU]l0OiKO00<0OiKO0P00000303Nak`030000
0021Z^l0PJ[_0080PJ[_00<0000009>Ge02CUm@00P2CUm@00`000000VXk509Z>a@0509Z>a@030000
002ORkl0Wh^o00<0Wh^o00<000000:><_02SS;`0102SS;`00`000000YXnm0:J?_@040:J?_@030000
002iYlL0^JO700H0^JO700@000000;n_b`2o[l/000001@3FgM`00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00480oooo00<000000?ooo`3oool0
9P3oool9000000@0_>3b0`0000000`28k>400000000000020<7]l@030000002n//h0_[;>00<0_[;>
00<0000007nFg`1oU]l00P1oU]l01P000000:F_K000000000000=k7_000000@0PJ[_00<0000009>G
e02CUm@00`2CUm@00`000000VXk509Z>a@0409Z>a@030000002ORkl0Wh^o00<0Wh^o00<000000:><
_02SS;`0102SS;`00`000000YXnm0:J?_@020:J?_@<00000202iYlL00`000000_jo;000000050=KM
g0030000003oool0oooo04L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`00@`3oool2000002L0oooo0`00000507O8o`P0000000@0g<:o00000000000000001P2n//h00`00
0000OiKO07nFg`0307nFg`030000000YJm/0:F_K00<000001021Z^l00`000000TiOD09>Ge00209>G
e0030000002JS/D0VXk500@0VXk500<0000009n;_`2ORkl0102ORkl00`000000Xhbl0:><_0030:><
_0050000002VSkd0YXnm0:J?_@0000000`2bXLH00`000000^JO70;VWa`060;VWa`030000003FgM`0
e]gL0080e]gL0P00001;0?ooo`050000003oool0oooo0?ooo`0000002@3oool004D0oooo00<00000
0?ooo`3oool09@3oool00`00000077oW0000000800000080c<CC00L000000=c2_`3L`[l0g<:o0000
003P`;L0000000H0_[;>1`00000202U[f`@000000`21Z^l00`000000TiOD09>Ge00209>Ge0030000
002JS/D0VXk500@0VXk500<0000009n;_`2ORkl00`2ORkl00`000000Xhbl0:><_0040:><_0<00000
102bXLH00`000000^JO70;VWa`040;VWa`80000000D0e>KS000000000000e]gL0000001>0?ooo`04
0000003oool0oooo000000T0oooo00160?ooo`030000003oool0oooo02D0oooo1000000409Rkl004
0000003<a=<0c<CC000000@0g<:o00<000000>30]`0000001@2n//h2000000D0TWJa0`0000000`0Y
Jm/0000000000005000000@0TiOD00<0000009Z>a@2JS/D0102JS/D00`000000Wh^o09n;_`0309n;
_`030000002SS;`0Xhbl00<0Xhbl0P0000070;:QaP030000002iYlL0^JO70080^JO700<000000=CV
h`3Di^<00`3Di^<00`000000oooo0?ooo`1=0?ooo`040000003oool0oooo000000T0oooo00170?oo
o`030000003oool0oooo02D0oooo00<0000009Rkl02H^o000P2H^o0200000080c<CC00<000000=c2
_`3L`[l00P3L`[l01@000000h<2g0>30]`3P`;L000000080_[;>0P0000000`2ZRK<00000099f/@04
099f/@030000001nKkL0OVng00D000000P0UO>H3000000<0TiOD00<0000009Z>a@2JS/D00`2JS/D0
0`000000Wh^o09n;_`0409n;_`030000002SS;`000000080000000<0ZI_80000002bXLH01P2bXLH0
1@000000^JO70;VWa`2iYlL0000000@0e>KS0P00001A0?ooo`030000003oool0000000T0oooo0018
0?ooo`8000009P3oool20000000309Rkl0000000c<CC00<0c<CC00<000000=c2_`3L`[l00P3L`[l0
1`000000h<2g0>30]`3P`;L000000;jbcP000000102ZRK<00`000000TWJa099f/@03099f/@040000
001nKkL0OVng07i_]`80000000<004O60000000UO>H00P0UO>H5000000H0VXk500@0000009n;_`2O
Rkl0Wh^o100000050:VKb0030000002bXLH0/Z7600D0/Z760`0000030=CVh`800000E03oool00`00
0000oooo000000080?ooo`00BP3oool00`000000oooo0?ooo`0U0?ooo`030000003<a=<0c<CC0080
c<CC00<000000=c2_`3L`[l00P3L`[l00`000000h<2g0>30]`030>30]`030000002ZRK<0ZXVc00<0
ZXVc00<00000099f/@2BM[400`2BM[400`000000OVng07i_]`0207i_]`D0000000<09GcV0000001Y
SN<00P1YSN<;00000080WIO=00<000000:VKb02YVlP0102YVlP00`000000/Z760;:QaP050;:QaP80
00000P3Di^<2000005L0oooo0P0000080?ooo`00B`3oool00`000000oooo0?ooo`0U0?ooo`040000
003<a=<0c<CC000000D0g<:o00<000000>30]`3P`;L00P3P`;L2000000D0ZXVc00<00000099f/@2B
M[400`2BM[400`000000OVng07i_]`0307i_]`030000001MK/`000000080000000<09GcV0000001Y
SN<00P1YSN<00`000000Ri?F08^CeP0308^CeP030000002MUld0WIO=00@0WIO=00<000000:VKb02Y
VlP0102YVlP00`000000/Z760;:QaP020;:QaP8000000P38kNh2000005T0oooo0P0000080?ooo`00
C03oool00`000000oooo0?ooo`0U0?ooo`030000003<a=<0000000@0g<:o00<000000>30]`3P`;L0
0`3P`;L00`000000g/6l000000040:Z9/`030000002BM[40TWJa00<0TWJa00<0000007i_]`1nKkL0
0`1nKkL010000000GFk<05e^c01MK/`3000000@0JHgS00<0000008^CeP2;TmH00`2;TmH00`000000
WIO=09fGc@0309fGc@030000002YVlP0ZI_800@0ZI_800D000000;:QaP2bXLH0/Z76000000030<S]
kP800000FP3oool2000000P0oooo001=0?ooo`030000003oool0oooo02D0oooo00<000000=c2_`3L
`[l00`3L`[l00`000000h<2g0>30]`020>30]`040000003N`K`0g/6l000000D0ZXVc00<00000099f
/@2BM[400`2BM[400`000000OVng07i_]`0307i_]`040000001MK/`0GFk<05e^c0<000000`1YSN<0
0`000000Ri?F08^CeP0308^CeP030000002MUld0WIO=00@0WIO=00<000000:VKb02YVlP0102YVlP3
000000<0b>g^00<000000?ooo`3oool0EP3oool4000000X0oooo001>0?ooo`8000009P3oool01@00
0000g<:o0=c2_`3L`[l0000000@0h<2g00D000000=k1_03N`K`0g/6l000000050:Z9/`030000002B
M[40TWJa00<0TWJa00<0000007i_]`1nKkL00`1nKkL00`000000GFk<05e^c00305e^c0<000000P1Y
SN<00`000000Ri?F08^CeP0308^CeP030000002MUld0WIO=00<0WIO=00<000000:VKb02YVlP00`2Y
VlP300000080b>g^0P00001E0?ooo`@000003P3oool00500oooo00<000000?ooo`3oool0903oool0
10000000g<:o0=c2_`0000040>30]`050000003N`K`0g/6l0=k1_00000001@2ZRK<00`000000TWJa
099f/@03099f/@030000001nKkL0OVng00@0OVng00<0000005e^c00000000P0000020?ooo`@00000
1@2;TmH00`000000WIO=09fGc@0409fGc@030000002YVlP00000008000000`2WjoT2000005<0oooo
1000000B0?ooo`00D@3oool00`000000oooo0?ooo`0T0?ooo`800000103P`;L00`000000g/6l0=k1
_0030=k1_0030000002ZRK<0ZXVc0080ZXVc00<00000099f/@2BM[400`2BM[400`000000OVng07i_
]`0307i_]`<00000203oool4000000<0Ri?F00@0000009fGc@2MUld0WIO=100000030:O[n@<00000
D@3oool4000001H0oooo001B0?ooo`030000003oool0oooo02@0oooo00D000000>30]`3P`;L0h<2g
000000060=k1_0030000002ZRK<0ZXVc00<0ZXVc00<00000099f/@2BM[400`2BM[400`000000OVng
00000002000000h0oooo2000000306O@nP@00000D03oool4000001X0oooo001C0?ooo`8000009@3o
ool2000000030>30]`000000g/6l00D0g/6l00<000000:Z9/`2ZRK<00`2ZRK<010000000TWJa099f
/@2BM[44000001D0oooo1`00001A0?ooo`<000007P3oool005D0oooo00<000000?ooo`3oool0903o
ool00`000000g/6l0=k1_0050=k1_0030000002ZRK<0ZXVc0080ZXVc1@00001]0?ooo`@000008@3o
ool005H0oooo00<000000?ooo`3oool0903oool00`000000g/6l0=k1_0050=k1_0040000002ZRK<0
0000000006h0oooo1000000U0?ooo`00E`3oool00`000000oooo0?ooo`0T0?ooo`030000003N`K`0
g/6l0080g/6l1000001/0?ooo`@00000:@3oool005P0oooo0P00000U0?ooo`@00000K03oool40000
02d0oooo001J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0JP3oool300000340
oooo001K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0IP3oool4000003@0oooo
001L0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0HP3oool4000003P0oooo001M
0?ooo`800000803oool00`000000oooo0?ooo`1N0?ooo`@00000?03oool005l0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000@03oool00600oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1F0?ooo`@00000A03oool00640oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`1C0?ooo`<00000B03oool00680oooo0P00000K0?ooo`030000003o
ool0oooo04l0oooo1000001;0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo04/0oooo1000001?0?ooo`00I@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
04L0oooo1000001C0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04<0
oooo1000001G0?ooo`00I`3oool2000001H0oooo00<000000?ooo`3oool0?`3oool4000005/0oooo
001Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?03oool3000005l0oooo001Z
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool400000680oooo001[0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool4000006H0oooo001/0?ooo`80
00004@3oool00`000000oooo0?ooo`0`0?ooo`@00000JP3oool006h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0]0?ooo`@00000KP3oool006l0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0Y0?ooo`@00000LP3oool00700oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0V0?ooo`<00000MP3oool00740oooo0P00000;0?ooo`030000003oool0oooo
0280oooo1000001i0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0
oooo1000001m0?ooo`00M03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo
100000210?ooo`00M@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo1000
00250?ooo`00MP3oool2000000H0oooo00<000000?ooo`3oool04`3oool3000008T0oooo001h0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool4000008`0oooo001i0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000900oooo001j0?ooo`050000
003oool0oooo0?ooo`0000002@3oool4000009@0oooo001k0?ooo`80000000<0oooo0000003oool0
103oool4000009P0oooo001m0?ooo`80000000<0oooo0000000000000P00002L0?ooo`00OP3oool2
00000:00oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0972833, 0.00572575, \
0.00375703, 0.00375703}},
  CellTags->"b:8.1.0"]
}, Closed]],

Cell["\<\
Here the Gauss points and weights are calculated for \
ngp\[Times]ngp\[Times]ngp Gauss numerical integration of the free energy over \
the domain [-.0.5m,0.5m]\[Times][-0.5m,0.5m]\[Times][0,1m].\
\>", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.0"],

Cell[BoxData[{
    \(\(ngp = 6;\)\), "\[IndentingNewLine]", 
    \(\(<< NumericalMath`GaussianQuadrature`;\)\), "\[IndentingNewLine]", 
    \(\(g1 = GaussianQuadratureWeights[ngp, \(-0.5\), 0.5];\)\), "\n", 
    \(\(g2 = GaussianQuadratureWeights[ngp, \(-0.5\), 0.5];\)\), "\n", 
    \(\(g3 = GaussianQuadratureWeights[ngp, 0, 1];\)\), "\n", 
    \(\(gp = \({g1[\([#1[\([1]\)], 1]\)], g2[\([#1[\([2]\)], 1]\)], 
              g3[\([#1[\([3]\)], 1]\)], 
              g1[\([#1[\([1]\)], 2]\)]*g2[\([#1[\([2]\)], 2]\)]*
                g3[\([#1[\([3]\)], 2]\)]} &\) /@ 
          Flatten[Array[{#3, #2, #1} &, {ngp, ngp, ngp}], 2];\)\)}], "Input",
  CellLabel->"In[260]:=",
  CellTags->"b:8.1.0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Direct use of Mathematica", "SubsubsectionIcon",
  CellTags->"b:8.1.0"],

Cell["\<\
The subsection Definitions has to be executed before the current \
subsection.\
\>", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(start = SessionTime[];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalDelta]\[Phi] = {D[\[Phi], x], D[\[Phi], y], 
          D[\[Phi], z]};\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPi] = 
        1/2\ kcond\ \[CapitalDelta]\[Phi] . \[CapitalDelta]\[Phi] - \[Phi]\ \
Q;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPi]i = 
        Total[Map[\((#[\([4]\)]\ \[CapitalPi] /. {x \[Rule] #[\([1]\)], 
                    y \[Rule] #[\([2]\)], z \[Rule] #[\([3]\)]})\) &, 
            gp]];\)\), "\[IndentingNewLine]", 
    \(derivation = SessionTime[] - start\)}], "Input",
  CellLabel->"In[266]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \(9.7540256`8.139698888919828\)], "Output",
  CellLabel->"Out[270]=",
  CellTags->"b:8.1.0"]
}, Closed]],

Cell["G. Gradient based optimization", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(start = SessionTime[]; ii = 0;\), "\[IndentingNewLine]", 
    \(\(sol = 
        FindMinimum[\[CapitalPi]i, Array[{a[#]\ , 0. } &, nterm], 
          Method \[Rule] "\<Gradient\>", 
          EvaluationMonitor \[RuleDelayed] \((\(\(ii++\);\))\)];\)\), "\
\[IndentingNewLine]", 
    \({ii, \(\[Phi] /. sol[\([2]\)]\) /. {x \[Rule] 0, y \[Rule] 0, 
          z \[Rule] 0.5}}\), "\[IndentingNewLine]", 
    \(SessionTime[] - start\)}], "Input",
  CellLabel->"In[271]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \({946, 55.872379099299295`}\)], "Output",
  CellLabel->"Out[273]=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \(66.8160768`8.975395969670895\)], "Output",
  CellLabel->"Out[274]=",
  CellTags->"b:8.1.0"]
}, Closed]],

Cell["N. Newton method based optimization", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(start = SessionTime[]; ii = 0;\), "\[IndentingNewLine]", 
    \(\(sol = 
        FindMinimum[\[CapitalPi]i, Array[{a[#]\ , 0. } &, nterm], 
          Method \[Rule] "\<Newton\>", 
          EvaluationMonitor \[RuleDelayed] \((\(\(ii++\);\))\)];\)\), "\
\[IndentingNewLine]", 
    \({ii, \(\[Phi] /. sol[\([2]\)]\) /. {x \[Rule] 0, y \[Rule] 0, 
          z \[Rule] 0.5}}\), "\[IndentingNewLine]", 
    \(SessionTime[] - start\)}], "Input",
  CellLabel->"In[275]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \({3, 55.872379098741725`}\)], "Output",
  CellLabel->"Out[30]=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \(2588.3418528`10.56353663264939\)], "Output",
  CellLabel->"Out[31]=",
  CellTags->"b:8.1.0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AceGen code generation", "SubsubsectionIcon",
  CellTags->"b:8.1.0"],

Cell["\<\
The subsection Definitions has to be executed before the current \
subsection.\
\>", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.0"],

Cell[BoxData[{
    \(\(\(start = SessionTime[]; 
    SMSInitialize["\<Thermal\>", "\<Environment\>" -> "\<MathLink\>", "\<Mode\
\>" \[Rule] "\<Prototype\>", "\<ADMethod\>" -> "\<Forward\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[CapitalPi]f[
        i_] := \((\[IndentingNewLine]ai \[DoubleRightTee] 
          SMSReal[Array[a$$, nterm]]; \[IndentingNewLine]ag \[DoubleRightTee] 
          SMSArray[ai]; \[IndentingNewLine]{xa, ya, za, wa} \[DoubleRightTee] 
          Map[SMSArray, Transpose[gp]]; \[IndentingNewLine]{xi, yi, 
            zi} \[DoubleRightTee] 
          SMSFreeze[{SMSPart[xa, i], SMSPart[ya, i], 
              SMSPart[za, i]}]; \[IndentingNewLine]{xpr, ypr, 
            zpr} \[DoubleRightTee] {xp /. x \[Rule] xi, yp /. y \[Rule] yi, 
            zp /. z \[Rule] zi}; \[IndentingNewLine]poly \[DoubleRightTee] 
          SMSArray[
            Flatten[Outer[Times, xpr, ypr, 
                zpr]]]; \[IndentingNewLine]\[Phi]t \[DoubleRightTee] 
          SMSDot[poly, 
            ag]; \[IndentingNewLine]\[CapitalDelta]\[Phi] \[DoubleRightTee] 
          SMSD[\[Phi]t, {xi, yi, 
              zi}]; \[IndentingNewLine]wi \[DoubleRightTee] 
          SMSPart[wa, 
            i]; \[IndentingNewLine]wi \((1/
                  2\ kcond\ \[CapitalDelta]\[Phi] . \[CapitalDelta]\[Phi] - \
\[Phi]t\ Q)\)\[IndentingNewLine])\)\)}], "Input",
  CellLabel->"In[19]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[{
    \(\(SMSModule["\<FThermal\>", 
        Real[a$$[nterm], f$$], "\<Input\>" \[Rule] a$$, "\<Output\>" \[Rule] 
          f$$];\)\), "\n", 
    \(\(SMSExport[0, f$$];\)\), "\[IndentingNewLine]", 
    \(\(SMSDo[i, 1, gp // Length];\)\), "\[IndentingNewLine]", 
    \(\t\(\[CapitalPi] \[DoubleRightTee] \[CapitalPi]f[i];\)\), "\n", 
    \(\t\(SMSExport[\ \[CapitalPi], 
        f$$, "\<AddIn\>" \[Rule] True];\)\), "\n", 
    \(\(SMSEndDo[];\)\)}], "Input",
  CellLabel->"In[21]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[{
    \(\(SMSModule["\<GThermal\>", 
        Real[a$$[nterm], g$$[nterm]], "\<Input\>" \[Rule] 
          a$$, "\<Output\>" \[Rule] g$$];\)\), "\n", 
    \(\(SMSExport[Table[0, {nterm}], g$$];\)\), "\[IndentingNewLine]", 
    \(\(SMSDo[i, 1, gp // Length];\)\), "\n", 
    \(\t\(\[CapitalPi] \[DoubleRightTee] \[CapitalPi]f[i];\)\), "\n", 
    \(\t\(SMSDo[j, 1, nterm];\)\), "\n", 
    \(\t\t\(\[Delta]\[CapitalPi] \[DoubleRightTee] 
        SMSD[\[CapitalPi], ag, j, "\<Method\>" -> "\<Forward\>"];\)\), "\n", 
    \(\t\t\(SMSExport[\[Delta]\[CapitalPi], 
        g$$[j], "\<AddIn\>" \[Rule] True];\)\), "\n", 
    \(\t\(SMSEndDo[];\)\), "\n", 
    \(\(SMSEndDo[];\)\)}], "Input",
  CellLabel->"In[27]:=",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{

Cell[BoxData[
    \(derivation = SessionTime[] - start\)], "Input",
  CellLabel->"In[36]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \(5.8984816`7.921255226828315\)], "Output",
  CellLabel->"Out[36]=",
  CellTags->"b:8.1.0"]
}, Closed]],

Cell[BoxData[{
    \(\(SMSModule["\<HThermal\>", 
        Real[a$$[nterm], h$$[nterm, nterm]], "\<Input\>" \[Rule] 
          a$$, "\<Output\>" \[Rule] h$$];\)\), "\n", 
    \(\(SMSDo[i, 1, nterm];\)\), "\[IndentingNewLine]", 
    \(\t\(SMSDo[j, 1, nterm];\)\), "\[IndentingNewLine]", 
    \(\t\t\(SMSExport[0, h$$[i, j]];\)\), "\[IndentingNewLine]", 
    \(\t\(SMSEndDo[];\)\), "\[IndentingNewLine]", 
    \(\(SMSEndDo[];\)\), "\[IndentingNewLine]", 
    \(\(SMSDo[i, 1, gp // Length];\)\), "\n", 
    \(\t\(\[CapitalPi] \[DoubleRightTee] \[CapitalPi]f[i];\)\), "\n", 
    \(\t\(SMSDo[j, 1, nterm];\)\), "\n", 
    \(\t\t\(\[Delta]\[CapitalPi] \[DoubleRightTee] 
        SMSD[\[CapitalPi], ag, j, "\<Method\>" -> "\<Forward\>"];\)\), "\n", 
    \(\t\t\(SMSDo[k, 1, nterm];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\(hij \[DoubleRightTee] 
        SMSD[\[Delta]\[CapitalPi], ag, 
          k, "\<Method\>" -> "\<Forward\>"];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\(SMSExport[hij, 
        h$$[j, k], "\<AddIn\>" \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\t\t\(SMSEndDo[];\)\), "\n", 
    \(\t\(SMSEndDo[];\)\), "\n", 
    \(\(SMSEndDo[];\)\)}], "Input",
  CellLabel->"In[37]:=",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SMSWrite[];\)\)], "Input",
  CellLabel->"In[53]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Method : \"\>",
            Background->RGBColor[0.996109, 0.996109, 0]],
          (
          StyleForm[ #, Background -> 
            RGBColor[ .99610900000000002, .99610900000000002, 0]]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"FThermal\"\>",
            FontSize->20,
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0.589853, 0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> RGBColor[ 
            0, .58985299999999996, 0], FontSize -> 20]&)], 
        "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "170", 
        "\[InvisibleSpace]", "\<\" formulae, \"\>", "\[InvisibleSpace]", 
        "6007", "\[InvisibleSpace]", "\<\" sub-expressions\"\>"}],
      SequenceForm[ 
        StyleForm[ 
        "Method : ", Background -> 
          RGBColor[ .99610900000000002, .99610900000000002, 0]], 
        StyleForm[ 
        "FThermal", FontWeight -> "Bold", FontColor -> RGBColor[ 
          0, .58985299999999996, 0], FontSize -> 20], " ", 170, " formulae, ",
         6007, " sub-expressions"],
      Editable->False]], "Print",
  CellLabel->"From In[53]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Method : \"\>",
            Background->RGBColor[0.996109, 0.996109, 0]],
          (
          StyleForm[ #, Background -> 
            RGBColor[ .99610900000000002, .99610900000000002, 0]]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"GThermal\"\>",
            FontSize->20,
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0.589853, 0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> RGBColor[ 
            0, .58985299999999996, 0], FontSize -> 20]&)], 
        "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "169", 
        "\[InvisibleSpace]", "\<\" formulae, \"\>", "\[InvisibleSpace]", 
        "6115", "\[InvisibleSpace]", "\<\" sub-expressions\"\>"}],
      SequenceForm[ 
        StyleForm[ 
        "Method : ", Background -> 
          RGBColor[ .99610900000000002, .99610900000000002, 0]], 
        StyleForm[ 
        "GThermal", FontWeight -> "Bold", FontColor -> RGBColor[ 
          0, .58985299999999996, 0], FontSize -> 20], " ", 169, " formulae, ",
         6115, " sub-expressions"],
      Editable->False]], "Print",
  CellLabel->"From In[53]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Method : \"\>",
            Background->RGBColor[0.996109, 0.996109, 0]],
          (
          StyleForm[ #, Background -> 
            RGBColor[ .99610900000000002, .99610900000000002, 0]]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"HThermal\"\>",
            FontSize->20,
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0.589853, 0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> RGBColor[ 
            0, .58985299999999996, 0], FontSize -> 20]&)], 
        "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "87", 
        "\[InvisibleSpace]", "\<\" formulae, \"\>", "\[InvisibleSpace]", 
        "4588", "\[InvisibleSpace]", "\<\" sub-expressions\"\>"}],
      SequenceForm[ 
        StyleForm[ 
        "Method : ", Background -> 
          RGBColor[ .99610900000000002, .99610900000000002, 0]], 
        StyleForm[ 
        "HThermal", FontWeight -> "Bold", FontColor -> RGBColor[ 
          0, .58985299999999996, 0], FontSize -> 20], " ", 87, " formulae, ", 
        4588, " sub-expressions"],
      Editable->False]], "Print",
  CellLabel->"From In[53]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "10", 
        "\[InvisibleSpace]", "\<\"] \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"File created : \"\>",
            Background->RGBColor[0.996109, 0.996109, 0]],
          (
          StyleForm[ #, Background -> 
            RGBColor[ .99610900000000002, .99610900000000002, 0]]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"Thermal.c\"\>",
            FontSize->20,
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0.589853, 0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> RGBColor[ 
            0, .58985299999999996, 0], FontSize -> 20]&)], 
        "\[InvisibleSpace]", "\<\" Size : \"\>", "\[InvisibleSpace]", 
        "134572"}],
      SequenceForm[ "[", 10, "] ", 
        StyleForm[ 
        "File created : ", Background -> 
          RGBColor[ .99610900000000002, .99610900000000002, 0]], 
        StyleForm[ 
        "Thermal.c", FontWeight -> "Bold", FontColor -> RGBColor[ 
          0, .58985299999999996, 0], FontSize -> 20], " Size : ", 134572],
      Editable->False]], "Print",
  CellLabel->"From In[53]:=",
  CellTags->"b:8.1.0"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SMSInstallMathLink["\<Optimize\>" \[Rule] 
        False]\), "\[IndentingNewLine]", 
    \(derivation = SessionTime[] - start\)}], "Input",
  CellLabel->"In[54]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(SMSMathLink["Thermal", i_Integer, j_Integer : 0]\),
          HoldForm], ",", 
        TagBox[\(FThermal[
            a_?\((ArrayQ[#1, 1, NumberQ] && Dimensions[#1] === {80} &)\)]\),
          HoldForm], ",", 
        TagBox[\(GThermal[
            a_?\((ArrayQ[#1, 1, NumberQ] && Dimensions[#1] === {80} &)\)]\),
          HoldForm], ",", 
        TagBox[\(HThermal[
            a_?\((ArrayQ[#1, 1, NumberQ] && Dimensions[#1] === {80} &)\)]\),
          HoldForm]}], "}"}]], "Output",
  CellLabel->"Out[54]=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \(12.3277264`8.24139798497253\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"b:8.1.0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AceGen Solution", "SubsubsectionIcon",
  CellTags->"b:8.1.0"],

Cell["G. Gradient based optimization", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(start = SessionTime[]; ii = 0;\), "\[IndentingNewLine]", 
    \(\(sol = 
        FindMinimum[FThermal[\[Phi]i], {\[Phi]i, Table[0, {nterm}]}, 
          Method \[Rule] "\<Gradient\>", Gradient \[Rule] GThermal[\[Phi]i], 
          EvaluationMonitor \[RuleDelayed] \((\(\(ii++\);\))\)];\)\), "\
\[IndentingNewLine]", 
    \({ii, \(\[Phi] /. 
          MapThread[Rule, List @@ sol[\([2, 1]\)]]\) /. {x \[Rule] 0, 
          y \[Rule] 0, z \[Rule] 0.5}, SessionTime[] - start}\)}], "Input",
  CellLabel->"In[83]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \({962, 55.87238074045553`, 3.0243488`7.631146874998364}\)], "Output",
  CellLabel->"Out[85]=",
  CellTags->"b:8.1.0"]
}, Closed]],

Cell["N. Newton method based optimization", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(start = SessionTime[]; ii = 0;\), "\[IndentingNewLine]", 
    \(\(sol = 
        FindMinimum[
          FThermal[\[Phi]i], {\[Phi]i, 
            Table[0, {nterm}]}, \[IndentingNewLine]Method \[Rule] \
{"\<Newton\>", \ 
              Hessian \[Rule] 
                HThermal[\[Phi]i]}, \[IndentingNewLine]Gradient \[Rule] 
            GThermal[\[Phi]i], 
          EvaluationMonitor \[RuleDelayed] \((\(\(ii++\);\))\)];\)\), "\
\[IndentingNewLine]", 
    \({ii, \(\[Phi] /. 
          MapThread[Rule, List @@ sol[\([2, 1]\)]]\) /. {x \[Rule] 0, 
          y \[Rule] 0, z \[Rule] 0.5}, SessionTime[] - start}\)}], "Input",
  CellLabel->"In[86]:=",
  CellTags->"b:8.1.0"],

Cell[BoxData[
    \({4, 55.87237909874222`, 0.7711088`7.037630657213695}\)], "Output",
  CellLabel->"Out[88]=",
  CellTags->"b:8.1.0"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["B) Finite difference interpolation", "Subsection",
  CellTags->{"i:61", "b:8.1.1", "c:46"}],

Cell[CellGroupData[{

Cell["Definitions", "SubsubsectionIcon",
  CellTags->"b:8.1.1"],

Cell["\<\
The central difference approximation of derivatives is used for the points \
inside the cube and backward or forward difference for the points on the \
boundary.\
\>", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.1"],

Cell[BoxData[{
    \(\(<< AceGen`;\)\), "\[IndentingNewLine]", 
    \(\(Clear[a, i, j, k];\)\), "\[IndentingNewLine]", 
    \(\(nx = \(ny = \(nz = 11\)\);\)\), "\[IndentingNewLine]", 
    \(\(dlx = 1. /\((nx - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(dly = 1. /\((ny - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(dlz = 1. /\((nz - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(bound = {0};\)\), "\[IndentingNewLine]", 
    \(\(nboun = 1;\)\), "\[IndentingNewLine]", 
    \(kcond = 0.58; Q = 500;\)}], "Input",
  CellLabel->"In[1]:=",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nterm = 0; dofs = {};\), "\[IndentingNewLine]", 
    \(\(index = 
        Table[Which[\[IndentingNewLine]i \[LessEqual] 2\  || \ 
                i\  \[GreaterEqual] \ \ nx + 1\ \  || \ 
                j \[LessEqual] 2\  || \ 
                j\  \[GreaterEqual] \ \ ny + 1\ \  || \ k \[LessEqual] \ 2\ , 
              b[1]\[IndentingNewLine], 
              k \[Equal] nz + 2, \[IndentingNewLine]If[
                FreeQ[dofs, a[i, j, k - 1]]\[IndentingNewLine], \(++nterm\); 
                AppendTo[dofs, a[i, j, k - 1] \[Rule] nterm]; 
                nterm\[IndentingNewLine], 
                a[i, j, k - 1] /. 
                  dofs\[IndentingNewLine]]\[IndentingNewLine], 
              True, \[IndentingNewLine]If[
                FreeQ[dofs, a[i, j, k]]\[IndentingNewLine], \(++nterm\); 
                AppendTo[dofs, a[i, j, k] \[Rule] nterm]; 
                nterm\[IndentingNewLine], 
                a[i, j, k] /. 
                  dofs\[IndentingNewLine]]\[IndentingNewLine]], \
\[IndentingNewLine]{i, 1, nx + 2}, {j, 1, ny + 2}, {k, 1, nz + 2}] /. 
          b[i_] \[RuleDelayed] nterm + i;\)\), "\[IndentingNewLine]", 
    \(\(\[Phi]i = Array[a, nterm];\)\), "\[IndentingNewLine]", 
    \(nterm\)}], "Input",
  CellLabel->"In[10]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(810\)], "Output",
  CellLabel->"Out[13]=",
  CellTags->"b:8.1.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Direct use of Mathematica", "SubsubsectionIcon",
  CellTags->"b:8.1.1"],

Cell["\<\
The subsection Definitions have to be executed before the current subsection.\
\
\>", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(start = SessionTime[];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPi]i = 
        Sum[\[IndentingNewLine]dlxt = 
            If[i \[Equal] 2\  || \ i \[Equal] nx + 1\ , dlxt = dlx/2, 
              dlx]; \[IndentingNewLine]dlyt = 
            If[j \[Equal] 2\  || \ j \[Equal] ny + 1\ , dlyt = dly/2, 
              dly]; \[IndentingNewLine]dlzt = 
            If[k \[Equal] 2\  || \ k \[Equal] nz + 1\ , dlzt = dlz/2, 
              dlz]; \[IndentingNewLine]vol = 
            dlxt\ dlyt\ dlzt; \[IndentingNewLine]aijk = 
            Map[If[# > nterm, bound[\([# - nterm]\)], 
                  a[#]] &, \[IndentingNewLine]Extract[
                index, {{i, j, k}, {i - 1, j, k}, {i + 1, j, k}, {i, j - 1, 
                    k}, \[IndentingNewLine]{i, j + 1, k}, {i, j, k - 1}, {i, 
                    j, k + 1}}]]; \[IndentingNewLine]grad = {\(aijk[\([3]\)] \
- aijk[\([2]\)]\)\/\(2\ dlxt\), \(aijk[\([5]\)] - aijk[\([4]\)]\)\/\(2\ \
dlyt\), \(aijk[\([7]\)] - aijk[\([6]\)]\)\/\(2\ dlzt\)}; \[IndentingNewLine]\
\[IndentingNewLine]vol \((1/2\ kcond\ grad . grad - 
                Q\ aijk[\([1]\)])\)\[IndentingNewLine], {i, 2, nx + 1}, {j, 
            2, ny + 1}, {k, 2, 
            nz + 1}\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(derivation = SessionTime[] - start\)}], "Input",
  CellLabel->"In[14]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(0.2904176`6.613537929940169\)], "Output",
  CellLabel->"Out[16]=",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell["G. Gradient based optimization", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(start = SessionTime[]; ii = 0;\), "\[IndentingNewLine]", 
    \(\(sol = 
        FindMinimum[\[CapitalPi]i, Array[{a[#]\ , 0. } &, nterm], 
          Method \[Rule] "\<Gradient\>", 
          EvaluationMonitor \[RuleDelayed] \((\(\(ii++\);\))\)];\)\), "\
\[IndentingNewLine]", 
    \({ii, 
      a[index[\([\((nx + 3)\)/2, \((ny + 3)\)/2, \((nz + 3)\)/2]\)]] /. 
        sol[\([2]\)], SessionTime[] - start}\)}], "Input",
  CellLabel->"In[17]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    RowBox[{\(FindMinimum::"cvmit"\), \(\(:\)\(\ \)\), "\<\"Failed to \
converge to the requested accuracy or precision within \\!\\(100\\) \
iterations. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"FindMinimum::cvmit\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[17]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \({1685, 57.50340182121007`, 387.5973376`9.738895783059018}\)], "Output",
  CellLabel->"Out[19]=",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell["N. Newton method based optimization", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(start = SessionTime[]; ii = 0;\), "\[IndentingNewLine]", 
    \(\(sol = 
        FindMinimum[\[CapitalPi]i, Array[{a[#]\ , 0. } &, nterm], 
          Method \[Rule] "\<Newton\>", 
          EvaluationMonitor \[RuleDelayed] \((\(\(ii++\);\))\)];\)\), "\
\[IndentingNewLine]", 
    \({ii, 
      a[index[\([\((nx + 3)\)/2, \((ny + 3)\)/2, \((nz + 3)\)/2]\)]] /. 
        sol[\([2]\)], SessionTime[] - start}\)}], "Input",
  CellLabel->"In[17]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \({4, 57.50340181959712`, 3.7654144`7.7263277769688745}\)], "Output",
  CellLabel->"Out[19]=",
  CellTags->"b:8.1.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AceGen code generation", "SubsubsectionIcon",
  CellTags->"b:8.1.1"],

Cell["\<\
The subsection Definitions have to be executed before the current subsection.\
\
\>", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.1"],

Cell[BoxData[{
    \(\(\(start = SessionTime[]; 
    SMSInitialize["\<Thermal\>", "\<Environment\>" -> "\<MathLink\>", "\<Mode\
\>" \[Rule] "\<Prototype\>", "\<ADMethod\>" -> "\<Backward\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[CapitalPi]f[i_, j_, 
        k_] := \((\[IndentingNewLine]indexp \[DoubleRightTee] 
          SMSInteger[
            Map[\[IndentingNewLine]index$$[\((#[\([1]\)] - 1)\)*\((nyp + 
                          2)\) \((nzp + 2)\) + \((#[\([2]\)] - 1)\)*\((nzp + 
                          2)\) + #[\([3]\)]] &, \[IndentingNewLine]{{i, j, 
                  k}, {i - 1, j, k}, {i + 1, j, k}, {i, j - 1, 
                  k}, \[IndentingNewLine]{i, j + 1, k}, {i, j, k - 1}, {i, j, 
                  k + 1}}]]; \[IndentingNewLine]aijk \[DoubleRightTee] 
          SMSReal[Map[a$$[#] &, indexp]]; \[IndentingNewLine]{dx, dy, dz, kc, 
            Qt} \[DoubleRightTee] 
          SMSReal[Array[mc$$, 5]]; \[IndentingNewLine]SMSIf[
          i \[Equal] 2\  || \ i \[Equal] nxp + 1\ ]; \[IndentingNewLine]\t
        dlxt \[DoubleLeftTee] 
          dx/2; \[IndentingNewLine]SMSElse[]; \[IndentingNewLine]\t
        dlxt \[LeftTee] dx; \[IndentingNewLine]SMSEndIf[
          dlxt]; \[IndentingNewLine]SMSIf[
          j \[Equal] 2\  || \ j \[Equal] nyp + 1\ ]; \[IndentingNewLine]\t
        dlyt \[DoubleLeftTee] 
          dy/2; \[IndentingNewLine]SMSElse[]; \[IndentingNewLine]\t
        dlyt \[LeftTee] dy; \[IndentingNewLine]SMSEndIf[
          dlyt]; \[IndentingNewLine]SMSIf[
          k \[Equal] 2\  || \ k \[Equal] nzp + 1\ ]; \[IndentingNewLine]\t
        dlzt \[DoubleLeftTee] 
          dz/2; \[IndentingNewLine]SMSElse[]; \[IndentingNewLine]\t
        dlzt \[LeftTee] dz; \[IndentingNewLine]SMSEndIf[
          dlzt]; \[IndentingNewLine]vol \[DoubleRightTee] 
          dlxt\ dlyt\ dlzt; \[IndentingNewLine]grad = {\(aijk[\([3]\)] - \
aijk[\([2]\)]\)\/\(2\ dlxt\), \(aijk[\([5]\)] - aijk[\([4]\)]\)\/\(2\ dlyt\), \
\(aijk[\([7]\)] - aijk[\([6]\)]\)\/\(2\ dlzt\)}; \[IndentingNewLine]vol\ \((1/
                  2\ kc\ grad . grad - 
              Qt\ aijk[\([1]\)])\)\[IndentingNewLine])\)\)}], "Input",
  CellLabel->"In[14]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[{
    \(\(SMSModule["\<FThermal\>", Integer[ndof$$, nt$$[3], index$$["\<*\>"]], 
        Real[a$$["\<*\>"], mc$$["\<*\>"], 
          f$$], "\<Input\>" \[Rule] {ndof$$, nt$$, index$$, a$$, 
            mc$$}, "\<Output\>" \[Rule] f$$];\)\), "\[IndentingNewLine]", 
    \(\(SMSExport[0, f$$];\)\), "\[IndentingNewLine]", 
    \(\({nxp, nyp, nzp} \[DoubleRightTee] 
        SMSInteger[Array[nt$$, 3]];\)\), "\[IndentingNewLine]", 
    \(\(SMSDo[i, 2, nxp + 1];\)\), "\n", 
    \(\t\(SMSDo[j, 2, nyp + 1];\)\), "\n", 
    \(\t\t\(SMSDo[k, 2, nzp + 1];\)\), "\n", 
    \(\t\t\t\(\[CapitalPi] \[DoubleRightTee] \[CapitalPi]f[i, j, 
          k];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\(SMSExport[\[CapitalPi], 
        f$$, "\<AddIn\>" \[Rule] True];\)\), "\n", 
    \(\t\t\(SMSEndDo[];\)\), "\n", 
    \(\t\(SMSEndDo[];\)\), "\n", 
    \(\(SMSEndDo[];\)\)}], "Input",
  CellLabel->"In[16]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[{
    \(\(SMSModule["\<GThermal\>", Integer[ndof$$, nt$$[3], index$$["\<*\>"]], 
        Real[a$$["\<*\>"], mc$$["\<*\>"], 
          g$$[ndof$$]], "\<Input\>" \[Rule] {ndof$$, nt$$, index$$, a$$, 
            mc$$}, "\<Output\>" \[Rule] g$$];\)\), "\[IndentingNewLine]", 
    \(\(ndof \[DoubleRightTee] 
        SMSInteger[ndof$$];\)\), "\[IndentingNewLine]", 
    \(\({nxp, nyp, nzp} \[DoubleRightTee] 
        SMSInteger[Array[nt$$, 3]];\)\), "\[IndentingNewLine]", 
    \(\(SMSDo[i, 1, ndof];\)\), "\[IndentingNewLine]", 
    \(\t\(SMSExport[0, g$$[i]];\)\), "\[IndentingNewLine]", 
    \(\(\(SMSEndDo[];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SMSDo[i, 2, nxp + 1];\)\), "\n", 
    \(\t\(SMSDo[j, 2, nyp + 1];\)\), "\n", 
    \(\t\t\(SMSDo[k, 2, nzp + 1];\)\), "\n", 
    \(\t\t\t\(\[CapitalPi] \[DoubleRightTee] \[CapitalPi]f[i, j, 
          k];\)\), "\n", 
    \(\t\t\t\(SMSDo[i1, 1, indexp // Length];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\(dof \[DoubleRightTee] 
        SMSPart[indexp, i1];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\(SMSIf[dof <= ndof];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\t\(gi \[DoubleRightTee] 
        SMSD[\[CapitalPi], aijk, i1];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\t\(SMSExport[gi, 
        g$$[dof], "\<AddIn\>" \[Rule] True];\)\), "\n", 
    \(\t\t\t\t\(SMSEndIf[];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\(SMSEndDo[];\)\), "\n", 
    \(\t\t\(SMSEndDo[];\)\), "\n", 
    \(\t\(SMSEndDo[];\)\), "\[IndentingNewLine]", 
    \(\(SMSEndDo[];\)\)}], "Input",
  CellLabel->"In[27]:=",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(derivation = SessionTime[] - start\)], "Input",
  CellLabel->"In[47]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(1.4420736`7.309502424136462\)], "Output",
  CellLabel->"Out[47]=",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell[BoxData[{
    \(\(SMSModule["\<HThermal\>", Integer[ndof$$, nt$$[3], index$$["\<*\>"]], 
        Real[a$$["\<*\>"], mc$$["\<*\>"], 
          h$$[ndof$$, ndof$$]], "\<Input\>" \[Rule] {ndof$$, nt$$, index$$, 
            a$$, mc$$}, "\<Output\>" \[Rule] 
          h$$];\)\), "\[IndentingNewLine]", 
    \(\(ndof \[DoubleRightTee] 
        SMSInteger[ndof$$];\)\), "\[IndentingNewLine]", 
    \(\({nxp, nyp, nzp} \[DoubleRightTee] 
        SMSInteger[Array[nt$$, 3]];\)\), "\[IndentingNewLine]", 
    \(\(SMSDo[i, 1, ndof];\)\), "\[IndentingNewLine]", 
    \(\t\(SMSDo[j, 1, ndof];\)\), "\[IndentingNewLine]", 
    \(\t\t\(SMSExport[0, h$$[i, j]];\)\), "\[IndentingNewLine]", 
    \(\t\(SMSEndDo[];\)\), "\[IndentingNewLine]", 
    \(\(\(SMSEndDo[];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SMSDo[i, 2, nxp + 1];\)\), "\n", 
    \(\t\(SMSDo[j, 2, nyp + 1];\)\), "\n", 
    \(\t\t\(SMSDo[k, 2, nzp + 1];\)\), "\n", 
    \(\t\t\t\(\[CapitalPi] \[DoubleRightTee] \[CapitalPi]f[i, j, 
          k];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\(SMSDo[i1, 1, indexp // Length];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\(dofi \[DoubleRightTee] 
        SMSPart[indexp, i1];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\(SMSIf[dofi <= ndof];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\t\(gi \[DoubleRightTee] 
        SMSD[\[CapitalPi], aijk, i1];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\t\(SMSDo[j1, 1, 
        indexp // Length];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\t\t\(dofj \[DoubleRightTee] 
        SMSPart[indexp, j1];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\t\t\(SMSIf[dofj <= ndof];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\t\t\t\(hij \[DoubleRightTee] 
        SMSD[gi, aijk, j1];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\t\t\t\(SMSExport[hij, 
        h$$[dofi, dofj], "\<AddIn\>" \[Rule] True];\)\), "\n", 
    \(\t\t\t\t\t\t\(SMSEndIf[];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\t\t\(SMSEndDo[];\)\), "\n", 
    \(\t\t\t\t\(SMSEndIf[];\)\), "\[IndentingNewLine]", 
    \(\t\t\t\(SMSEndDo[];\)\), "\[IndentingNewLine]", 
    \(\t\t\(SMSEndDo[];\)\), "\n", 
    \(\t\(SMSEndDo[];\)\), "\[IndentingNewLine]", 
    \(\(SMSEndDo[];\)\)}], "Input",
  CellLabel->"In[48]:=",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SMSWrite[];\)\)], "Input",
  CellLabel->"In[76]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Method : \"\>",
            Background->RGBColor[0.996109, 0.996109, 0]],
          (
          StyleForm[ #, Background -> 
            RGBColor[ .99610900000000002, .99610900000000002, 0]]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"FThermal\"\>",
            FontSize->20,
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0.589853, 0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> RGBColor[ 
            0, .58985299999999996, 0], FontSize -> 20]&)], 
        "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "32", 
        "\[InvisibleSpace]", "\<\" formulae, \"\>", "\[InvisibleSpace]", 
        "471", "\[InvisibleSpace]", "\<\" sub-expressions\"\>"}],
      SequenceForm[ 
        StyleForm[ 
        "Method : ", Background -> 
          RGBColor[ .99610900000000002, .99610900000000002, 0]], 
        StyleForm[ 
        "FThermal", FontWeight -> "Bold", FontColor -> RGBColor[ 
          0, .58985299999999996, 0], FontSize -> 20], " ", 32, " formulae, ", 
        471, " sub-expressions"],
      Editable->False]], "Print",
  CellLabel->"From In[76]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Method : \"\>",
            Background->RGBColor[0.996109, 0.996109, 0]],
          (
          StyleForm[ #, Background -> 
            RGBColor[ .99610900000000002, .99610900000000002, 0]]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"GThermal\"\>",
            FontSize->20,
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0.589853, 0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> RGBColor[ 
            0, .58985299999999996, 0], FontSize -> 20]&)], 
        "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "42", 
        "\[InvisibleSpace]", "\<\" formulae, \"\>", "\[InvisibleSpace]", 
        "550", "\[InvisibleSpace]", "\<\" sub-expressions\"\>"}],
      SequenceForm[ 
        StyleForm[ 
        "Method : ", Background -> 
          RGBColor[ .99610900000000002, .99610900000000002, 0]], 
        StyleForm[ 
        "GThermal", FontWeight -> "Bold", FontColor -> RGBColor[ 
          0, .58985299999999996, 0], FontSize -> 20], " ", 42, " formulae, ", 
        550, " sub-expressions"],
      Editable->False]], "Print",
  CellLabel->"From In[76]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Method : \"\>",
            Background->RGBColor[0.996109, 0.996109, 0]],
          (
          StyleForm[ #, Background -> 
            RGBColor[ .99610900000000002, .99610900000000002, 0]]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"HThermal\"\>",
            FontSize->20,
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0.589853, 0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> RGBColor[ 
            0, .58985299999999996, 0], FontSize -> 20]&)], 
        "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "38", 
        "\[InvisibleSpace]", "\<\" formulae, \"\>", "\[InvisibleSpace]", 
        "559", "\[InvisibleSpace]", "\<\" sub-expressions\"\>"}],
      SequenceForm[ 
        StyleForm[ 
        "Method : ", Background -> 
          RGBColor[ .99610900000000002, .99610900000000002, 0]], 
        StyleForm[ 
        "HThermal", FontWeight -> "Bold", FontColor -> RGBColor[ 
          0, .58985299999999996, 0], FontSize -> 20], " ", 38, " formulae, ", 
        559, " sub-expressions"],
      Editable->False]], "Print",
  CellLabel->"From In[76]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\"] \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"File created : \"\>",
            Background->RGBColor[0.996109, 0.996109, 0]],
          (
          StyleForm[ #, Background -> 
            RGBColor[ .99610900000000002, .99610900000000002, 0]]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"Thermal.c\"\>",
            FontSize->20,
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0.589853, 0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> RGBColor[ 
            0, .58985299999999996, 0], FontSize -> 20]&)], 
        "\[InvisibleSpace]", "\<\" Size : \"\>", "\[InvisibleSpace]", 
        "12054"}],
      SequenceForm[ "[", 2, "] ", 
        StyleForm[ 
        "File created : ", Background -> 
          RGBColor[ .99610900000000002, .99610900000000002, 0]], 
        StyleForm[ 
        "Thermal.c", FontWeight -> "Bold", FontColor -> RGBColor[ 
          0, .58985299999999996, 0], FontSize -> 20], " Size : ", 12054],
      Editable->False]], "Print",
  CellLabel->"From In[76]:=",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SMSInstallMathLink["\<Optimize\>" \[Rule] 
        True]\), "\[IndentingNewLine]", 
    \(derivation = SessionTime[] - start\)}], "Input",
  CellLabel->"In[77]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(SMSMathLink["Thermal", i_Integer, j_Integer : 0]\),
          HoldForm], ",", 
        TagBox[\(FThermal[ndof_?NumberQ, 
            nt_?\((ArrayQ[#1, 1, NumberQ] && Dimensions[#1] === {3} &)\), 
            index_?\((ArrayQ[#1, 1, NumberQ] &)\), 
            a_?\((ArrayQ[#1, 1, NumberQ] &)\), 
            mc_?\((ArrayQ[#1, 1, NumberQ] &)\)]\),
          HoldForm], ",", 
        TagBox[\(GThermal[ndof_?NumberQ, 
            nt_?\((ArrayQ[#1, 1, NumberQ] && Dimensions[#1] === {3} &)\), 
            index_?\((ArrayQ[#1, 1, NumberQ] &)\), 
            a_?\((ArrayQ[#1, 1, NumberQ] &)\), 
            mc_?\((ArrayQ[#1, 1, NumberQ] &)\)]\),
          HoldForm], ",", 
        TagBox[\(HThermal[ndof_?NumberQ, 
            nt_?\((ArrayQ[#1, 1, NumberQ] && Dimensions[#1] === {3} &)\), 
            index_?\((ArrayQ[#1, 1, NumberQ] &)\), 
            a_?\((ArrayQ[#1, 1, NumberQ] &)\), 
            mc_?\((ArrayQ[#1, 1, NumberQ] &)\)]\),
          HoldForm]}], "}"}]], "Output",
  CellLabel->"Out[77]=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(3.9156304`7.743316689437079\)], "Output",
  CellLabel->"Out[78]=",
  CellTags->"b:8.1.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AceGen Solution", "SubsubsectionIcon",
  CellTags->"b:8.1.1"],

Cell["G. Gradient based optimization", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(start = SessionTime[]; ii = 0;\), "\[IndentingNewLine]", 
    \(\(indexb = Flatten[index];\)\), "\[IndentingNewLine]", 
    \(sol = 
      FindMinimum[\[IndentingNewLine]FThermal[nterm, {nx, ny, nz}, indexb, 
          Join[\[Phi]i, bound], {dlx, dly, dlz, kcond, 
            Q}]\[IndentingNewLine], {\[Phi]i, 
          Table[0, {nterm}]}, \[IndentingNewLine]Method \[Rule] \
"\<Gradient\>", \[IndentingNewLine]Gradient \[Rule] 
          GThermal[nterm, {nx, ny, nz}, indexb, 
            Join[\[Phi]i, bound], {dlx, dly, dlz, kcond, 
              Q}]\[IndentingNewLine], 
        EvaluationMonitor \[RuleDelayed] \((\(\(ii++\);\))\)]; {ii, 
      a[index[\([\((nx + 3)\)/2, \((ny + 3)\)/2, \((nz + 3)\)/2]\)]] /. 
        MapThread[Rule, List @@ sol[\([2, 1]\)]], 
      SessionTime[] - start}\)}], "Input",
  CellLabel->"In[191]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    RowBox[{\(FindMinimum::"cvmit"\), \(\(:\)\(\ \)\), "\<\"Failed to \
converge to the requested accuracy or precision within \\!\\(100\\) \
iterations. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"FindMinimum::cvmit\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[191]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \({1598, 57.50340181358931`, 28.1604928`8.600155248389}\)], "Output",
  CellLabel->"Out[193]=",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell["N. Newton method based optimization", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(start = SessionTime[]; ii = 0;\), "\[IndentingNewLine]", 
    \(\(indexb = 
        Flatten[index /. 
            b[i_] \[RuleDelayed] nterm + i];\)\), "\[IndentingNewLine]", 
    \(sol = 
      FindMinimum[\[IndentingNewLine]FThermal[nterm, {nx, ny, nz}, indexb, 
          Join[\[Phi]i, bound], {dlx, dly, dlz, kcond, 
            Q}]\[IndentingNewLine], {\[Phi]i, 
          Table[0, {nterm}]}, \[IndentingNewLine]Method \[Rule] \
{"\<Newton\>", \ 
            Hessian \[Rule] 
              HThermal[nterm, {nx, ny, nz}, indexb, 
                Join[\[Phi]i, bound], {dlx, dly, dlz, kcond, 
                  Q}]}, \[IndentingNewLine]Gradient \[Rule] 
          GThermal[nterm, {nx, ny, nz}, indexb, 
            Join[\[Phi]i, bound], {dlx, dly, dlz, kcond, 
              Q}]\[IndentingNewLine], 
        EvaluationMonitor \[RuleDelayed] \((\(\(ii++\);\))\)]; {ii, 
      a[index[\([\((nx + 3)\)/2, \((ny + 3)\)/2, \((nz + 3)\)/2]\)]] /. 
        MapThread[Rule, List @@ sol[\([2, 1]\)]], 
      SessionTime[] - start}\)}], "Input",
  CellLabel->"In[79]:=",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \({4, 57.50340181959709`, 1.9828512`7.447805122302744}\)], "Output",
  CellLabel->"Out[81]=",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell["\<\
The tangent matrix is in the case of finite difference approximation \
extremely sparse.\
\>", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MatrixPlot[
        HThermal[nterm, {nx, ny, nz}, index, 
          Join[0\ \[Phi]i, bound], {dlx, dly, dlz, kcond, Q}]];\)\)], "Input",\

  CellLabel->"In[92]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00235156 0.0238095 0.00235156 [
[.0244 -0.0125 -3 -9 ]
[.0244 -0.0125 3 0 ]
[.25838 -0.0125 -9 -9 ]
[.25838 -0.0125 9 0 ]
[.49353 -0.0125 -9 -9 ]
[.49353 -0.0125 9 0 ]
[.72869 -0.0125 -9 -9 ]
[.72869 -0.0125 9 0 ]
[.9756 -0.0125 -9 -9 ]
[.9756 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .9756 -6 -4.5 ]
[-0.0125 .9756 0 4.5 ]
[-0.0125 .74162 -18 -4.5 ]
[-0.0125 .74162 0 4.5 ]
[-0.0125 .50647 -18 -4.5 ]
[-0.0125 .50647 0 4.5 ]
[-0.0125 .27131 -18 -4.5 ]
[-0.0125 .27131 0 4.5 ]
[-0.0125 .0244 -18 -4.5 ]
[-0.0125 .0244 0 4.5 ]
[ 0 0 -0.125 0 ]
[.0244 1.0125 -3 0 ]
[.0244 1.0125 3 9 ]
[.25838 1.0125 -9 0 ]
[.25838 1.0125 9 9 ]
[.49353 1.0125 -9 0 ]
[.49353 1.0125 9 9 ]
[.72869 1.0125 -9 0 ]
[.72869 1.0125 9 9 ]
[.9756 1.0125 -9 0 ]
[.9756 1.0125 9 9 ]
[ 0 1 .125 0 ]
[1.0125 .9756 0 -4.5 ]
[1.0125 .9756 6 4.5 ]
[1.0125 .74162 0 -4.5 ]
[1.0125 .74162 18 4.5 ]
[1.0125 .50647 0 -4.5 ]
[1.0125 .50647 18 4.5 ]
[1.0125 .27131 0 -4.5 ]
[1.0125 .27131 18 4.5 ]
[1.0125 .0244 0 -4.5 ]
[1.0125 .0244 18 4.5 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0244 0 m
.0244 .00625 L
s
[(1)] .0244 -0.0125 0 1 Mshowa
.25838 0 m
.25838 .00625 L
s
[(200)] .25838 -0.0125 0 1 Mshowa
.49353 0 m
.49353 .00625 L
s
[(400)] .49353 -0.0125 0 1 Mshowa
.72869 0 m
.72869 .00625 L
s
[(600)] .72869 -0.0125 0 1 Mshowa
.9756 0 m
.9756 .00625 L
s
[(810)] .9756 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .9756 m
.00625 .9756 L
s
[(1)] -0.0125 .9756 1 0 Mshowa
0 .74162 m
.00625 .74162 L
s
[(200)] -0.0125 .74162 1 0 Mshowa
0 .50647 m
.00625 .50647 L
s
[(400)] -0.0125 .50647 1 0 Mshowa
0 .27131 m
.00625 .27131 L
s
[(600)] -0.0125 .27131 1 0 Mshowa
0 .0244 m
.00625 .0244 L
s
[(810)] -0.0125 .0244 1 0 Mshowa
0 0 m
0 1 L
s
.0244 .99375 m
.0244 1 L
s
[(1)] .0244 1.0125 0 -1 Mshowa
.25838 .99375 m
.25838 1 L
s
[(200)] .25838 1.0125 0 -1 Mshowa
.49353 .99375 m
.49353 1 L
s
[(400)] .49353 1.0125 0 -1 Mshowa
.72869 .99375 m
.72869 1 L
s
[(600)] .72869 1.0125 0 -1 Mshowa
.9756 .99375 m
.9756 1 L
s
[(810)] .9756 1.0125 0 -1 Mshowa
0 1 m
1 1 L
s
.99375 .9756 m
1 .9756 L
s
[(1)] 1.0125 .9756 -1 0 Mshowa
.99375 .74162 m
1 .74162 L
s
[(200)] 1.0125 .74162 -1 0 Mshowa
.99375 .50647 m
1 .50647 L
s
[(400)] 1.0125 .50647 -1 0 Mshowa
.99375 .27131 m
1 .27131 L
s
[(600)] 1.0125 .27131 -1 0 Mshowa
.99375 .0244 m
1 .0244 L
s
[(810)] 1.0125 .0244 -1 0 Mshowa
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
0 g
.7622 .02381 m
.7622 .02616 L
.76455 .02616 L
.76455 .02381 L
F
.95032 .02381 m
.95032 .02616 L
.95267 .02616 L
.95267 .02381 L
F
.97149 .02381 m
.97149 .02616 L
.97384 .02616 L
.97384 .02381 L
F
.97384 .02381 m
.97384 .02616 L
.97619 .02616 L
.97619 .02381 L
F
.75985 .02616 m
.75985 .02851 L
.7622 .02851 L
.7622 .02616 L
F
.94797 .02616 m
.94797 .02851 L
.95032 .02851 L
.95032 .02616 L
F
.96914 .02616 m
.96914 .02851 L
.97149 .02851 L
.97149 .02616 L
F
.97149 .02616 m
.97149 .02851 L
.97384 .02851 L
.97384 .02616 L
F
.97384 .02616 m
.97384 .02851 L
.97619 .02851 L
.97619 .02616 L
F
.7575 .02851 m
.7575 .03086 L
.75985 .03086 L
.75985 .02851 L
F
.94562 .02851 m
.94562 .03086 L
.94797 .03086 L
.94797 .02851 L
F
.96678 .02851 m
.96678 .03086 L
.96914 .03086 L
.96914 .02851 L
F
.96914 .02851 m
.96914 .03086 L
.97149 .03086 L
.97149 .02851 L
F
.97149 .02851 m
.97149 .03086 L
.97384 .03086 L
.97384 .02851 L
F
.75514 .03086 m
.75514 .03322 L
.7575 .03322 L
.7575 .03086 L
F
.94327 .03086 m
.94327 .03322 L
.94562 .03322 L
.94562 .03086 L
F
.96443 .03086 m
.96443 .03322 L
.96678 .03322 L
.96678 .03086 L
F
.96678 .03086 m
.96678 .03322 L
.96914 .03322 L
.96914 .03086 L
F
.96914 .03086 m
.96914 .03322 L
.97149 .03322 L
.97149 .03086 L
F
.75279 .03322 m
.75279 .03557 L
.75514 .03557 L
.75514 .03322 L
F
.94092 .03322 m
.94092 .03557 L
.94327 .03557 L
.94327 .03322 L
F
.96443 .03322 m
.96443 .03557 L
.96678 .03557 L
.96678 .03322 L
F
.96678 .03322 m
.96678 .03557 L
.96914 .03557 L
.96914 .03322 L
F
.75044 .03557 m
.75044 .03792 L
.75279 .03792 L
.75279 .03557 L
F
.93857 .03557 m
.93857 .03792 L
.94092 .03792 L
.94092 .03557 L
F
.95973 .03557 m
.95973 .03792 L
.96208 .03792 L
.96208 .03557 L
F
.96208 .03557 m
.96208 .03792 L
.96443 .03792 L
.96443 .03557 L
F
.74809 .03792 m
.74809 .04027 L
.75044 .04027 L
.75044 .03792 L
F
.93621 .03792 m
.93621 .04027 L
.93857 .04027 L
.93857 .03792 L
F
.95738 .03792 m
.95738 .04027 L
.95973 .04027 L
.95973 .03792 L
F
.95973 .03792 m
.95973 .04027 L
.96208 .04027 L
.96208 .03792 L
F
.96208 .03792 m
.96208 .04027 L
.96443 .04027 L
.96443 .03792 L
F
.74574 .04027 m
.74574 .04262 L
.74809 .04262 L
.74809 .04027 L
F
.93386 .04027 m
.93386 .04262 L
.93621 .04262 L
.93621 .04027 L
F
.95503 .04027 m
.95503 .04262 L
.95738 .04262 L
.95738 .04027 L
F
.95738 .04027 m
.95738 .04262 L
.95973 .04262 L
.95973 .04027 L
F
.95973 .04027 m
.95973 .04262 L
.96208 .04262 L
.96208 .04027 L
F
.74339 .04262 m
.74339 .04497 L
.74574 .04497 L
.74574 .04262 L
F
.93151 .04262 m
.93151 .04497 L
.93386 .04497 L
.93386 .04262 L
F
.95267 .04262 m
.95267 .04497 L
.95503 .04497 L
.95503 .04262 L
F
.95503 .04262 m
.95503 .04497 L
.95738 .04497 L
.95738 .04262 L
F
.95738 .04262 m
.95738 .04497 L
.95973 .04497 L
.95973 .04262 L
F
.74103 .04497 m
.74103 .04733 L
.74339 .04733 L
.74339 .04497 L
F
.92916 .04497 m
.92916 .04733 L
.93151 .04733 L
.93151 .04497 L
F
.95267 .04497 m
.95267 .04733 L
.95503 .04733 L
.95503 .04497 L
F
.95503 .04497 m
.95503 .04733 L
.95738 .04733 L
.95738 .04497 L
F
.73868 .04733 m
.73868 .04968 L
.74103 .04968 L
.74103 .04733 L
F
.92681 .04733 m
.92681 .04968 L
.92916 .04968 L
.92916 .04733 L
F
.94797 .04733 m
.94797 .04968 L
.95032 .04968 L
.95032 .04733 L
F
.95032 .04733 m
.95032 .04968 L
.95267 .04968 L
.95267 .04733 L
F
.97384 .04733 m
.97384 .04968 L
.97619 .04968 L
.97619 .04733 L
F
.73633 .04968 m
.73633 .05203 L
.73868 .05203 L
.73868 .04968 L
F
.92446 .04968 m
.92446 .05203 L
.92681 .05203 L
.92681 .04968 L
F
.94562 .04968 m
.94562 .05203 L
.94797 .05203 L
.94797 .04968 L
F
.94797 .04968 m
.94797 .05203 L
.95032 .05203 L
.95032 .04968 L
F
.95032 .04968 m
.95032 .05203 L
.95267 .05203 L
.95267 .04968 L
F
.97149 .04968 m
.97149 .05203 L
.97384 .05203 L
.97384 .04968 L
F
.73398 .05203 m
.73398 .05438 L
.73633 .05438 L
.73633 .05203 L
F
.9221 .05203 m
.9221 .05438 L
.92446 .05438 L
.92446 .05203 L
F
.94327 .05203 m
.94327 .05438 L
.94562 .05438 L
.94562 .05203 L
F
.94562 .05203 m
.94562 .05438 L
.94797 .05438 L
.94797 .05203 L
F
.94797 .05203 m
.94797 .05438 L
.95032 .05438 L
.95032 .05203 L
F
.96914 .05203 m
.96914 .05438 L
.97149 .05438 L
.97149 .05203 L
F
.73163 .05438 m
.73163 .05673 L
.73398 .05673 L
.73398 .05438 L
F
.91975 .05438 m
.91975 .05673 L
.9221 .05673 L
.9221 .05438 L
F
.94092 .05438 m
.94092 .05673 L
.94327 .05673 L
.94327 .05438 L
F
.94327 .05438 m
.94327 .05673 L
.94562 .05673 L
.94562 .05438 L
F
.94562 .05438 m
.94562 .05673 L
.94797 .05673 L
.94797 .05438 L
F
.96678 .05438 m
.96678 .05673 L
.96914 .05673 L
.96914 .05438 L
F
.72928 .05673 m
.72928 .05908 L
.73163 .05908 L
.73163 .05673 L
F
.9174 .05673 m
.9174 .05908 L
.91975 .05908 L
.91975 .05673 L
F
.94092 .05673 m
.94092 .05908 L
.94327 .05908 L
.94327 .05673 L
F
.94327 .05673 m
.94327 .05908 L
.94562 .05908 L
.94562 .05673 L
F
.96443 .05673 m
.96443 .05908 L
.96678 .05908 L
.96678 .05673 L
F
.72693 .05908 m
.72693 .06143 L
.72928 .06143 L
.72928 .05908 L
F
.91505 .05908 m
.91505 .06143 L
.9174 .06143 L
.9174 .05908 L
F
.93621 .05908 m
.93621 .06143 L
.93857 .06143 L
.93857 .05908 L
F
.93857 .05908 m
.93857 .06143 L
.94092 .06143 L
.94092 .05908 L
F
.96208 .05908 m
.96208 .06143 L
.96443 .06143 L
.96443 .05908 L
F
.72457 .06143 m
.72457 .06379 L
.72693 .06379 L
.72693 .06143 L
F
.9127 .06143 m
.9127 .06379 L
.91505 .06379 L
.91505 .06143 L
F
.93386 .06143 m
.93386 .06379 L
.93621 .06379 L
.93621 .06143 L
F
.93621 .06143 m
.93621 .06379 L
.93857 .06379 L
.93857 .06143 L
F
.93857 .06143 m
.93857 .06379 L
.94092 .06379 L
.94092 .06143 L
F
.95973 .06143 m
.95973 .06379 L
.96208 .06379 L
.96208 .06143 L
F
.72222 .06379 m
.72222 .06614 L
.72457 .06614 L
.72457 .06379 L
F
.91035 .06379 m
.91035 .06614 L
.9127 .06614 L
.9127 .06379 L
F
.93151 .06379 m
.93151 .06614 L
.93386 .06614 L
.93386 .06379 L
F
.93386 .06379 m
.93386 .06614 L
.93621 .06614 L
.93621 .06379 L
F
.93621 .06379 m
.93621 .06614 L
.93857 .06614 L
.93857 .06379 L
F
.95738 .06379 m
.95738 .06614 L
.95973 .06614 L
.95973 .06379 L
F
.71987 .06614 m
.71987 .06849 L
.72222 .06849 L
.72222 .06614 L
F
.908 .06614 m
.908 .06849 L
.91035 .06849 L
.91035 .06614 L
F
.92916 .06614 m
.92916 .06849 L
.93151 .06849 L
.93151 .06614 L
F
.93151 .06614 m
.93151 .06849 L
.93386 .06849 L
.93386 .06614 L
F
.93386 .06614 m
.93386 .06849 L
.93621 .06849 L
.93621 .06614 L
F
.95503 .06614 m
.95503 .06849 L
.95738 .06849 L
.95738 .06614 L
F
.71752 .06849 m
.71752 .07084 L
.71987 .07084 L
.71987 .06849 L
F
.90564 .06849 m
.90564 .07084 L
.908 .07084 L
.908 .06849 L
F
.92916 .06849 m
.92916 .07084 L
.93151 .07084 L
.93151 .06849 L
F
.93151 .06849 m
.93151 .07084 L
.93386 .07084 L
.93386 .06849 L
F
.95267 .06849 m
.95267 .07084 L
.95503 .07084 L
.95503 .06849 L
F
.71517 .07084 m
.71517 .07319 L
.71752 .07319 L
.71752 .07084 L
F
.90329 .07084 m
.90329 .07319 L
.90564 .07319 L
.90564 .07084 L
F
.92446 .07084 m
.92446 .07319 L
.92681 .07319 L
.92681 .07084 L
F
.92681 .07084 m
.92681 .07319 L
.92916 .07319 L
.92916 .07084 L
F
.95032 .07084 m
.95032 .07319 L
.95267 .07319 L
.95267 .07084 L
F
.71282 .07319 m
.71282 .07554 L
.71517 .07554 L
.71517 .07319 L
F
.90094 .07319 m
.90094 .07554 L
.90329 .07554 L
.90329 .07319 L
F
.9221 .07319 m
.9221 .07554 L
.92446 .07554 L
.92446 .07319 L
F
.92446 .07319 m
.92446 .07554 L
.92681 .07554 L
.92681 .07319 L
F
.92681 .07319 m
.92681 .07554 L
.92916 .07554 L
.92916 .07319 L
F
.94797 .07319 m
.94797 .07554 L
.95032 .07554 L
.95032 .07319 L
F
.71046 .07554 m
.71046 .0779 L
.71282 .0779 L
.71282 .07554 L
F
.89859 .07554 m
.89859 .0779 L
.90094 .0779 L
.90094 .07554 L
F
.91975 .07554 m
.91975 .0779 L
.9221 .0779 L
.9221 .07554 L
F
.9221 .07554 m
.9221 .0779 L
.92446 .0779 L
.92446 .07554 L
F
.92446 .07554 m
.92446 .0779 L
.92681 .0779 L
.92681 .07554 L
F
.94562 .07554 m
.94562 .0779 L
.94797 .0779 L
.94797 .07554 L
F
.70811 .0779 m
.70811 .08025 L
.71046 .08025 L
.71046 .0779 L
F
.89624 .0779 m
.89624 .08025 L
.89859 .08025 L
.89859 .0779 L
F
.9174 .0779 m
.9174 .08025 L
.91975 .08025 L
.91975 .0779 L
F
.91975 .0779 m
.91975 .08025 L
.9221 .08025 L
.9221 .0779 L
F
.9221 .0779 m
.9221 .08025 L
.92446 .08025 L
.92446 .0779 L
F
.94327 .0779 m
.94327 .08025 L
.94562 .08025 L
.94562 .0779 L
F
.70576 .08025 m
.70576 .0826 L
.70811 .0826 L
.70811 .08025 L
F
.89389 .08025 m
.89389 .0826 L
.89624 .0826 L
.89624 .08025 L
F
.9174 .08025 m
.9174 .0826 L
.91975 .0826 L
.91975 .08025 L
F
.91975 .08025 m
.91975 .0826 L
.9221 .0826 L
.9221 .08025 L
F
.94092 .08025 m
.94092 .0826 L
.94327 .0826 L
.94327 .08025 L
F
.70341 .0826 m
.70341 .08495 L
.70576 .08495 L
.70576 .0826 L
F
.89153 .0826 m
.89153 .08495 L
.89389 .08495 L
.89389 .0826 L
F
.9127 .0826 m
.9127 .08495 L
.91505 .08495 L
.91505 .0826 L
F
.91505 .0826 m
.91505 .08495 L
.9174 .08495 L
.9174 .0826 L
F
.93857 .0826 m
.93857 .08495 L
.94092 .08495 L
.94092 .0826 L
F
.70106 .08495 m
.70106 .0873 L
.70341 .0873 L
.70341 .08495 L
F
.88918 .08495 m
.88918 .0873 L
.89153 .0873 L
.89153 .08495 L
F
.91035 .08495 m
.91035 .0873 L
.9127 .0873 L
.9127 .08495 L
F
.9127 .08495 m
.9127 .0873 L
.91505 .0873 L
.91505 .08495 L
F
.91505 .08495 m
.91505 .0873 L
.9174 .0873 L
.9174 .08495 L
F
.93621 .08495 m
.93621 .0873 L
.93857 .0873 L
.93857 .08495 L
F
.69871 .0873 m
.69871 .08965 L
.70106 .08965 L
.70106 .0873 L
F
.88683 .0873 m
.88683 .08965 L
.88918 .08965 L
.88918 .0873 L
F
.908 .0873 m
.908 .08965 L
.91035 .08965 L
.91035 .0873 L
F
.91035 .0873 m
.91035 .08965 L
.9127 .08965 L
.9127 .0873 L
F
.9127 .0873 m
.9127 .08965 L
.91505 .08965 L
.91505 .0873 L
F
.93386 .0873 m
.93386 .08965 L
.93621 .08965 L
.93621 .0873 L
F
.69636 .08965 m
.69636 .092 L
.69871 .092 L
.69871 .08965 L
F
.88448 .08965 m
.88448 .092 L
.88683 .092 L
.88683 .08965 L
F
.90564 .08965 m
.90564 .092 L
.908 .092 L
.908 .08965 L
F
.908 .08965 m
.908 .092 L
.91035 .092 L
.91035 .08965 L
F
.91035 .08965 m
.91035 .092 L
.9127 .092 L
.9127 .08965 L
F
.93151 .08965 m
.93151 .092 L
.93386 .092 L
.93386 .08965 L
F
.694 .092 m
.694 .09436 L
.69636 .09436 L
.69636 .092 L
F
.88213 .092 m
.88213 .09436 L
.88448 .09436 L
.88448 .092 L
F
.90564 .092 m
.90564 .09436 L
.908 .09436 L
.908 .092 L
F
.908 .092 m
.908 .09436 L
.91035 .09436 L
.91035 .092 L
F
.92916 .092 m
.92916 .09436 L
.93151 .09436 L
.93151 .092 L
F
.69165 .09436 m
.69165 .09671 L
.694 .09671 L
.694 .09436 L
F
.87978 .09436 m
.87978 .09671 L
.88213 .09671 L
.88213 .09436 L
F
.90094 .09436 m
.90094 .09671 L
.90329 .09671 L
.90329 .09436 L
F
.90329 .09436 m
.90329 .09671 L
.90564 .09671 L
.90564 .09436 L
F
.92681 .09436 m
.92681 .09671 L
.92916 .09671 L
.92916 .09436 L
F
.6893 .09671 m
.6893 .09906 L
.69165 .09906 L
.69165 .09671 L
F
.87743 .09671 m
.87743 .09906 L
.87978 .09906 L
.87978 .09671 L
F
.89859 .09671 m
.89859 .09906 L
.90094 .09906 L
.90094 .09671 L
F
.90094 .09671 m
.90094 .09906 L
.90329 .09906 L
.90329 .09671 L
F
.90329 .09671 m
.90329 .09906 L
.90564 .09906 L
.90564 .09671 L
F
.92446 .09671 m
.92446 .09906 L
.92681 .09906 L
.92681 .09671 L
F
.68695 .09906 m
.68695 .10141 L
.6893 .10141 L
.6893 .09906 L
F
.87507 .09906 m
.87507 .10141 L
.87743 .10141 L
.87743 .09906 L
F
.89624 .09906 m
.89624 .10141 L
.89859 .10141 L
.89859 .09906 L
F
.89859 .09906 m
.89859 .10141 L
.90094 .10141 L
.90094 .09906 L
F
.90094 .09906 m
.90094 .10141 L
.90329 .10141 L
.90329 .09906 L
F
.9221 .09906 m
.9221 .10141 L
.92446 .10141 L
.92446 .09906 L
F
.6846 .10141 m
.6846 .10376 L
.68695 .10376 L
.68695 .10141 L
F
.87272 .10141 m
.87272 .10376 L
.87507 .10376 L
.87507 .10141 L
F
.89389 .10141 m
.89389 .10376 L
.89624 .10376 L
.89624 .10141 L
F
.89624 .10141 m
.89624 .10376 L
.89859 .10376 L
.89859 .10141 L
F
.89859 .10141 m
.89859 .10376 L
.90094 .10376 L
.90094 .10141 L
F
.91975 .10141 m
.91975 .10376 L
.9221 .10376 L
.9221 .10141 L
F
.68225 .10376 m
.68225 .10611 L
.6846 .10611 L
.6846 .10376 L
F
.87037 .10376 m
.87037 .10611 L
.87272 .10611 L
.87272 .10376 L
F
.89389 .10376 m
.89389 .10611 L
.89624 .10611 L
.89624 .10376 L
F
.89624 .10376 m
.89624 .10611 L
.89859 .10611 L
.89859 .10376 L
F
.9174 .10376 m
.9174 .10611 L
.91975 .10611 L
.91975 .10376 L
F
.67989 .10611 m
.67989 .10847 L
.68225 .10847 L
.68225 .10611 L
F
.88918 .10611 m
.88918 .10847 L
.89153 .10847 L
.89153 .10611 L
F
.89153 .10611 m
.89153 .10847 L
.89389 .10847 L
.89389 .10611 L
F
.91505 .10611 m
.91505 .10847 L
.9174 .10847 L
.9174 .10611 L
F
.67754 .10847 m
.67754 .11082 L
.67989 .11082 L
.67989 .10847 L
F
.88683 .10847 m
.88683 .11082 L
.88918 .11082 L
.88918 .10847 L
F
.88918 .10847 m
.88918 .11082 L
.89153 .11082 L
.89153 .10847 L
F
.89153 .10847 m
.89153 .11082 L
.89389 .11082 L
.89389 .10847 L
F
.9127 .10847 m
.9127 .11082 L
.91505 .11082 L
.91505 .10847 L
F
.67519 .11082 m
.67519 .11317 L
.67754 .11317 L
.67754 .11082 L
F
.88448 .11082 m
.88448 .11317 L
.88683 .11317 L
.88683 .11082 L
F
.88683 .11082 m
.88683 .11317 L
.88918 .11317 L
.88918 .11082 L
F
.88918 .11082 m
.88918 .11317 L
.89153 .11317 L
.89153 .11082 L
F
.91035 .11082 m
.91035 .11317 L
.9127 .11317 L
.9127 .11082 L
F
.67284 .11317 m
.67284 .11552 L
.67519 .11552 L
.67519 .11317 L
F
.88213 .11317 m
.88213 .11552 L
.88448 .11552 L
.88448 .11317 L
F
.88448 .11317 m
.88448 .11552 L
.88683 .11552 L
.88683 .11317 L
F
.88683 .11317 m
.88683 .11552 L
.88918 .11552 L
.88918 .11317 L
F
.908 .11317 m
.908 .11552 L
.91035 .11552 L
.91035 .11317 L
F
.67049 .11552 m
.67049 .11787 L
.67284 .11787 L
.67284 .11552 L
F
.88213 .11552 m
.88213 .11787 L
.88448 .11787 L
.88448 .11552 L
F
.88448 .11552 m
.88448 .11787 L
.88683 .11787 L
.88683 .11552 L
F
.90564 .11552 m
.90564 .11787 L
.908 .11787 L
.908 .11552 L
F
.66814 .11787 m
.66814 .12022 L
.67049 .12022 L
.67049 .11787 L
F
.87743 .11787 m
.87743 .12022 L
.87978 .12022 L
.87978 .11787 L
F
.87978 .11787 m
.87978 .12022 L
.88213 .12022 L
.88213 .11787 L
F
.90329 .11787 m
.90329 .12022 L
.90564 .12022 L
.90564 .11787 L
F
.66578 .12022 m
.66578 .12257 L
.66814 .12257 L
.66814 .12022 L
F
.87507 .12022 m
.87507 .12257 L
.87743 .12257 L
.87743 .12022 L
F
.87743 .12022 m
.87743 .12257 L
.87978 .12257 L
.87978 .12022 L
F
.87978 .12022 m
.87978 .12257 L
.88213 .12257 L
.88213 .12022 L
F
.90094 .12022 m
.90094 .12257 L
.90329 .12257 L
.90329 .12022 L
F
.66343 .12257 m
.66343 .12493 L
.66578 .12493 L
.66578 .12257 L
F
.87272 .12257 m
.87272 .12493 L
.87507 .12493 L
.87507 .12257 L
F
.87507 .12257 m
.87507 .12493 L
.87743 .12493 L
.87743 .12257 L
F
.87743 .12257 m
.87743 .12493 L
.87978 .12493 L
.87978 .12257 L
F
.89859 .12257 m
.89859 .12493 L
.90094 .12493 L
.90094 .12257 L
F
.66108 .12493 m
.66108 .12728 L
.66343 .12728 L
.66343 .12493 L
F
.87037 .12493 m
.87037 .12728 L
.87272 .12728 L
.87272 .12493 L
F
.87272 .12493 m
.87272 .12728 L
.87507 .12728 L
.87507 .12493 L
F
.87507 .12493 m
.87507 .12728 L
.87743 .12728 L
.87743 .12493 L
F
.89624 .12493 m
.89624 .12728 L
.89859 .12728 L
.89859 .12493 L
F
.65873 .12728 m
.65873 .12963 L
.66108 .12963 L
.66108 .12728 L
F
.87037 .12728 m
.87037 .12963 L
.87272 .12963 L
.87272 .12728 L
F
.87272 .12728 m
.87272 .12963 L
.87507 .12963 L
.87507 .12728 L
F
.89389 .12728 m
.89389 .12963 L
.89624 .12963 L
.89624 .12728 L
F
.65638 .12963 m
.65638 .13198 L
.65873 .13198 L
.65873 .12963 L
F
.8445 .12963 m
.8445 .13198 L
.84685 .13198 L
.84685 .12963 L
F
.86567 .12963 m
.86567 .13198 L
.86802 .13198 L
.86802 .12963 L
F
.86802 .12963 m
.86802 .13198 L
.87037 .13198 L
.87037 .12963 L
F
.65403 .13198 m
.65403 .13433 L
.65638 .13433 L
.65638 .13198 L
F
.84215 .13198 m
.84215 .13433 L
.8445 .13433 L
.8445 .13198 L
F
.86332 .13198 m
.86332 .13433 L
.86567 .13433 L
.86567 .13198 L
F
.86567 .13198 m
.86567 .13433 L
.86802 .13433 L
.86802 .13198 L
F
.86802 .13198 m
.86802 .13433 L
.87037 .13433 L
.87037 .13198 L
F
.65168 .13433 m
.65168 .13668 L
.65403 .13668 L
.65403 .13433 L
F
.8398 .13433 m
.8398 .13668 L
.84215 .13668 L
.84215 .13433 L
F
.86096 .13433 m
.86096 .13668 L
.86332 .13668 L
.86332 .13433 L
F
.86332 .13433 m
.86332 .13668 L
.86567 .13668 L
.86567 .13433 L
F
.86567 .13433 m
.86567 .13668 L
.86802 .13668 L
.86802 .13433 L
F
.64932 .13668 m
.64932 .13904 L
.65168 .13904 L
.65168 .13668 L
F
.83745 .13668 m
.83745 .13904 L
.8398 .13904 L
.8398 .13668 L
F
.85861 .13668 m
.85861 .13904 L
.86096 .13904 L
.86096 .13668 L
F
.86096 .13668 m
.86096 .13904 L
.86332 .13904 L
.86332 .13668 L
F
.86332 .13668 m
.86332 .13904 L
.86567 .13904 L
.86567 .13668 L
F
.64697 .13904 m
.64697 .14139 L
.64932 .14139 L
.64932 .13904 L
F
.8351 .13904 m
.8351 .14139 L
.83745 .14139 L
.83745 .13904 L
F
.85861 .13904 m
.85861 .14139 L
.86096 .14139 L
.86096 .13904 L
F
.86096 .13904 m
.86096 .14139 L
.86332 .14139 L
.86332 .13904 L
F
.64462 .14139 m
.64462 .14374 L
.64697 .14374 L
.64697 .14139 L
F
.83275 .14139 m
.83275 .14374 L
.8351 .14374 L
.8351 .14139 L
F
.85391 .14139 m
.85391 .14374 L
.85626 .14374 L
.85626 .14139 L
F
.85626 .14139 m
.85626 .14374 L
.85861 .14374 L
.85861 .14139 L
F
.64227 .14374 m
.64227 .14609 L
.64462 .14609 L
.64462 .14374 L
F
.83039 .14374 m
.83039 .14609 L
.83275 .14609 L
.83275 .14374 L
F
.85156 .14374 m
.85156 .14609 L
.85391 .14609 L
.85391 .14374 L
F
.85391 .14374 m
.85391 .14609 L
.85626 .14609 L
.85626 .14374 L
F
.85626 .14374 m
.85626 .14609 L
.85861 .14609 L
.85861 .14374 L
F
.63992 .14609 m
.63992 .14844 L
.64227 .14844 L
.64227 .14609 L
F
.82804 .14609 m
.82804 .14844 L
.83039 .14844 L
.83039 .14609 L
F
.84921 .14609 m
.84921 .14844 L
.85156 .14844 L
.85156 .14609 L
F
.85156 .14609 m
.85156 .14844 L
.85391 .14844 L
.85391 .14609 L
F
.85391 .14609 m
.85391 .14844 L
.85626 .14844 L
.85626 .14609 L
F
.63757 .14844 m
.63757 .15079 L
.63992 .15079 L
.63992 .14844 L
F
.82569 .14844 m
.82569 .15079 L
.82804 .15079 L
.82804 .14844 L
F
.84685 .14844 m
.84685 .15079 L
.84921 .15079 L
.84921 .14844 L
F
.84921 .14844 m
.84921 .15079 L
.85156 .15079 L
.85156 .14844 L
F
.85156 .14844 m
.85156 .15079 L
.85391 .15079 L
.85391 .14844 L
F
.63521 .15079 m
.63521 .15315 L
.63757 .15315 L
.63757 .15079 L
F
.82334 .15079 m
.82334 .15315 L
.82569 .15315 L
.82569 .15079 L
F
.84685 .15079 m
.84685 .15315 L
.84921 .15315 L
.84921 .15079 L
F
.84921 .15079 m
.84921 .15315 L
.85156 .15315 L
.85156 .15079 L
F
.63286 .15315 m
.63286 .1555 L
.63521 .1555 L
.63521 .15315 L
F
.82099 .15315 m
.82099 .1555 L
.82334 .1555 L
.82334 .15315 L
F
.84215 .15315 m
.84215 .1555 L
.8445 .1555 L
.8445 .15315 L
F
.8445 .15315 m
.8445 .1555 L
.84685 .1555 L
.84685 .15315 L
F
.86802 .15315 m
.86802 .1555 L
.87037 .1555 L
.87037 .15315 L
F
.63051 .1555 m
.63051 .15785 L
.63286 .15785 L
.63286 .1555 L
F
.81864 .1555 m
.81864 .15785 L
.82099 .15785 L
.82099 .1555 L
F
.8398 .1555 m
.8398 .15785 L
.84215 .15785 L
.84215 .1555 L
F
.84215 .1555 m
.84215 .15785 L
.8445 .15785 L
.8445 .1555 L
F
.8445 .1555 m
.8445 .15785 L
.84685 .15785 L
.84685 .1555 L
F
.86567 .1555 m
.86567 .15785 L
.86802 .15785 L
.86802 .1555 L
F
.62816 .15785 m
.62816 .1602 L
.63051 .1602 L
.63051 .15785 L
F
.81628 .15785 m
.81628 .1602 L
.81864 .1602 L
.81864 .15785 L
F
.83745 .15785 m
.83745 .1602 L
.8398 .1602 L
.8398 .15785 L
F
.8398 .15785 m
.8398 .1602 L
.84215 .1602 L
.84215 .15785 L
F
.84215 .15785 m
.84215 .1602 L
.8445 .1602 L
.8445 .15785 L
F
.86332 .15785 m
.86332 .1602 L
.86567 .1602 L
.86567 .15785 L
F
.62581 .1602 m
.62581 .16255 L
.62816 .16255 L
.62816 .1602 L
F
.81393 .1602 m
.81393 .16255 L
.81628 .16255 L
.81628 .1602 L
F
.8351 .1602 m
.8351 .16255 L
.83745 .16255 L
.83745 .1602 L
F
.83745 .1602 m
.83745 .16255 L
.8398 .16255 L
.8398 .1602 L
F
.8398 .1602 m
.8398 .16255 L
.84215 .16255 L
.84215 .1602 L
F
.86096 .1602 m
.86096 .16255 L
.86332 .16255 L
.86332 .1602 L
F
.62346 .16255 m
.62346 .1649 L
.62581 .1649 L
.62581 .16255 L
F
.81158 .16255 m
.81158 .1649 L
.81393 .1649 L
.81393 .16255 L
F
.8351 .16255 m
.8351 .1649 L
.83745 .1649 L
.83745 .16255 L
F
.83745 .16255 m
.83745 .1649 L
.8398 .1649 L
.8398 .16255 L
F
.85861 .16255 m
.85861 .1649 L
.86096 .1649 L
.86096 .16255 L
F
.62111 .1649 m
.62111 .16725 L
.62346 .16725 L
.62346 .1649 L
F
.80923 .1649 m
.80923 .16725 L
.81158 .16725 L
.81158 .1649 L
F
.83039 .1649 m
.83039 .16725 L
.83275 .16725 L
.83275 .1649 L
F
.83275 .1649 m
.83275 .16725 L
.8351 .16725 L
.8351 .1649 L
F
.85626 .1649 m
.85626 .16725 L
.85861 .16725 L
.85861 .1649 L
F
.61875 .16725 m
.61875 .16961 L
.62111 .16961 L
.62111 .16725 L
F
.80688 .16725 m
.80688 .16961 L
.80923 .16961 L
.80923 .16725 L
F
.82804 .16725 m
.82804 .16961 L
.83039 .16961 L
.83039 .16725 L
F
.83039 .16725 m
.83039 .16961 L
.83275 .16961 L
.83275 .16725 L
F
.83275 .16725 m
.83275 .16961 L
.8351 .16961 L
.8351 .16725 L
F
.85391 .16725 m
.85391 .16961 L
.85626 .16961 L
.85626 .16725 L
F
.6164 .16961 m
.6164 .17196 L
.61875 .17196 L
.61875 .16961 L
F
.80453 .16961 m
.80453 .17196 L
.80688 .17196 L
.80688 .16961 L
F
.82569 .16961 m
.82569 .17196 L
.82804 .17196 L
.82804 .16961 L
F
.82804 .16961 m
.82804 .17196 L
.83039 .17196 L
.83039 .16961 L
F
.83039 .16961 m
.83039 .17196 L
.83275 .17196 L
.83275 .16961 L
F
.85156 .16961 m
.85156 .17196 L
.85391 .17196 L
.85391 .16961 L
F
.61405 .17196 m
.61405 .17431 L
.6164 .17431 L
.6164 .17196 L
F
.80218 .17196 m
.80218 .17431 L
.80453 .17431 L
.80453 .17196 L
F
.82334 .17196 m
.82334 .17431 L
.82569 .17431 L
.82569 .17196 L
F
.82569 .17196 m
.82569 .17431 L
.82804 .17431 L
.82804 .17196 L
F
.82804 .17196 m
.82804 .17431 L
.83039 .17431 L
.83039 .17196 L
F
.84921 .17196 m
.84921 .17431 L
.85156 .17431 L
.85156 .17196 L
F
.6117 .17431 m
.6117 .17666 L
.61405 .17666 L
.61405 .17431 L
F
.79982 .17431 m
.79982 .17666 L
.80218 .17666 L
.80218 .17431 L
F
.82334 .17431 m
.82334 .17666 L
.82569 .17666 L
.82569 .17431 L
F
.82569 .17431 m
.82569 .17666 L
.82804 .17666 L
.82804 .17431 L
F
.84685 .17431 m
.84685 .17666 L
.84921 .17666 L
.84921 .17431 L
F
.60935 .17666 m
.60935 .17901 L
.6117 .17901 L
.6117 .17666 L
F
.79747 .17666 m
.79747 .17901 L
.79982 .17901 L
.79982 .17666 L
F
.81864 .17666 m
.81864 .17901 L
.82099 .17901 L
.82099 .17666 L
F
.82099 .17666 m
.82099 .17901 L
.82334 .17901 L
.82334 .17666 L
F
.8445 .17666 m
.8445 .17901 L
.84685 .17901 L
.84685 .17666 L
F
.607 .17901 m
.607 .18136 L
.60935 .18136 L
.60935 .17901 L
F
.79512 .17901 m
.79512 .18136 L
.79747 .18136 L
.79747 .17901 L
F
.81628 .17901 m
.81628 .18136 L
.81864 .18136 L
.81864 .17901 L
F
.81864 .17901 m
.81864 .18136 L
.82099 .18136 L
.82099 .17901 L
F
.82099 .17901 m
.82099 .18136 L
.82334 .18136 L
.82334 .17901 L
F
.84215 .17901 m
.84215 .18136 L
.8445 .18136 L
.8445 .17901 L
F
.60464 .18136 m
.60464 .18372 L
.607 .18372 L
.607 .18136 L
F
.79277 .18136 m
.79277 .18372 L
.79512 .18372 L
.79512 .18136 L
F
.81393 .18136 m
.81393 .18372 L
.81628 .18372 L
.81628 .18136 L
F
.81628 .18136 m
.81628 .18372 L
.81864 .18372 L
.81864 .18136 L
F
.81864 .18136 m
.81864 .18372 L
.82099 .18372 L
.82099 .18136 L
F
.8398 .18136 m
.8398 .18372 L
.84215 .18372 L
.84215 .18136 L
F
.60229 .18372 m
.60229 .18607 L
.60464 .18607 L
.60464 .18372 L
F
.79042 .18372 m
.79042 .18607 L
.79277 .18607 L
.79277 .18372 L
F
.81158 .18372 m
.81158 .18607 L
.81393 .18607 L
.81393 .18372 L
F
.81393 .18372 m
.81393 .18607 L
.81628 .18607 L
.81628 .18372 L
F
.81628 .18372 m
.81628 .18607 L
.81864 .18607 L
.81864 .18372 L
F
.83745 .18372 m
.83745 .18607 L
.8398 .18607 L
.8398 .18372 L
F
.59994 .18607 m
.59994 .18842 L
.60229 .18842 L
.60229 .18607 L
F
.78807 .18607 m
.78807 .18842 L
.79042 .18842 L
.79042 .18607 L
F
.81158 .18607 m
.81158 .18842 L
.81393 .18842 L
.81393 .18607 L
F
.81393 .18607 m
.81393 .18842 L
.81628 .18842 L
.81628 .18607 L
F
.8351 .18607 m
.8351 .18842 L
.83745 .18842 L
.83745 .18607 L
F
.59759 .18842 m
.59759 .19077 L
.59994 .19077 L
.59994 .18842 L
F
.78571 .18842 m
.78571 .19077 L
.78807 .19077 L
.78807 .18842 L
F
.80688 .18842 m
.80688 .19077 L
.80923 .19077 L
.80923 .18842 L
F
.80923 .18842 m
.80923 .19077 L
.81158 .19077 L
.81158 .18842 L
F
.83275 .18842 m
.83275 .19077 L
.8351 .19077 L
.8351 .18842 L
F
.59524 .19077 m
.59524 .19312 L
.59759 .19312 L
.59759 .19077 L
F
.78336 .19077 m
.78336 .19312 L
.78571 .19312 L
.78571 .19077 L
F
.80453 .19077 m
.80453 .19312 L
.80688 .19312 L
.80688 .19077 L
F
.80688 .19077 m
.80688 .19312 L
.80923 .19312 L
.80923 .19077 L
F
.80923 .19077 m
.80923 .19312 L
.81158 .19312 L
.81158 .19077 L
F
.83039 .19077 m
.83039 .19312 L
.83275 .19312 L
.83275 .19077 L
F
.59289 .19312 m
.59289 .19547 L
.59524 .19547 L
.59524 .19312 L
F
.78101 .19312 m
.78101 .19547 L
.78336 .19547 L
.78336 .19312 L
F
.80218 .19312 m
.80218 .19547 L
.80453 .19547 L
.80453 .19312 L
F
.80453 .19312 m
.80453 .19547 L
.80688 .19547 L
.80688 .19312 L
F
.80688 .19312 m
.80688 .19547 L
.80923 .19547 L
.80923 .19312 L
F
.82804 .19312 m
.82804 .19547 L
.83039 .19547 L
.83039 .19312 L
F
.59053 .19547 m
.59053 .19782 L
.59289 .19782 L
.59289 .19547 L
F
.77866 .19547 m
.77866 .19782 L
.78101 .19782 L
.78101 .19547 L
F
.79982 .19547 m
.79982 .19782 L
.80218 .19782 L
.80218 .19547 L
F
.80218 .19547 m
.80218 .19782 L
.80453 .19782 L
.80453 .19547 L
F
.80453 .19547 m
.80453 .19782 L
.80688 .19782 L
.80688 .19547 L
F
.82569 .19547 m
.82569 .19782 L
.82804 .19782 L
.82804 .19547 L
F
.58818 .19782 m
.58818 .20018 L
.59053 .20018 L
.59053 .19782 L
F
.77631 .19782 m
.77631 .20018 L
.77866 .20018 L
.77866 .19782 L
F
.79982 .19782 m
.79982 .20018 L
.80218 .20018 L
.80218 .19782 L
F
.80218 .19782 m
.80218 .20018 L
.80453 .20018 L
.80453 .19782 L
F
.82334 .19782 m
.82334 .20018 L
.82569 .20018 L
.82569 .19782 L
F
.58583 .20018 m
.58583 .20253 L
.58818 .20253 L
.58818 .20018 L
F
.77396 .20018 m
.77396 .20253 L
.77631 .20253 L
.77631 .20018 L
F
.79512 .20018 m
.79512 .20253 L
.79747 .20253 L
.79747 .20018 L
F
.79747 .20018 m
.79747 .20253 L
.79982 .20253 L
.79982 .20018 L
F
.82099 .20018 m
.82099 .20253 L
.82334 .20253 L
.82334 .20018 L
F
.58348 .20253 m
.58348 .20488 L
.58583 .20488 L
.58583 .20253 L
F
.7716 .20253 m
.7716 .20488 L
.77396 .20488 L
.77396 .20253 L
F
.79277 .20253 m
.79277 .20488 L
.79512 .20488 L
.79512 .20253 L
F
.79512 .20253 m
.79512 .20488 L
.79747 .20488 L
.79747 .20253 L
F
.79747 .20253 m
.79747 .20488 L
.79982 .20488 L
.79982 .20253 L
F
.81864 .20253 m
.81864 .20488 L
.82099 .20488 L
.82099 .20253 L
F
.58113 .20488 m
.58113 .20723 L
.58348 .20723 L
.58348 .20488 L
F
.76925 .20488 m
.76925 .20723 L
.7716 .20723 L
.7716 .20488 L
F
.79042 .20488 m
.79042 .20723 L
.79277 .20723 L
.79277 .20488 L
F
.79277 .20488 m
.79277 .20723 L
.79512 .20723 L
.79512 .20488 L
F
.79512 .20488 m
.79512 .20723 L
.79747 .20723 L
.79747 .20488 L
F
.81628 .20488 m
.81628 .20723 L
.81864 .20723 L
.81864 .20488 L
F
.57878 .20723 m
.57878 .20958 L
.58113 .20958 L
.58113 .20723 L
F
.7669 .20723 m
.7669 .20958 L
.76925 .20958 L
.76925 .20723 L
F
.78807 .20723 m
.78807 .20958 L
.79042 .20958 L
.79042 .20723 L
F
.79042 .20723 m
.79042 .20958 L
.79277 .20958 L
.79277 .20723 L
F
.79277 .20723 m
.79277 .20958 L
.79512 .20958 L
.79512 .20723 L
F
.81393 .20723 m
.81393 .20958 L
.81628 .20958 L
.81628 .20723 L
F
.57643 .20958 m
.57643 .21193 L
.57878 .21193 L
.57878 .20958 L
F
.76455 .20958 m
.76455 .21193 L
.7669 .21193 L
.7669 .20958 L
F
.78807 .20958 m
.78807 .21193 L
.79042 .21193 L
.79042 .20958 L
F
.79042 .20958 m
.79042 .21193 L
.79277 .21193 L
.79277 .20958 L
F
.81158 .20958 m
.81158 .21193 L
.81393 .21193 L
.81393 .20958 L
F
.57407 .21193 m
.57407 .21429 L
.57643 .21429 L
.57643 .21193 L
F
.78336 .21193 m
.78336 .21429 L
.78571 .21429 L
.78571 .21193 L
F
.78571 .21193 m
.78571 .21429 L
.78807 .21429 L
.78807 .21193 L
F
.80923 .21193 m
.80923 .21429 L
.81158 .21429 L
.81158 .21193 L
F
.57172 .21429 m
.57172 .21664 L
.57407 .21664 L
.57407 .21429 L
F
.78101 .21429 m
.78101 .21664 L
.78336 .21664 L
.78336 .21429 L
F
.78336 .21429 m
.78336 .21664 L
.78571 .21664 L
.78571 .21429 L
F
.78571 .21429 m
.78571 .21664 L
.78807 .21664 L
.78807 .21429 L
F
.80688 .21429 m
.80688 .21664 L
.80923 .21664 L
.80923 .21429 L
F
.56937 .21664 m
.56937 .21899 L
.57172 .21899 L
.57172 .21664 L
F
.77866 .21664 m
.77866 .21899 L
.78101 .21899 L
.78101 .21664 L
F
.78101 .21664 m
.78101 .21899 L
.78336 .21899 L
.78336 .21664 L
F
.78336 .21664 m
.78336 .21899 L
.78571 .21899 L
.78571 .21664 L
F
.80453 .21664 m
.80453 .21899 L
.80688 .21899 L
.80688 .21664 L
F
.56702 .21899 m
.56702 .22134 L
.56937 .22134 L
.56937 .21899 L
F
.77631 .21899 m
.77631 .22134 L
.77866 .22134 L
.77866 .21899 L
F
.77866 .21899 m
.77866 .22134 L
.78101 .22134 L
.78101 .21899 L
F
.78101 .21899 m
.78101 .22134 L
.78336 .22134 L
.78336 .21899 L
F
.80218 .21899 m
.80218 .22134 L
.80453 .22134 L
.80453 .21899 L
F
.56467 .22134 m
.56467 .22369 L
.56702 .22369 L
.56702 .22134 L
F
.77631 .22134 m
.77631 .22369 L
.77866 .22369 L
.77866 .22134 L
F
.77866 .22134 m
.77866 .22369 L
.78101 .22369 L
.78101 .22134 L
F
.79982 .22134 m
.79982 .22369 L
.80218 .22369 L
.80218 .22134 L
F
.56232 .22369 m
.56232 .22604 L
.56467 .22604 L
.56467 .22369 L
F
.7716 .22369 m
.7716 .22604 L
.77396 .22604 L
.77396 .22369 L
F
.77396 .22369 m
.77396 .22604 L
.77631 .22604 L
.77631 .22369 L
F
.79747 .22369 m
.79747 .22604 L
.79982 .22604 L
.79982 .22369 L
F
.55996 .22604 m
.55996 .2284 L
.56232 .2284 L
.56232 .22604 L
F
.76925 .22604 m
.76925 .2284 L
.7716 .2284 L
.7716 .22604 L
F
.7716 .22604 m
.7716 .2284 L
.77396 .2284 L
.77396 .22604 L
F
.77396 .22604 m
.77396 .2284 L
.77631 .2284 L
.77631 .22604 L
F
.79512 .22604 m
.79512 .2284 L
.79747 .2284 L
.79747 .22604 L
F
.55761 .2284 m
.55761 .23075 L
.55996 .23075 L
.55996 .2284 L
F
.7669 .2284 m
.7669 .23075 L
.76925 .23075 L
.76925 .2284 L
F
.76925 .2284 m
.76925 .23075 L
.7716 .23075 L
.7716 .2284 L
F
.7716 .2284 m
.7716 .23075 L
.77396 .23075 L
.77396 .2284 L
F
.79277 .2284 m
.79277 .23075 L
.79512 .23075 L
.79512 .2284 L
F
.55526 .23075 m
.55526 .2331 L
.55761 .2331 L
.55761 .23075 L
F
.76455 .23075 m
.76455 .2331 L
.7669 .2331 L
.7669 .23075 L
F
.7669 .23075 m
.7669 .2331 L
.76925 .2331 L
.76925 .23075 L
F
.76925 .23075 m
.76925 .2331 L
.7716 .2331 L
.7716 .23075 L
F
.79042 .23075 m
.79042 .2331 L
.79277 .2331 L
.79277 .23075 L
F
.55291 .2331 m
.55291 .23545 L
.55526 .23545 L
.55526 .2331 L
F
.76455 .2331 m
.76455 .23545 L
.7669 .23545 L
.7669 .2331 L
F
.7669 .2331 m
.7669 .23545 L
.76925 .23545 L
.76925 .2331 L
F
.78807 .2331 m
.78807 .23545 L
.79042 .23545 L
.79042 .2331 L
F
.55056 .23545 m
.55056 .2378 L
.55291 .2378 L
.55291 .23545 L
F
.73868 .23545 m
.73868 .2378 L
.74103 .2378 L
.74103 .23545 L
F
.75985 .23545 m
.75985 .2378 L
.7622 .2378 L
.7622 .23545 L
F
.7622 .23545 m
.7622 .2378 L
.76455 .2378 L
.76455 .23545 L
F
.97384 .23545 m
.97384 .2378 L
.97619 .2378 L
.97619 .23545 L
F
.54821 .2378 m
.54821 .24015 L
.55056 .24015 L
.55056 .2378 L
F
.73633 .2378 m
.73633 .24015 L
.73868 .24015 L
.73868 .2378 L
F
.7575 .2378 m
.7575 .24015 L
.75985 .24015 L
.75985 .2378 L
F
.75985 .2378 m
.75985 .24015 L
.7622 .24015 L
.7622 .2378 L
F
.7622 .2378 m
.7622 .24015 L
.76455 .24015 L
.76455 .2378 L
F
.97149 .2378 m
.97149 .24015 L
.97384 .24015 L
.97384 .2378 L
F
.54586 .24015 m
.54586 .2425 L
.54821 .2425 L
.54821 .24015 L
F
.73398 .24015 m
.73398 .2425 L
.73633 .2425 L
.73633 .24015 L
F
.75514 .24015 m
.75514 .2425 L
.7575 .2425 L
.7575 .24015 L
F
.7575 .24015 m
.7575 .2425 L
.75985 .2425 L
.75985 .24015 L
F
.75985 .24015 m
.75985 .2425 L
.7622 .2425 L
.7622 .24015 L
F
.96914 .24015 m
.96914 .2425 L
.97149 .2425 L
.97149 .24015 L
F
.5435 .2425 m
.5435 .24486 L
.54586 .24486 L
.54586 .2425 L
F
.73163 .2425 m
.73163 .24486 L
.73398 .24486 L
.73398 .2425 L
F
.75279 .2425 m
.75279 .24486 L
.75514 .24486 L
.75514 .2425 L
F
.75514 .2425 m
.75514 .24486 L
.7575 .24486 L
.7575 .2425 L
F
.7575 .2425 m
.7575 .24486 L
.75985 .24486 L
.75985 .2425 L
F
.96678 .2425 m
.96678 .24486 L
.96914 .24486 L
.96914 .2425 L
F
.54115 .24486 m
.54115 .24721 L
.5435 .24721 L
.5435 .24486 L
F
.72928 .24486 m
.72928 .24721 L
.73163 .24721 L
.73163 .24486 L
F
.75279 .24486 m
.75279 .24721 L
.75514 .24721 L
.75514 .24486 L
F
.75514 .24486 m
.75514 .24721 L
.7575 .24721 L
.7575 .24486 L
F
.96443 .24486 m
.96443 .24721 L
.96678 .24721 L
.96678 .24486 L
F
.5388 .24721 m
.5388 .24956 L
.54115 .24956 L
.54115 .24721 L
F
.72693 .24721 m
.72693 .24956 L
.72928 .24956 L
.72928 .24721 L
F
.74809 .24721 m
.74809 .24956 L
.75044 .24956 L
.75044 .24721 L
F
.75044 .24721 m
.75044 .24956 L
.75279 .24956 L
.75279 .24721 L
F
.96208 .24721 m
.96208 .24956 L
.96443 .24956 L
.96443 .24721 L
F
.53645 .24956 m
.53645 .25191 L
.5388 .25191 L
.5388 .24956 L
F
.72457 .24956 m
.72457 .25191 L
.72693 .25191 L
.72693 .24956 L
F
.74574 .24956 m
.74574 .25191 L
.74809 .25191 L
.74809 .24956 L
F
.74809 .24956 m
.74809 .25191 L
.75044 .25191 L
.75044 .24956 L
F
.75044 .24956 m
.75044 .25191 L
.75279 .25191 L
.75279 .24956 L
F
.95973 .24956 m
.95973 .25191 L
.96208 .25191 L
.96208 .24956 L
F
.5341 .25191 m
.5341 .25426 L
.53645 .25426 L
.53645 .25191 L
F
.72222 .25191 m
.72222 .25426 L
.72457 .25426 L
.72457 .25191 L
F
.74339 .25191 m
.74339 .25426 L
.74574 .25426 L
.74574 .25191 L
F
.74574 .25191 m
.74574 .25426 L
.74809 .25426 L
.74809 .25191 L
F
.74809 .25191 m
.74809 .25426 L
.75044 .25426 L
.75044 .25191 L
F
.95738 .25191 m
.95738 .25426 L
.95973 .25426 L
.95973 .25191 L
F
.53175 .25426 m
.53175 .25661 L
.5341 .25661 L
.5341 .25426 L
F
.71987 .25426 m
.71987 .25661 L
.72222 .25661 L
.72222 .25426 L
F
.74103 .25426 m
.74103 .25661 L
.74339 .25661 L
.74339 .25426 L
F
.74339 .25426 m
.74339 .25661 L
.74574 .25661 L
.74574 .25426 L
F
.74574 .25426 m
.74574 .25661 L
.74809 .25661 L
.74809 .25426 L
F
.95503 .25426 m
.95503 .25661 L
.95738 .25661 L
.95738 .25426 L
F
.52939 .25661 m
.52939 .25897 L
.53175 .25897 L
.53175 .25661 L
F
.71752 .25661 m
.71752 .25897 L
.71987 .25897 L
.71987 .25661 L
F
.74103 .25661 m
.74103 .25897 L
.74339 .25897 L
.74339 .25661 L
F
.74339 .25661 m
.74339 .25897 L
.74574 .25897 L
.74574 .25661 L
F
.95267 .25661 m
.95267 .25897 L
.95503 .25897 L
.95503 .25661 L
F
.52704 .25897 m
.52704 .26132 L
.52939 .26132 L
.52939 .25897 L
F
.71517 .25897 m
.71517 .26132 L
.71752 .26132 L
.71752 .25897 L
F
.73633 .25897 m
.73633 .26132 L
.73868 .26132 L
.73868 .25897 L
F
.73868 .25897 m
.73868 .26132 L
.74103 .26132 L
.74103 .25897 L
F
.7622 .25897 m
.7622 .26132 L
.76455 .26132 L
.76455 .25897 L
F
.95032 .25897 m
.95032 .26132 L
.95267 .26132 L
.95267 .25897 L
F
.52469 .26132 m
.52469 .26367 L
.52704 .26367 L
.52704 .26132 L
F
.71282 .26132 m
.71282 .26367 L
.71517 .26367 L
.71517 .26132 L
F
.73398 .26132 m
.73398 .26367 L
.73633 .26367 L
.73633 .26132 L
F
.73633 .26132 m
.73633 .26367 L
.73868 .26367 L
.73868 .26132 L
F
.73868 .26132 m
.73868 .26367 L
.74103 .26367 L
.74103 .26132 L
F
.75985 .26132 m
.75985 .26367 L
.7622 .26367 L
.7622 .26132 L
F
.94797 .26132 m
.94797 .26367 L
.95032 .26367 L
.95032 .26132 L
F
.52234 .26367 m
.52234 .26602 L
.52469 .26602 L
.52469 .26367 L
F
.71046 .26367 m
.71046 .26602 L
.71282 .26602 L
.71282 .26367 L
F
.73163 .26367 m
.73163 .26602 L
.73398 .26602 L
.73398 .26367 L
F
.73398 .26367 m
.73398 .26602 L
.73633 .26602 L
.73633 .26367 L
F
.73633 .26367 m
.73633 .26602 L
.73868 .26602 L
.73868 .26367 L
F
.7575 .26367 m
.7575 .26602 L
.75985 .26602 L
.75985 .26367 L
F
.94562 .26367 m
.94562 .26602 L
.94797 .26602 L
.94797 .26367 L
F
.51999 .26602 m
.51999 .26837 L
.52234 .26837 L
.52234 .26602 L
F
.70811 .26602 m
.70811 .26837 L
.71046 .26837 L
.71046 .26602 L
F
.72928 .26602 m
.72928 .26837 L
.73163 .26837 L
.73163 .26602 L
F
.73163 .26602 m
.73163 .26837 L
.73398 .26837 L
.73398 .26602 L
F
.73398 .26602 m
.73398 .26837 L
.73633 .26837 L
.73633 .26602 L
F
.75514 .26602 m
.75514 .26837 L
.7575 .26837 L
.7575 .26602 L
F
.94327 .26602 m
.94327 .26837 L
.94562 .26837 L
.94562 .26602 L
F
.51764 .26837 m
.51764 .27072 L
.51999 .27072 L
.51999 .26837 L
F
.70576 .26837 m
.70576 .27072 L
.70811 .27072 L
.70811 .26837 L
F
.72928 .26837 m
.72928 .27072 L
.73163 .27072 L
.73163 .26837 L
F
.73163 .26837 m
.73163 .27072 L
.73398 .27072 L
.73398 .26837 L
F
.75279 .26837 m
.75279 .27072 L
.75514 .27072 L
.75514 .26837 L
F
.94092 .26837 m
.94092 .27072 L
.94327 .27072 L
.94327 .26837 L
F
.51529 .27072 m
.51529 .27307 L
.51764 .27307 L
.51764 .27072 L
F
.70341 .27072 m
.70341 .27307 L
.70576 .27307 L
.70576 .27072 L
F
.72457 .27072 m
.72457 .27307 L
.72693 .27307 L
.72693 .27072 L
F
.72693 .27072 m
.72693 .27307 L
.72928 .27307 L
.72928 .27072 L
F
.75044 .27072 m
.75044 .27307 L
.75279 .27307 L
.75279 .27072 L
F
.93857 .27072 m
.93857 .27307 L
.94092 .27307 L
.94092 .27072 L
F
.51293 .27307 m
.51293 .27543 L
.51529 .27543 L
.51529 .27307 L
F
.70106 .27307 m
.70106 .27543 L
.70341 .27543 L
.70341 .27307 L
F
.72222 .27307 m
.72222 .27543 L
.72457 .27543 L
.72457 .27307 L
F
.72457 .27307 m
.72457 .27543 L
.72693 .27543 L
.72693 .27307 L
F
.72693 .27307 m
.72693 .27543 L
.72928 .27543 L
.72928 .27307 L
F
.74809 .27307 m
.74809 .27543 L
.75044 .27543 L
.75044 .27307 L
F
.93621 .27307 m
.93621 .27543 L
.93857 .27543 L
.93857 .27307 L
F
.51058 .27543 m
.51058 .27778 L
.51293 .27778 L
.51293 .27543 L
F
.69871 .27543 m
.69871 .27778 L
.70106 .27778 L
.70106 .27543 L
F
.71987 .27543 m
.71987 .27778 L
.72222 .27778 L
.72222 .27543 L
F
.72222 .27543 m
.72222 .27778 L
.72457 .27778 L
.72457 .27543 L
F
.72457 .27543 m
.72457 .27778 L
.72693 .27778 L
.72693 .27543 L
F
.74574 .27543 m
.74574 .27778 L
.74809 .27778 L
.74809 .27543 L
F
.93386 .27543 m
.93386 .27778 L
.93621 .27778 L
.93621 .27543 L
F
.50823 .27778 m
.50823 .28013 L
.51058 .28013 L
.51058 .27778 L
F
.69636 .27778 m
.69636 .28013 L
.69871 .28013 L
.69871 .27778 L
F
.71752 .27778 m
.71752 .28013 L
.71987 .28013 L
.71987 .27778 L
F
.71987 .27778 m
.71987 .28013 L
.72222 .28013 L
.72222 .27778 L
F
.72222 .27778 m
.72222 .28013 L
.72457 .28013 L
.72457 .27778 L
F
.74339 .27778 m
.74339 .28013 L
.74574 .28013 L
.74574 .27778 L
F
.93151 .27778 m
.93151 .28013 L
.93386 .28013 L
.93386 .27778 L
F
.50588 .28013 m
.50588 .28248 L
.50823 .28248 L
.50823 .28013 L
F
.694 .28013 m
.694 .28248 L
.69636 .28248 L
.69636 .28013 L
F
.71752 .28013 m
.71752 .28248 L
.71987 .28248 L
.71987 .28013 L
F
.71987 .28013 m
.71987 .28248 L
.72222 .28248 L
.72222 .28013 L
F
.74103 .28013 m
.74103 .28248 L
.74339 .28248 L
.74339 .28013 L
F
.92916 .28013 m
.92916 .28248 L
.93151 .28248 L
.93151 .28013 L
F
.50353 .28248 m
.50353 .28483 L
.50588 .28483 L
.50588 .28248 L
F
.69165 .28248 m
.69165 .28483 L
.694 .28483 L
.694 .28248 L
F
.71282 .28248 m
.71282 .28483 L
.71517 .28483 L
.71517 .28248 L
F
.71517 .28248 m
.71517 .28483 L
.71752 .28483 L
.71752 .28248 L
F
.73868 .28248 m
.73868 .28483 L
.74103 .28483 L
.74103 .28248 L
F
.92681 .28248 m
.92681 .28483 L
.92916 .28483 L
.92916 .28248 L
F
.50118 .28483 m
.50118 .28718 L
.50353 .28718 L
.50353 .28483 L
F
.6893 .28483 m
.6893 .28718 L
.69165 .28718 L
.69165 .28483 L
F
.71046 .28483 m
.71046 .28718 L
.71282 .28718 L
.71282 .28483 L
F
.71282 .28483 m
.71282 .28718 L
.71517 .28718 L
.71517 .28483 L
F
.71517 .28483 m
.71517 .28718 L
.71752 .28718 L
.71752 .28483 L
F
.73633 .28483 m
.73633 .28718 L
.73868 .28718 L
.73868 .28483 L
F
.92446 .28483 m
.92446 .28718 L
.92681 .28718 L
.92681 .28483 L
F
.49882 .28718 m
.49882 .28954 L
.50118 .28954 L
.50118 .28718 L
F
.68695 .28718 m
.68695 .28954 L
.6893 .28954 L
.6893 .28718 L
F
.70811 .28718 m
.70811 .28954 L
.71046 .28954 L
.71046 .28718 L
F
.71046 .28718 m
.71046 .28954 L
.71282 .28954 L
.71282 .28718 L
F
.71282 .28718 m
.71282 .28954 L
.71517 .28954 L
.71517 .28718 L
F
.73398 .28718 m
.73398 .28954 L
.73633 .28954 L
.73633 .28718 L
F
.9221 .28718 m
.9221 .28954 L
.92446 .28954 L
.92446 .28718 L
F
.49647 .28954 m
.49647 .29189 L
.49882 .29189 L
.49882 .28954 L
F
.6846 .28954 m
.6846 .29189 L
.68695 .29189 L
.68695 .28954 L
F
.70576 .28954 m
.70576 .29189 L
.70811 .29189 L
.70811 .28954 L
F
.70811 .28954 m
.70811 .29189 L
.71046 .29189 L
.71046 .28954 L
F
.71046 .28954 m
.71046 .29189 L
.71282 .29189 L
.71282 .28954 L
F
.73163 .28954 m
.73163 .29189 L
.73398 .29189 L
.73398 .28954 L
F
.91975 .28954 m
.91975 .29189 L
.9221 .29189 L
.9221 .28954 L
F
.49412 .29189 m
.49412 .29424 L
.49647 .29424 L
.49647 .29189 L
F
.68225 .29189 m
.68225 .29424 L
.6846 .29424 L
.6846 .29189 L
F
.70576 .29189 m
.70576 .29424 L
.70811 .29424 L
.70811 .29189 L
F
.70811 .29189 m
.70811 .29424 L
.71046 .29424 L
.71046 .29189 L
F
.72928 .29189 m
.72928 .29424 L
.73163 .29424 L
.73163 .29189 L
F
.9174 .29189 m
.9174 .29424 L
.91975 .29424 L
.91975 .29189 L
F
.49177 .29424 m
.49177 .29659 L
.49412 .29659 L
.49412 .29424 L
F
.67989 .29424 m
.67989 .29659 L
.68225 .29659 L
.68225 .29424 L
F
.70106 .29424 m
.70106 .29659 L
.70341 .29659 L
.70341 .29424 L
F
.70341 .29424 m
.70341 .29659 L
.70576 .29659 L
.70576 .29424 L
F
.72693 .29424 m
.72693 .29659 L
.72928 .29659 L
.72928 .29424 L
F
.91505 .29424 m
.91505 .29659 L
.9174 .29659 L
.9174 .29424 L
F
.48942 .29659 m
.48942 .29894 L
.49177 .29894 L
.49177 .29659 L
F
.67754 .29659 m
.67754 .29894 L
.67989 .29894 L
.67989 .29659 L
F
.69871 .29659 m
.69871 .29894 L
.70106 .29894 L
.70106 .29659 L
F
.70106 .29659 m
.70106 .29894 L
.70341 .29894 L
.70341 .29659 L
F
.70341 .29659 m
.70341 .29894 L
.70576 .29894 L
.70576 .29659 L
F
.72457 .29659 m
.72457 .29894 L
.72693 .29894 L
.72693 .29659 L
F
.9127 .29659 m
.9127 .29894 L
.91505 .29894 L
.91505 .29659 L
F
.48707 .29894 m
.48707 .30129 L
.48942 .30129 L
.48942 .29894 L
F
.67519 .29894 m
.67519 .30129 L
.67754 .30129 L
.67754 .29894 L
F
.69636 .29894 m
.69636 .30129 L
.69871 .30129 L
.69871 .29894 L
F
.69871 .29894 m
.69871 .30129 L
.70106 .30129 L
.70106 .29894 L
F
.70106 .29894 m
.70106 .30129 L
.70341 .30129 L
.70341 .29894 L
F
.72222 .29894 m
.72222 .30129 L
.72457 .30129 L
.72457 .29894 L
F
.91035 .29894 m
.91035 .30129 L
.9127 .30129 L
.9127 .29894 L
F
.48471 .30129 m
.48471 .30364 L
.48707 .30364 L
.48707 .30129 L
F
.67284 .30129 m
.67284 .30364 L
.67519 .30364 L
.67519 .30129 L
F
.694 .30129 m
.694 .30364 L
.69636 .30364 L
.69636 .30129 L
F
.69636 .30129 m
.69636 .30364 L
.69871 .30364 L
.69871 .30129 L
F
.69871 .30129 m
.69871 .30364 L
.70106 .30364 L
.70106 .30129 L
F
.71987 .30129 m
.71987 .30364 L
.72222 .30364 L
.72222 .30129 L
F
.908 .30129 m
.908 .30364 L
.91035 .30364 L
.91035 .30129 L
F
.48236 .30364 m
.48236 .306 L
.48471 .306 L
.48471 .30364 L
F
.67049 .30364 m
.67049 .306 L
.67284 .306 L
.67284 .30364 L
F
.694 .30364 m
.694 .306 L
.69636 .306 L
.69636 .30364 L
F
.69636 .30364 m
.69636 .306 L
.69871 .306 L
.69871 .30364 L
F
.71752 .30364 m
.71752 .306 L
.71987 .306 L
.71987 .30364 L
F
.90564 .30364 m
.90564 .306 L
.908 .306 L
.908 .30364 L
F
.48001 .306 m
.48001 .30835 L
.48236 .30835 L
.48236 .306 L
F
.66814 .306 m
.66814 .30835 L
.67049 .30835 L
.67049 .306 L
F
.6893 .306 m
.6893 .30835 L
.69165 .30835 L
.69165 .306 L
F
.69165 .306 m
.69165 .30835 L
.694 .30835 L
.694 .306 L
F
.71517 .306 m
.71517 .30835 L
.71752 .30835 L
.71752 .306 L
F
.90329 .306 m
.90329 .30835 L
.90564 .30835 L
.90564 .306 L
F
.47766 .30835 m
.47766 .3107 L
.48001 .3107 L
.48001 .30835 L
F
.66578 .30835 m
.66578 .3107 L
.66814 .3107 L
.66814 .30835 L
F
.68695 .30835 m
.68695 .3107 L
.6893 .3107 L
.6893 .30835 L
F
.6893 .30835 m
.6893 .3107 L
.69165 .3107 L
.69165 .30835 L
F
.69165 .30835 m
.69165 .3107 L
.694 .3107 L
.694 .30835 L
F
.71282 .30835 m
.71282 .3107 L
.71517 .3107 L
.71517 .30835 L
F
.90094 .30835 m
.90094 .3107 L
.90329 .3107 L
.90329 .30835 L
F
.47531 .3107 m
.47531 .31305 L
.47766 .31305 L
.47766 .3107 L
F
.66343 .3107 m
.66343 .31305 L
.66578 .31305 L
.66578 .3107 L
F
.6846 .3107 m
.6846 .31305 L
.68695 .31305 L
.68695 .3107 L
F
.68695 .3107 m
.68695 .31305 L
.6893 .31305 L
.6893 .3107 L
F
.6893 .3107 m
.6893 .31305 L
.69165 .31305 L
.69165 .3107 L
F
.71046 .3107 m
.71046 .31305 L
.71282 .31305 L
.71282 .3107 L
F
.89859 .3107 m
.89859 .31305 L
.90094 .31305 L
.90094 .3107 L
F
.47296 .31305 m
.47296 .3154 L
.47531 .3154 L
.47531 .31305 L
F
.66108 .31305 m
.66108 .3154 L
.66343 .3154 L
.66343 .31305 L
F
.68225 .31305 m
.68225 .3154 L
.6846 .3154 L
.6846 .31305 L
F
.6846 .31305 m
.6846 .3154 L
.68695 .3154 L
.68695 .31305 L
F
.68695 .31305 m
.68695 .3154 L
.6893 .3154 L
.6893 .31305 L
F
.70811 .31305 m
.70811 .3154 L
.71046 .3154 L
.71046 .31305 L
F
.89624 .31305 m
.89624 .3154 L
.89859 .3154 L
.89859 .31305 L
F
.47061 .3154 m
.47061 .31775 L
.47296 .31775 L
.47296 .3154 L
F
.65873 .3154 m
.65873 .31775 L
.66108 .31775 L
.66108 .3154 L
F
.68225 .3154 m
.68225 .31775 L
.6846 .31775 L
.6846 .3154 L
F
.6846 .3154 m
.6846 .31775 L
.68695 .31775 L
.68695 .3154 L
F
.70576 .3154 m
.70576 .31775 L
.70811 .31775 L
.70811 .3154 L
F
.89389 .3154 m
.89389 .31775 L
.89624 .31775 L
.89624 .3154 L
F
.46825 .31775 m
.46825 .32011 L
.47061 .32011 L
.47061 .31775 L
F
.67754 .31775 m
.67754 .32011 L
.67989 .32011 L
.67989 .31775 L
F
.67989 .31775 m
.67989 .32011 L
.68225 .32011 L
.68225 .31775 L
F
.70341 .31775 m
.70341 .32011 L
.70576 .32011 L
.70576 .31775 L
F
.89153 .31775 m
.89153 .32011 L
.89389 .32011 L
.89389 .31775 L
F
.4659 .32011 m
.4659 .32246 L
.46825 .32246 L
.46825 .32011 L
F
.67519 .32011 m
.67519 .32246 L
.67754 .32246 L
.67754 .32011 L
F
.67754 .32011 m
.67754 .32246 L
.67989 .32246 L
.67989 .32011 L
F
.67989 .32011 m
.67989 .32246 L
.68225 .32246 L
.68225 .32011 L
F
.70106 .32011 m
.70106 .32246 L
.70341 .32246 L
.70341 .32011 L
F
.88918 .32011 m
.88918 .32246 L
.89153 .32246 L
.89153 .32011 L
F
.46355 .32246 m
.46355 .32481 L
.4659 .32481 L
.4659 .32246 L
F
.67284 .32246 m
.67284 .32481 L
.67519 .32481 L
.67519 .32246 L
F
.67519 .32246 m
.67519 .32481 L
.67754 .32481 L
.67754 .32246 L
F
.67754 .32246 m
.67754 .32481 L
.67989 .32481 L
.67989 .32246 L
F
.69871 .32246 m
.69871 .32481 L
.70106 .32481 L
.70106 .32246 L
F
.88683 .32246 m
.88683 .32481 L
.88918 .32481 L
.88918 .32246 L
F
.4612 .32481 m
.4612 .32716 L
.46355 .32716 L
.46355 .32481 L
F
.67049 .32481 m
.67049 .32716 L
.67284 .32716 L
.67284 .32481 L
F
.67284 .32481 m
.67284 .32716 L
.67519 .32716 L
.67519 .32481 L
F
.67519 .32481 m
.67519 .32716 L
.67754 .32716 L
.67754 .32481 L
F
.69636 .32481 m
.69636 .32716 L
.69871 .32716 L
.69871 .32481 L
F
.88448 .32481 m
.88448 .32716 L
.88683 .32716 L
.88683 .32481 L
F
.45885 .32716 m
.45885 .32951 L
.4612 .32951 L
.4612 .32716 L
F
.67049 .32716 m
.67049 .32951 L
.67284 .32951 L
.67284 .32716 L
F
.67284 .32716 m
.67284 .32951 L
.67519 .32951 L
.67519 .32716 L
F
.694 .32716 m
.694 .32951 L
.69636 .32951 L
.69636 .32716 L
F
.88213 .32716 m
.88213 .32951 L
.88448 .32951 L
.88448 .32716 L
F
.4565 .32951 m
.4565 .33186 L
.45885 .33186 L
.45885 .32951 L
F
.66578 .32951 m
.66578 .33186 L
.66814 .33186 L
.66814 .32951 L
F
.66814 .32951 m
.66814 .33186 L
.67049 .33186 L
.67049 .32951 L
F
.69165 .32951 m
.69165 .33186 L
.694 .33186 L
.694 .32951 L
F
.87978 .32951 m
.87978 .33186 L
.88213 .33186 L
.88213 .32951 L
F
.45414 .33186 m
.45414 .33422 L
.4565 .33422 L
.4565 .33186 L
F
.66343 .33186 m
.66343 .33422 L
.66578 .33422 L
.66578 .33186 L
F
.66578 .33186 m
.66578 .33422 L
.66814 .33422 L
.66814 .33186 L
F
.66814 .33186 m
.66814 .33422 L
.67049 .33422 L
.67049 .33186 L
F
.6893 .33186 m
.6893 .33422 L
.69165 .33422 L
.69165 .33186 L
F
.87743 .33186 m
.87743 .33422 L
.87978 .33422 L
.87978 .33186 L
F
.45179 .33422 m
.45179 .33657 L
.45414 .33657 L
.45414 .33422 L
F
.66108 .33422 m
.66108 .33657 L
.66343 .33657 L
.66343 .33422 L
F
.66343 .33422 m
.66343 .33657 L
.66578 .33657 L
.66578 .33422 L
F
.66578 .33422 m
.66578 .33657 L
.66814 .33657 L
.66814 .33422 L
F
.68695 .33422 m
.68695 .33657 L
.6893 .33657 L
.6893 .33422 L
F
.87507 .33422 m
.87507 .33657 L
.87743 .33657 L
.87743 .33422 L
F
.44944 .33657 m
.44944 .33892 L
.45179 .33892 L
.45179 .33657 L
F
.65873 .33657 m
.65873 .33892 L
.66108 .33892 L
.66108 .33657 L
F
.66108 .33657 m
.66108 .33892 L
.66343 .33892 L
.66343 .33657 L
F
.66343 .33657 m
.66343 .33892 L
.66578 .33892 L
.66578 .33657 L
F
.6846 .33657 m
.6846 .33892 L
.68695 .33892 L
.68695 .33657 L
F
.87272 .33657 m
.87272 .33892 L
.87507 .33892 L
.87507 .33657 L
F
.44709 .33892 m
.44709 .34127 L
.44944 .34127 L
.44944 .33892 L
F
.65873 .33892 m
.65873 .34127 L
.66108 .34127 L
.66108 .33892 L
F
.66108 .33892 m
.66108 .34127 L
.66343 .34127 L
.66343 .33892 L
F
.68225 .33892 m
.68225 .34127 L
.6846 .34127 L
.6846 .33892 L
F
.87037 .33892 m
.87037 .34127 L
.87272 .34127 L
.87272 .33892 L
F
.44474 .34127 m
.44474 .34362 L
.44709 .34362 L
.44709 .34127 L
F
.63286 .34127 m
.63286 .34362 L
.63521 .34362 L
.63521 .34127 L
F
.65403 .34127 m
.65403 .34362 L
.65638 .34362 L
.65638 .34127 L
F
.65638 .34127 m
.65638 .34362 L
.65873 .34362 L
.65873 .34127 L
F
.86802 .34127 m
.86802 .34362 L
.87037 .34362 L
.87037 .34127 L
F
.44239 .34362 m
.44239 .34597 L
.44474 .34597 L
.44474 .34362 L
F
.63051 .34362 m
.63051 .34597 L
.63286 .34597 L
.63286 .34362 L
F
.65168 .34362 m
.65168 .34597 L
.65403 .34597 L
.65403 .34362 L
F
.65403 .34362 m
.65403 .34597 L
.65638 .34597 L
.65638 .34362 L
F
.65638 .34362 m
.65638 .34597 L
.65873 .34597 L
.65873 .34362 L
F
.86567 .34362 m
.86567 .34597 L
.86802 .34597 L
.86802 .34362 L
F
.44004 .34597 m
.44004 .34832 L
.44239 .34832 L
.44239 .34597 L
F
.62816 .34597 m
.62816 .34832 L
.63051 .34832 L
.63051 .34597 L
F
.64932 .34597 m
.64932 .34832 L
.65168 .34832 L
.65168 .34597 L
F
.65168 .34597 m
.65168 .34832 L
.65403 .34832 L
.65403 .34597 L
F
.65403 .34597 m
.65403 .34832 L
.65638 .34832 L
.65638 .34597 L
F
.86332 .34597 m
.86332 .34832 L
.86567 .34832 L
.86567 .34597 L
F
.43768 .34832 m
.43768 .35068 L
.44004 .35068 L
.44004 .34832 L
F
.62581 .34832 m
.62581 .35068 L
.62816 .35068 L
.62816 .34832 L
F
.64697 .34832 m
.64697 .35068 L
.64932 .35068 L
.64932 .34832 L
F
.64932 .34832 m
.64932 .35068 L
.65168 .35068 L
.65168 .34832 L
F
.65168 .34832 m
.65168 .35068 L
.65403 .35068 L
.65403 .34832 L
F
.86096 .34832 m
.86096 .35068 L
.86332 .35068 L
.86332 .34832 L
F
.43533 .35068 m
.43533 .35303 L
.43768 .35303 L
.43768 .35068 L
F
.62346 .35068 m
.62346 .35303 L
.62581 .35303 L
.62581 .35068 L
F
.64697 .35068 m
.64697 .35303 L
.64932 .35303 L
.64932 .35068 L
F
.64932 .35068 m
.64932 .35303 L
.65168 .35303 L
.65168 .35068 L
F
.85861 .35068 m
.85861 .35303 L
.86096 .35303 L
.86096 .35068 L
F
.43298 .35303 m
.43298 .35538 L
.43533 .35538 L
.43533 .35303 L
F
.62111 .35303 m
.62111 .35538 L
.62346 .35538 L
.62346 .35303 L
F
.64227 .35303 m
.64227 .35538 L
.64462 .35538 L
.64462 .35303 L
F
.64462 .35303 m
.64462 .35538 L
.64697 .35538 L
.64697 .35303 L
F
.85626 .35303 m
.85626 .35538 L
.85861 .35538 L
.85861 .35303 L
F
.43063 .35538 m
.43063 .35773 L
.43298 .35773 L
.43298 .35538 L
F
.61875 .35538 m
.61875 .35773 L
.62111 .35773 L
.62111 .35538 L
F
.63992 .35538 m
.63992 .35773 L
.64227 .35773 L
.64227 .35538 L
F
.64227 .35538 m
.64227 .35773 L
.64462 .35773 L
.64462 .35538 L
F
.64462 .35538 m
.64462 .35773 L
.64697 .35773 L
.64697 .35538 L
F
.85391 .35538 m
.85391 .35773 L
.85626 .35773 L
.85626 .35538 L
F
.42828 .35773 m
.42828 .36008 L
.43063 .36008 L
.43063 .35773 L
F
.6164 .35773 m
.6164 .36008 L
.61875 .36008 L
.61875 .35773 L
F
.63757 .35773 m
.63757 .36008 L
.63992 .36008 L
.63992 .35773 L
F
.63992 .35773 m
.63992 .36008 L
.64227 .36008 L
.64227 .35773 L
F
.64227 .35773 m
.64227 .36008 L
.64462 .36008 L
.64462 .35773 L
F
.85156 .35773 m
.85156 .36008 L
.85391 .36008 L
.85391 .35773 L
F
.42593 .36008 m
.42593 .36243 L
.42828 .36243 L
.42828 .36008 L
F
.61405 .36008 m
.61405 .36243 L
.6164 .36243 L
.6164 .36008 L
F
.63521 .36008 m
.63521 .36243 L
.63757 .36243 L
.63757 .36008 L
F
.63757 .36008 m
.63757 .36243 L
.63992 .36243 L
.63992 .36008 L
F
.63992 .36008 m
.63992 .36243 L
.64227 .36243 L
.64227 .36008 L
F
.84921 .36008 m
.84921 .36243 L
.85156 .36243 L
.85156 .36008 L
F
.42357 .36243 m
.42357 .36479 L
.42593 .36479 L
.42593 .36243 L
F
.6117 .36243 m
.6117 .36479 L
.61405 .36479 L
.61405 .36243 L
F
.63521 .36243 m
.63521 .36479 L
.63757 .36479 L
.63757 .36243 L
F
.63757 .36243 m
.63757 .36479 L
.63992 .36479 L
.63992 .36243 L
F
.84685 .36243 m
.84685 .36479 L
.84921 .36479 L
.84921 .36243 L
F
.42122 .36479 m
.42122 .36714 L
.42357 .36714 L
.42357 .36479 L
F
.60935 .36479 m
.60935 .36714 L
.6117 .36714 L
.6117 .36479 L
F
.63051 .36479 m
.63051 .36714 L
.63286 .36714 L
.63286 .36479 L
F
.63286 .36479 m
.63286 .36714 L
.63521 .36714 L
.63521 .36479 L
F
.65638 .36479 m
.65638 .36714 L
.65873 .36714 L
.65873 .36479 L
F
.8445 .36479 m
.8445 .36714 L
.84685 .36714 L
.84685 .36479 L
F
.41887 .36714 m
.41887 .36949 L
.42122 .36949 L
.42122 .36714 L
F
.607 .36714 m
.607 .36949 L
.60935 .36949 L
.60935 .36714 L
F
.62816 .36714 m
.62816 .36949 L
.63051 .36949 L
.63051 .36714 L
F
.63051 .36714 m
.63051 .36949 L
.63286 .36949 L
.63286 .36714 L
F
.63286 .36714 m
.63286 .36949 L
.63521 .36949 L
.63521 .36714 L
F
.65403 .36714 m
.65403 .36949 L
.65638 .36949 L
.65638 .36714 L
F
.84215 .36714 m
.84215 .36949 L
.8445 .36949 L
.8445 .36714 L
F
.41652 .36949 m
.41652 .37184 L
.41887 .37184 L
.41887 .36949 L
F
.60464 .36949 m
.60464 .37184 L
.607 .37184 L
.607 .36949 L
F
.62581 .36949 m
.62581 .37184 L
.62816 .37184 L
.62816 .36949 L
F
.62816 .36949 m
.62816 .37184 L
.63051 .37184 L
.63051 .36949 L
F
.63051 .36949 m
.63051 .37184 L
.63286 .37184 L
.63286 .36949 L
F
.65168 .36949 m
.65168 .37184 L
.65403 .37184 L
.65403 .36949 L
F
.8398 .36949 m
.8398 .37184 L
.84215 .37184 L
.84215 .36949 L
F
.41417 .37184 m
.41417 .37419 L
.41652 .37419 L
.41652 .37184 L
F
.60229 .37184 m
.60229 .37419 L
.60464 .37419 L
.60464 .37184 L
F
.62346 .37184 m
.62346 .37419 L
.62581 .37419 L
.62581 .37184 L
F
.62581 .37184 m
.62581 .37419 L
.62816 .37419 L
.62816 .37184 L
F
.62816 .37184 m
.62816 .37419 L
.63051 .37419 L
.63051 .37184 L
F
.64932 .37184 m
.64932 .37419 L
.65168 .37419 L
.65168 .37184 L
F
.83745 .37184 m
.83745 .37419 L
.8398 .37419 L
.8398 .37184 L
F
.41182 .37419 m
.41182 .37654 L
.41417 .37654 L
.41417 .37419 L
F
.59994 .37419 m
.59994 .37654 L
.60229 .37654 L
.60229 .37419 L
F
.62346 .37419 m
.62346 .37654 L
.62581 .37654 L
.62581 .37419 L
F
.62581 .37419 m
.62581 .37654 L
.62816 .37654 L
.62816 .37419 L
F
.64697 .37419 m
.64697 .37654 L
.64932 .37654 L
.64932 .37419 L
F
.8351 .37419 m
.8351 .37654 L
.83745 .37654 L
.83745 .37419 L
F
.40947 .37654 m
.40947 .37889 L
.41182 .37889 L
.41182 .37654 L
F
.59759 .37654 m
.59759 .37889 L
.59994 .37889 L
.59994 .37654 L
F
.61875 .37654 m
.61875 .37889 L
.62111 .37889 L
.62111 .37654 L
F
.62111 .37654 m
.62111 .37889 L
.62346 .37889 L
.62346 .37654 L
F
.64462 .37654 m
.64462 .37889 L
.64697 .37889 L
.64697 .37654 L
F
.83275 .37654 m
.83275 .37889 L
.8351 .37889 L
.8351 .37654 L
F
.40711 .37889 m
.40711 .38125 L
.40947 .38125 L
.40947 .37889 L
F
.59524 .37889 m
.59524 .38125 L
.59759 .38125 L
.59759 .37889 L
F
.6164 .37889 m
.6164 .38125 L
.61875 .38125 L
.61875 .37889 L
F
.61875 .37889 m
.61875 .38125 L
.62111 .38125 L
.62111 .37889 L
F
.62111 .37889 m
.62111 .38125 L
.62346 .38125 L
.62346 .37889 L
F
.64227 .37889 m
.64227 .38125 L
.64462 .38125 L
.64462 .37889 L
F
.83039 .37889 m
.83039 .38125 L
.83275 .38125 L
.83275 .37889 L
F
.40476 .38125 m
.40476 .3836 L
.40711 .3836 L
.40711 .38125 L
F
.59289 .38125 m
.59289 .3836 L
.59524 .3836 L
.59524 .38125 L
F
.61405 .38125 m
.61405 .3836 L
.6164 .3836 L
.6164 .38125 L
F
.6164 .38125 m
.6164 .3836 L
.61875 .3836 L
.61875 .38125 L
F
.61875 .38125 m
.61875 .3836 L
.62111 .3836 L
.62111 .38125 L
F
.63992 .38125 m
.63992 .3836 L
.64227 .3836 L
.64227 .38125 L
F
.82804 .38125 m
.82804 .3836 L
.83039 .3836 L
.83039 .38125 L
F
.40241 .3836 m
.40241 .38595 L
.40476 .38595 L
.40476 .3836 L
F
.59053 .3836 m
.59053 .38595 L
.59289 .38595 L
.59289 .3836 L
F
.6117 .3836 m
.6117 .38595 L
.61405 .38595 L
.61405 .3836 L
F
.61405 .3836 m
.61405 .38595 L
.6164 .38595 L
.6164 .3836 L
F
.6164 .3836 m
.6164 .38595 L
.61875 .38595 L
.61875 .3836 L
F
.63757 .3836 m
.63757 .38595 L
.63992 .38595 L
.63992 .3836 L
F
.82569 .3836 m
.82569 .38595 L
.82804 .38595 L
.82804 .3836 L
F
.40006 .38595 m
.40006 .3883 L
.40241 .3883 L
.40241 .38595 L
F
.58818 .38595 m
.58818 .3883 L
.59053 .3883 L
.59053 .38595 L
F
.6117 .38595 m
.6117 .3883 L
.61405 .3883 L
.61405 .38595 L
F
.61405 .38595 m
.61405 .3883 L
.6164 .3883 L
.6164 .38595 L
F
.63521 .38595 m
.63521 .3883 L
.63757 .3883 L
.63757 .38595 L
F
.82334 .38595 m
.82334 .3883 L
.82569 .3883 L
.82569 .38595 L
F
.39771 .3883 m
.39771 .39065 L
.40006 .39065 L
.40006 .3883 L
F
.58583 .3883 m
.58583 .39065 L
.58818 .39065 L
.58818 .3883 L
F
.607 .3883 m
.607 .39065 L
.60935 .39065 L
.60935 .3883 L
F
.60935 .3883 m
.60935 .39065 L
.6117 .39065 L
.6117 .3883 L
F
.63286 .3883 m
.63286 .39065 L
.63521 .39065 L
.63521 .3883 L
F
.82099 .3883 m
.82099 .39065 L
.82334 .39065 L
.82334 .3883 L
F
.39536 .39065 m
.39536 .393 L
.39771 .393 L
.39771 .39065 L
F
.58348 .39065 m
.58348 .393 L
.58583 .393 L
.58583 .39065 L
F
.60464 .39065 m
.60464 .393 L
.607 .393 L
.607 .39065 L
F
.607 .39065 m
.607 .393 L
.60935 .393 L
.60935 .39065 L
F
.60935 .39065 m
.60935 .393 L
.6117 .393 L
.6117 .39065 L
F
.63051 .39065 m
.63051 .393 L
.63286 .393 L
.63286 .39065 L
F
.81864 .39065 m
.81864 .393 L
.82099 .393 L
.82099 .39065 L
F
.393 .393 m
.393 .39536 L
.39536 .39536 L
.39536 .393 L
F
.58113 .393 m
.58113 .39536 L
.58348 .39536 L
.58348 .393 L
F
.60229 .393 m
.60229 .39536 L
.60464 .39536 L
.60464 .393 L
F
.60464 .393 m
.60464 .39536 L
.607 .39536 L
.607 .393 L
F
.607 .393 m
.607 .39536 L
.60935 .39536 L
.60935 .393 L
F
.62816 .393 m
.62816 .39536 L
.63051 .39536 L
.63051 .393 L
F
.81628 .393 m
.81628 .39536 L
.81864 .39536 L
.81864 .393 L
F
.39065 .39536 m
.39065 .39771 L
.393 .39771 L
.393 .39536 L
F
.57878 .39536 m
.57878 .39771 L
.58113 .39771 L
.58113 .39536 L
F
.59994 .39536 m
.59994 .39771 L
.60229 .39771 L
.60229 .39536 L
F
.60229 .39536 m
.60229 .39771 L
.60464 .39771 L
.60464 .39536 L
F
.60464 .39536 m
.60464 .39771 L
.607 .39771 L
.607 .39536 L
F
.62581 .39536 m
.62581 .39771 L
.62816 .39771 L
.62816 .39536 L
F
.81393 .39536 m
.81393 .39771 L
.81628 .39771 L
.81628 .39536 L
F
.3883 .39771 m
.3883 .40006 L
.39065 .40006 L
.39065 .39771 L
F
.57643 .39771 m
.57643 .40006 L
.57878 .40006 L
.57878 .39771 L
F
.59994 .39771 m
.59994 .40006 L
.60229 .40006 L
.60229 .39771 L
F
.60229 .39771 m
.60229 .40006 L
.60464 .40006 L
.60464 .39771 L
F
.62346 .39771 m
.62346 .40006 L
.62581 .40006 L
.62581 .39771 L
F
.81158 .39771 m
.81158 .40006 L
.81393 .40006 L
.81393 .39771 L
F
.38595 .40006 m
.38595 .40241 L
.3883 .40241 L
.3883 .40006 L
F
.57407 .40006 m
.57407 .40241 L
.57643 .40241 L
.57643 .40006 L
F
.59524 .40006 m
.59524 .40241 L
.59759 .40241 L
.59759 .40006 L
F
.59759 .40006 m
.59759 .40241 L
.59994 .40241 L
.59994 .40006 L
F
.62111 .40006 m
.62111 .40241 L
.62346 .40241 L
.62346 .40006 L
F
.80923 .40006 m
.80923 .40241 L
.81158 .40241 L
.81158 .40006 L
F
.3836 .40241 m
.3836 .40476 L
.38595 .40476 L
.38595 .40241 L
F
.57172 .40241 m
.57172 .40476 L
.57407 .40476 L
.57407 .40241 L
F
.59289 .40241 m
.59289 .40476 L
.59524 .40476 L
.59524 .40241 L
F
.59524 .40241 m
.59524 .40476 L
.59759 .40476 L
.59759 .40241 L
F
.59759 .40241 m
.59759 .40476 L
.59994 .40476 L
.59994 .40241 L
F
.61875 .40241 m
.61875 .40476 L
.62111 .40476 L
.62111 .40241 L
F
.80688 .40241 m
.80688 .40476 L
.80923 .40476 L
.80923 .40241 L
F
.38125 .40476 m
.38125 .40711 L
.3836 .40711 L
.3836 .40476 L
F
.56937 .40476 m
.56937 .40711 L
.57172 .40711 L
.57172 .40476 L
F
.59053 .40476 m
.59053 .40711 L
.59289 .40711 L
.59289 .40476 L
F
.59289 .40476 m
.59289 .40711 L
.59524 .40711 L
.59524 .40476 L
F
.59524 .40476 m
.59524 .40711 L
.59759 .40711 L
.59759 .40476 L
F
.6164 .40476 m
.6164 .40711 L
.61875 .40711 L
.61875 .40476 L
F
.80453 .40476 m
.80453 .40711 L
.80688 .40711 L
.80688 .40476 L
F
.37889 .40711 m
.37889 .40947 L
.38125 .40947 L
.38125 .40711 L
F
.56702 .40711 m
.56702 .40947 L
.56937 .40947 L
.56937 .40711 L
F
.58818 .40711 m
.58818 .40947 L
.59053 .40947 L
.59053 .40711 L
F
.59053 .40711 m
.59053 .40947 L
.59289 .40947 L
.59289 .40711 L
F
.59289 .40711 m
.59289 .40947 L
.59524 .40947 L
.59524 .40711 L
F
.61405 .40711 m
.61405 .40947 L
.6164 .40947 L
.6164 .40711 L
F
.80218 .40711 m
.80218 .40947 L
.80453 .40947 L
.80453 .40711 L
F
.37654 .40947 m
.37654 .41182 L
.37889 .41182 L
.37889 .40947 L
F
.56467 .40947 m
.56467 .41182 L
.56702 .41182 L
.56702 .40947 L
F
.58818 .40947 m
.58818 .41182 L
.59053 .41182 L
.59053 .40947 L
F
.59053 .40947 m
.59053 .41182 L
.59289 .41182 L
.59289 .40947 L
F
.6117 .40947 m
.6117 .41182 L
.61405 .41182 L
.61405 .40947 L
F
.79982 .40947 m
.79982 .41182 L
.80218 .41182 L
.80218 .40947 L
F
.37419 .41182 m
.37419 .41417 L
.37654 .41417 L
.37654 .41182 L
F
.56232 .41182 m
.56232 .41417 L
.56467 .41417 L
.56467 .41182 L
F
.58348 .41182 m
.58348 .41417 L
.58583 .41417 L
.58583 .41182 L
F
.58583 .41182 m
.58583 .41417 L
.58818 .41417 L
.58818 .41182 L
F
.60935 .41182 m
.60935 .41417 L
.6117 .41417 L
.6117 .41182 L
F
.79747 .41182 m
.79747 .41417 L
.79982 .41417 L
.79982 .41182 L
F
.37184 .41417 m
.37184 .41652 L
.37419 .41652 L
.37419 .41417 L
F
.55996 .41417 m
.55996 .41652 L
.56232 .41652 L
.56232 .41417 L
F
.58113 .41417 m
.58113 .41652 L
.58348 .41652 L
.58348 .41417 L
F
.58348 .41417 m
.58348 .41652 L
.58583 .41652 L
.58583 .41417 L
F
.58583 .41417 m
.58583 .41652 L
.58818 .41652 L
.58818 .41417 L
F
.607 .41417 m
.607 .41652 L
.60935 .41652 L
.60935 .41417 L
F
.79512 .41417 m
.79512 .41652 L
.79747 .41652 L
.79747 .41417 L
F
.36949 .41652 m
.36949 .41887 L
.37184 .41887 L
.37184 .41652 L
F
.55761 .41652 m
.55761 .41887 L
.55996 .41887 L
.55996 .41652 L
F
.57878 .41652 m
.57878 .41887 L
.58113 .41887 L
.58113 .41652 L
F
.58113 .41652 m
.58113 .41887 L
.58348 .41887 L
.58348 .41652 L
F
.58348 .41652 m
.58348 .41887 L
.58583 .41887 L
.58583 .41652 L
F
.60464 .41652 m
.60464 .41887 L
.607 .41887 L
.607 .41652 L
F
.79277 .41652 m
.79277 .41887 L
.79512 .41887 L
.79512 .41652 L
F
.36714 .41887 m
.36714 .42122 L
.36949 .42122 L
.36949 .41887 L
F
.55526 .41887 m
.55526 .42122 L
.55761 .42122 L
.55761 .41887 L
F
.57643 .41887 m
.57643 .42122 L
.57878 .42122 L
.57878 .41887 L
F
.57878 .41887 m
.57878 .42122 L
.58113 .42122 L
.58113 .41887 L
F
.58113 .41887 m
.58113 .42122 L
.58348 .42122 L
.58348 .41887 L
F
.60229 .41887 m
.60229 .42122 L
.60464 .42122 L
.60464 .41887 L
F
.79042 .41887 m
.79042 .42122 L
.79277 .42122 L
.79277 .41887 L
F
.36479 .42122 m
.36479 .42357 L
.36714 .42357 L
.36714 .42122 L
F
.55291 .42122 m
.55291 .42357 L
.55526 .42357 L
.55526 .42122 L
F
.57643 .42122 m
.57643 .42357 L
.57878 .42357 L
.57878 .42122 L
F
.57878 .42122 m
.57878 .42357 L
.58113 .42357 L
.58113 .42122 L
F
.59994 .42122 m
.59994 .42357 L
.60229 .42357 L
.60229 .42122 L
F
.78807 .42122 m
.78807 .42357 L
.79042 .42357 L
.79042 .42122 L
F
.36243 .42357 m
.36243 .42593 L
.36479 .42593 L
.36479 .42357 L
F
.57172 .42357 m
.57172 .42593 L
.57407 .42593 L
.57407 .42357 L
F
.57407 .42357 m
.57407 .42593 L
.57643 .42593 L
.57643 .42357 L
F
.59759 .42357 m
.59759 .42593 L
.59994 .42593 L
.59994 .42357 L
F
.78571 .42357 m
.78571 .42593 L
.78807 .42593 L
.78807 .42357 L
F
.36008 .42593 m
.36008 .42828 L
.36243 .42828 L
.36243 .42593 L
F
.56937 .42593 m
.56937 .42828 L
.57172 .42828 L
.57172 .42593 L
F
.57172 .42593 m
.57172 .42828 L
.57407 .42828 L
.57407 .42593 L
F
.57407 .42593 m
.57407 .42828 L
.57643 .42828 L
.57643 .42593 L
F
.59524 .42593 m
.59524 .42828 L
.59759 .42828 L
.59759 .42593 L
F
.78336 .42593 m
.78336 .42828 L
.78571 .42828 L
.78571 .42593 L
F
.35773 .42828 m
.35773 .43063 L
.36008 .43063 L
.36008 .42828 L
F
.56702 .42828 m
.56702 .43063 L
.56937 .43063 L
.56937 .42828 L
F
.56937 .42828 m
.56937 .43063 L
.57172 .43063 L
.57172 .42828 L
F
.57172 .42828 m
.57172 .43063 L
.57407 .43063 L
.57407 .42828 L
F
.59289 .42828 m
.59289 .43063 L
.59524 .43063 L
.59524 .42828 L
F
.78101 .42828 m
.78101 .43063 L
.78336 .43063 L
.78336 .42828 L
F
.35538 .43063 m
.35538 .43298 L
.35773 .43298 L
.35773 .43063 L
F
.56467 .43063 m
.56467 .43298 L
.56702 .43298 L
.56702 .43063 L
F
.56702 .43063 m
.56702 .43298 L
.56937 .43298 L
.56937 .43063 L
F
.56937 .43063 m
.56937 .43298 L
.57172 .43298 L
.57172 .43063 L
F
.59053 .43063 m
.59053 .43298 L
.59289 .43298 L
.59289 .43063 L
F
.77866 .43063 m
.77866 .43298 L
.78101 .43298 L
.78101 .43063 L
F
.35303 .43298 m
.35303 .43533 L
.35538 .43533 L
.35538 .43298 L
F
.56467 .43298 m
.56467 .43533 L
.56702 .43533 L
.56702 .43298 L
F
.56702 .43298 m
.56702 .43533 L
.56937 .43533 L
.56937 .43298 L
F
.58818 .43298 m
.58818 .43533 L
.59053 .43533 L
.59053 .43298 L
F
.77631 .43298 m
.77631 .43533 L
.77866 .43533 L
.77866 .43298 L
F
.35068 .43533 m
.35068 .43768 L
.35303 .43768 L
.35303 .43533 L
F
.55996 .43533 m
.55996 .43768 L
.56232 .43768 L
.56232 .43533 L
F
.56232 .43533 m
.56232 .43768 L
.56467 .43768 L
.56467 .43533 L
F
.58583 .43533 m
.58583 .43768 L
.58818 .43768 L
.58818 .43533 L
F
.77396 .43533 m
.77396 .43768 L
.77631 .43768 L
.77631 .43533 L
F
.34832 .43768 m
.34832 .44004 L
.35068 .44004 L
.35068 .43768 L
F
.55761 .43768 m
.55761 .44004 L
.55996 .44004 L
.55996 .43768 L
F
.55996 .43768 m
.55996 .44004 L
.56232 .44004 L
.56232 .43768 L
F
.56232 .43768 m
.56232 .44004 L
.56467 .44004 L
.56467 .43768 L
F
.58348 .43768 m
.58348 .44004 L
.58583 .44004 L
.58583 .43768 L
F
.7716 .43768 m
.7716 .44004 L
.77396 .44004 L
.77396 .43768 L
F
.34597 .44004 m
.34597 .44239 L
.34832 .44239 L
.34832 .44004 L
F
.55526 .44004 m
.55526 .44239 L
.55761 .44239 L
.55761 .44004 L
F
.55761 .44004 m
.55761 .44239 L
.55996 .44239 L
.55996 .44004 L
F
.55996 .44004 m
.55996 .44239 L
.56232 .44239 L
.56232 .44004 L
F
.58113 .44004 m
.58113 .44239 L
.58348 .44239 L
.58348 .44004 L
F
.76925 .44004 m
.76925 .44239 L
.7716 .44239 L
.7716 .44004 L
F
.34362 .44239 m
.34362 .44474 L
.34597 .44474 L
.34597 .44239 L
F
.55291 .44239 m
.55291 .44474 L
.55526 .44474 L
.55526 .44239 L
F
.55526 .44239 m
.55526 .44474 L
.55761 .44474 L
.55761 .44239 L
F
.55761 .44239 m
.55761 .44474 L
.55996 .44474 L
.55996 .44239 L
F
.57878 .44239 m
.57878 .44474 L
.58113 .44474 L
.58113 .44239 L
F
.7669 .44239 m
.7669 .44474 L
.76925 .44474 L
.76925 .44239 L
F
.34127 .44474 m
.34127 .44709 L
.34362 .44709 L
.34362 .44474 L
F
.55291 .44474 m
.55291 .44709 L
.55526 .44709 L
.55526 .44474 L
F
.55526 .44474 m
.55526 .44709 L
.55761 .44709 L
.55761 .44474 L
F
.57643 .44474 m
.57643 .44709 L
.57878 .44709 L
.57878 .44474 L
F
.76455 .44474 m
.76455 .44709 L
.7669 .44709 L
.7669 .44474 L
F
.33892 .44709 m
.33892 .44944 L
.34127 .44944 L
.34127 .44709 L
F
.52704 .44709 m
.52704 .44944 L
.52939 .44944 L
.52939 .44709 L
F
.54821 .44709 m
.54821 .44944 L
.55056 .44944 L
.55056 .44709 L
F
.55056 .44709 m
.55056 .44944 L
.55291 .44944 L
.55291 .44709 L
F
.7622 .44709 m
.7622 .44944 L
.76455 .44944 L
.76455 .44709 L
F
.33657 .44944 m
.33657 .45179 L
.33892 .45179 L
.33892 .44944 L
F
.52469 .44944 m
.52469 .45179 L
.52704 .45179 L
.52704 .44944 L
F
.54586 .44944 m
.54586 .45179 L
.54821 .45179 L
.54821 .44944 L
F
.54821 .44944 m
.54821 .45179 L
.55056 .45179 L
.55056 .44944 L
F
.55056 .44944 m
.55056 .45179 L
.55291 .45179 L
.55291 .44944 L
F
.75985 .44944 m
.75985 .45179 L
.7622 .45179 L
.7622 .44944 L
F
.33422 .45179 m
.33422 .45414 L
.33657 .45414 L
.33657 .45179 L
F
.52234 .45179 m
.52234 .45414 L
.52469 .45414 L
.52469 .45179 L
F
.5435 .45179 m
.5435 .45414 L
.54586 .45414 L
.54586 .45179 L
F
.54586 .45179 m
.54586 .45414 L
.54821 .45414 L
.54821 .45179 L
F
.54821 .45179 m
.54821 .45414 L
.55056 .45414 L
.55056 .45179 L
F
.7575 .45179 m
.7575 .45414 L
.75985 .45414 L
.75985 .45179 L
F
.33186 .45414 m
.33186 .4565 L
.33422 .4565 L
.33422 .45414 L
F
.51999 .45414 m
.51999 .4565 L
.52234 .4565 L
.52234 .45414 L
F
.54115 .45414 m
.54115 .4565 L
.5435 .4565 L
.5435 .45414 L
F
.5435 .45414 m
.5435 .4565 L
.54586 .4565 L
.54586 .45414 L
F
.54586 .45414 m
.54586 .4565 L
.54821 .4565 L
.54821 .45414 L
F
.75514 .45414 m
.75514 .4565 L
.7575 .4565 L
.7575 .45414 L
F
.32951 .4565 m
.32951 .45885 L
.33186 .45885 L
.33186 .4565 L
F
.51764 .4565 m
.51764 .45885 L
.51999 .45885 L
.51999 .4565 L
F
.54115 .4565 m
.54115 .45885 L
.5435 .45885 L
.5435 .4565 L
F
.5435 .4565 m
.5435 .45885 L
.54586 .45885 L
.54586 .4565 L
F
.75279 .4565 m
.75279 .45885 L
.75514 .45885 L
.75514 .4565 L
F
.32716 .45885 m
.32716 .4612 L
.32951 .4612 L
.32951 .45885 L
F
.51529 .45885 m
.51529 .4612 L
.51764 .4612 L
.51764 .45885 L
F
.53645 .45885 m
.53645 .4612 L
.5388 .4612 L
.5388 .45885 L
F
.5388 .45885 m
.5388 .4612 L
.54115 .4612 L
.54115 .45885 L
F
.75044 .45885 m
.75044 .4612 L
.75279 .4612 L
.75279 .45885 L
F
.32481 .4612 m
.32481 .46355 L
.32716 .46355 L
.32716 .4612 L
F
.51293 .4612 m
.51293 .46355 L
.51529 .46355 L
.51529 .4612 L
F
.5341 .4612 m
.5341 .46355 L
.53645 .46355 L
.53645 .4612 L
F
.53645 .4612 m
.53645 .46355 L
.5388 .46355 L
.5388 .4612 L
F
.5388 .4612 m
.5388 .46355 L
.54115 .46355 L
.54115 .4612 L
F
.74809 .4612 m
.74809 .46355 L
.75044 .46355 L
.75044 .4612 L
F
.32246 .46355 m
.32246 .4659 L
.32481 .4659 L
.32481 .46355 L
F
.51058 .46355 m
.51058 .4659 L
.51293 .4659 L
.51293 .46355 L
F
.53175 .46355 m
.53175 .4659 L
.5341 .4659 L
.5341 .46355 L
F
.5341 .46355 m
.5341 .4659 L
.53645 .4659 L
.53645 .46355 L
F
.53645 .46355 m
.53645 .4659 L
.5388 .4659 L
.5388 .46355 L
F
.74574 .46355 m
.74574 .4659 L
.74809 .4659 L
.74809 .46355 L
F
.32011 .4659 m
.32011 .46825 L
.32246 .46825 L
.32246 .4659 L
F
.50823 .4659 m
.50823 .46825 L
.51058 .46825 L
.51058 .4659 L
F
.52939 .4659 m
.52939 .46825 L
.53175 .46825 L
.53175 .4659 L
F
.53175 .4659 m
.53175 .46825 L
.5341 .46825 L
.5341 .4659 L
F
.5341 .4659 m
.5341 .46825 L
.53645 .46825 L
.53645 .4659 L
F
.74339 .4659 m
.74339 .46825 L
.74574 .46825 L
.74574 .4659 L
F
.31775 .46825 m
.31775 .47061 L
.32011 .47061 L
.32011 .46825 L
F
.50588 .46825 m
.50588 .47061 L
.50823 .47061 L
.50823 .46825 L
F
.52939 .46825 m
.52939 .47061 L
.53175 .47061 L
.53175 .46825 L
F
.53175 .46825 m
.53175 .47061 L
.5341 .47061 L
.5341 .46825 L
F
.74103 .46825 m
.74103 .47061 L
.74339 .47061 L
.74339 .46825 L
F
.3154 .47061 m
.3154 .47296 L
.31775 .47296 L
.31775 .47061 L
F
.50353 .47061 m
.50353 .47296 L
.50588 .47296 L
.50588 .47061 L
F
.52469 .47061 m
.52469 .47296 L
.52704 .47296 L
.52704 .47061 L
F
.52704 .47061 m
.52704 .47296 L
.52939 .47296 L
.52939 .47061 L
F
.55056 .47061 m
.55056 .47296 L
.55291 .47296 L
.55291 .47061 L
F
.73868 .47061 m
.73868 .47296 L
.74103 .47296 L
.74103 .47061 L
F
.31305 .47296 m
.31305 .47531 L
.3154 .47531 L
.3154 .47296 L
F
.50118 .47296 m
.50118 .47531 L
.50353 .47531 L
.50353 .47296 L
F
.52234 .47296 m
.52234 .47531 L
.52469 .47531 L
.52469 .47296 L
F
.52469 .47296 m
.52469 .47531 L
.52704 .47531 L
.52704 .47296 L
F
.52704 .47296 m
.52704 .47531 L
.52939 .47531 L
.52939 .47296 L
F
.54821 .47296 m
.54821 .47531 L
.55056 .47531 L
.55056 .47296 L
F
.73633 .47296 m
.73633 .47531 L
.73868 .47531 L
.73868 .47296 L
F
.3107 .47531 m
.3107 .47766 L
.31305 .47766 L
.31305 .47531 L
F
.49882 .47531 m
.49882 .47766 L
.50118 .47766 L
.50118 .47531 L
F
.51999 .47531 m
.51999 .47766 L
.52234 .47766 L
.52234 .47531 L
F
.52234 .47531 m
.52234 .47766 L
.52469 .47766 L
.52469 .47531 L
F
.52469 .47531 m
.52469 .47766 L
.52704 .47766 L
.52704 .47531 L
F
.54586 .47531 m
.54586 .47766 L
.54821 .47766 L
.54821 .47531 L
F
.73398 .47531 m
.73398 .47766 L
.73633 .47766 L
.73633 .47531 L
F
.30835 .47766 m
.30835 .48001 L
.3107 .48001 L
.3107 .47766 L
F
.49647 .47766 m
.49647 .48001 L
.49882 .48001 L
.49882 .47766 L
F
.51764 .47766 m
.51764 .48001 L
.51999 .48001 L
.51999 .47766 L
F
.51999 .47766 m
.51999 .48001 L
.52234 .48001 L
.52234 .47766 L
F
.52234 .47766 m
.52234 .48001 L
.52469 .48001 L
.52469 .47766 L
F
.5435 .47766 m
.5435 .48001 L
.54586 .48001 L
.54586 .47766 L
F
.73163 .47766 m
.73163 .48001 L
.73398 .48001 L
.73398 .47766 L
F
.306 .48001 m
.306 .48236 L
.30835 .48236 L
.30835 .48001 L
F
.49412 .48001 m
.49412 .48236 L
.49647 .48236 L
.49647 .48001 L
F
.51764 .48001 m
.51764 .48236 L
.51999 .48236 L
.51999 .48001 L
F
.51999 .48001 m
.51999 .48236 L
.52234 .48236 L
.52234 .48001 L
F
.54115 .48001 m
.54115 .48236 L
.5435 .48236 L
.5435 .48001 L
F
.72928 .48001 m
.72928 .48236 L
.73163 .48236 L
.73163 .48001 L
F
.30364 .48236 m
.30364 .48471 L
.306 .48471 L
.306 .48236 L
F
.49177 .48236 m
.49177 .48471 L
.49412 .48471 L
.49412 .48236 L
F
.51293 .48236 m
.51293 .48471 L
.51529 .48471 L
.51529 .48236 L
F
.51529 .48236 m
.51529 .48471 L
.51764 .48471 L
.51764 .48236 L
F
.5388 .48236 m
.5388 .48471 L
.54115 .48471 L
.54115 .48236 L
F
.72693 .48236 m
.72693 .48471 L
.72928 .48471 L
.72928 .48236 L
F
.30129 .48471 m
.30129 .48707 L
.30364 .48707 L
.30364 .48471 L
F
.48942 .48471 m
.48942 .48707 L
.49177 .48707 L
.49177 .48471 L
F
.51058 .48471 m
.51058 .48707 L
.51293 .48707 L
.51293 .48471 L
F
.51293 .48471 m
.51293 .48707 L
.51529 .48707 L
.51529 .48471 L
F
.51529 .48471 m
.51529 .48707 L
.51764 .48707 L
.51764 .48471 L
F
.53645 .48471 m
.53645 .48707 L
.5388 .48707 L
.5388 .48471 L
F
.72457 .48471 m
.72457 .48707 L
.72693 .48707 L
.72693 .48471 L
F
.29894 .48707 m
.29894 .48942 L
.30129 .48942 L
.30129 .48707 L
F
.48707 .48707 m
.48707 .48942 L
.48942 .48942 L
.48942 .48707 L
F
.50823 .48707 m
.50823 .48942 L
.51058 .48942 L
.51058 .48707 L
F
.51058 .48707 m
.51058 .48942 L
.51293 .48942 L
.51293 .48707 L
F
.51293 .48707 m
.51293 .48942 L
.51529 .48942 L
.51529 .48707 L
F
.5341 .48707 m
.5341 .48942 L
.53645 .48942 L
.53645 .48707 L
F
.72222 .48707 m
.72222 .48942 L
.72457 .48942 L
.72457 .48707 L
F
.29659 .48942 m
.29659 .49177 L
.29894 .49177 L
.29894 .48942 L
F
.48471 .48942 m
.48471 .49177 L
.48707 .49177 L
.48707 .48942 L
F
.50588 .48942 m
.50588 .49177 L
.50823 .49177 L
.50823 .48942 L
F
.50823 .48942 m
.50823 .49177 L
.51058 .49177 L
.51058 .48942 L
F
.51058 .48942 m
.51058 .49177 L
.51293 .49177 L
.51293 .48942 L
F
.53175 .48942 m
.53175 .49177 L
.5341 .49177 L
.5341 .48942 L
F
.71987 .48942 m
.71987 .49177 L
.72222 .49177 L
.72222 .48942 L
F
.29424 .49177 m
.29424 .49412 L
.29659 .49412 L
.29659 .49177 L
F
.48236 .49177 m
.48236 .49412 L
.48471 .49412 L
.48471 .49177 L
F
.50588 .49177 m
.50588 .49412 L
.50823 .49412 L
.50823 .49177 L
F
.50823 .49177 m
.50823 .49412 L
.51058 .49412 L
.51058 .49177 L
F
.52939 .49177 m
.52939 .49412 L
.53175 .49412 L
.53175 .49177 L
F
.71752 .49177 m
.71752 .49412 L
.71987 .49412 L
.71987 .49177 L
F
.29189 .49412 m
.29189 .49647 L
.29424 .49647 L
.29424 .49412 L
F
.48001 .49412 m
.48001 .49647 L
.48236 .49647 L
.48236 .49412 L
F
.50118 .49412 m
.50118 .49647 L
.50353 .49647 L
.50353 .49412 L
F
.50353 .49412 m
.50353 .49647 L
.50588 .49647 L
.50588 .49412 L
F
.52704 .49412 m
.52704 .49647 L
.52939 .49647 L
.52939 .49412 L
F
.71517 .49412 m
.71517 .49647 L
.71752 .49647 L
.71752 .49412 L
F
.28954 .49647 m
.28954 .49882 L
.29189 .49882 L
.29189 .49647 L
F
.47766 .49647 m
.47766 .49882 L
.48001 .49882 L
.48001 .49647 L
F
.49882 .49647 m
.49882 .49882 L
.50118 .49882 L
.50118 .49647 L
F
.50118 .49647 m
.50118 .49882 L
.50353 .49882 L
.50353 .49647 L
F
.50353 .49647 m
.50353 .49882 L
.50588 .49882 L
.50588 .49647 L
F
.52469 .49647 m
.52469 .49882 L
.52704 .49882 L
.52704 .49647 L
F
.71282 .49647 m
.71282 .49882 L
.71517 .49882 L
.71517 .49647 L
F
.28718 .49882 m
.28718 .50118 L
.28954 .50118 L
.28954 .49882 L
F
.47531 .49882 m
.47531 .50118 L
.47766 .50118 L
.47766 .49882 L
F
.49647 .49882 m
.49647 .50118 L
.49882 .50118 L
.49882 .49882 L
F
.49882 .49882 m
.49882 .50118 L
.50118 .50118 L
.50118 .49882 L
F
.50118 .49882 m
.50118 .50118 L
.50353 .50118 L
.50353 .49882 L
F
.52234 .49882 m
.52234 .50118 L
.52469 .50118 L
.52469 .49882 L
F
.71046 .49882 m
.71046 .50118 L
.71282 .50118 L
.71282 .49882 L
F
.28483 .50118 m
.28483 .50353 L
.28718 .50353 L
.28718 .50118 L
F
.47296 .50118 m
.47296 .50353 L
.47531 .50353 L
.47531 .50118 L
F
.49412 .50118 m
.49412 .50353 L
.49647 .50353 L
.49647 .50118 L
F
.49647 .50118 m
.49647 .50353 L
.49882 .50353 L
.49882 .50118 L
F
.49882 .50118 m
.49882 .50353 L
.50118 .50353 L
.50118 .50118 L
F
.51999 .50118 m
.51999 .50353 L
.52234 .50353 L
.52234 .50118 L
F
.70811 .50118 m
.70811 .50353 L
.71046 .50353 L
.71046 .50118 L
F
.28248 .50353 m
.28248 .50588 L
.28483 .50588 L
.28483 .50353 L
F
.47061 .50353 m
.47061 .50588 L
.47296 .50588 L
.47296 .50353 L
F
.49412 .50353 m
.49412 .50588 L
.49647 .50588 L
.49647 .50353 L
F
.49647 .50353 m
.49647 .50588 L
.49882 .50588 L
.49882 .50353 L
F
.51764 .50353 m
.51764 .50588 L
.51999 .50588 L
.51999 .50353 L
F
.70576 .50353 m
.70576 .50588 L
.70811 .50588 L
.70811 .50353 L
F
.28013 .50588 m
.28013 .50823 L
.28248 .50823 L
.28248 .50588 L
F
.46825 .50588 m
.46825 .50823 L
.47061 .50823 L
.47061 .50588 L
F
.48942 .50588 m
.48942 .50823 L
.49177 .50823 L
.49177 .50588 L
F
.49177 .50588 m
.49177 .50823 L
.49412 .50823 L
.49412 .50588 L
F
.51529 .50588 m
.51529 .50823 L
.51764 .50823 L
.51764 .50588 L
F
.70341 .50588 m
.70341 .50823 L
.70576 .50823 L
.70576 .50588 L
F
.27778 .50823 m
.27778 .51058 L
.28013 .51058 L
.28013 .50823 L
F
.4659 .50823 m
.4659 .51058 L
.46825 .51058 L
.46825 .50823 L
F
.48707 .50823 m
.48707 .51058 L
.48942 .51058 L
.48942 .50823 L
F
.48942 .50823 m
.48942 .51058 L
.49177 .51058 L
.49177 .50823 L
F
.49177 .50823 m
.49177 .51058 L
.49412 .51058 L
.49412 .50823 L
F
.51293 .50823 m
.51293 .51058 L
.51529 .51058 L
.51529 .50823 L
F
.70106 .50823 m
.70106 .51058 L
.70341 .51058 L
.70341 .50823 L
F
.27543 .51058 m
.27543 .51293 L
.27778 .51293 L
.27778 .51058 L
F
.46355 .51058 m
.46355 .51293 L
.4659 .51293 L
.4659 .51058 L
F
.48471 .51058 m
.48471 .51293 L
.48707 .51293 L
.48707 .51058 L
F
.48707 .51058 m
.48707 .51293 L
.48942 .51293 L
.48942 .51058 L
F
.48942 .51058 m
.48942 .51293 L
.49177 .51293 L
.49177 .51058 L
F
.51058 .51058 m
.51058 .51293 L
.51293 .51293 L
.51293 .51058 L
F
.69871 .51058 m
.69871 .51293 L
.70106 .51293 L
.70106 .51058 L
F
.27307 .51293 m
.27307 .51529 L
.27543 .51529 L
.27543 .51293 L
F
.4612 .51293 m
.4612 .51529 L
.46355 .51529 L
.46355 .51293 L
F
.48236 .51293 m
.48236 .51529 L
.48471 .51529 L
.48471 .51293 L
F
.48471 .51293 m
.48471 .51529 L
.48707 .51529 L
.48707 .51293 L
F
.48707 .51293 m
.48707 .51529 L
.48942 .51529 L
.48942 .51293 L
F
.50823 .51293 m
.50823 .51529 L
.51058 .51529 L
.51058 .51293 L
F
.69636 .51293 m
.69636 .51529 L
.69871 .51529 L
.69871 .51293 L
F
.27072 .51529 m
.27072 .51764 L
.27307 .51764 L
.27307 .51529 L
F
.45885 .51529 m
.45885 .51764 L
.4612 .51764 L
.4612 .51529 L
F
.48236 .51529 m
.48236 .51764 L
.48471 .51764 L
.48471 .51529 L
F
.48471 .51529 m
.48471 .51764 L
.48707 .51764 L
.48707 .51529 L
F
.50588 .51529 m
.50588 .51764 L
.50823 .51764 L
.50823 .51529 L
F
.694 .51529 m
.694 .51764 L
.69636 .51764 L
.69636 .51529 L
F
.26837 .51764 m
.26837 .51999 L
.27072 .51999 L
.27072 .51764 L
F
.4565 .51764 m
.4565 .51999 L
.45885 .51999 L
.45885 .51764 L
F
.47766 .51764 m
.47766 .51999 L
.48001 .51999 L
.48001 .51764 L
F
.48001 .51764 m
.48001 .51999 L
.48236 .51999 L
.48236 .51764 L
F
.50353 .51764 m
.50353 .51999 L
.50588 .51999 L
.50588 .51764 L
F
.69165 .51764 m
.69165 .51999 L
.694 .51999 L
.694 .51764 L
F
.26602 .51999 m
.26602 .52234 L
.26837 .52234 L
.26837 .51999 L
F
.45414 .51999 m
.45414 .52234 L
.4565 .52234 L
.4565 .51999 L
F
.47531 .51999 m
.47531 .52234 L
.47766 .52234 L
.47766 .51999 L
F
.47766 .51999 m
.47766 .52234 L
.48001 .52234 L
.48001 .51999 L
F
.48001 .51999 m
.48001 .52234 L
.48236 .52234 L
.48236 .51999 L
F
.50118 .51999 m
.50118 .52234 L
.50353 .52234 L
.50353 .51999 L
F
.6893 .51999 m
.6893 .52234 L
.69165 .52234 L
.69165 .51999 L
F
.26367 .52234 m
.26367 .52469 L
.26602 .52469 L
.26602 .52234 L
F
.45179 .52234 m
.45179 .52469 L
.45414 .52469 L
.45414 .52234 L
F
.47296 .52234 m
.47296 .52469 L
.47531 .52469 L
.47531 .52234 L
F
.47531 .52234 m
.47531 .52469 L
.47766 .52469 L
.47766 .52234 L
F
.47766 .52234 m
.47766 .52469 L
.48001 .52469 L
.48001 .52234 L
F
.49882 .52234 m
.49882 .52469 L
.50118 .52469 L
.50118 .52234 L
F
.68695 .52234 m
.68695 .52469 L
.6893 .52469 L
.6893 .52234 L
F
.26132 .52469 m
.26132 .52704 L
.26367 .52704 L
.26367 .52469 L
F
.44944 .52469 m
.44944 .52704 L
.45179 .52704 L
.45179 .52469 L
F
.47061 .52469 m
.47061 .52704 L
.47296 .52704 L
.47296 .52469 L
F
.47296 .52469 m
.47296 .52704 L
.47531 .52704 L
.47531 .52469 L
F
.47531 .52469 m
.47531 .52704 L
.47766 .52704 L
.47766 .52469 L
F
.49647 .52469 m
.49647 .52704 L
.49882 .52704 L
.49882 .52469 L
F
.6846 .52469 m
.6846 .52704 L
.68695 .52704 L
.68695 .52469 L
F
.25897 .52704 m
.25897 .52939 L
.26132 .52939 L
.26132 .52704 L
F
.44709 .52704 m
.44709 .52939 L
.44944 .52939 L
.44944 .52704 L
F
.47061 .52704 m
.47061 .52939 L
.47296 .52939 L
.47296 .52704 L
F
.47296 .52704 m
.47296 .52939 L
.47531 .52939 L
.47531 .52704 L
F
.49412 .52704 m
.49412 .52939 L
.49647 .52939 L
.49647 .52704 L
F
.68225 .52704 m
.68225 .52939 L
.6846 .52939 L
.6846 .52704 L
F
.25661 .52939 m
.25661 .53175 L
.25897 .53175 L
.25897 .52939 L
F
.4659 .52939 m
.4659 .53175 L
.46825 .53175 L
.46825 .52939 L
F
.46825 .52939 m
.46825 .53175 L
.47061 .53175 L
.47061 .52939 L
F
.49177 .52939 m
.49177 .53175 L
.49412 .53175 L
.49412 .52939 L
F
.67989 .52939 m
.67989 .53175 L
.68225 .53175 L
.68225 .52939 L
F
.25426 .53175 m
.25426 .5341 L
.25661 .5341 L
.25661 .53175 L
F
.46355 .53175 m
.46355 .5341 L
.4659 .5341 L
.4659 .53175 L
F
.4659 .53175 m
.4659 .5341 L
.46825 .5341 L
.46825 .53175 L
F
.46825 .53175 m
.46825 .5341 L
.47061 .5341 L
.47061 .53175 L
F
.48942 .53175 m
.48942 .5341 L
.49177 .5341 L
.49177 .53175 L
F
.67754 .53175 m
.67754 .5341 L
.67989 .5341 L
.67989 .53175 L
F
.25191 .5341 m
.25191 .53645 L
.25426 .53645 L
.25426 .5341 L
F
.4612 .5341 m
.4612 .53645 L
.46355 .53645 L
.46355 .5341 L
F
.46355 .5341 m
.46355 .53645 L
.4659 .53645 L
.4659 .5341 L
F
.4659 .5341 m
.4659 .53645 L
.46825 .53645 L
.46825 .5341 L
F
.48707 .5341 m
.48707 .53645 L
.48942 .53645 L
.48942 .5341 L
F
.67519 .5341 m
.67519 .53645 L
.67754 .53645 L
.67754 .5341 L
F
.24956 .53645 m
.24956 .5388 L
.25191 .5388 L
.25191 .53645 L
F
.45885 .53645 m
.45885 .5388 L
.4612 .5388 L
.4612 .53645 L
F
.4612 .53645 m
.4612 .5388 L
.46355 .5388 L
.46355 .53645 L
F
.46355 .53645 m
.46355 .5388 L
.4659 .5388 L
.4659 .53645 L
F
.48471 .53645 m
.48471 .5388 L
.48707 .5388 L
.48707 .53645 L
F
.67284 .53645 m
.67284 .5388 L
.67519 .5388 L
.67519 .53645 L
F
.24721 .5388 m
.24721 .54115 L
.24956 .54115 L
.24956 .5388 L
F
.45885 .5388 m
.45885 .54115 L
.4612 .54115 L
.4612 .5388 L
F
.4612 .5388 m
.4612 .54115 L
.46355 .54115 L
.46355 .5388 L
F
.48236 .5388 m
.48236 .54115 L
.48471 .54115 L
.48471 .5388 L
F
.67049 .5388 m
.67049 .54115 L
.67284 .54115 L
.67284 .5388 L
F
.24486 .54115 m
.24486 .5435 L
.24721 .5435 L
.24721 .54115 L
F
.45414 .54115 m
.45414 .5435 L
.4565 .5435 L
.4565 .54115 L
F
.4565 .54115 m
.4565 .5435 L
.45885 .5435 L
.45885 .54115 L
F
.48001 .54115 m
.48001 .5435 L
.48236 .5435 L
.48236 .54115 L
F
.66814 .54115 m
.66814 .5435 L
.67049 .5435 L
.67049 .54115 L
F
.2425 .5435 m
.2425 .54586 L
.24486 .54586 L
.24486 .5435 L
F
.45179 .5435 m
.45179 .54586 L
.45414 .54586 L
.45414 .5435 L
F
.45414 .5435 m
.45414 .54586 L
.4565 .54586 L
.4565 .5435 L
F
.4565 .5435 m
.4565 .54586 L
.45885 .54586 L
.45885 .5435 L
F
.47766 .5435 m
.47766 .54586 L
.48001 .54586 L
.48001 .5435 L
F
.66578 .5435 m
.66578 .54586 L
.66814 .54586 L
.66814 .5435 L
F
.24015 .54586 m
.24015 .54821 L
.2425 .54821 L
.2425 .54586 L
F
.44944 .54586 m
.44944 .54821 L
.45179 .54821 L
.45179 .54586 L
F
.45179 .54586 m
.45179 .54821 L
.45414 .54821 L
.45414 .54586 L
F
.45414 .54586 m
.45414 .54821 L
.4565 .54821 L
.4565 .54586 L
F
.47531 .54586 m
.47531 .54821 L
.47766 .54821 L
.47766 .54586 L
F
.66343 .54586 m
.66343 .54821 L
.66578 .54821 L
.66578 .54586 L
F
.2378 .54821 m
.2378 .55056 L
.24015 .55056 L
.24015 .54821 L
F
.44709 .54821 m
.44709 .55056 L
.44944 .55056 L
.44944 .54821 L
F
.44944 .54821 m
.44944 .55056 L
.45179 .55056 L
.45179 .54821 L
F
.45179 .54821 m
.45179 .55056 L
.45414 .55056 L
.45414 .54821 L
F
.47296 .54821 m
.47296 .55056 L
.47531 .55056 L
.47531 .54821 L
F
.66108 .54821 m
.66108 .55056 L
.66343 .55056 L
.66343 .54821 L
F
.23545 .55056 m
.23545 .55291 L
.2378 .55291 L
.2378 .55056 L
F
.44709 .55056 m
.44709 .55291 L
.44944 .55291 L
.44944 .55056 L
F
.44944 .55056 m
.44944 .55291 L
.45179 .55291 L
.45179 .55056 L
F
.47061 .55056 m
.47061 .55291 L
.47296 .55291 L
.47296 .55056 L
F
.65873 .55056 m
.65873 .55291 L
.66108 .55291 L
.66108 .55056 L
F
.2331 .55291 m
.2331 .55526 L
.23545 .55526 L
.23545 .55291 L
F
.42122 .55291 m
.42122 .55526 L
.42357 .55526 L
.42357 .55291 L
F
.44239 .55291 m
.44239 .55526 L
.44474 .55526 L
.44474 .55291 L
F
.44474 .55291 m
.44474 .55526 L
.44709 .55526 L
.44709 .55291 L
F
.65638 .55291 m
.65638 .55526 L
.65873 .55526 L
.65873 .55291 L
F
.23075 .55526 m
.23075 .55761 L
.2331 .55761 L
.2331 .55526 L
F
.41887 .55526 m
.41887 .55761 L
.42122 .55761 L
.42122 .55526 L
F
.44004 .55526 m
.44004 .55761 L
.44239 .55761 L
.44239 .55526 L
F
.44239 .55526 m
.44239 .55761 L
.44474 .55761 L
.44474 .55526 L
F
.44474 .55526 m
.44474 .55761 L
.44709 .55761 L
.44709 .55526 L
F
.65403 .55526 m
.65403 .55761 L
.65638 .55761 L
.65638 .55526 L
F
.2284 .55761 m
.2284 .55996 L
.23075 .55996 L
.23075 .55761 L
F
.41652 .55761 m
.41652 .55996 L
.41887 .55996 L
.41887 .55761 L
F
.43768 .55761 m
.43768 .55996 L
.44004 .55996 L
.44004 .55761 L
F
.44004 .55761 m
.44004 .55996 L
.44239 .55996 L
.44239 .55761 L
F
.44239 .55761 m
.44239 .55996 L
.44474 .55996 L
.44474 .55761 L
F
.65168 .55761 m
.65168 .55996 L
.65403 .55996 L
.65403 .55761 L
F
.22604 .55996 m
.22604 .56232 L
.2284 .56232 L
.2284 .55996 L
F
.41417 .55996 m
.41417 .56232 L
.41652 .56232 L
.41652 .55996 L
F
.43533 .55996 m
.43533 .56232 L
.43768 .56232 L
.43768 .55996 L
F
.43768 .55996 m
.43768 .56232 L
.44004 .56232 L
.44004 .55996 L
F
.44004 .55996 m
.44004 .56232 L
.44239 .56232 L
.44239 .55996 L
F
.64932 .55996 m
.64932 .56232 L
.65168 .56232 L
.65168 .55996 L
F
.22369 .56232 m
.22369 .56467 L
.22604 .56467 L
.22604 .56232 L
F
.41182 .56232 m
.41182 .56467 L
.41417 .56467 L
.41417 .56232 L
F
.43533 .56232 m
.43533 .56467 L
.43768 .56467 L
.43768 .56232 L
F
.43768 .56232 m
.43768 .56467 L
.44004 .56467 L
.44004 .56232 L
F
.64697 .56232 m
.64697 .56467 L
.64932 .56467 L
.64932 .56232 L
F
.22134 .56467 m
.22134 .56702 L
.22369 .56702 L
.22369 .56467 L
F
.40947 .56467 m
.40947 .56702 L
.41182 .56702 L
.41182 .56467 L
F
.43063 .56467 m
.43063 .56702 L
.43298 .56702 L
.43298 .56467 L
F
.43298 .56467 m
.43298 .56702 L
.43533 .56702 L
.43533 .56467 L
F
.64462 .56467 m
.64462 .56702 L
.64697 .56702 L
.64697 .56467 L
F
.21899 .56702 m
.21899 .56937 L
.22134 .56937 L
.22134 .56702 L
F
.40711 .56702 m
.40711 .56937 L
.40947 .56937 L
.40947 .56702 L
F
.42828 .56702 m
.42828 .56937 L
.43063 .56937 L
.43063 .56702 L
F
.43063 .56702 m
.43063 .56937 L
.43298 .56937 L
.43298 .56702 L
F
.43298 .56702 m
.43298 .56937 L
.43533 .56937 L
.43533 .56702 L
F
.64227 .56702 m
.64227 .56937 L
.64462 .56937 L
.64462 .56702 L
F
.21664 .56937 m
.21664 .57172 L
.21899 .57172 L
.21899 .56937 L
F
.40476 .56937 m
.40476 .57172 L
.40711 .57172 L
.40711 .56937 L
F
.42593 .56937 m
.42593 .57172 L
.42828 .57172 L
.42828 .56937 L
F
.42828 .56937 m
.42828 .57172 L
.43063 .57172 L
.43063 .56937 L
F
.43063 .56937 m
.43063 .57172 L
.43298 .57172 L
.43298 .56937 L
F
.63992 .56937 m
.63992 .57172 L
.64227 .57172 L
.64227 .56937 L
F
.21429 .57172 m
.21429 .57407 L
.21664 .57407 L
.21664 .57172 L
F
.40241 .57172 m
.40241 .57407 L
.40476 .57407 L
.40476 .57172 L
F
.42357 .57172 m
.42357 .57407 L
.42593 .57407 L
.42593 .57172 L
F
.42593 .57172 m
.42593 .57407 L
.42828 .57407 L
.42828 .57172 L
F
.42828 .57172 m
.42828 .57407 L
.43063 .57407 L
.43063 .57172 L
F
.63757 .57172 m
.63757 .57407 L
.63992 .57407 L
.63992 .57172 L
F
.21193 .57407 m
.21193 .57643 L
.21429 .57643 L
.21429 .57407 L
F
.40006 .57407 m
.40006 .57643 L
.40241 .57643 L
.40241 .57407 L
F
.42357 .57407 m
.42357 .57643 L
.42593 .57643 L
.42593 .57407 L
F
.42593 .57407 m
.42593 .57643 L
.42828 .57643 L
.42828 .57407 L
F
.63521 .57407 m
.63521 .57643 L
.63757 .57643 L
.63757 .57407 L
F
.20958 .57643 m
.20958 .57878 L
.21193 .57878 L
.21193 .57643 L
F
.39771 .57643 m
.39771 .57878 L
.40006 .57878 L
.40006 .57643 L
F
.41887 .57643 m
.41887 .57878 L
.42122 .57878 L
.42122 .57643 L
F
.42122 .57643 m
.42122 .57878 L
.42357 .57878 L
.42357 .57643 L
F
.44474 .57643 m
.44474 .57878 L
.44709 .57878 L
.44709 .57643 L
F
.63286 .57643 m
.63286 .57878 L
.63521 .57878 L
.63521 .57643 L
F
.20723 .57878 m
.20723 .58113 L
.20958 .58113 L
.20958 .57878 L
F
.39536 .57878 m
.39536 .58113 L
.39771 .58113 L
.39771 .57878 L
F
.41652 .57878 m
.41652 .58113 L
.41887 .58113 L
.41887 .57878 L
F
.41887 .57878 m
.41887 .58113 L
.42122 .58113 L
.42122 .57878 L
F
.42122 .57878 m
.42122 .58113 L
.42357 .58113 L
.42357 .57878 L
F
.44239 .57878 m
.44239 .58113 L
.44474 .58113 L
.44474 .57878 L
F
.63051 .57878 m
.63051 .58113 L
.63286 .58113 L
.63286 .57878 L
F
.20488 .58113 m
.20488 .58348 L
.20723 .58348 L
.20723 .58113 L
F
.393 .58113 m
.393 .58348 L
.39536 .58348 L
.39536 .58113 L
F
.41417 .58113 m
.41417 .58348 L
.41652 .58348 L
.41652 .58113 L
F
.41652 .58113 m
.41652 .58348 L
.41887 .58348 L
.41887 .58113 L
F
.41887 .58113 m
.41887 .58348 L
.42122 .58348 L
.42122 .58113 L
F
.44004 .58113 m
.44004 .58348 L
.44239 .58348 L
.44239 .58113 L
F
.62816 .58113 m
.62816 .58348 L
.63051 .58348 L
.63051 .58113 L
F
.20253 .58348 m
.20253 .58583 L
.20488 .58583 L
.20488 .58348 L
F
.39065 .58348 m
.39065 .58583 L
.393 .58583 L
.393 .58348 L
F
.41182 .58348 m
.41182 .58583 L
.41417 .58583 L
.41417 .58348 L
F
.41417 .58348 m
.41417 .58583 L
.41652 .58583 L
.41652 .58348 L
F
.41652 .58348 m
.41652 .58583 L
.41887 .58583 L
.41887 .58348 L
F
.43768 .58348 m
.43768 .58583 L
.44004 .58583 L
.44004 .58348 L
F
.62581 .58348 m
.62581 .58583 L
.62816 .58583 L
.62816 .58348 L
F
.20018 .58583 m
.20018 .58818 L
.20253 .58818 L
.20253 .58583 L
F
.3883 .58583 m
.3883 .58818 L
.39065 .58818 L
.39065 .58583 L
F
.41182 .58583 m
.41182 .58818 L
.41417 .58818 L
.41417 .58583 L
F
.41417 .58583 m
.41417 .58818 L
.41652 .58818 L
.41652 .58583 L
F
.43533 .58583 m
.43533 .58818 L
.43768 .58818 L
.43768 .58583 L
F
.62346 .58583 m
.62346 .58818 L
.62581 .58818 L
.62581 .58583 L
F
.19782 .58818 m
.19782 .59053 L
.20018 .59053 L
.20018 .58818 L
F
.38595 .58818 m
.38595 .59053 L
.3883 .59053 L
.3883 .58818 L
F
.40711 .58818 m
.40711 .59053 L
.40947 .59053 L
.40947 .58818 L
F
.40947 .58818 m
.40947 .59053 L
.41182 .59053 L
.41182 .58818 L
F
.43298 .58818 m
.43298 .59053 L
.43533 .59053 L
.43533 .58818 L
F
.62111 .58818 m
.62111 .59053 L
.62346 .59053 L
.62346 .58818 L
F
.19547 .59053 m
.19547 .59289 L
.19782 .59289 L
.19782 .59053 L
F
.3836 .59053 m
.3836 .59289 L
.38595 .59289 L
.38595 .59053 L
F
.40476 .59053 m
.40476 .59289 L
.40711 .59289 L
.40711 .59053 L
F
.40711 .59053 m
.40711 .59289 L
.40947 .59289 L
.40947 .59053 L
F
.40947 .59053 m
.40947 .59289 L
.41182 .59289 L
.41182 .59053 L
F
.43063 .59053 m
.43063 .59289 L
.43298 .59289 L
.43298 .59053 L
F
.61875 .59053 m
.61875 .59289 L
.62111 .59289 L
.62111 .59053 L
F
.19312 .59289 m
.19312 .59524 L
.19547 .59524 L
.19547 .59289 L
F
.38125 .59289 m
.38125 .59524 L
.3836 .59524 L
.3836 .59289 L
F
.40241 .59289 m
.40241 .59524 L
.40476 .59524 L
.40476 .59289 L
F
.40476 .59289 m
.40476 .59524 L
.40711 .59524 L
.40711 .59289 L
F
.40711 .59289 m
.40711 .59524 L
.40947 .59524 L
.40947 .59289 L
F
.42828 .59289 m
.42828 .59524 L
.43063 .59524 L
.43063 .59289 L
F
.6164 .59289 m
.6164 .59524 L
.61875 .59524 L
.61875 .59289 L
F
.19077 .59524 m
.19077 .59759 L
.19312 .59759 L
.19312 .59524 L
F
.37889 .59524 m
.37889 .59759 L
.38125 .59759 L
.38125 .59524 L
F
.40006 .59524 m
.40006 .59759 L
.40241 .59759 L
.40241 .59524 L
F
.40241 .59524 m
.40241 .59759 L
.40476 .59759 L
.40476 .59524 L
F
.40476 .59524 m
.40476 .59759 L
.40711 .59759 L
.40711 .59524 L
F
.42593 .59524 m
.42593 .59759 L
.42828 .59759 L
.42828 .59524 L
F
.61405 .59524 m
.61405 .59759 L
.6164 .59759 L
.6164 .59524 L
F
.18842 .59759 m
.18842 .59994 L
.19077 .59994 L
.19077 .59759 L
F
.37654 .59759 m
.37654 .59994 L
.37889 .59994 L
.37889 .59759 L
F
.40006 .59759 m
.40006 .59994 L
.40241 .59994 L
.40241 .59759 L
F
.40241 .59759 m
.40241 .59994 L
.40476 .59994 L
.40476 .59759 L
F
.42357 .59759 m
.42357 .59994 L
.42593 .59994 L
.42593 .59759 L
F
.6117 .59759 m
.6117 .59994 L
.61405 .59994 L
.61405 .59759 L
F
.18607 .59994 m
.18607 .60229 L
.18842 .60229 L
.18842 .59994 L
F
.37419 .59994 m
.37419 .60229 L
.37654 .60229 L
.37654 .59994 L
F
.39536 .59994 m
.39536 .60229 L
.39771 .60229 L
.39771 .59994 L
F
.39771 .59994 m
.39771 .60229 L
.40006 .60229 L
.40006 .59994 L
F
.42122 .59994 m
.42122 .60229 L
.42357 .60229 L
.42357 .59994 L
F
.60935 .59994 m
.60935 .60229 L
.6117 .60229 L
.6117 .59994 L
F
.18372 .60229 m
.18372 .60464 L
.18607 .60464 L
.18607 .60229 L
F
.37184 .60229 m
.37184 .60464 L
.37419 .60464 L
.37419 .60229 L
F
.393 .60229 m
.393 .60464 L
.39536 .60464 L
.39536 .60229 L
F
.39536 .60229 m
.39536 .60464 L
.39771 .60464 L
.39771 .60229 L
F
.39771 .60229 m
.39771 .60464 L
.40006 .60464 L
.40006 .60229 L
F
.41887 .60229 m
.41887 .60464 L
.42122 .60464 L
.42122 .60229 L
F
.607 .60229 m
.607 .60464 L
.60935 .60464 L
.60935 .60229 L
F
.18136 .60464 m
.18136 .607 L
.18372 .607 L
.18372 .60464 L
F
.36949 .60464 m
.36949 .607 L
.37184 .607 L
.37184 .60464 L
F
.39065 .60464 m
.39065 .607 L
.393 .607 L
.393 .60464 L
F
.393 .60464 m
.393 .607 L
.39536 .607 L
.39536 .60464 L
F
.39536 .60464 m
.39536 .607 L
.39771 .607 L
.39771 .60464 L
F
.41652 .60464 m
.41652 .607 L
.41887 .607 L
.41887 .60464 L
F
.60464 .60464 m
.60464 .607 L
.607 .607 L
.607 .60464 L
F
.17901 .607 m
.17901 .60935 L
.18136 .60935 L
.18136 .607 L
F
.36714 .607 m
.36714 .60935 L
.36949 .60935 L
.36949 .607 L
F
.3883 .607 m
.3883 .60935 L
.39065 .60935 L
.39065 .607 L
F
.39065 .607 m
.39065 .60935 L
.393 .60935 L
.393 .607 L
F
.393 .607 m
.393 .60935 L
.39536 .60935 L
.39536 .607 L
F
.41417 .607 m
.41417 .60935 L
.41652 .60935 L
.41652 .607 L
F
.60229 .607 m
.60229 .60935 L
.60464 .60935 L
.60464 .607 L
F
.17666 .60935 m
.17666 .6117 L
.17901 .6117 L
.17901 .60935 L
F
.36479 .60935 m
.36479 .6117 L
.36714 .6117 L
.36714 .60935 L
F
.3883 .60935 m
.3883 .6117 L
.39065 .6117 L
.39065 .60935 L
F
.39065 .60935 m
.39065 .6117 L
.393 .6117 L
.393 .60935 L
F
.41182 .60935 m
.41182 .6117 L
.41417 .6117 L
.41417 .60935 L
F
.59994 .60935 m
.59994 .6117 L
.60229 .6117 L
.60229 .60935 L
F
.17431 .6117 m
.17431 .61405 L
.17666 .61405 L
.17666 .6117 L
F
.36243 .6117 m
.36243 .61405 L
.36479 .61405 L
.36479 .6117 L
F
.3836 .6117 m
.3836 .61405 L
.38595 .61405 L
.38595 .6117 L
F
.38595 .6117 m
.38595 .61405 L
.3883 .61405 L
.3883 .6117 L
F
.40947 .6117 m
.40947 .61405 L
.41182 .61405 L
.41182 .6117 L
F
.59759 .6117 m
.59759 .61405 L
.59994 .61405 L
.59994 .6117 L
F
.17196 .61405 m
.17196 .6164 L
.17431 .6164 L
.17431 .61405 L
F
.36008 .61405 m
.36008 .6164 L
.36243 .6164 L
.36243 .61405 L
F
.38125 .61405 m
.38125 .6164 L
.3836 .6164 L
.3836 .61405 L
F
.3836 .61405 m
.3836 .6164 L
.38595 .6164 L
.38595 .61405 L
F
.38595 .61405 m
.38595 .6164 L
.3883 .6164 L
.3883 .61405 L
F
.40711 .61405 m
.40711 .6164 L
.40947 .6164 L
.40947 .61405 L
F
.59524 .61405 m
.59524 .6164 L
.59759 .6164 L
.59759 .61405 L
F
.16961 .6164 m
.16961 .61875 L
.17196 .61875 L
.17196 .6164 L
F
.35773 .6164 m
.35773 .61875 L
.36008 .61875 L
.36008 .6164 L
F
.37889 .6164 m
.37889 .61875 L
.38125 .61875 L
.38125 .6164 L
F
.38125 .6164 m
.38125 .61875 L
.3836 .61875 L
.3836 .6164 L
F
.3836 .6164 m
.3836 .61875 L
.38595 .61875 L
.38595 .6164 L
F
.40476 .6164 m
.40476 .61875 L
.40711 .61875 L
.40711 .6164 L
F
.59289 .6164 m
.59289 .61875 L
.59524 .61875 L
.59524 .6164 L
F
.16725 .61875 m
.16725 .62111 L
.16961 .62111 L
.16961 .61875 L
F
.35538 .61875 m
.35538 .62111 L
.35773 .62111 L
.35773 .61875 L
F
.37654 .61875 m
.37654 .62111 L
.37889 .62111 L
.37889 .61875 L
F
.37889 .61875 m
.37889 .62111 L
.38125 .62111 L
.38125 .61875 L
F
.38125 .61875 m
.38125 .62111 L
.3836 .62111 L
.3836 .61875 L
F
.40241 .61875 m
.40241 .62111 L
.40476 .62111 L
.40476 .61875 L
F
.59053 .61875 m
.59053 .62111 L
.59289 .62111 L
.59289 .61875 L
F
.1649 .62111 m
.1649 .62346 L
.16725 .62346 L
.16725 .62111 L
F
.35303 .62111 m
.35303 .62346 L
.35538 .62346 L
.35538 .62111 L
F
.37654 .62111 m
.37654 .62346 L
.37889 .62346 L
.37889 .62111 L
F
.37889 .62111 m
.37889 .62346 L
.38125 .62346 L
.38125 .62111 L
F
.40006 .62111 m
.40006 .62346 L
.40241 .62346 L
.40241 .62111 L
F
.58818 .62111 m
.58818 .62346 L
.59053 .62346 L
.59053 .62111 L
F
.16255 .62346 m
.16255 .62581 L
.1649 .62581 L
.1649 .62346 L
F
.35068 .62346 m
.35068 .62581 L
.35303 .62581 L
.35303 .62346 L
F
.37184 .62346 m
.37184 .62581 L
.37419 .62581 L
.37419 .62346 L
F
.37419 .62346 m
.37419 .62581 L
.37654 .62581 L
.37654 .62346 L
F
.39771 .62346 m
.39771 .62581 L
.40006 .62581 L
.40006 .62346 L
F
.58583 .62346 m
.58583 .62581 L
.58818 .62581 L
.58818 .62346 L
F
.1602 .62581 m
.1602 .62816 L
.16255 .62816 L
.16255 .62581 L
F
.34832 .62581 m
.34832 .62816 L
.35068 .62816 L
.35068 .62581 L
F
.36949 .62581 m
.36949 .62816 L
.37184 .62816 L
.37184 .62581 L
F
.37184 .62581 m
.37184 .62816 L
.37419 .62816 L
.37419 .62581 L
F
.37419 .62581 m
.37419 .62816 L
.37654 .62816 L
.37654 .62581 L
F
.39536 .62581 m
.39536 .62816 L
.39771 .62816 L
.39771 .62581 L
F
.58348 .62581 m
.58348 .62816 L
.58583 .62816 L
.58583 .62581 L
F
.15785 .62816 m
.15785 .63051 L
.1602 .63051 L
.1602 .62816 L
F
.34597 .62816 m
.34597 .63051 L
.34832 .63051 L
.34832 .62816 L
F
.36714 .62816 m
.36714 .63051 L
.36949 .63051 L
.36949 .62816 L
F
.36949 .62816 m
.36949 .63051 L
.37184 .63051 L
.37184 .62816 L
F
.37184 .62816 m
.37184 .63051 L
.37419 .63051 L
.37419 .62816 L
F
.393 .62816 m
.393 .63051 L
.39536 .63051 L
.39536 .62816 L
F
.58113 .62816 m
.58113 .63051 L
.58348 .63051 L
.58348 .62816 L
F
.1555 .63051 m
.1555 .63286 L
.15785 .63286 L
.15785 .63051 L
F
.34362 .63051 m
.34362 .63286 L
.34597 .63286 L
.34597 .63051 L
F
.36479 .63051 m
.36479 .63286 L
.36714 .63286 L
.36714 .63051 L
F
.36714 .63051 m
.36714 .63286 L
.36949 .63286 L
.36949 .63051 L
F
.36949 .63051 m
.36949 .63286 L
.37184 .63286 L
.37184 .63051 L
F
.39065 .63051 m
.39065 .63286 L
.393 .63286 L
.393 .63051 L
F
.57878 .63051 m
.57878 .63286 L
.58113 .63286 L
.58113 .63051 L
F
.15315 .63286 m
.15315 .63521 L
.1555 .63521 L
.1555 .63286 L
F
.34127 .63286 m
.34127 .63521 L
.34362 .63521 L
.34362 .63286 L
F
.36479 .63286 m
.36479 .63521 L
.36714 .63521 L
.36714 .63286 L
F
.36714 .63286 m
.36714 .63521 L
.36949 .63521 L
.36949 .63286 L
F
.3883 .63286 m
.3883 .63521 L
.39065 .63521 L
.39065 .63286 L
F
.57643 .63286 m
.57643 .63521 L
.57878 .63521 L
.57878 .63286 L
F
.15079 .63521 m
.15079 .63757 L
.15315 .63757 L
.15315 .63521 L
F
.36008 .63521 m
.36008 .63757 L
.36243 .63757 L
.36243 .63521 L
F
.36243 .63521 m
.36243 .63757 L
.36479 .63757 L
.36479 .63521 L
F
.38595 .63521 m
.38595 .63757 L
.3883 .63757 L
.3883 .63521 L
F
.57407 .63521 m
.57407 .63757 L
.57643 .63757 L
.57643 .63521 L
F
.14844 .63757 m
.14844 .63992 L
.15079 .63992 L
.15079 .63757 L
F
.35773 .63757 m
.35773 .63992 L
.36008 .63992 L
.36008 .63757 L
F
.36008 .63757 m
.36008 .63992 L
.36243 .63992 L
.36243 .63757 L
F
.36243 .63757 m
.36243 .63992 L
.36479 .63992 L
.36479 .63757 L
F
.3836 .63757 m
.3836 .63992 L
.38595 .63992 L
.38595 .63757 L
F
.57172 .63757 m
.57172 .63992 L
.57407 .63992 L
.57407 .63757 L
F
.14609 .63992 m
.14609 .64227 L
.14844 .64227 L
.14844 .63992 L
F
.35538 .63992 m
.35538 .64227 L
.35773 .64227 L
.35773 .63992 L
F
.35773 .63992 m
.35773 .64227 L
.36008 .64227 L
.36008 .63992 L
F
.36008 .63992 m
.36008 .64227 L
.36243 .64227 L
.36243 .63992 L
F
.38125 .63992 m
.38125 .64227 L
.3836 .64227 L
.3836 .63992 L
F
.56937 .63992 m
.56937 .64227 L
.57172 .64227 L
.57172 .63992 L
F
.14374 .64227 m
.14374 .64462 L
.14609 .64462 L
.14609 .64227 L
F
.35303 .64227 m
.35303 .64462 L
.35538 .64462 L
.35538 .64227 L
F
.35538 .64227 m
.35538 .64462 L
.35773 .64462 L
.35773 .64227 L
F
.35773 .64227 m
.35773 .64462 L
.36008 .64462 L
.36008 .64227 L
F
.37889 .64227 m
.37889 .64462 L
.38125 .64462 L
.38125 .64227 L
F
.56702 .64227 m
.56702 .64462 L
.56937 .64462 L
.56937 .64227 L
F
.14139 .64462 m
.14139 .64697 L
.14374 .64697 L
.14374 .64462 L
F
.35303 .64462 m
.35303 .64697 L
.35538 .64697 L
.35538 .64462 L
F
.35538 .64462 m
.35538 .64697 L
.35773 .64697 L
.35773 .64462 L
F
.37654 .64462 m
.37654 .64697 L
.37889 .64697 L
.37889 .64462 L
F
.56467 .64462 m
.56467 .64697 L
.56702 .64697 L
.56702 .64462 L
F
.13904 .64697 m
.13904 .64932 L
.14139 .64932 L
.14139 .64697 L
F
.34832 .64697 m
.34832 .64932 L
.35068 .64932 L
.35068 .64697 L
F
.35068 .64697 m
.35068 .64932 L
.35303 .64932 L
.35303 .64697 L
F
.37419 .64697 m
.37419 .64932 L
.37654 .64932 L
.37654 .64697 L
F
.56232 .64697 m
.56232 .64932 L
.56467 .64932 L
.56467 .64697 L
F
.13668 .64932 m
.13668 .65168 L
.13904 .65168 L
.13904 .64932 L
F
.34597 .64932 m
.34597 .65168 L
.34832 .65168 L
.34832 .64932 L
F
.34832 .64932 m
.34832 .65168 L
.35068 .65168 L
.35068 .64932 L
F
.35068 .64932 m
.35068 .65168 L
.35303 .65168 L
.35303 .64932 L
F
.37184 .64932 m
.37184 .65168 L
.37419 .65168 L
.37419 .64932 L
F
.55996 .64932 m
.55996 .65168 L
.56232 .65168 L
.56232 .64932 L
F
.13433 .65168 m
.13433 .65403 L
.13668 .65403 L
.13668 .65168 L
F
.34362 .65168 m
.34362 .65403 L
.34597 .65403 L
.34597 .65168 L
F
.34597 .65168 m
.34597 .65403 L
.34832 .65403 L
.34832 .65168 L
F
.34832 .65168 m
.34832 .65403 L
.35068 .65403 L
.35068 .65168 L
F
.36949 .65168 m
.36949 .65403 L
.37184 .65403 L
.37184 .65168 L
F
.55761 .65168 m
.55761 .65403 L
.55996 .65403 L
.55996 .65168 L
F
.13198 .65403 m
.13198 .65638 L
.13433 .65638 L
.13433 .65403 L
F
.34127 .65403 m
.34127 .65638 L
.34362 .65638 L
.34362 .65403 L
F
.34362 .65403 m
.34362 .65638 L
.34597 .65638 L
.34597 .65403 L
F
.34597 .65403 m
.34597 .65638 L
.34832 .65638 L
.34832 .65403 L
F
.36714 .65403 m
.36714 .65638 L
.36949 .65638 L
.36949 .65403 L
F
.55526 .65403 m
.55526 .65638 L
.55761 .65638 L
.55761 .65403 L
F
.12963 .65638 m
.12963 .65873 L
.13198 .65873 L
.13198 .65638 L
F
.34127 .65638 m
.34127 .65873 L
.34362 .65873 L
.34362 .65638 L
F
.34362 .65638 m
.34362 .65873 L
.34597 .65873 L
.34597 .65638 L
F
.36479 .65638 m
.36479 .65873 L
.36714 .65873 L
.36714 .65638 L
F
.55291 .65638 m
.55291 .65873 L
.55526 .65873 L
.55526 .65638 L
F
.12728 .65873 m
.12728 .66108 L
.12963 .66108 L
.12963 .65873 L
F
.3154 .65873 m
.3154 .66108 L
.31775 .66108 L
.31775 .65873 L
F
.33657 .65873 m
.33657 .66108 L
.33892 .66108 L
.33892 .65873 L
F
.33892 .65873 m
.33892 .66108 L
.34127 .66108 L
.34127 .65873 L
F
.55056 .65873 m
.55056 .66108 L
.55291 .66108 L
.55291 .65873 L
F
.12493 .66108 m
.12493 .66343 L
.12728 .66343 L
.12728 .66108 L
F
.31305 .66108 m
.31305 .66343 L
.3154 .66343 L
.3154 .66108 L
F
.33422 .66108 m
.33422 .66343 L
.33657 .66343 L
.33657 .66108 L
F
.33657 .66108 m
.33657 .66343 L
.33892 .66343 L
.33892 .66108 L
F
.33892 .66108 m
.33892 .66343 L
.34127 .66343 L
.34127 .66108 L
F
.54821 .66108 m
.54821 .66343 L
.55056 .66343 L
.55056 .66108 L
F
.12257 .66343 m
.12257 .66578 L
.12493 .66578 L
.12493 .66343 L
F
.3107 .66343 m
.3107 .66578 L
.31305 .66578 L
.31305 .66343 L
F
.33186 .66343 m
.33186 .66578 L
.33422 .66578 L
.33422 .66343 L
F
.33422 .66343 m
.33422 .66578 L
.33657 .66578 L
.33657 .66343 L
F
.33657 .66343 m
.33657 .66578 L
.33892 .66578 L
.33892 .66343 L
F
.54586 .66343 m
.54586 .66578 L
.54821 .66578 L
.54821 .66343 L
F
.12022 .66578 m
.12022 .66814 L
.12257 .66814 L
.12257 .66578 L
F
.30835 .66578 m
.30835 .66814 L
.3107 .66814 L
.3107 .66578 L
F
.32951 .66578 m
.32951 .66814 L
.33186 .66814 L
.33186 .66578 L
F
.33186 .66578 m
.33186 .66814 L
.33422 .66814 L
.33422 .66578 L
F
.33422 .66578 m
.33422 .66814 L
.33657 .66814 L
.33657 .66578 L
F
.5435 .66578 m
.5435 .66814 L
.54586 .66814 L
.54586 .66578 L
F
.11787 .66814 m
.11787 .67049 L
.12022 .67049 L
.12022 .66814 L
F
.306 .66814 m
.306 .67049 L
.30835 .67049 L
.30835 .66814 L
F
.32951 .66814 m
.32951 .67049 L
.33186 .67049 L
.33186 .66814 L
F
.33186 .66814 m
.33186 .67049 L
.33422 .67049 L
.33422 .66814 L
F
.54115 .66814 m
.54115 .67049 L
.5435 .67049 L
.5435 .66814 L
F
.11552 .67049 m
.11552 .67284 L
.11787 .67284 L
.11787 .67049 L
F
.30364 .67049 m
.30364 .67284 L
.306 .67284 L
.306 .67049 L
F
.32481 .67049 m
.32481 .67284 L
.32716 .67284 L
.32716 .67049 L
F
.32716 .67049 m
.32716 .67284 L
.32951 .67284 L
.32951 .67049 L
F
.5388 .67049 m
.5388 .67284 L
.54115 .67284 L
.54115 .67049 L
F
.11317 .67284 m
.11317 .67519 L
.11552 .67519 L
.11552 .67284 L
F
.30129 .67284 m
.30129 .67519 L
.30364 .67519 L
.30364 .67284 L
F
.32246 .67284 m
.32246 .67519 L
.32481 .67519 L
.32481 .67284 L
F
.32481 .67284 m
.32481 .67519 L
.32716 .67519 L
.32716 .67284 L
F
.32716 .67284 m
.32716 .67519 L
.32951 .67519 L
.32951 .67284 L
F
.53645 .67284 m
.53645 .67519 L
.5388 .67519 L
.5388 .67284 L
F
.11082 .67519 m
.11082 .67754 L
.11317 .67754 L
.11317 .67519 L
F
.29894 .67519 m
.29894 .67754 L
.30129 .67754 L
.30129 .67519 L
F
.32011 .67519 m
.32011 .67754 L
.32246 .67754 L
.32246 .67519 L
F
.32246 .67519 m
.32246 .67754 L
.32481 .67754 L
.32481 .67519 L
F
.32481 .67519 m
.32481 .67754 L
.32716 .67754 L
.32716 .67519 L
F
.5341 .67519 m
.5341 .67754 L
.53645 .67754 L
.53645 .67519 L
F
.10847 .67754 m
.10847 .67989 L
.11082 .67989 L
.11082 .67754 L
F
.29659 .67754 m
.29659 .67989 L
.29894 .67989 L
.29894 .67754 L
F
.31775 .67754 m
.31775 .67989 L
.32011 .67989 L
.32011 .67754 L
F
.32011 .67754 m
.32011 .67989 L
.32246 .67989 L
.32246 .67754 L
F
.32246 .67754 m
.32246 .67989 L
.32481 .67989 L
.32481 .67754 L
F
.53175 .67754 m
.53175 .67989 L
.5341 .67989 L
.5341 .67754 L
F
.10611 .67989 m
.10611 .68225 L
.10847 .68225 L
.10847 .67989 L
F
.29424 .67989 m
.29424 .68225 L
.29659 .68225 L
.29659 .67989 L
F
.31775 .67989 m
.31775 .68225 L
.32011 .68225 L
.32011 .67989 L
F
.32011 .67989 m
.32011 .68225 L
.32246 .68225 L
.32246 .67989 L
F
.52939 .67989 m
.52939 .68225 L
.53175 .68225 L
.53175 .67989 L
F
.10376 .68225 m
.10376 .6846 L
.10611 .6846 L
.10611 .68225 L
F
.29189 .68225 m
.29189 .6846 L
.29424 .6846 L
.29424 .68225 L
F
.31305 .68225 m
.31305 .6846 L
.3154 .6846 L
.3154 .68225 L
F
.3154 .68225 m
.3154 .6846 L
.31775 .6846 L
.31775 .68225 L
F
.33892 .68225 m
.33892 .6846 L
.34127 .6846 L
.34127 .68225 L
F
.52704 .68225 m
.52704 .6846 L
.52939 .6846 L
.52939 .68225 L
F
.10141 .6846 m
.10141 .68695 L
.10376 .68695 L
.10376 .6846 L
F
.28954 .6846 m
.28954 .68695 L
.29189 .68695 L
.29189 .6846 L
F
.3107 .6846 m
.3107 .68695 L
.31305 .68695 L
.31305 .6846 L
F
.31305 .6846 m
.31305 .68695 L
.3154 .68695 L
.3154 .6846 L
F
.3154 .6846 m
.3154 .68695 L
.31775 .68695 L
.31775 .6846 L
F
.33657 .6846 m
.33657 .68695 L
.33892 .68695 L
.33892 .6846 L
F
.52469 .6846 m
.52469 .68695 L
.52704 .68695 L
.52704 .6846 L
F
.09906 .68695 m
.09906 .6893 L
.10141 .6893 L
.10141 .68695 L
F
.28718 .68695 m
.28718 .6893 L
.28954 .6893 L
.28954 .68695 L
F
.30835 .68695 m
.30835 .6893 L
.3107 .6893 L
.3107 .68695 L
F
.3107 .68695 m
.3107 .6893 L
.31305 .6893 L
.31305 .68695 L
F
.31305 .68695 m
.31305 .6893 L
.3154 .6893 L
.3154 .68695 L
F
.33422 .68695 m
.33422 .6893 L
.33657 .6893 L
.33657 .68695 L
F
.52234 .68695 m
.52234 .6893 L
.52469 .6893 L
.52469 .68695 L
F
.09671 .6893 m
.09671 .69165 L
.09906 .69165 L
.09906 .6893 L
F
.28483 .6893 m
.28483 .69165 L
.28718 .69165 L
.28718 .6893 L
F
.306 .6893 m
.306 .69165 L
.30835 .69165 L
.30835 .6893 L
F
.30835 .6893 m
.30835 .69165 L
.3107 .69165 L
.3107 .6893 L
F
.3107 .6893 m
.3107 .69165 L
.31305 .69165 L
.31305 .6893 L
F
.33186 .6893 m
.33186 .69165 L
.33422 .69165 L
.33422 .6893 L
F
.51999 .6893 m
.51999 .69165 L
.52234 .69165 L
.52234 .6893 L
F
.09436 .69165 m
.09436 .694 L
.09671 .694 L
.09671 .69165 L
F
.28248 .69165 m
.28248 .694 L
.28483 .694 L
.28483 .69165 L
F
.306 .69165 m
.306 .694 L
.30835 .694 L
.30835 .69165 L
F
.30835 .69165 m
.30835 .694 L
.3107 .694 L
.3107 .69165 L
F
.32951 .69165 m
.32951 .694 L
.33186 .694 L
.33186 .69165 L
F
.51764 .69165 m
.51764 .694 L
.51999 .694 L
.51999 .69165 L
F
.092 .694 m
.092 .69636 L
.09436 .69636 L
.09436 .694 L
F
.28013 .694 m
.28013 .69636 L
.28248 .69636 L
.28248 .694 L
F
.30129 .694 m
.30129 .69636 L
.30364 .69636 L
.30364 .694 L
F
.30364 .694 m
.30364 .69636 L
.306 .69636 L
.306 .694 L
F
.32716 .694 m
.32716 .69636 L
.32951 .69636 L
.32951 .694 L
F
.51529 .694 m
.51529 .69636 L
.51764 .69636 L
.51764 .694 L
F
.08965 .69636 m
.08965 .69871 L
.092 .69871 L
.092 .69636 L
F
.27778 .69636 m
.27778 .69871 L
.28013 .69871 L
.28013 .69636 L
F
.29894 .69636 m
.29894 .69871 L
.30129 .69871 L
.30129 .69636 L
F
.30129 .69636 m
.30129 .69871 L
.30364 .69871 L
.30364 .69636 L
F
.30364 .69636 m
.30364 .69871 L
.306 .69871 L
.306 .69636 L
F
.32481 .69636 m
.32481 .69871 L
.32716 .69871 L
.32716 .69636 L
F
.51293 .69636 m
.51293 .69871 L
.51529 .69871 L
.51529 .69636 L
F
.0873 .69871 m
.0873 .70106 L
.08965 .70106 L
.08965 .69871 L
F
.27543 .69871 m
.27543 .70106 L
.27778 .70106 L
.27778 .69871 L
F
.29659 .69871 m
.29659 .70106 L
.29894 .70106 L
.29894 .69871 L
F
.29894 .69871 m
.29894 .70106 L
.30129 .70106 L
.30129 .69871 L
F
.30129 .69871 m
.30129 .70106 L
.30364 .70106 L
.30364 .69871 L
F
.32246 .69871 m
.32246 .70106 L
.32481 .70106 L
.32481 .69871 L
F
.51058 .69871 m
.51058 .70106 L
.51293 .70106 L
.51293 .69871 L
F
.08495 .70106 m
.08495 .70341 L
.0873 .70341 L
.0873 .70106 L
F
.27307 .70106 m
.27307 .70341 L
.27543 .70341 L
.27543 .70106 L
F
.29424 .70106 m
.29424 .70341 L
.29659 .70341 L
.29659 .70106 L
F
.29659 .70106 m
.29659 .70341 L
.29894 .70341 L
.29894 .70106 L
F
.29894 .70106 m
.29894 .70341 L
.30129 .70341 L
.30129 .70106 L
F
.32011 .70106 m
.32011 .70341 L
.32246 .70341 L
.32246 .70106 L
F
.50823 .70106 m
.50823 .70341 L
.51058 .70341 L
.51058 .70106 L
F
.0826 .70341 m
.0826 .70576 L
.08495 .70576 L
.08495 .70341 L
F
.27072 .70341 m
.27072 .70576 L
.27307 .70576 L
.27307 .70341 L
F
.29424 .70341 m
.29424 .70576 L
.29659 .70576 L
.29659 .70341 L
F
.29659 .70341 m
.29659 .70576 L
.29894 .70576 L
.29894 .70341 L
F
.31775 .70341 m
.31775 .70576 L
.32011 .70576 L
.32011 .70341 L
F
.50588 .70341 m
.50588 .70576 L
.50823 .70576 L
.50823 .70341 L
F
.08025 .70576 m
.08025 .70811 L
.0826 .70811 L
.0826 .70576 L
F
.26837 .70576 m
.26837 .70811 L
.27072 .70811 L
.27072 .70576 L
F
.28954 .70576 m
.28954 .70811 L
.29189 .70811 L
.29189 .70576 L
F
.29189 .70576 m
.29189 .70811 L
.29424 .70811 L
.29424 .70576 L
F
.3154 .70576 m
.3154 .70811 L
.31775 .70811 L
.31775 .70576 L
F
.50353 .70576 m
.50353 .70811 L
.50588 .70811 L
.50588 .70576 L
F
.0779 .70811 m
.0779 .71046 L
.08025 .71046 L
.08025 .70811 L
F
.26602 .70811 m
.26602 .71046 L
.26837 .71046 L
.26837 .70811 L
F
.28718 .70811 m
.28718 .71046 L
.28954 .71046 L
.28954 .70811 L
F
.28954 .70811 m
.28954 .71046 L
.29189 .71046 L
.29189 .70811 L
F
.29189 .70811 m
.29189 .71046 L
.29424 .71046 L
.29424 .70811 L
F
.31305 .70811 m
.31305 .71046 L
.3154 .71046 L
.3154 .70811 L
F
.50118 .70811 m
.50118 .71046 L
.50353 .71046 L
.50353 .70811 L
F
.07554 .71046 m
.07554 .71282 L
.0779 .71282 L
.0779 .71046 L
F
.26367 .71046 m
.26367 .71282 L
.26602 .71282 L
.26602 .71046 L
F
.28483 .71046 m
.28483 .71282 L
.28718 .71282 L
.28718 .71046 L
F
.28718 .71046 m
.28718 .71282 L
.28954 .71282 L
.28954 .71046 L
F
.28954 .71046 m
.28954 .71282 L
.29189 .71282 L
.29189 .71046 L
F
.3107 .71046 m
.3107 .71282 L
.31305 .71282 L
.31305 .71046 L
F
.49882 .71046 m
.49882 .71282 L
.50118 .71282 L
.50118 .71046 L
F
.07319 .71282 m
.07319 .71517 L
.07554 .71517 L
.07554 .71282 L
F
.26132 .71282 m
.26132 .71517 L
.26367 .71517 L
.26367 .71282 L
F
.28248 .71282 m
.28248 .71517 L
.28483 .71517 L
.28483 .71282 L
F
.28483 .71282 m
.28483 .71517 L
.28718 .71517 L
.28718 .71282 L
F
.28718 .71282 m
.28718 .71517 L
.28954 .71517 L
.28954 .71282 L
F
.30835 .71282 m
.30835 .71517 L
.3107 .71517 L
.3107 .71282 L
F
.49647 .71282 m
.49647 .71517 L
.49882 .71517 L
.49882 .71282 L
F
.07084 .71517 m
.07084 .71752 L
.07319 .71752 L
.07319 .71517 L
F
.25897 .71517 m
.25897 .71752 L
.26132 .71752 L
.26132 .71517 L
F
.28248 .71517 m
.28248 .71752 L
.28483 .71752 L
.28483 .71517 L
F
.28483 .71517 m
.28483 .71752 L
.28718 .71752 L
.28718 .71517 L
F
.306 .71517 m
.306 .71752 L
.30835 .71752 L
.30835 .71517 L
F
.49412 .71517 m
.49412 .71752 L
.49647 .71752 L
.49647 .71517 L
F
.06849 .71752 m
.06849 .71987 L
.07084 .71987 L
.07084 .71752 L
F
.25661 .71752 m
.25661 .71987 L
.25897 .71987 L
.25897 .71752 L
F
.27778 .71752 m
.27778 .71987 L
.28013 .71987 L
.28013 .71752 L
F
.28013 .71752 m
.28013 .71987 L
.28248 .71987 L
.28248 .71752 L
F
.30364 .71752 m
.30364 .71987 L
.306 .71987 L
.306 .71752 L
F
.49177 .71752 m
.49177 .71987 L
.49412 .71987 L
.49412 .71752 L
F
.06614 .71987 m
.06614 .72222 L
.06849 .72222 L
.06849 .71987 L
F
.25426 .71987 m
.25426 .72222 L
.25661 .72222 L
.25661 .71987 L
F
.27543 .71987 m
.27543 .72222 L
.27778 .72222 L
.27778 .71987 L
F
.27778 .71987 m
.27778 .72222 L
.28013 .72222 L
.28013 .71987 L
F
.28013 .71987 m
.28013 .72222 L
.28248 .72222 L
.28248 .71987 L
F
.30129 .71987 m
.30129 .72222 L
.30364 .72222 L
.30364 .71987 L
F
.48942 .71987 m
.48942 .72222 L
.49177 .72222 L
.49177 .71987 L
F
.06379 .72222 m
.06379 .72457 L
.06614 .72457 L
.06614 .72222 L
F
.25191 .72222 m
.25191 .72457 L
.25426 .72457 L
.25426 .72222 L
F
.27307 .72222 m
.27307 .72457 L
.27543 .72457 L
.27543 .72222 L
F
.27543 .72222 m
.27543 .72457 L
.27778 .72457 L
.27778 .72222 L
F
.27778 .72222 m
.27778 .72457 L
.28013 .72457 L
.28013 .72222 L
F
.29894 .72222 m
.29894 .72457 L
.30129 .72457 L
.30129 .72222 L
F
.48707 .72222 m
.48707 .72457 L
.48942 .72457 L
.48942 .72222 L
F
.06143 .72457 m
.06143 .72693 L
.06379 .72693 L
.06379 .72457 L
F
.24956 .72457 m
.24956 .72693 L
.25191 .72693 L
.25191 .72457 L
F
.27072 .72457 m
.27072 .72693 L
.27307 .72693 L
.27307 .72457 L
F
.27307 .72457 m
.27307 .72693 L
.27543 .72693 L
.27543 .72457 L
F
.27543 .72457 m
.27543 .72693 L
.27778 .72693 L
.27778 .72457 L
F
.29659 .72457 m
.29659 .72693 L
.29894 .72693 L
.29894 .72457 L
F
.48471 .72457 m
.48471 .72693 L
.48707 .72693 L
.48707 .72457 L
F
.05908 .72693 m
.05908 .72928 L
.06143 .72928 L
.06143 .72693 L
F
.24721 .72693 m
.24721 .72928 L
.24956 .72928 L
.24956 .72693 L
F
.27072 .72693 m
.27072 .72928 L
.27307 .72928 L
.27307 .72693 L
F
.27307 .72693 m
.27307 .72928 L
.27543 .72928 L
.27543 .72693 L
F
.29424 .72693 m
.29424 .72928 L
.29659 .72928 L
.29659 .72693 L
F
.48236 .72693 m
.48236 .72928 L
.48471 .72928 L
.48471 .72693 L
F
.05673 .72928 m
.05673 .73163 L
.05908 .73163 L
.05908 .72928 L
F
.24486 .72928 m
.24486 .73163 L
.24721 .73163 L
.24721 .72928 L
F
.26602 .72928 m
.26602 .73163 L
.26837 .73163 L
.26837 .72928 L
F
.26837 .72928 m
.26837 .73163 L
.27072 .73163 L
.27072 .72928 L
F
.29189 .72928 m
.29189 .73163 L
.29424 .73163 L
.29424 .72928 L
F
.48001 .72928 m
.48001 .73163 L
.48236 .73163 L
.48236 .72928 L
F
.05438 .73163 m
.05438 .73398 L
.05673 .73398 L
.05673 .73163 L
F
.2425 .73163 m
.2425 .73398 L
.24486 .73398 L
.24486 .73163 L
F
.26367 .73163 m
.26367 .73398 L
.26602 .73398 L
.26602 .73163 L
F
.26602 .73163 m
.26602 .73398 L
.26837 .73398 L
.26837 .73163 L
F
.26837 .73163 m
.26837 .73398 L
.27072 .73398 L
.27072 .73163 L
F
.28954 .73163 m
.28954 .73398 L
.29189 .73398 L
.29189 .73163 L
F
.47766 .73163 m
.47766 .73398 L
.48001 .73398 L
.48001 .73163 L
F
.05203 .73398 m
.05203 .73633 L
.05438 .73633 L
.05438 .73398 L
F
.24015 .73398 m
.24015 .73633 L
.2425 .73633 L
.2425 .73398 L
F
.26132 .73398 m
.26132 .73633 L
.26367 .73633 L
.26367 .73398 L
F
.26367 .73398 m
.26367 .73633 L
.26602 .73633 L
.26602 .73398 L
F
.26602 .73398 m
.26602 .73633 L
.26837 .73633 L
.26837 .73398 L
F
.28718 .73398 m
.28718 .73633 L
.28954 .73633 L
.28954 .73398 L
F
.47531 .73398 m
.47531 .73633 L
.47766 .73633 L
.47766 .73398 L
F
.04968 .73633 m
.04968 .73868 L
.05203 .73868 L
.05203 .73633 L
F
.2378 .73633 m
.2378 .73868 L
.24015 .73868 L
.24015 .73633 L
F
.25897 .73633 m
.25897 .73868 L
.26132 .73868 L
.26132 .73633 L
F
.26132 .73633 m
.26132 .73868 L
.26367 .73868 L
.26367 .73633 L
F
.26367 .73633 m
.26367 .73868 L
.26602 .73868 L
.26602 .73633 L
F
.28483 .73633 m
.28483 .73868 L
.28718 .73868 L
.28718 .73633 L
F
.47296 .73633 m
.47296 .73868 L
.47531 .73868 L
.47531 .73633 L
F
.04733 .73868 m
.04733 .74103 L
.04968 .74103 L
.04968 .73868 L
F
.23545 .73868 m
.23545 .74103 L
.2378 .74103 L
.2378 .73868 L
F
.25897 .73868 m
.25897 .74103 L
.26132 .74103 L
.26132 .73868 L
F
.26132 .73868 m
.26132 .74103 L
.26367 .74103 L
.26367 .73868 L
F
.28248 .73868 m
.28248 .74103 L
.28483 .74103 L
.28483 .73868 L
F
.47061 .73868 m
.47061 .74103 L
.47296 .74103 L
.47296 .73868 L
F
.04497 .74103 m
.04497 .74339 L
.04733 .74339 L
.04733 .74103 L
F
.25426 .74103 m
.25426 .74339 L
.25661 .74339 L
.25661 .74103 L
F
.25661 .74103 m
.25661 .74339 L
.25897 .74339 L
.25897 .74103 L
F
.28013 .74103 m
.28013 .74339 L
.28248 .74339 L
.28248 .74103 L
F
.46825 .74103 m
.46825 .74339 L
.47061 .74339 L
.47061 .74103 L
F
.04262 .74339 m
.04262 .74574 L
.04497 .74574 L
.04497 .74339 L
F
.25191 .74339 m
.25191 .74574 L
.25426 .74574 L
.25426 .74339 L
F
.25426 .74339 m
.25426 .74574 L
.25661 .74574 L
.25661 .74339 L
F
.25661 .74339 m
.25661 .74574 L
.25897 .74574 L
.25897 .74339 L
F
.27778 .74339 m
.27778 .74574 L
.28013 .74574 L
.28013 .74339 L
F
.4659 .74339 m
.4659 .74574 L
.46825 .74574 L
.46825 .74339 L
F
.04027 .74574 m
.04027 .74809 L
.04262 .74809 L
.04262 .74574 L
F
.24956 .74574 m
.24956 .74809 L
.25191 .74809 L
.25191 .74574 L
F
.25191 .74574 m
.25191 .74809 L
.25426 .74809 L
.25426 .74574 L
F
.25426 .74574 m
.25426 .74809 L
.25661 .74809 L
.25661 .74574 L
F
.27543 .74574 m
.27543 .74809 L
.27778 .74809 L
.27778 .74574 L
F
.46355 .74574 m
.46355 .74809 L
.4659 .74809 L
.4659 .74574 L
F
.03792 .74809 m
.03792 .75044 L
.04027 .75044 L
.04027 .74809 L
F
.24721 .74809 m
.24721 .75044 L
.24956 .75044 L
.24956 .74809 L
F
.24956 .74809 m
.24956 .75044 L
.25191 .75044 L
.25191 .74809 L
F
.25191 .74809 m
.25191 .75044 L
.25426 .75044 L
.25426 .74809 L
F
.27307 .74809 m
.27307 .75044 L
.27543 .75044 L
.27543 .74809 L
F
.4612 .74809 m
.4612 .75044 L
.46355 .75044 L
.46355 .74809 L
F
.03557 .75044 m
.03557 .75279 L
.03792 .75279 L
.03792 .75044 L
F
.24721 .75044 m
.24721 .75279 L
.24956 .75279 L
.24956 .75044 L
F
.24956 .75044 m
.24956 .75279 L
.25191 .75279 L
.25191 .75044 L
F
.27072 .75044 m
.27072 .75279 L
.27307 .75279 L
.27307 .75044 L
F
.45885 .75044 m
.45885 .75279 L
.4612 .75279 L
.4612 .75044 L
F
.03322 .75279 m
.03322 .75514 L
.03557 .75514 L
.03557 .75279 L
F
.2425 .75279 m
.2425 .75514 L
.24486 .75514 L
.24486 .75279 L
F
.24486 .75279 m
.24486 .75514 L
.24721 .75514 L
.24721 .75279 L
F
.26837 .75279 m
.26837 .75514 L
.27072 .75514 L
.27072 .75279 L
F
.4565 .75279 m
.4565 .75514 L
.45885 .75514 L
.45885 .75279 L
F
.03086 .75514 m
.03086 .7575 L
.03322 .7575 L
.03322 .75514 L
F
.24015 .75514 m
.24015 .7575 L
.2425 .7575 L
.2425 .75514 L
F
.2425 .75514 m
.2425 .7575 L
.24486 .7575 L
.24486 .75514 L
F
.24486 .75514 m
.24486 .7575 L
.24721 .7575 L
.24721 .75514 L
F
.26602 .75514 m
.26602 .7575 L
.26837 .7575 L
.26837 .75514 L
F
.45414 .75514 m
.45414 .7575 L
.4565 .7575 L
.4565 .75514 L
F
.02851 .7575 m
.02851 .75985 L
.03086 .75985 L
.03086 .7575 L
F
.2378 .7575 m
.2378 .75985 L
.24015 .75985 L
.24015 .7575 L
F
.24015 .7575 m
.24015 .75985 L
.2425 .75985 L
.2425 .7575 L
F
.2425 .7575 m
.2425 .75985 L
.24486 .75985 L
.24486 .7575 L
F
.26367 .7575 m
.26367 .75985 L
.26602 .75985 L
.26602 .7575 L
F
.45179 .7575 m
.45179 .75985 L
.45414 .75985 L
.45414 .7575 L
F
.02616 .75985 m
.02616 .7622 L
.02851 .7622 L
.02851 .75985 L
F
.23545 .75985 m
.23545 .7622 L
.2378 .7622 L
.2378 .75985 L
F
.2378 .75985 m
.2378 .7622 L
.24015 .7622 L
.24015 .75985 L
F
.24015 .75985 m
.24015 .7622 L
.2425 .7622 L
.2425 .75985 L
F
.26132 .75985 m
.26132 .7622 L
.26367 .7622 L
.26367 .75985 L
F
.44944 .75985 m
.44944 .7622 L
.45179 .7622 L
.45179 .75985 L
F
.02381 .7622 m
.02381 .76455 L
.02616 .76455 L
.02616 .7622 L
F
.23545 .7622 m
.23545 .76455 L
.2378 .76455 L
.2378 .7622 L
F
.2378 .7622 m
.2378 .76455 L
.24015 .76455 L
.24015 .7622 L
F
.25897 .7622 m
.25897 .76455 L
.26132 .76455 L
.26132 .7622 L
F
.44709 .7622 m
.44709 .76455 L
.44944 .76455 L
.44944 .7622 L
F
.20958 .76455 m
.20958 .7669 L
.21193 .7669 L
.21193 .76455 L
F
.23075 .76455 m
.23075 .7669 L
.2331 .7669 L
.2331 .76455 L
F
.2331 .76455 m
.2331 .7669 L
.23545 .7669 L
.23545 .76455 L
F
.44474 .76455 m
.44474 .7669 L
.44709 .7669 L
.44709 .76455 L
F
.20723 .7669 m
.20723 .76925 L
.20958 .76925 L
.20958 .7669 L
F
.2284 .7669 m
.2284 .76925 L
.23075 .76925 L
.23075 .7669 L
F
.23075 .7669 m
.23075 .76925 L
.2331 .76925 L
.2331 .7669 L
F
.2331 .7669 m
.2331 .76925 L
.23545 .76925 L
.23545 .7669 L
F
.44239 .7669 m
.44239 .76925 L
.44474 .76925 L
.44474 .7669 L
F
.20488 .76925 m
.20488 .7716 L
.20723 .7716 L
.20723 .76925 L
F
.22604 .76925 m
.22604 .7716 L
.2284 .7716 L
.2284 .76925 L
F
.2284 .76925 m
.2284 .7716 L
.23075 .7716 L
.23075 .76925 L
F
.23075 .76925 m
.23075 .7716 L
.2331 .7716 L
.2331 .76925 L
F
.44004 .76925 m
.44004 .7716 L
.44239 .7716 L
.44239 .76925 L
F
.20253 .7716 m
.20253 .77396 L
.20488 .77396 L
.20488 .7716 L
F
.22369 .7716 m
.22369 .77396 L
.22604 .77396 L
.22604 .7716 L
F
.22604 .7716 m
.22604 .77396 L
.2284 .77396 L
.2284 .7716 L
F
.2284 .7716 m
.2284 .77396 L
.23075 .77396 L
.23075 .7716 L
F
.43768 .7716 m
.43768 .77396 L
.44004 .77396 L
.44004 .7716 L
F
.20018 .77396 m
.20018 .77631 L
.20253 .77631 L
.20253 .77396 L
F
.22369 .77396 m
.22369 .77631 L
.22604 .77631 L
.22604 .77396 L
F
.22604 .77396 m
.22604 .77631 L
.2284 .77631 L
.2284 .77396 L
F
.43533 .77396 m
.43533 .77631 L
.43768 .77631 L
.43768 .77396 L
F
.19782 .77631 m
.19782 .77866 L
.20018 .77866 L
.20018 .77631 L
F
.21899 .77631 m
.21899 .77866 L
.22134 .77866 L
.22134 .77631 L
F
.22134 .77631 m
.22134 .77866 L
.22369 .77866 L
.22369 .77631 L
F
.43298 .77631 m
.43298 .77866 L
.43533 .77866 L
.43533 .77631 L
F
.19547 .77866 m
.19547 .78101 L
.19782 .78101 L
.19782 .77866 L
F
.21664 .77866 m
.21664 .78101 L
.21899 .78101 L
.21899 .77866 L
F
.21899 .77866 m
.21899 .78101 L
.22134 .78101 L
.22134 .77866 L
F
.22134 .77866 m
.22134 .78101 L
.22369 .78101 L
.22369 .77866 L
F
.43063 .77866 m
.43063 .78101 L
.43298 .78101 L
.43298 .77866 L
F
.19312 .78101 m
.19312 .78336 L
.19547 .78336 L
.19547 .78101 L
F
.21429 .78101 m
.21429 .78336 L
.21664 .78336 L
.21664 .78101 L
F
.21664 .78101 m
.21664 .78336 L
.21899 .78336 L
.21899 .78101 L
F
.21899 .78101 m
.21899 .78336 L
.22134 .78336 L
.22134 .78101 L
F
.42828 .78101 m
.42828 .78336 L
.43063 .78336 L
.43063 .78101 L
F
.19077 .78336 m
.19077 .78571 L
.19312 .78571 L
.19312 .78336 L
F
.21193 .78336 m
.21193 .78571 L
.21429 .78571 L
.21429 .78336 L
F
.21429 .78336 m
.21429 .78571 L
.21664 .78571 L
.21664 .78336 L
F
.21664 .78336 m
.21664 .78571 L
.21899 .78571 L
.21899 .78336 L
F
.42593 .78336 m
.42593 .78571 L
.42828 .78571 L
.42828 .78336 L
F
.18842 .78571 m
.18842 .78807 L
.19077 .78807 L
.19077 .78571 L
F
.21193 .78571 m
.21193 .78807 L
.21429 .78807 L
.21429 .78571 L
F
.21429 .78571 m
.21429 .78807 L
.21664 .78807 L
.21664 .78571 L
F
.42357 .78571 m
.42357 .78807 L
.42593 .78807 L
.42593 .78571 L
F
.18607 .78807 m
.18607 .79042 L
.18842 .79042 L
.18842 .78807 L
F
.20723 .78807 m
.20723 .79042 L
.20958 .79042 L
.20958 .78807 L
F
.20958 .78807 m
.20958 .79042 L
.21193 .79042 L
.21193 .78807 L
F
.2331 .78807 m
.2331 .79042 L
.23545 .79042 L
.23545 .78807 L
F
.42122 .78807 m
.42122 .79042 L
.42357 .79042 L
.42357 .78807 L
F
.18372 .79042 m
.18372 .79277 L
.18607 .79277 L
.18607 .79042 L
F
.20488 .79042 m
.20488 .79277 L
.20723 .79277 L
.20723 .79042 L
F
.20723 .79042 m
.20723 .79277 L
.20958 .79277 L
.20958 .79042 L
F
.20958 .79042 m
.20958 .79277 L
.21193 .79277 L
.21193 .79042 L
F
.23075 .79042 m
.23075 .79277 L
.2331 .79277 L
.2331 .79042 L
F
.41887 .79042 m
.41887 .79277 L
.42122 .79277 L
.42122 .79042 L
F
.18136 .79277 m
.18136 .79512 L
.18372 .79512 L
.18372 .79277 L
F
.20253 .79277 m
.20253 .79512 L
.20488 .79512 L
.20488 .79277 L
F
.20488 .79277 m
.20488 .79512 L
.20723 .79512 L
.20723 .79277 L
F
.20723 .79277 m
.20723 .79512 L
.20958 .79512 L
.20958 .79277 L
F
.2284 .79277 m
.2284 .79512 L
.23075 .79512 L
.23075 .79277 L
F
.41652 .79277 m
.41652 .79512 L
.41887 .79512 L
.41887 .79277 L
F
.17901 .79512 m
.17901 .79747 L
.18136 .79747 L
.18136 .79512 L
F
.20018 .79512 m
.20018 .79747 L
.20253 .79747 L
.20253 .79512 L
F
.20253 .79512 m
.20253 .79747 L
.20488 .79747 L
.20488 .79512 L
F
.20488 .79512 m
.20488 .79747 L
.20723 .79747 L
.20723 .79512 L
F
.22604 .79512 m
.22604 .79747 L
.2284 .79747 L
.2284 .79512 L
F
.41417 .79512 m
.41417 .79747 L
.41652 .79747 L
.41652 .79512 L
F
.17666 .79747 m
.17666 .79982 L
.17901 .79982 L
.17901 .79747 L
F
.20018 .79747 m
.20018 .79982 L
.20253 .79982 L
.20253 .79747 L
F
.20253 .79747 m
.20253 .79982 L
.20488 .79982 L
.20488 .79747 L
F
.22369 .79747 m
.22369 .79982 L
.22604 .79982 L
.22604 .79747 L
F
.41182 .79747 m
.41182 .79982 L
.41417 .79982 L
.41417 .79747 L
F
.17431 .79982 m
.17431 .80218 L
.17666 .80218 L
.17666 .79982 L
F
.19547 .79982 m
.19547 .80218 L
.19782 .80218 L
.19782 .79982 L
F
.19782 .79982 m
.19782 .80218 L
.20018 .80218 L
.20018 .79982 L
F
.22134 .79982 m
.22134 .80218 L
.22369 .80218 L
.22369 .79982 L
F
.40947 .79982 m
.40947 .80218 L
.41182 .80218 L
.41182 .79982 L
F
.17196 .80218 m
.17196 .80453 L
.17431 .80453 L
.17431 .80218 L
F
.19312 .80218 m
.19312 .80453 L
.19547 .80453 L
.19547 .80218 L
F
.19547 .80218 m
.19547 .80453 L
.19782 .80453 L
.19782 .80218 L
F
.19782 .80218 m
.19782 .80453 L
.20018 .80453 L
.20018 .80218 L
F
.21899 .80218 m
.21899 .80453 L
.22134 .80453 L
.22134 .80218 L
F
.40711 .80218 m
.40711 .80453 L
.40947 .80453 L
.40947 .80218 L
F
.16961 .80453 m
.16961 .80688 L
.17196 .80688 L
.17196 .80453 L
F
.19077 .80453 m
.19077 .80688 L
.19312 .80688 L
.19312 .80453 L
F
.19312 .80453 m
.19312 .80688 L
.19547 .80688 L
.19547 .80453 L
F
.19547 .80453 m
.19547 .80688 L
.19782 .80688 L
.19782 .80453 L
F
.21664 .80453 m
.21664 .80688 L
.21899 .80688 L
.21899 .80453 L
F
.40476 .80453 m
.40476 .80688 L
.40711 .80688 L
.40711 .80453 L
F
.16725 .80688 m
.16725 .80923 L
.16961 .80923 L
.16961 .80688 L
F
.18842 .80688 m
.18842 .80923 L
.19077 .80923 L
.19077 .80688 L
F
.19077 .80688 m
.19077 .80923 L
.19312 .80923 L
.19312 .80688 L
F
.19312 .80688 m
.19312 .80923 L
.19547 .80923 L
.19547 .80688 L
F
.21429 .80688 m
.21429 .80923 L
.21664 .80923 L
.21664 .80688 L
F
.40241 .80688 m
.40241 .80923 L
.40476 .80923 L
.40476 .80688 L
F
.1649 .80923 m
.1649 .81158 L
.16725 .81158 L
.16725 .80923 L
F
.18842 .80923 m
.18842 .81158 L
.19077 .81158 L
.19077 .80923 L
F
.19077 .80923 m
.19077 .81158 L
.19312 .81158 L
.19312 .80923 L
F
.21193 .80923 m
.21193 .81158 L
.21429 .81158 L
.21429 .80923 L
F
.40006 .80923 m
.40006 .81158 L
.40241 .81158 L
.40241 .80923 L
F
.16255 .81158 m
.16255 .81393 L
.1649 .81393 L
.1649 .81158 L
F
.18372 .81158 m
.18372 .81393 L
.18607 .81393 L
.18607 .81158 L
F
.18607 .81158 m
.18607 .81393 L
.18842 .81393 L
.18842 .81158 L
F
.20958 .81158 m
.20958 .81393 L
.21193 .81393 L
.21193 .81158 L
F
.39771 .81158 m
.39771 .81393 L
.40006 .81393 L
.40006 .81158 L
F
.1602 .81393 m
.1602 .81628 L
.16255 .81628 L
.16255 .81393 L
F
.18136 .81393 m
.18136 .81628 L
.18372 .81628 L
.18372 .81393 L
F
.18372 .81393 m
.18372 .81628 L
.18607 .81628 L
.18607 .81393 L
F
.18607 .81393 m
.18607 .81628 L
.18842 .81628 L
.18842 .81393 L
F
.20723 .81393 m
.20723 .81628 L
.20958 .81628 L
.20958 .81393 L
F
.39536 .81393 m
.39536 .81628 L
.39771 .81628 L
.39771 .81393 L
F
.15785 .81628 m
.15785 .81864 L
.1602 .81864 L
.1602 .81628 L
F
.17901 .81628 m
.17901 .81864 L
.18136 .81864 L
.18136 .81628 L
F
.18136 .81628 m
.18136 .81864 L
.18372 .81864 L
.18372 .81628 L
F
.18372 .81628 m
.18372 .81864 L
.18607 .81864 L
.18607 .81628 L
F
.20488 .81628 m
.20488 .81864 L
.20723 .81864 L
.20723 .81628 L
F
.393 .81628 m
.393 .81864 L
.39536 .81864 L
.39536 .81628 L
F
.1555 .81864 m
.1555 .82099 L
.15785 .82099 L
.15785 .81864 L
F
.17666 .81864 m
.17666 .82099 L
.17901 .82099 L
.17901 .81864 L
F
.17901 .81864 m
.17901 .82099 L
.18136 .82099 L
.18136 .81864 L
F
.18136 .81864 m
.18136 .82099 L
.18372 .82099 L
.18372 .81864 L
F
.20253 .81864 m
.20253 .82099 L
.20488 .82099 L
.20488 .81864 L
F
.39065 .81864 m
.39065 .82099 L
.393 .82099 L
.393 .81864 L
F
.15315 .82099 m
.15315 .82334 L
.1555 .82334 L
.1555 .82099 L
F
.17666 .82099 m
.17666 .82334 L
.17901 .82334 L
.17901 .82099 L
F
.17901 .82099 m
.17901 .82334 L
.18136 .82334 L
.18136 .82099 L
F
.20018 .82099 m
.20018 .82334 L
.20253 .82334 L
.20253 .82099 L
F
.3883 .82099 m
.3883 .82334 L
.39065 .82334 L
.39065 .82099 L
F
.15079 .82334 m
.15079 .82569 L
.15315 .82569 L
.15315 .82334 L
F
.17196 .82334 m
.17196 .82569 L
.17431 .82569 L
.17431 .82334 L
F
.17431 .82334 m
.17431 .82569 L
.17666 .82569 L
.17666 .82334 L
F
.19782 .82334 m
.19782 .82569 L
.20018 .82569 L
.20018 .82334 L
F
.38595 .82334 m
.38595 .82569 L
.3883 .82569 L
.3883 .82334 L
F
.14844 .82569 m
.14844 .82804 L
.15079 .82804 L
.15079 .82569 L
F
.16961 .82569 m
.16961 .82804 L
.17196 .82804 L
.17196 .82569 L
F
.17196 .82569 m
.17196 .82804 L
.17431 .82804 L
.17431 .82569 L
F
.17431 .82569 m
.17431 .82804 L
.17666 .82804 L
.17666 .82569 L
F
.19547 .82569 m
.19547 .82804 L
.19782 .82804 L
.19782 .82569 L
F
.3836 .82569 m
.3836 .82804 L
.38595 .82804 L
.38595 .82569 L
F
.14609 .82804 m
.14609 .83039 L
.14844 .83039 L
.14844 .82804 L
F
.16725 .82804 m
.16725 .83039 L
.16961 .83039 L
.16961 .82804 L
F
.16961 .82804 m
.16961 .83039 L
.17196 .83039 L
.17196 .82804 L
F
.17196 .82804 m
.17196 .83039 L
.17431 .83039 L
.17431 .82804 L
F
.19312 .82804 m
.19312 .83039 L
.19547 .83039 L
.19547 .82804 L
F
.38125 .82804 m
.38125 .83039 L
.3836 .83039 L
.3836 .82804 L
F
.14374 .83039 m
.14374 .83275 L
.14609 .83275 L
.14609 .83039 L
F
.1649 .83039 m
.1649 .83275 L
.16725 .83275 L
.16725 .83039 L
F
.16725 .83039 m
.16725 .83275 L
.16961 .83275 L
.16961 .83039 L
F
.16961 .83039 m
.16961 .83275 L
.17196 .83275 L
.17196 .83039 L
F
.19077 .83039 m
.19077 .83275 L
.19312 .83275 L
.19312 .83039 L
F
.37889 .83039 m
.37889 .83275 L
.38125 .83275 L
.38125 .83039 L
F
.14139 .83275 m
.14139 .8351 L
.14374 .8351 L
.14374 .83275 L
F
.1649 .83275 m
.1649 .8351 L
.16725 .8351 L
.16725 .83275 L
F
.16725 .83275 m
.16725 .8351 L
.16961 .8351 L
.16961 .83275 L
F
.18842 .83275 m
.18842 .8351 L
.19077 .8351 L
.19077 .83275 L
F
.37654 .83275 m
.37654 .8351 L
.37889 .8351 L
.37889 .83275 L
F
.13904 .8351 m
.13904 .83745 L
.14139 .83745 L
.14139 .8351 L
F
.1602 .8351 m
.1602 .83745 L
.16255 .83745 L
.16255 .8351 L
F
.16255 .8351 m
.16255 .83745 L
.1649 .83745 L
.1649 .8351 L
F
.18607 .8351 m
.18607 .83745 L
.18842 .83745 L
.18842 .8351 L
F
.37419 .8351 m
.37419 .83745 L
.37654 .83745 L
.37654 .8351 L
F
.13668 .83745 m
.13668 .8398 L
.13904 .8398 L
.13904 .83745 L
F
.15785 .83745 m
.15785 .8398 L
.1602 .8398 L
.1602 .83745 L
F
.1602 .83745 m
.1602 .8398 L
.16255 .8398 L
.16255 .83745 L
F
.16255 .83745 m
.16255 .8398 L
.1649 .8398 L
.1649 .83745 L
F
.18372 .83745 m
.18372 .8398 L
.18607 .8398 L
.18607 .83745 L
F
.37184 .83745 m
.37184 .8398 L
.37419 .8398 L
.37419 .83745 L
F
.13433 .8398 m
.13433 .84215 L
.13668 .84215 L
.13668 .8398 L
F
.1555 .8398 m
.1555 .84215 L
.15785 .84215 L
.15785 .8398 L
F
.15785 .8398 m
.15785 .84215 L
.1602 .84215 L
.1602 .8398 L
F
.1602 .8398 m
.1602 .84215 L
.16255 .84215 L
.16255 .8398 L
F
.18136 .8398 m
.18136 .84215 L
.18372 .84215 L
.18372 .8398 L
F
.36949 .8398 m
.36949 .84215 L
.37184 .84215 L
.37184 .8398 L
F
.13198 .84215 m
.13198 .8445 L
.13433 .8445 L
.13433 .84215 L
F
.15315 .84215 m
.15315 .8445 L
.1555 .8445 L
.1555 .84215 L
F
.1555 .84215 m
.1555 .8445 L
.15785 .8445 L
.15785 .84215 L
F
.15785 .84215 m
.15785 .8445 L
.1602 .8445 L
.1602 .84215 L
F
.17901 .84215 m
.17901 .8445 L
.18136 .8445 L
.18136 .84215 L
F
.36714 .84215 m
.36714 .8445 L
.36949 .8445 L
.36949 .84215 L
F
.12963 .8445 m
.12963 .84685 L
.13198 .84685 L
.13198 .8445 L
F
.15315 .8445 m
.15315 .84685 L
.1555 .84685 L
.1555 .8445 L
F
.1555 .8445 m
.1555 .84685 L
.15785 .84685 L
.15785 .8445 L
F
.17666 .8445 m
.17666 .84685 L
.17901 .84685 L
.17901 .8445 L
F
.36479 .8445 m
.36479 .84685 L
.36714 .84685 L
.36714 .8445 L
F
.14844 .84685 m
.14844 .84921 L
.15079 .84921 L
.15079 .84685 L
F
.15079 .84685 m
.15079 .84921 L
.15315 .84921 L
.15315 .84685 L
F
.17431 .84685 m
.17431 .84921 L
.17666 .84921 L
.17666 .84685 L
F
.36243 .84685 m
.36243 .84921 L
.36479 .84921 L
.36479 .84685 L
F
.14609 .84921 m
.14609 .85156 L
.14844 .85156 L
.14844 .84921 L
F
.14844 .84921 m
.14844 .85156 L
.15079 .85156 L
.15079 .84921 L
F
.15079 .84921 m
.15079 .85156 L
.15315 .85156 L
.15315 .84921 L
F
.17196 .84921 m
.17196 .85156 L
.17431 .85156 L
.17431 .84921 L
F
.36008 .84921 m
.36008 .85156 L
.36243 .85156 L
.36243 .84921 L
F
.14374 .85156 m
.14374 .85391 L
.14609 .85391 L
.14609 .85156 L
F
.14609 .85156 m
.14609 .85391 L
.14844 .85391 L
.14844 .85156 L
F
.14844 .85156 m
.14844 .85391 L
.15079 .85391 L
.15079 .85156 L
F
.16961 .85156 m
.16961 .85391 L
.17196 .85391 L
.17196 .85156 L
F
.35773 .85156 m
.35773 .85391 L
.36008 .85391 L
.36008 .85156 L
F
.14139 .85391 m
.14139 .85626 L
.14374 .85626 L
.14374 .85391 L
F
.14374 .85391 m
.14374 .85626 L
.14609 .85626 L
.14609 .85391 L
F
.14609 .85391 m
.14609 .85626 L
.14844 .85626 L
.14844 .85391 L
F
.16725 .85391 m
.16725 .85626 L
.16961 .85626 L
.16961 .85391 L
F
.35538 .85391 m
.35538 .85626 L
.35773 .85626 L
.35773 .85391 L
F
.14139 .85626 m
.14139 .85861 L
.14374 .85861 L
.14374 .85626 L
F
.14374 .85626 m
.14374 .85861 L
.14609 .85861 L
.14609 .85626 L
F
.1649 .85626 m
.1649 .85861 L
.16725 .85861 L
.16725 .85626 L
F
.35303 .85626 m
.35303 .85861 L
.35538 .85861 L
.35538 .85626 L
F
.13668 .85861 m
.13668 .86096 L
.13904 .86096 L
.13904 .85861 L
F
.13904 .85861 m
.13904 .86096 L
.14139 .86096 L
.14139 .85861 L
F
.16255 .85861 m
.16255 .86096 L
.1649 .86096 L
.1649 .85861 L
F
.35068 .85861 m
.35068 .86096 L
.35303 .86096 L
.35303 .85861 L
F
.13433 .86096 m
.13433 .86332 L
.13668 .86332 L
.13668 .86096 L
F
.13668 .86096 m
.13668 .86332 L
.13904 .86332 L
.13904 .86096 L
F
.13904 .86096 m
.13904 .86332 L
.14139 .86332 L
.14139 .86096 L
F
.1602 .86096 m
.1602 .86332 L
.16255 .86332 L
.16255 .86096 L
F
.34832 .86096 m
.34832 .86332 L
.35068 .86332 L
.35068 .86096 L
F
.13198 .86332 m
.13198 .86567 L
.13433 .86567 L
.13433 .86332 L
F
.13433 .86332 m
.13433 .86567 L
.13668 .86567 L
.13668 .86332 L
F
.13668 .86332 m
.13668 .86567 L
.13904 .86567 L
.13904 .86332 L
F
.15785 .86332 m
.15785 .86567 L
.1602 .86567 L
.1602 .86332 L
F
.34597 .86332 m
.34597 .86567 L
.34832 .86567 L
.34832 .86332 L
F
.12963 .86567 m
.12963 .86802 L
.13198 .86802 L
.13198 .86567 L
F
.13198 .86567 m
.13198 .86802 L
.13433 .86802 L
.13433 .86567 L
F
.13433 .86567 m
.13433 .86802 L
.13668 .86802 L
.13668 .86567 L
F
.1555 .86567 m
.1555 .86802 L
.15785 .86802 L
.15785 .86567 L
F
.34362 .86567 m
.34362 .86802 L
.34597 .86802 L
.34597 .86567 L
F
.12963 .86802 m
.12963 .87037 L
.13198 .87037 L
.13198 .86802 L
F
.13198 .86802 m
.13198 .87037 L
.13433 .87037 L
.13433 .86802 L
F
.15315 .86802 m
.15315 .87037 L
.1555 .87037 L
.1555 .86802 L
F
.34127 .86802 m
.34127 .87037 L
.34362 .87037 L
.34362 .86802 L
F
.10376 .87037 m
.10376 .87272 L
.10611 .87272 L
.10611 .87037 L
F
.12493 .87037 m
.12493 .87272 L
.12728 .87272 L
.12728 .87037 L
F
.12728 .87037 m
.12728 .87272 L
.12963 .87272 L
.12963 .87037 L
F
.33892 .87037 m
.33892 .87272 L
.34127 .87272 L
.34127 .87037 L
F
.10141 .87272 m
.10141 .87507 L
.10376 .87507 L
.10376 .87272 L
F
.12257 .87272 m
.12257 .87507 L
.12493 .87507 L
.12493 .87272 L
F
.12493 .87272 m
.12493 .87507 L
.12728 .87507 L
.12728 .87272 L
F
.12728 .87272 m
.12728 .87507 L
.12963 .87507 L
.12963 .87272 L
F
.33657 .87272 m
.33657 .87507 L
.33892 .87507 L
.33892 .87272 L
F
.09906 .87507 m
.09906 .87743 L
.10141 .87743 L
.10141 .87507 L
F
.12022 .87507 m
.12022 .87743 L
.12257 .87743 L
.12257 .87507 L
F
.12257 .87507 m
.12257 .87743 L
.12493 .87743 L
.12493 .87507 L
F
.12493 .87507 m
.12493 .87743 L
.12728 .87743 L
.12728 .87507 L
F
.33422 .87507 m
.33422 .87743 L
.33657 .87743 L
.33657 .87507 L
F
.09671 .87743 m
.09671 .87978 L
.09906 .87978 L
.09906 .87743 L
F
.11787 .87743 m
.11787 .87978 L
.12022 .87978 L
.12022 .87743 L
F
.12022 .87743 m
.12022 .87978 L
.12257 .87978 L
.12257 .87743 L
F
.12257 .87743 m
.12257 .87978 L
.12493 .87978 L
.12493 .87743 L
F
.33186 .87743 m
.33186 .87978 L
.33422 .87978 L
.33422 .87743 L
F
.09436 .87978 m
.09436 .88213 L
.09671 .88213 L
.09671 .87978 L
F
.11787 .87978 m
.11787 .88213 L
.12022 .88213 L
.12022 .87978 L
F
.12022 .87978 m
.12022 .88213 L
.12257 .88213 L
.12257 .87978 L
F
.32951 .87978 m
.32951 .88213 L
.33186 .88213 L
.33186 .87978 L
F
.092 .88213 m
.092 .88448 L
.09436 .88448 L
.09436 .88213 L
F
.11317 .88213 m
.11317 .88448 L
.11552 .88448 L
.11552 .88213 L
F
.11552 .88213 m
.11552 .88448 L
.11787 .88448 L
.11787 .88213 L
F
.32716 .88213 m
.32716 .88448 L
.32951 .88448 L
.32951 .88213 L
F
.08965 .88448 m
.08965 .88683 L
.092 .88683 L
.092 .88448 L
F
.11082 .88448 m
.11082 .88683 L
.11317 .88683 L
.11317 .88448 L
F
.11317 .88448 m
.11317 .88683 L
.11552 .88683 L
.11552 .88448 L
F
.11552 .88448 m
.11552 .88683 L
.11787 .88683 L
.11787 .88448 L
F
.32481 .88448 m
.32481 .88683 L
.32716 .88683 L
.32716 .88448 L
F
.0873 .88683 m
.0873 .88918 L
.08965 .88918 L
.08965 .88683 L
F
.10847 .88683 m
.10847 .88918 L
.11082 .88918 L
.11082 .88683 L
F
.11082 .88683 m
.11082 .88918 L
.11317 .88918 L
.11317 .88683 L
F
.11317 .88683 m
.11317 .88918 L
.11552 .88918 L
.11552 .88683 L
F
.32246 .88683 m
.32246 .88918 L
.32481 .88918 L
.32481 .88683 L
F
.08495 .88918 m
.08495 .89153 L
.0873 .89153 L
.0873 .88918 L
F
.10611 .88918 m
.10611 .89153 L
.10847 .89153 L
.10847 .88918 L
F
.10847 .88918 m
.10847 .89153 L
.11082 .89153 L
.11082 .88918 L
F
.11082 .88918 m
.11082 .89153 L
.11317 .89153 L
.11317 .88918 L
F
.32011 .88918 m
.32011 .89153 L
.32246 .89153 L
.32246 .88918 L
F
.0826 .89153 m
.0826 .89389 L
.08495 .89389 L
.08495 .89153 L
F
.10611 .89153 m
.10611 .89389 L
.10847 .89389 L
.10847 .89153 L
F
.10847 .89153 m
.10847 .89389 L
.11082 .89389 L
.11082 .89153 L
F
.31775 .89153 m
.31775 .89389 L
.32011 .89389 L
.32011 .89153 L
F
.08025 .89389 m
.08025 .89624 L
.0826 .89624 L
.0826 .89389 L
F
.10141 .89389 m
.10141 .89624 L
.10376 .89624 L
.10376 .89389 L
F
.10376 .89389 m
.10376 .89624 L
.10611 .89624 L
.10611 .89389 L
F
.12728 .89389 m
.12728 .89624 L
.12963 .89624 L
.12963 .89389 L
F
.3154 .89389 m
.3154 .89624 L
.31775 .89624 L
.31775 .89389 L
F
.0779 .89624 m
.0779 .89859 L
.08025 .89859 L
.08025 .89624 L
F
.09906 .89624 m
.09906 .89859 L
.10141 .89859 L
.10141 .89624 L
F
.10141 .89624 m
.10141 .89859 L
.10376 .89859 L
.10376 .89624 L
F
.10376 .89624 m
.10376 .89859 L
.10611 .89859 L
.10611 .89624 L
F
.12493 .89624 m
.12493 .89859 L
.12728 .89859 L
.12728 .89624 L
F
.31305 .89624 m
.31305 .89859 L
.3154 .89859 L
.3154 .89624 L
F
.07554 .89859 m
.07554 .90094 L
.0779 .90094 L
.0779 .89859 L
F
.09671 .89859 m
.09671 .90094 L
.09906 .90094 L
.09906 .89859 L
F
.09906 .89859 m
.09906 .90094 L
.10141 .90094 L
.10141 .89859 L
F
.10141 .89859 m
.10141 .90094 L
.10376 .90094 L
.10376 .89859 L
F
.12257 .89859 m
.12257 .90094 L
.12493 .90094 L
.12493 .89859 L
F
.3107 .89859 m
.3107 .90094 L
.31305 .90094 L
.31305 .89859 L
F
.07319 .90094 m
.07319 .90329 L
.07554 .90329 L
.07554 .90094 L
F
.09436 .90094 m
.09436 .90329 L
.09671 .90329 L
.09671 .90094 L
F
.09671 .90094 m
.09671 .90329 L
.09906 .90329 L
.09906 .90094 L
F
.09906 .90094 m
.09906 .90329 L
.10141 .90329 L
.10141 .90094 L
F
.12022 .90094 m
.12022 .90329 L
.12257 .90329 L
.12257 .90094 L
F
.30835 .90094 m
.30835 .90329 L
.3107 .90329 L
.3107 .90094 L
F
.07084 .90329 m
.07084 .90564 L
.07319 .90564 L
.07319 .90329 L
F
.09436 .90329 m
.09436 .90564 L
.09671 .90564 L
.09671 .90329 L
F
.09671 .90329 m
.09671 .90564 L
.09906 .90564 L
.09906 .90329 L
F
.11787 .90329 m
.11787 .90564 L
.12022 .90564 L
.12022 .90329 L
F
.306 .90329 m
.306 .90564 L
.30835 .90564 L
.30835 .90329 L
F
.06849 .90564 m
.06849 .908 L
.07084 .908 L
.07084 .90564 L
F
.08965 .90564 m
.08965 .908 L
.092 .908 L
.092 .90564 L
F
.092 .90564 m
.092 .908 L
.09436 .908 L
.09436 .90564 L
F
.11552 .90564 m
.11552 .908 L
.11787 .908 L
.11787 .90564 L
F
.30364 .90564 m
.30364 .908 L
.306 .908 L
.306 .90564 L
F
.06614 .908 m
.06614 .91035 L
.06849 .91035 L
.06849 .908 L
F
.0873 .908 m
.0873 .91035 L
.08965 .91035 L
.08965 .908 L
F
.08965 .908 m
.08965 .91035 L
.092 .91035 L
.092 .908 L
F
.092 .908 m
.092 .91035 L
.09436 .91035 L
.09436 .908 L
F
.11317 .908 m
.11317 .91035 L
.11552 .91035 L
.11552 .908 L
F
.30129 .908 m
.30129 .91035 L
.30364 .91035 L
.30364 .908 L
F
.06379 .91035 m
.06379 .9127 L
.06614 .9127 L
.06614 .91035 L
F
.08495 .91035 m
.08495 .9127 L
.0873 .9127 L
.0873 .91035 L
F
.0873 .91035 m
.0873 .9127 L
.08965 .9127 L
.08965 .91035 L
F
.08965 .91035 m
.08965 .9127 L
.092 .9127 L
.092 .91035 L
F
.11082 .91035 m
.11082 .9127 L
.11317 .9127 L
.11317 .91035 L
F
.29894 .91035 m
.29894 .9127 L
.30129 .9127 L
.30129 .91035 L
F
.06143 .9127 m
.06143 .91505 L
.06379 .91505 L
.06379 .9127 L
F
.0826 .9127 m
.0826 .91505 L
.08495 .91505 L
.08495 .9127 L
F
.08495 .9127 m
.08495 .91505 L
.0873 .91505 L
.0873 .9127 L
F
.0873 .9127 m
.0873 .91505 L
.08965 .91505 L
.08965 .9127 L
F
.10847 .9127 m
.10847 .91505 L
.11082 .91505 L
.11082 .9127 L
F
.29659 .9127 m
.29659 .91505 L
.29894 .91505 L
.29894 .9127 L
F
.05908 .91505 m
.05908 .9174 L
.06143 .9174 L
.06143 .91505 L
F
.0826 .91505 m
.0826 .9174 L
.08495 .9174 L
.08495 .91505 L
F
.08495 .91505 m
.08495 .9174 L
.0873 .9174 L
.0873 .91505 L
F
.10611 .91505 m
.10611 .9174 L
.10847 .9174 L
.10847 .91505 L
F
.29424 .91505 m
.29424 .9174 L
.29659 .9174 L
.29659 .91505 L
F
.05673 .9174 m
.05673 .91975 L
.05908 .91975 L
.05908 .9174 L
F
.0779 .9174 m
.0779 .91975 L
.08025 .91975 L
.08025 .9174 L
F
.08025 .9174 m
.08025 .91975 L
.0826 .91975 L
.0826 .9174 L
F
.10376 .9174 m
.10376 .91975 L
.10611 .91975 L
.10611 .9174 L
F
.29189 .9174 m
.29189 .91975 L
.29424 .91975 L
.29424 .9174 L
F
.05438 .91975 m
.05438 .9221 L
.05673 .9221 L
.05673 .91975 L
F
.07554 .91975 m
.07554 .9221 L
.0779 .9221 L
.0779 .91975 L
F
.0779 .91975 m
.0779 .9221 L
.08025 .9221 L
.08025 .91975 L
F
.08025 .91975 m
.08025 .9221 L
.0826 .9221 L
.0826 .91975 L
F
.10141 .91975 m
.10141 .9221 L
.10376 .9221 L
.10376 .91975 L
F
.28954 .91975 m
.28954 .9221 L
.29189 .9221 L
.29189 .91975 L
F
.05203 .9221 m
.05203 .92446 L
.05438 .92446 L
.05438 .9221 L
F
.07319 .9221 m
.07319 .92446 L
.07554 .92446 L
.07554 .9221 L
F
.07554 .9221 m
.07554 .92446 L
.0779 .92446 L
.0779 .9221 L
F
.0779 .9221 m
.0779 .92446 L
.08025 .92446 L
.08025 .9221 L
F
.09906 .9221 m
.09906 .92446 L
.10141 .92446 L
.10141 .9221 L
F
.28718 .9221 m
.28718 .92446 L
.28954 .92446 L
.28954 .9221 L
F
.04968 .92446 m
.04968 .92681 L
.05203 .92681 L
.05203 .92446 L
F
.07084 .92446 m
.07084 .92681 L
.07319 .92681 L
.07319 .92446 L
F
.07319 .92446 m
.07319 .92681 L
.07554 .92681 L
.07554 .92446 L
F
.07554 .92446 m
.07554 .92681 L
.0779 .92681 L
.0779 .92446 L
F
.09671 .92446 m
.09671 .92681 L
.09906 .92681 L
.09906 .92446 L
F
.28483 .92446 m
.28483 .92681 L
.28718 .92681 L
.28718 .92446 L
F
.04733 .92681 m
.04733 .92916 L
.04968 .92916 L
.04968 .92681 L
F
.07084 .92681 m
.07084 .92916 L
.07319 .92916 L
.07319 .92681 L
F
.07319 .92681 m
.07319 .92916 L
.07554 .92916 L
.07554 .92681 L
F
.09436 .92681 m
.09436 .92916 L
.09671 .92916 L
.09671 .92681 L
F
.28248 .92681 m
.28248 .92916 L
.28483 .92916 L
.28483 .92681 L
F
.04497 .92916 m
.04497 .93151 L
.04733 .93151 L
.04733 .92916 L
F
.06614 .92916 m
.06614 .93151 L
.06849 .93151 L
.06849 .92916 L
F
.06849 .92916 m
.06849 .93151 L
.07084 .93151 L
.07084 .92916 L
F
.092 .92916 m
.092 .93151 L
.09436 .93151 L
.09436 .92916 L
F
.28013 .92916 m
.28013 .93151 L
.28248 .93151 L
.28248 .92916 L
F
.04262 .93151 m
.04262 .93386 L
.04497 .93386 L
.04497 .93151 L
F
.06379 .93151 m
.06379 .93386 L
.06614 .93386 L
.06614 .93151 L
F
.06614 .93151 m
.06614 .93386 L
.06849 .93386 L
.06849 .93151 L
F
.06849 .93151 m
.06849 .93386 L
.07084 .93386 L
.07084 .93151 L
F
.08965 .93151 m
.08965 .93386 L
.092 .93386 L
.092 .93151 L
F
.27778 .93151 m
.27778 .93386 L
.28013 .93386 L
.28013 .93151 L
F
.04027 .93386 m
.04027 .93621 L
.04262 .93621 L
.04262 .93386 L
F
.06143 .93386 m
.06143 .93621 L
.06379 .93621 L
.06379 .93386 L
F
.06379 .93386 m
.06379 .93621 L
.06614 .93621 L
.06614 .93386 L
F
.06614 .93386 m
.06614 .93621 L
.06849 .93621 L
.06849 .93386 L
F
.0873 .93386 m
.0873 .93621 L
.08965 .93621 L
.08965 .93386 L
F
.27543 .93386 m
.27543 .93621 L
.27778 .93621 L
.27778 .93386 L
F
.03792 .93621 m
.03792 .93857 L
.04027 .93857 L
.04027 .93621 L
F
.05908 .93621 m
.05908 .93857 L
.06143 .93857 L
.06143 .93621 L
F
.06143 .93621 m
.06143 .93857 L
.06379 .93857 L
.06379 .93621 L
F
.06379 .93621 m
.06379 .93857 L
.06614 .93857 L
.06614 .93621 L
F
.08495 .93621 m
.08495 .93857 L
.0873 .93857 L
.0873 .93621 L
F
.27307 .93621 m
.27307 .93857 L
.27543 .93857 L
.27543 .93621 L
F
.03557 .93857 m
.03557 .94092 L
.03792 .94092 L
.03792 .93857 L
F
.05908 .93857 m
.05908 .94092 L
.06143 .94092 L
.06143 .93857 L
F
.06143 .93857 m
.06143 .94092 L
.06379 .94092 L
.06379 .93857 L
F
.0826 .93857 m
.0826 .94092 L
.08495 .94092 L
.08495 .93857 L
F
.27072 .93857 m
.27072 .94092 L
.27307 .94092 L
.27307 .93857 L
F
.03322 .94092 m
.03322 .94327 L
.03557 .94327 L
.03557 .94092 L
F
.05438 .94092 m
.05438 .94327 L
.05673 .94327 L
.05673 .94092 L
F
.05673 .94092 m
.05673 .94327 L
.05908 .94327 L
.05908 .94092 L
F
.08025 .94092 m
.08025 .94327 L
.0826 .94327 L
.0826 .94092 L
F
.26837 .94092 m
.26837 .94327 L
.27072 .94327 L
.27072 .94092 L
F
.03086 .94327 m
.03086 .94562 L
.03322 .94562 L
.03322 .94327 L
F
.05203 .94327 m
.05203 .94562 L
.05438 .94562 L
.05438 .94327 L
F
.05438 .94327 m
.05438 .94562 L
.05673 .94562 L
.05673 .94327 L
F
.05673 .94327 m
.05673 .94562 L
.05908 .94562 L
.05908 .94327 L
F
.0779 .94327 m
.0779 .94562 L
.08025 .94562 L
.08025 .94327 L
F
.26602 .94327 m
.26602 .94562 L
.26837 .94562 L
.26837 .94327 L
F
.02851 .94562 m
.02851 .94797 L
.03086 .94797 L
.03086 .94562 L
F
.04968 .94562 m
.04968 .94797 L
.05203 .94797 L
.05203 .94562 L
F
.05203 .94562 m
.05203 .94797 L
.05438 .94797 L
.05438 .94562 L
F
.05438 .94562 m
.05438 .94797 L
.05673 .94797 L
.05673 .94562 L
F
.07554 .94562 m
.07554 .94797 L
.0779 .94797 L
.0779 .94562 L
F
.26367 .94562 m
.26367 .94797 L
.26602 .94797 L
.26602 .94562 L
F
.02616 .94797 m
.02616 .95032 L
.02851 .95032 L
.02851 .94797 L
F
.04733 .94797 m
.04733 .95032 L
.04968 .95032 L
.04968 .94797 L
F
.04968 .94797 m
.04968 .95032 L
.05203 .95032 L
.05203 .94797 L
F
.05203 .94797 m
.05203 .95032 L
.05438 .95032 L
.05438 .94797 L
F
.07319 .94797 m
.07319 .95032 L
.07554 .95032 L
.07554 .94797 L
F
.26132 .94797 m
.26132 .95032 L
.26367 .95032 L
.26367 .94797 L
F
.02381 .95032 m
.02381 .95267 L
.02616 .95267 L
.02616 .95032 L
F
.04733 .95032 m
.04733 .95267 L
.04968 .95267 L
.04968 .95032 L
F
.04968 .95032 m
.04968 .95267 L
.05203 .95267 L
.05203 .95032 L
F
.07084 .95032 m
.07084 .95267 L
.07319 .95267 L
.07319 .95032 L
F
.25897 .95032 m
.25897 .95267 L
.26132 .95267 L
.26132 .95032 L
F
.04262 .95267 m
.04262 .95503 L
.04497 .95503 L
.04497 .95267 L
F
.04497 .95267 m
.04497 .95503 L
.04733 .95503 L
.04733 .95267 L
F
.06849 .95267 m
.06849 .95503 L
.07084 .95503 L
.07084 .95267 L
F
.25661 .95267 m
.25661 .95503 L
.25897 .95503 L
.25897 .95267 L
F
.04027 .95503 m
.04027 .95738 L
.04262 .95738 L
.04262 .95503 L
F
.04262 .95503 m
.04262 .95738 L
.04497 .95738 L
.04497 .95503 L
F
.04497 .95503 m
.04497 .95738 L
.04733 .95738 L
.04733 .95503 L
F
.06614 .95503 m
.06614 .95738 L
.06849 .95738 L
.06849 .95503 L
F
.25426 .95503 m
.25426 .95738 L
.25661 .95738 L
.25661 .95503 L
F
.03792 .95738 m
.03792 .95973 L
.04027 .95973 L
.04027 .95738 L
F
.04027 .95738 m
.04027 .95973 L
.04262 .95973 L
.04262 .95738 L
F
.04262 .95738 m
.04262 .95973 L
.04497 .95973 L
.04497 .95738 L
F
.06379 .95738 m
.06379 .95973 L
.06614 .95973 L
.06614 .95738 L
F
.25191 .95738 m
.25191 .95973 L
.25426 .95973 L
.25426 .95738 L
F
.03557 .95973 m
.03557 .96208 L
.03792 .96208 L
.03792 .95973 L
F
.03792 .95973 m
.03792 .96208 L
.04027 .96208 L
.04027 .95973 L
F
.04027 .95973 m
.04027 .96208 L
.04262 .96208 L
.04262 .95973 L
F
.06143 .95973 m
.06143 .96208 L
.06379 .96208 L
.06379 .95973 L
F
.24956 .95973 m
.24956 .96208 L
.25191 .96208 L
.25191 .95973 L
F
.03557 .96208 m
.03557 .96443 L
.03792 .96443 L
.03792 .96208 L
F
.03792 .96208 m
.03792 .96443 L
.04027 .96443 L
.04027 .96208 L
F
.05908 .96208 m
.05908 .96443 L
.06143 .96443 L
.06143 .96208 L
F
.24721 .96208 m
.24721 .96443 L
.24956 .96443 L
.24956 .96208 L
F
.03086 .96443 m
.03086 .96678 L
.03322 .96678 L
.03322 .96443 L
F
.03322 .96443 m
.03322 .96678 L
.03557 .96678 L
.03557 .96443 L
F
.05673 .96443 m
.05673 .96678 L
.05908 .96678 L
.05908 .96443 L
F
.24486 .96443 m
.24486 .96678 L
.24721 .96678 L
.24721 .96443 L
F
.02851 .96678 m
.02851 .96914 L
.03086 .96914 L
.03086 .96678 L
F
.03086 .96678 m
.03086 .96914 L
.03322 .96914 L
.03322 .96678 L
F
.03322 .96678 m
.03322 .96914 L
.03557 .96914 L
.03557 .96678 L
F
.05438 .96678 m
.05438 .96914 L
.05673 .96914 L
.05673 .96678 L
F
.2425 .96678 m
.2425 .96914 L
.24486 .96914 L
.24486 .96678 L
F
.02616 .96914 m
.02616 .97149 L
.02851 .97149 L
.02851 .96914 L
F
.02851 .96914 m
.02851 .97149 L
.03086 .97149 L
.03086 .96914 L
F
.03086 .96914 m
.03086 .97149 L
.03322 .97149 L
.03322 .96914 L
F
.05203 .96914 m
.05203 .97149 L
.05438 .97149 L
.05438 .96914 L
F
.24015 .96914 m
.24015 .97149 L
.2425 .97149 L
.2425 .96914 L
F
.02381 .97149 m
.02381 .97384 L
.02616 .97384 L
.02616 .97149 L
F
.02616 .97149 m
.02616 .97384 L
.02851 .97384 L
.02851 .97149 L
F
.02851 .97149 m
.02851 .97384 L
.03086 .97384 L
.03086 .97149 L
F
.04968 .97149 m
.04968 .97384 L
.05203 .97384 L
.05203 .97149 L
F
.2378 .97149 m
.2378 .97384 L
.24015 .97384 L
.24015 .97149 L
F
.02381 .97384 m
.02381 .97619 L
.02616 .97619 L
.02616 .97384 L
F
.02616 .97384 m
.02616 .97619 L
.02851 .97619 L
.02851 .97384 L
F
.04733 .97384 m
.04733 .97619 L
.04968 .97619 L
.04968 .97384 L
F
.23545 .97384 m
.23545 .97619 L
.2378 .97619 L
.2378 .97384 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[92]:=",
  ImageSize->{288, 288},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006@3oool5
000002h0oooo100000030?ooo`800000103oool2000002`0oooo0`0000020?ooo`800000103oool2
000002/0oooo0`0000040?ooo`800000103oool2000002h0oooo0P0000030?ooo`D000000P3oool2
000001H0oooo000K0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000002`0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002`0oooo00@0
00000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool04`3oool001/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000:@3oool5000000050?ooo`000000oooo
0?ooo`0000000P3oool010000000oooo0?ooo`00000Z0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01<0oooo000K
0?ooo`030000003oool0oooo0300oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000]0?ooo`8000001@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool04`3oool001/0oooo00<000000?ooo`3oool0
;P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000:P3oool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000:`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000;03oool010000000oooo0?ooo`0000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0C0?ooo`006P3oool200000340oooo0P000004
0?ooo`800000103oool2000002`0oooo0P0000030?ooo`800000103oool2000002`0oooo0`000003
0?ooo`800000103oool2000002h0oooo0P0000040?ooo`800000103oool2000001H0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo000E0?ooooD000005P3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001D0oooo00<0
00000?ooo`3oool0l@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`3a
0?ooo`030000003oool0oooo01@0oooo00020?ooo`8000000`3oool500000080oooo0P0000050?oo
o`030000003oool0oooo0?40oooo00<000000?ooo`3oool00`3oool2000000<0oooo1@0000020?oo
o`8000000`3oool000050?ooo`000000oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo
0@0000010?ooo`40oooo00001@3oool000000?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo0P00002h0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`040000003oool0oooo0000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`4000000@3oool10?ooo`000P3oool20000
00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0]P3oool2000002`0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`03
0?ooo`8000001@3oool01@000000oooo0?ooo`3oool000000080oooo0@0000010?ooo`40oooo0000
1@3oool000000?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0[0?ooo`800000
0`3oool3000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool100000040oooo0@3oool00080oooo0P0000040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0080oooo0`0000070?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`80
0000103oool2000000<0oooo000E0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`020?ooo`<00000203oool00`000000oooo0?ooo`0D0?ooo`005@3o
ool00`000000oooo0?ooo`2b0?ooo`800000;03oool2000000<0oooo0`0000090?ooo`030000003o
ool0oooo01@0oooo000E0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0:`3oool2
000000<0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`00
0000oooo0?ooo`2`0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool30000
00<0oooo0P0000060?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`<00000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0:h0oooo
0P00000/0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool00P3oool3000000<0oooo0P0000090?ooo`030000003oool0oooo01@0oooo000E
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`02
0?ooo`<000000`3oool2000000X0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?oo
o`3oool0Z`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0`0000040?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3o
ool0ZP3oool2000002`0oooo0P0000030?ooo`<00000103oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool2000000d0oooo00<000000?ooo`3oool0
503oool001D0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0080oooo0`0000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0503o
ool001D0oooo00<000000?ooo`3oool0Y`3oool2000002`0oooo0P0000030?ooo`<00000103oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo
0:H0oooo0P00000/0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool00P3oool3000000<0oooo0P00000A0?ooo`030000003oool0oooo01@0
oooo000E0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`020?ooo`<00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo
000E0?ooo`030000003oool0oooo0:<0oooo0P00000]0?ooo`040000003oool0oooo0?ooo`<00000
103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003o
ool0oooo0:80oooo00<000000?ooo`3oool0<03oool3000000<0oooo0P00000D0?ooo`030000003o
ool0oooo01@0oooo000E0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0<@3oool2
000000<0oooo0P00000E0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0<03oool2000000D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`2O0?ooo`800000<@3oool3000000@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo0300oooo0`0000030?ooo`800000603oool00`000000oooo
0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool00P3oool3000001h0oooo00<000000?ooo`3oool0503oool001D0oooo00<00000
0?ooo`3oool0W03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0`00000O
0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo09/0oooo0P00000/0?oo
o`8000000`3oool300000200oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3o
ool0VP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0`00000Q0?ooo`03
0000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`020?ooo`<000008P3oool00`000000oooo0?ooo`0D0?ooo`005@3o
ool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool3000002<0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0U`3oool2
000002`0oooo0P0000030?ooo`<00000103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01@0oooo000E0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool200000200oooo00<000000?ooo`3oool0503oool001D0
oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080
oooo0`0000040?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool001D0oooo
00<000000?ooo`3oool0U03oool2000002`0oooo0P0000030?ooo`<00000103oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo09<0oooo0P00
000/0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0D0?ooo`005@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool00P3oool3000000<0oooo0P00000T0?ooo`030000003oool0oooo01@0oooo000E0?oo
o`030000003oool0oooo0940oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?oo
o`<00000103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01@0oooo000E0?ooo`03
0000003oool0oooo0900oooo0P00000/0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo02/0oooo0P0000030?ooo`<000000`3oool2000002L0oooo00<000000?ooo`3oool0
503oool001D0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0080oooo0`0000030?ooo`800000:03oool00`000000oooo0?ooo`0D0?ooo`005@3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool3
000000@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`00
0000oooo0?ooo`2<0?ooo`800000;03oool2000000<0oooo0`0000040?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0R`3oool00`000000
oooo0?ooo`0[0?ooo`8000000`3oool3000000<0oooo0P00000[0?ooo`030000003oool0oooo01@0
oooo000E0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`030?ooo`8000000`3oool2000002`0oooo00<000000?ooo`3oool0503oool001D0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`0`0?ooo`8000001@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo08P0oooo0P00000a
0?ooo`<00000103oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01@0oooo000E0?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool0<03oool3000000<0oooo0P00000_0?oo
o`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0<03oool3000000<0oooo0P00000`0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0<03oool3000000@0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`240?ooo`800000<@3o
ool3000000@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0D0?ooo`005@3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool3
00000340oooo0P0000050?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo
0880oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`<00000<P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0840
oooo0P00000/0?ooo`8000000`3oool300000380oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`200?ooo`800000;03oool2000000<0oooo
0`00000b0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool001D0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0`00
000a0?ooo`8000002@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool300000380oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`0000@0oooo0000000000000000103oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo07d0oooo0P00000/0?ooo`8000000`3oool3
000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0080oooo0`0000040?ooo`800000103oool2000000<0oooo00001@3oool000000?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool0:`3oool2000000<0oooo0`0000030?ooo`800000
;@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00001@3o
ool000000?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`800000O03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo
0`0000030?ooo`800000;03oool2000000`0oooo0P0000040?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`0000@0oooo0000
0000000000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo
0`0000040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`020?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo07T0oooo0P00000/0?ooo`8000000`3oool3
000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00020?ooo`<000000`3oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0:`3oool2000000<0oooo0`0000030?ooo`800000;@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`800000103o
ool2000000<0oooo000E0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`020?ooo`<000000`3oool2000002`0oooo0P00000A0?ooo`030000003oool0
oooo01@0oooo000E0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`020?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0M@3oool2000002`0
oooo0P0000030?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`800000;03oool2000001@0oooo
00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`800000;03oool2000001D0oooo00<0
00000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`1a0?oo
o`800000;03oool2000000<0oooo0`0000040?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0P00000/0?ooo`80
0000603oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo0300oooo0P0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`1^0?ooo`800000<@3o
ool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01@0oooo000E0?ooo`030000003oool0oooo06d0oooo0P00000a0?ooo`<00000103oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0503oool0
01D0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0`0?ooo`<000000`3oool20000
02`0oooo0P00000L0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0<03oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo06X0oooo
0P00000/0?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?oo
o`1Y0?ooo`030000003oool0oooo02/0oooo0P0000030?ooo`<00000<P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`<00000<@3oool200000200oooo00<00000
0?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0080oooo0`00000b0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0503oool001D0oooo00<000000?ooo`3oool0IP3oool2000002`0oooo0P0000030?ooo`<0
0000<P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0:`3oool2000000<0oooo0`00000b0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`800000;03o
ool2000002@0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`00
0000oooo0?ooo`1R0?ooo`800000;03oool2000000<0oooo0`0000040?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool3000000<0
oooo0P00000/0?ooo`8000009`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool3000000<0oooo
0P00000/0?ooo`800000:03oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01@0oooo000E
0?ooo`030000003oool0oooo05h0oooo0P00000/0?ooo`8000000`3oool3000000@0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01@0oooo000E0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?oo
o`<000000`3oool2000002`0oooo0P00000[0?ooo`030000003oool0oooo01@0oooo000E0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`<0
0000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0503oool001D0oooo00<000000?ooo`3oool0F`3oool2000002`0oooo0P0000030?ooo`<00000
103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
503oool001D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0[0?ooo`8000000`3o
ool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo01@0oooo000E0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`030?ooo`8000000`3oool2000002`0oooo0P00000_0?ooo`030000003oool0
oooo01@0oooo000E0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0E`3oool2000002`0
oooo0P0000030?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0[0?ooo`8000000`3oool3000000<0oooo0P00000]0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0`0?ooo`<000000`3oool2000002`0oooo0P00000c0?ooo`030000003oool0oooo01@0oooo000E
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0<03oool3000000@0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01@0oooo000E0?oo
o`030000003oool0oooo05<0oooo0P00000a0?ooo`<00000103oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0`0?ooo`<000000`3oool2000002d0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo0300oooo0`0000030?ooo`800000;03oool2000003L0oooo00<000000?ooo`3oool0
503oool001D0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0080oooo0`0000040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`1?0?ooo`800000;03oool2
000000<0oooo0`00000b0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool0
01D0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0080oooo0`00000a0?ooo`800000>P3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool300000340
oooo0P00000k0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`<00000<P3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo04/0oooo0P00
000/0?ooo`8000000`3oool300000380oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0D0?ooo`005@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool00P3oool3000000<0oooo0P00000/0?ooo`800000?P3oool00`000000oooo0?ooo`0D
0?ooo`005@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo04P0oooo0P00000/0?ooo`80
00000`3oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
:`3oool2000000<0oooo0`0000040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0P00000/0?ooo`800000@P3o
ool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo
04@0oooo0P00000/0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo01@0oooo00030?ooo`<000000P3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0:`3oool2000000<0
oooo0`0000030?ooo`800000;@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0
oooo0`0000020?ooo`800000103oool2000000<0oooo00040?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`8000000`3oool20000
02`0oooo0P0000160?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`4000000@3oool10?ooo`0000<0oooo0000000000000`000000
1@3oool000000?ooo`3oool000000080oooo00@000000?ooo`3oool00000103oool200000480oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo04@0oooo0P0000040?ooo`D0000000D0oooo0000003oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00001@3oool000000?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0400oooo0P00000/0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00020?ooo`03
0000003oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0:`3oool2000000<0oooo0`000003
0?ooo`800000;@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00030?ooo`8000000`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool2000002`0oooo0P00
001:0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`800000103oool2000000<0oooo000E
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`02
0?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0?03oool2000002`0oooo0P0000030?oo
o`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0503oool001D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0`0?ooo`<0
00000`3oool2000002`0oooo0P00001=0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0<03oool3000000<0oooo0P00000/0?ooo`800000
CP3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0300oooo0`0000040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0h0?ooo`800000<@3oool3
000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo01@0oooo000E0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0<03oool30000
00<0oooo0P00000/0?ooo`800000D@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool3000000@0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01@0
oooo000E0?ooo`030000003oool0oooo03D0oooo0P00000/0?ooo`8000000`3oool300000380oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo02/0oooo0P0000030?ooo`<00000<P3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`<00000<@3oool2000005D0oooo00<00000
0?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0080oooo0`00000b0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0503oool001D0oooo00<000000?ooo`3oool0<@3oool2000002`0oooo0P0000030?ooo`<0
0000<P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0:`3oool2000000<0oooo0`0000030?ooo`800000
;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`<000000`3o
ool2000002`0oooo0P00001I0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`<00000103oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
01D0oooo00<000000?ooo`3oool0;@3oool2000002`0oooo0P0000030?ooo`<00000103oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0503oool001D0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080
oooo0`0000030?ooo`800000;@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01@0
oooo000E0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`030?ooo`8000000`3oool2000002`0oooo0P00001M0?ooo`030000003oool0oooo01@0oooo
000E0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`020?ooo`8000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0:@3oool2000002`0oooo0P000003
0?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`800000;03oool200000600oooo00<000000?oo
o`3oool0503oool001D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0V0?ooo`800000
;03oool2000000<0oooo0`0000040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0U0?ooo`800000;03o
ool2000000<0oooo0`0000040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0P00000/0?ooo`800000I03oool0
0`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0280
oooo0P00000/0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0<03oool3000000<0oooo0P00000]0?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0`0?ooo`<000000`3oool2000002`0oooo0P00001X0?ooo`030000003oool0oooo01@0oooo000E
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<03oool3000000@0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01@0oooo000E0?oo
o`030000003oool0oooo01h0oooo0P00000a0?ooo`<00000103oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0`0?ooo`<000000`3oool2000002d0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0
:P3oool2000006`0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0`00000b0?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool06P3oool2
000002`0oooo0P0000030?ooo`<00000<P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo01@0oooo000E0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`020?ooo`<00000<P3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
01@0oooo000E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`020?ooo`<00000<@3oool200000700oooo00<000000?ooo`3oool0503oool001D0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo
0`00000b0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0503oool001D0oooo00<0
00000?ooo`3oool05P3oool2000002`0oooo0P0000030?ooo`<00000103oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0503oool001D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0`000003
0?ooo`800000;03oool2000007<0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0`0000040?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0D0?oo
o`005@3oool00`000000oooo0?ooo`0C0?ooo`800000;03oool2000000<0oooo0`0000040?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0D0?ooo`00
5@3oool00`000000oooo0?ooo`0B0?ooo`800000;03oool2000000<0oooo0`0000040?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0D0?ooo`005@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00`3o
ool2000000<0oooo0P00000/0?ooo`800000M`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool2
000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo01@0oooo000E0?ooo`030000003oool0oooo00l0oooo0P00000/0?ooo`8000000`3oool30000
00@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
01@0oooo000E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:`3oool2000000<0
oooo0`0000030?ooo`800000;@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01@0
oooo000E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`020?ooo`<000000`3oool2000002`0oooo0P00001k0?ooo`030000003oool0oooo01@0oooo
000E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`020?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool02`3oool2000002`0oooo0P000003
0?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo07/0oooo00<00000
0?ooo`3oool0503oool000030?ooo`0000000000008000000`3oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:`3oool2000000<0oooo0`0000030?oo
o`800000;@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo100000030?oo
o`800000103oool2000000<0oooo00000`3oool000000?ooo`040?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0P00000/0?ooo`800000O`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool2000000T0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`020?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo07d0oooo0P0000050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo0P00000a0?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool100000040oooo0@3oool000050?ooo`000000oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0`0?ooo`<000000`3oool2000002d0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`000P3oool2000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0300oooo
0`0000030?ooo`800000;03oool2000008<0oooo00<000000?ooo`3oool00`3oool2000000@0oooo
0P0000040?ooo`8000000`3oool001D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0`0?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool00`3oool200000340oooo0`000004
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0D
0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0:P3oool2000008H0oooo00<000000?oo
o`3oool0503oool001D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`<0
0000<P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000
003oool0oooo02h0oooo0P0000030?ooo`<00000<P3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo02d0oooo0P0000030?ooo`<00000<P3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool00P3oool300000340oooo0P00002:0?ooo`030000003oool0
oooo01@0oooo000E0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool30000
0380oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000
oooo0?ooo`0Z0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo02T0oooo
0P0000030?ooo`<000000`3oool2000002d0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo0P00
00030?ooo`800000;03oool2000008h0oooo00<000000?ooo`3oool0503oool001D0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?oo
o`3oool09P3oool2000000<0oooo0`0000040?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0U0?ooo`80
00000`3oool3000000<0oooo0P00000]0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool0503oool001D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`<00000
0`3oool2000002`0oooo0P00002B0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0
oooo0280oooo0P0000030?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0980oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool2000002`0oooo0P00002E0?ooo`030000003oool0oooo
01@0oooo000E0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool3000000<0
oooo0P00000/0?ooo`800000UP3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?oo
o`0N0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool00P3oool3000000<0oooo0P00000/0?ooo`800000V@3oool00`000000oooo0?ooo`0D
0?ooo`005@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo0`0000040?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0D0?oo
o`005@3oool00`000000oooo0?ooo`0P0?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0
7`3oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo01h0oooo0`0000030?ooo`800000;03o
ool2000009d0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool07@3oool3
000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo01@0oooo000E0?ooo`030000003oool0oooo01`0oooo0`0000040?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000
oooo0?ooo`0F0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`2N0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool00P3oool300000340oooo0P00002Q0?ooo`030000003oool0oooo01@0oooo
000E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool300000380oooo00<0
00000?ooo`3oool0X03oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0C
0?ooo`8000000`3oool300000380oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0D
0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000000`3oool300000380oooo00<000000?oo
o`3oool0XP3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo02/0oooo0P00002U0?ooo`03
0000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool2000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2T0?ooo`030000
003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo00l0oooo0P0000030?ooo`<00000103o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0503o
ool001D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`<000000`3oool2
000002`0oooo0P00002X0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0P00000/0?ooo`800000Z@3oool00`00
0000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
oooo0`0000040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0Z03oool00`000000
oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`0;0?ooo`8000000`3oool3000000@0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo01@0oooo
000E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0P00
000/0?ooo`800000[03oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0Z`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`080?oo
o`8000000`3oool3000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2/0?oo
o`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`<0
0000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool0503oool001D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`<00000
0`3oool2000002`0oooo0P00002`0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0
oooo00@0oooo0P0000030?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool00`3oool20000
00<0oooo0`0000030?ooo`800000;@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
01@0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool3000000<0
oooo0P00000/0?ooo`800000]03oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo
0?ooo`060?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool01@3oool3000000@0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01@0oooo000=
0?ooo`D000000`3oool00`000000oooo0?ooo`040?ooo`<000000`3oool2000002d0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`020?ooo`D000003@3oool000l0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool2000002`0oooo0P00002h0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3o
ool00`3oool2000000<0oooo0`0000040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0]P3oool2000000H0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0;P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`003`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0=0?ooo`003P3oool2000000D0oooo00<000000?ooo`3oool0l@3oool0
0`000000oooo0?ooo`030?ooo`8000003`3oool001D0oooo00<000000?ooo`3oool0l@3oool00`00
0000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`005@3ooooe000001H0oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo000I0?ooo`D00000;P3oool4000000<0oooo0P0000040?ooo`800000;03oool3
00000080oooo0P0000040?ooo`800000:`3oool3000000@0oooo0P0000040?ooo`800000;P3oool2
000000<0oooo1@0000020?ooo`8000005P3oool001/0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000;03o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0:03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000;03oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0C0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000Y0?oo
o`D0000000D0oooo0000003oool0oooo000000020?ooo`040000003oool0oooo000002X0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
02`0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool04`3oool001/0oooo00<000000?ooo`3oool0<03oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0W0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000Z
0?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002d0oooo
0P0000050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0C0?ooo`00
6`3oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000Z0?ooo`030000003oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000[0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01<0oooo000J
0?ooo`800000<@3oool2000000@0oooo0P0000040?ooo`800000;03oool2000000<0oooo0P000004
0?ooo`800000;03oool3000000<0oooo0P0000040?ooo`800000;P3oool2000000@0oooo0P000004
0?ooo`8000005P3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-46.7015, -46.7015, 1.73659, \
1.73659}}]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 824}},
ScreenStyleEnvironment->"Brackets",
WindowSize->{497, 712},
WindowMargins->{{129, Automatic}, {27, Automatic}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "i:60"->{
    Cell[1776, 53, 76, 1, 65, "Section",
      CellTags->{"i:60", "c:44"}]},
  "c:44"->{
    Cell[1776, 53, 76, 1, 65, "Section",
      CellTags->{"i:60", "c:44"}]},
  "b:8.1.0"->{
    Cell[4733, 127, 97, 1, 39, "Subsection",
      CellTags->{"b:8.1.0", "c:45"}],
    Cell[4855, 132, 63, 1, 25, "SubsubsectionIcon",
      CellTags->"b:8.1.0"],
    Cell[4921, 135, 309, 7, 25, "MathCaption",
      CellTags->"b:8.1.0"],
    Cell[5255, 146, 344, 7, 110, "Input",
      CellTags->"b:8.1.0"],
    Cell[5602, 155, 85, 3, 41, "Output",
      CellTags->"b:8.1.0"],
    Cell[5702, 161, 181, 6, 25, "MathCaption",
      CellTags->"b:8.1.0"],
    Cell[5886, 169, 905, 21, 150, "Input",
      CellTags->"b:8.1.0"],
    Cell[6816, 194, 259, 6, 50, "Input",
      CellTags->"b:8.1.0"],
    Cell[7078, 202, 1343, 25, 79, "Output",
      CellTags->"b:8.1.0"],
    Cell[8424, 229, 141357, 2680, 254, 51357, 1563, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"b:8.1.0"],
    Cell[149796, 2912, 295, 7, 25, "MathCaption",
      CellTags->"b:8.1.0"],
    Cell[150094, 2921, 694, 12, 150, "Input",
      CellTags->"b:8.1.0"],
    Cell[150825, 2938, 77, 1, 21, "SubsubsectionIcon",
      CellTags->"b:8.1.0"],
    Cell[150905, 2941, 179, 6, 25, "MathCaption",
      CellTags->"b:8.1.0"],
    Cell[151109, 2951, 644, 13, 110, "Input",
      CellTags->"b:8.1.0"],
    Cell[151756, 2966, 110, 3, 43, "Output",
      CellTags->"b:8.1.0"],
    Cell[151881, 2972, 123, 3, 25, "MathCaption",
      CellTags->"b:8.1.0"],
    Cell[152029, 2979, 511, 11, 90, "Input",
      CellTags->"b:8.1.0"],
    Cell[152543, 2992, 109, 3, 43, "Output",
      CellTags->"b:8.1.0"],
    Cell[152655, 2997, 111, 3, 43, "Output",
      CellTags->"b:8.1.0"],
    Cell[152781, 3003, 128, 3, 25, "MathCaption",
      CellTags->"b:8.1.0"],
    Cell[152934, 3010, 509, 11, 90, "Input",
      CellTags->"b:8.1.0"],
    Cell[153446, 3023, 106, 3, 33, "Output",
      CellTags->"b:8.1.0"],
    Cell[153555, 3028, 112, 3, 33, "Output",
      CellTags->"b:8.1.0"],
    Cell[153716, 3037, 74, 1, 21, "SubsubsectionIcon",
      CellTags->"b:8.1.0"],
    Cell[153793, 3040, 179, 6, 25, "MathCaption",
      CellTags->"b:8.1.0"],
    Cell[153975, 3048, 1435, 28, 290, "Input",
      CellTags->"b:8.1.0"],
    Cell[155413, 3078, 519, 11, 130, "Input",
      CellTags->"b:8.1.0"],
    Cell[155935, 3091, 742, 15, 190, "Input",
      CellTags->"b:8.1.0"],
    Cell[156702, 3110, 115, 3, 30, "Input",
      CellTags->"b:8.1.0"],
    Cell[156820, 3115, 109, 3, 33, "Output",
      CellTags->"b:8.1.0"],
    Cell[156944, 3121, 1212, 24, 327, "Input",
      CellTags->"b:8.1.0"],
    Cell[158181, 3149, 96, 3, 30, "Input",
      CellTags->"b:8.1.0"],
    Cell[158280, 3154, 1265, 31, 34, "Print",
      CellTags->"b:8.1.0"],
    Cell[159548, 3187, 1265, 31, 34, "Print",
      CellTags->"b:8.1.0"],
    Cell[160816, 3220, 1263, 31, 38, "Print",
      CellTags->"b:8.1.0"],
    Cell[162082, 3253, 1238, 30, 34, "Print",
      CellTags->"b:8.1.0"],
    Cell[163357, 3288, 208, 5, 47, "Input",
      CellTags->"b:8.1.0"],
    Cell[163568, 3295, 597, 15, 98, "Output",
      CellTags->"b:8.1.0"],
    Cell[164168, 3312, 109, 3, 41, "Output",
      CellTags->"b:8.1.0"],
    Cell[164326, 3321, 67, 1, 21, "SubsubsectionIcon",
      CellTags->"b:8.1.0"],
    Cell[164396, 3324, 123, 3, 25, "MathCaption",
      CellTags->"b:8.1.0"],
    Cell[164544, 3331, 556, 11, 70, "Input",
      CellTags->"b:8.1.0"],
    Cell[165103, 3344, 136, 3, 41, "Output",
      CellTags->"b:8.1.0"],
    Cell[165254, 3350, 128, 3, 25, "MathCaption",
      CellTags->"b:8.1.0"],
    Cell[165407, 3357, 691, 16, 110, "Input",
      CellTags->"b:8.1.0"],
    Cell[166101, 3375, 134, 3, 41, "Output",
      CellTags->"b:8.1.0"]},
  "c:45"->{
    Cell[4733, 127, 97, 1, 39, "Subsection",
      CellTags->{"b:8.1.0", "c:45"}]},
  "i:61"->{
    Cell[166296, 3385, 97, 1, 39, "Subsection",
      CellTags->{"i:61", "b:8.1.1", "c:46"}]},
  "b:8.1.1"->{
    Cell[166296, 3385, 97, 1, 39, "Subsection",
      CellTags->{"i:61", "b:8.1.1", "c:46"}],
    Cell[166418, 3390, 63, 1, 25, "SubsubsectionIcon",
      CellTags->"b:8.1.1"],
    Cell[166484, 3393, 262, 7, 25, "MathCaption",
      CellTags->"b:8.1.1"],
    Cell[166749, 3402, 554, 11, 210, "Input",
      CellTags->"b:8.1.1"],
    Cell[167328, 3417, 1302, 25, 350, "Input",
      CellTags->"b:8.1.1"],
    Cell[168633, 3444, 85, 3, 33, "Output",
      CellTags->"b:8.1.1"],
    Cell[168767, 3453, 77, 1, 21, "SubsubsectionIcon",
      CellTags->"b:8.1.1"],
    Cell[168847, 3456, 180, 6, 25, "MathCaption",
      CellTags->"b:8.1.1"],
    Cell[169052, 3466, 1379, 24, 328, "Input",
      CellTags->"b:8.1.1"],
    Cell[170434, 3492, 109, 3, 33, "Output",
      CellTags->"b:8.1.1"],
    Cell[170558, 3498, 123, 3, 25, "MathCaption",
      CellTags->"b:8.1.1"],
    Cell[170706, 3505, 490, 11, 70, "Input",
      CellTags->"b:8.1.1"],
    Cell[171199, 3518, 389, 7, 40, "Message",
      CellTags->"b:8.1.1"],
    Cell[171591, 3527, 139, 3, 33, "Output",
      CellTags->"b:8.1.1"],
    Cell[171745, 3533, 128, 3, 25, "MathCaption",
      CellTags->"b:8.1.1"],
    Cell[171898, 3540, 488, 11, 70, "Input",
      CellTags->"b:8.1.1"],
    Cell[172389, 3553, 135, 3, 33, "Output",
      CellTags->"b:8.1.1"],
    Cell[172573, 3562, 74, 1, 21, "SubsubsectionIcon",
      CellTags->"b:8.1.1"],
    Cell[172650, 3565, 180, 6, 25, "MathCaption",
      CellTags->"b:8.1.1"],
    Cell[172833, 3573, 2214, 39, 611, "Input",
      CellTags->"b:8.1.1"],
    Cell[175050, 3614, 927, 19, 250, "Input",
      CellTags->"b:8.1.1"],
    Cell[175980, 3635, 1604, 32, 450, "Input",
      CellTags->"b:8.1.1"],
    Cell[177609, 3671, 115, 3, 30, "Input",
      CellTags->"b:8.1.1"],
    Cell[177727, 3676, 109, 3, 33, "Output",
      CellTags->"b:8.1.1"],
    Cell[177851, 3682, 2250, 44, 607, "Input",
      CellTags->"b:8.1.1"],
    Cell[180126, 3730, 96, 3, 30, "Input",
      CellTags->"b:8.1.1"],
    Cell[180225, 3735, 1261, 31, 34, "Print",
      CellTags->"b:8.1.1"],
    Cell[181489, 3768, 1261, 31, 34, "Print",
      CellTags->"b:8.1.1"],
    Cell[182753, 3801, 1261, 31, 34, "Print",
      CellTags->"b:8.1.1"],
    Cell[184017, 3834, 1234, 30, 34, "Print",
      CellTags->"b:8.1.1"],
    Cell[185288, 3869, 207, 5, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[185498, 3876, 1089, 24, 140, "Output",
      CellTags->"b:8.1.1"],
    Cell[186590, 3902, 109, 3, 41, "Output",
      CellTags->"b:8.1.1"],
    Cell[186748, 3911, 67, 1, 21, "SubsubsectionIcon",
      CellTags->"b:8.1.1"],
    Cell[186818, 3914, 123, 3, 25, "MathCaption",
      CellTags->"b:8.1.1"],
    Cell[186966, 3921, 882, 17, 190, "Input",
      CellTags->"b:8.1.1"],
    Cell[187851, 3940, 390, 7, 34, "Message",
      CellTags->"b:8.1.1"],
    Cell[188244, 3949, 136, 3, 41, "Output",
      CellTags->"b:8.1.1"],
    Cell[188395, 3955, 128, 3, 25, "MathCaption",
      CellTags->"b:8.1.1"],
    Cell[188548, 3962, 1107, 23, 190, "Input",
      CellTags->"b:8.1.1"],
    Cell[189658, 3987, 134, 3, 41, "Output",
      CellTags->"b:8.1.1"],
    Cell[189807, 3993, 189, 6, 25, "MathCaption",
      CellTags->"b:8.1.1"]},
  "c:46"->{
    Cell[166296, 3385, 97, 1, 39, "Subsection",
      CellTags->{"i:61", "b:8.1.1", "c:46"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"i:60", 388064, 16325},
  {"c:44", 388153, 16328},
  {"b:8.1.0", 388245, 16331},
  {"c:45", 391825, 16427},
  {"i:61", 391921, 16430},
  {"b:8.1.1", 392031, 16433},
  {"c:46", 395230, 16518}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 76, 1, 65, "Section",
  CellTags->{"i:60", "c:44"}],
Cell[1855, 56, 782, 15, 147, "Text"],
Cell[2640, 73, 1583, 38, 385, "Text"],
Cell[4226, 113, 482, 10, 175, "Text"],

Cell[CellGroupData[{
Cell[4733, 127, 97, 1, 39, "Subsection",
  CellTags->{"b:8.1.0", "c:45"}],

Cell[CellGroupData[{
Cell[4855, 132, 63, 1, 25, "SubsubsectionIcon",
  CellTags->"b:8.1.0"],
Cell[4921, 135, 309, 7, 25, "MathCaption",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{
Cell[5255, 146, 344, 7, 110, "Input",
  CellTags->"b:8.1.0"],
Cell[5602, 155, 85, 3, 41, "Output",
  CellTags->"b:8.1.0"]
}, Closed]],
Cell[5702, 161, 181, 6, 25, "MathCaption",
  CellTags->"b:8.1.0"],
Cell[5886, 169, 905, 21, 150, "Input",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{
Cell[6816, 194, 259, 6, 50, "Input",
  CellTags->"b:8.1.0"],
Cell[7078, 202, 1343, 25, 79, "Output",
  CellTags->"b:8.1.0"],
Cell[8424, 229, 141357, 2680, 254, 51357, 1563, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"b:8.1.0"]
}, Closed]],
Cell[149796, 2912, 295, 7, 25, "MathCaption",
  CellTags->"b:8.1.0"],
Cell[150094, 2921, 694, 12, 150, "Input",
  CellTags->"b:8.1.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[150825, 2938, 77, 1, 21, "SubsubsectionIcon",
  CellTags->"b:8.1.0"],
Cell[150905, 2941, 179, 6, 25, "MathCaption",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{
Cell[151109, 2951, 644, 13, 110, "Input",
  CellTags->"b:8.1.0"],
Cell[151756, 2966, 110, 3, 43, "Output",
  CellTags->"b:8.1.0"]
}, Closed]],
Cell[151881, 2972, 123, 3, 25, "MathCaption",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{
Cell[152029, 2979, 511, 11, 90, "Input",
  CellTags->"b:8.1.0"],
Cell[152543, 2992, 109, 3, 43, "Output",
  CellTags->"b:8.1.0"],
Cell[152655, 2997, 111, 3, 43, "Output",
  CellTags->"b:8.1.0"]
}, Closed]],
Cell[152781, 3003, 128, 3, 25, "MathCaption",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{
Cell[152934, 3010, 509, 11, 90, "Input",
  CellTags->"b:8.1.0"],
Cell[153446, 3023, 106, 3, 33, "Output",
  CellTags->"b:8.1.0"],
Cell[153555, 3028, 112, 3, 33, "Output",
  CellTags->"b:8.1.0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[153716, 3037, 74, 1, 21, "SubsubsectionIcon",
  CellTags->"b:8.1.0"],
Cell[153793, 3040, 179, 6, 25, "MathCaption",
  CellTags->"b:8.1.0"],
Cell[153975, 3048, 1435, 28, 290, "Input",
  CellTags->"b:8.1.0"],
Cell[155413, 3078, 519, 11, 130, "Input",
  CellTags->"b:8.1.0"],
Cell[155935, 3091, 742, 15, 190, "Input",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{
Cell[156702, 3110, 115, 3, 30, "Input",
  CellTags->"b:8.1.0"],
Cell[156820, 3115, 109, 3, 33, "Output",
  CellTags->"b:8.1.0"]
}, Closed]],
Cell[156944, 3121, 1212, 24, 327, "Input",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{
Cell[158181, 3149, 96, 3, 30, "Input",
  CellTags->"b:8.1.0"],
Cell[158280, 3154, 1265, 31, 34, "Print",
  CellTags->"b:8.1.0"],
Cell[159548, 3187, 1265, 31, 34, "Print",
  CellTags->"b:8.1.0"],
Cell[160816, 3220, 1263, 31, 38, "Print",
  CellTags->"b:8.1.0"],
Cell[162082, 3253, 1238, 30, 34, "Print",
  CellTags->"b:8.1.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[163357, 3288, 208, 5, 47, "Input",
  CellTags->"b:8.1.0"],
Cell[163568, 3295, 597, 15, 98, "Output",
  CellTags->"b:8.1.0"],
Cell[164168, 3312, 109, 3, 41, "Output",
  CellTags->"b:8.1.0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[164326, 3321, 67, 1, 21, "SubsubsectionIcon",
  CellTags->"b:8.1.0"],
Cell[164396, 3324, 123, 3, 25, "MathCaption",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{
Cell[164544, 3331, 556, 11, 70, "Input",
  CellTags->"b:8.1.0"],
Cell[165103, 3344, 136, 3, 41, "Output",
  CellTags->"b:8.1.0"]
}, Closed]],
Cell[165254, 3350, 128, 3, 25, "MathCaption",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{
Cell[165407, 3357, 691, 16, 110, "Input",
  CellTags->"b:8.1.0"],
Cell[166101, 3375, 134, 3, 41, "Output",
  CellTags->"b:8.1.0"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[166296, 3385, 97, 1, 39, "Subsection",
  CellTags->{"i:61", "b:8.1.1", "c:46"}],

Cell[CellGroupData[{
Cell[166418, 3390, 63, 1, 25, "SubsubsectionIcon",
  CellTags->"b:8.1.1"],
Cell[166484, 3393, 262, 7, 25, "MathCaption",
  CellTags->"b:8.1.1"],
Cell[166749, 3402, 554, 11, 210, "Input",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{
Cell[167328, 3417, 1302, 25, 350, "Input",
  CellTags->"b:8.1.1"],
Cell[168633, 3444, 85, 3, 33, "Output",
  CellTags->"b:8.1.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[168767, 3453, 77, 1, 21, "SubsubsectionIcon",
  CellTags->"b:8.1.1"],
Cell[168847, 3456, 180, 6, 25, "MathCaption",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{
Cell[169052, 3466, 1379, 24, 328, "Input",
  CellTags->"b:8.1.1"],
Cell[170434, 3492, 109, 3, 33, "Output",
  CellTags->"b:8.1.1"]
}, Closed]],
Cell[170558, 3498, 123, 3, 25, "MathCaption",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{
Cell[170706, 3505, 490, 11, 70, "Input",
  CellTags->"b:8.1.1"],
Cell[171199, 3518, 389, 7, 40, "Message",
  CellTags->"b:8.1.1"],
Cell[171591, 3527, 139, 3, 33, "Output",
  CellTags->"b:8.1.1"]
}, Closed]],
Cell[171745, 3533, 128, 3, 25, "MathCaption",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{
Cell[171898, 3540, 488, 11, 70, "Input",
  CellTags->"b:8.1.1"],
Cell[172389, 3553, 135, 3, 33, "Output",
  CellTags->"b:8.1.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[172573, 3562, 74, 1, 21, "SubsubsectionIcon",
  CellTags->"b:8.1.1"],
Cell[172650, 3565, 180, 6, 25, "MathCaption",
  CellTags->"b:8.1.1"],
Cell[172833, 3573, 2214, 39, 611, "Input",
  CellTags->"b:8.1.1"],
Cell[175050, 3614, 927, 19, 250, "Input",
  CellTags->"b:8.1.1"],
Cell[175980, 3635, 1604, 32, 450, "Input",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{
Cell[177609, 3671, 115, 3, 30, "Input",
  CellTags->"b:8.1.1"],
Cell[177727, 3676, 109, 3, 33, "Output",
  CellTags->"b:8.1.1"]
}, Closed]],
Cell[177851, 3682, 2250, 44, 607, "Input",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{
Cell[180126, 3730, 96, 3, 30, "Input",
  CellTags->"b:8.1.1"],
Cell[180225, 3735, 1261, 31, 34, "Print",
  CellTags->"b:8.1.1"],
Cell[181489, 3768, 1261, 31, 34, "Print",
  CellTags->"b:8.1.1"],
Cell[182753, 3801, 1261, 31, 34, "Print",
  CellTags->"b:8.1.1"],
Cell[184017, 3834, 1234, 30, 34, "Print",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[185288, 3869, 207, 5, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[185498, 3876, 1089, 24, 140, "Output",
  CellTags->"b:8.1.1"],
Cell[186590, 3902, 109, 3, 41, "Output",
  CellTags->"b:8.1.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[186748, 3911, 67, 1, 21, "SubsubsectionIcon",
  CellTags->"b:8.1.1"],
Cell[186818, 3914, 123, 3, 25, "MathCaption",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{
Cell[186966, 3921, 882, 17, 190, "Input",
  CellTags->"b:8.1.1"],
Cell[187851, 3940, 390, 7, 34, "Message",
  CellTags->"b:8.1.1"],
Cell[188244, 3949, 136, 3, 41, "Output",
  CellTags->"b:8.1.1"]
}, Closed]],
Cell[188395, 3955, 128, 3, 25, "MathCaption",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{
Cell[188548, 3962, 1107, 23, 190, "Input",
  CellTags->"b:8.1.1"],
Cell[189658, 3987, 134, 3, 41, "Output",
  CellTags->"b:8.1.1"]
}, Closed]],
Cell[189807, 3993, 189, 6, 25, "MathCaption",
  CellTags->"b:8.1.1"],

Cell[CellGroupData[{
Cell[190021, 4003, 185, 5, 30, "Input"],
Cell[190209, 4010, 197138, 12292, 294, 153454, 11747, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

